(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    425927,      16009]*)
(*NotebookOutlinePosition[    427089,      16046]*)
(*  CellTagsIndexPosition[    427045,      16042]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[StyleBox["Saving Memory in Radia",
  FontSize->24]], "Title",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
March 1999,
Pascal Elleaume, ESRF

\
\>", "Text"],

Cell["Introduction", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox[
"As  for any 3D magnetostatic code, the two most important  limitations  in \
the field computation are due to the cpu time and the memory requirement. In \
Radia, the memory required is proportional to the square number of elements \
of iron (or any soft material). One needs roughly 50 M of memory to solve a \
structure made of 1000 elements. The solving time depends on platforms and \
geometry. With modern PCs, we have found that the memory issue in Radia is \
usually  a more severe limitation than the cpu time issue. In this notebook, \
we review a number of tricks to reduce the memory requirement without \
sacrificing the precision of the field computation. Anyone intending to do \
sophisticated computations with Radia should read this notebook  carefully. ",
  
  Evaluatable->False,
  AspectRatioFixed->True]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Various hints for Memory Saving", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "-  As one creates objects (iron volume, coil, material,...), Radia \
allocates memory. If one wants to iteratively solve a structure with \
different dimensions or position,...one needs to continuously re-create an \
object with the neccessary modification. However Radia does not  \
automatically delete unsused objects . Consequently,  after sometime the user \
may run out of memory simply beceause the memory is full of useless objects. \
The recommended and simplest method to deal with this situation is to call \
the function \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  "radUtiDelAll",
  StyleBox["\"  and then to fully regenerate the structure.  \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  "radUtiDelAll\"",
  StyleBox[
  " remove all objects in the memory of Radia and makes the corresponding \
memory available. One may also use ",
    Evaluatable->False,
    AspectRatioFixed->True],
  "radUtiDel[obj] to delete a particular object,  \n- An other VERY IMPORTANT \
way to save memory and to accelerate the computation consists in making use \
of the symmetries present in the structure. This is proabably the most \
important point. It is explained in the next section by mean of a \
computational example. \n- The accuracy of the field computation largely \
depends on the subdivision through the resulting number of elements. Before \
solving the structure, it  is  good practice to call radObjDegFre which \
returns the number of degrees of freedom which is equal to 3 times the number \
of elements.  As stated above,  the memory requirement is roughly \
proportionnal to the square number of elements, one simple element needing 36 \
bytes. Care should be taken when using \"radObjDivMag\" in order not to  \
subdivide an object into too many elements. A good practice is to start with \
a low subdivision to limit the number of elements and debug the modelling  \
with a short reponse time of one or a few seconds. When this is done, one \
would gradually increase separately each  subdivision numbers and watch the \
result of interest (field, field integral or force) until it is stable. An \
attempt to  increase the subdivision further will ultimately result in a long \
response time or a large  memory requirement. \n- It is very important for \
the user to learn which level of subdivision is important. For example,  a \
hybrid wiggler for which one requires an accurate prediction of the peak \
field in the middle of the gap. One  finds that the pole needs to be heavily \
subdivided in the vertical plane while a low subdivision in the horizontal \
and longitudinal planes is usually sufficient. This can be found by  \
experimenting in Example#3 with several subdivision parameters . Nothing can \
replace a real experience, and it is importnat to spend some time doing this \
exercise. Nevertheless, there are methods of guessing which subdivision is \
critical and which is not. They are all based on some sort of estimation of \
the final magnetization in the iron.  If the magnetization is uniform , a \
loose subdivision is probably acceptable. If the magnetization presents an \
important gradient, a strong subdivision should be applied in the direction \
of the gradient. This can be illustrated  with the pole of a hybrid wiggler. \
The magnetization in the pole varies from a maximum value to almost zero at \
the other end along the vertical  axis. As a result there is an important \
vertical gradient which imposse  a sufficient vertical segmentation if one \
wants to reach a good precision . For this reason, it is almost never \
necessary to finely subdivide a permanent magnet block since the permeability \
is close to one and therefore its magnetization  slowly varies from one of \
the block  to the next. For example the  change in peak field introduced by \
segmenting the NdFeB permanent magnets in either a pure permanent magnet or a \
hybrid undulator is  of the order of one to a few percent.  Another critical \
situation appears in a magnetic circuit where the magnetization is rotated in \
a corner. In such a case one should apply a circular type of segmentation \
rather than a rectangular one . The goal is to maintain the cutting planes as \
 prallel or perpendicular as possible to the magnetization. The circular \
segmentation  is applied in examples #5 (dipole magnet) and #6 (quadrupole \
magnet) which are included in the distribution. Whichever segmentation is \
applied (rectangular or circular), one ultimately reaches the same precision \
but the number of elements required may vary significantly. In other words, \
if the segmentation is not applied properly, one may not reach a sufficient \
precision out of the memory available on the computer. \n- Care should be \
taken if too much memory is required, the operating system may start to swap \
part of the data on the disk. This will result in a serious degradation of \
the response time. The memory handled by the MacOS  is not as performant as \
that of Windows . This has several consequences. On a Macintosh, the total \
memory allocated to Radia cannot be changed dynamically, it must fixed before \
launching Radia in the finder as with any other application (Select Radia.exe \
do : Menu File -> Get Info... and enter the memory needed).On  a macintosh,  \
depending on the context , if radia.exe runs out of memory, it may  either  \
report it to mathematica, or simply quit without saying anything (in which \
case, it is also best to quit the mathematica kernel and restart the whole \
computation). It may also block the operating system and require a reboot. To \
avoid losing important data, frequently save your notebooks. Note that, with \
the exception of possible memory problem discussed above , Radia has been \
found to be quite  stable and reliable."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Use the Symmetries  as much as possible.", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "It is very common to deal with some magnetic structures where the field is \
some part of the yoke is identical to the field  in some  other places of the \
yoke beceause of a symmetry  present in the structure under study. Radia is \
carefully designed to make use of these symmetries and only allocates  memory \
for the  independent elements. This is done by creating a volume V which \
contains the minimum number of elements and then to generate the others by \
applying a set of  transformations (called symmetries) to V. The  simplest \
and most useful way to input symmetries in Radia is to call the functions \"",
    
    Evaluatable->False,
    AspectRatioFixed->True],
  "RadTrfZerPerp",
  StyleBox["\" and \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  "RadTrfZerPara",
  StyleBox[
  "\" which define a transformation with respect to a plane so that the \
magnetic field must  be either parallel or orthogonal to the plane. An \
important parameter of the problem under study is the order P of the \
symmetry. A simple call to ",
    Evaluatable->False,
    AspectRatioFixed->True],
  "RadTrfZerPerp",
  StyleBox[" or ",
    Evaluatable->False,
    AspectRatioFixed->True],
  "RadTrfZerPara",
  StyleBox[
  " gives P = 2. Two calls of one or the other gives P = 4 and so on, n call \
to either ",
    Evaluatable->False,
    AspectRatioFixed->True],
  "RadTrfZerPerp",
  StyleBox[" or ",
    Evaluatable->False,
    AspectRatioFixed->True],
  "RadTrfZerPara",
  StyleBox[
  " gives P = 2^n . The important thing is that for a given level of \
subdivision of the iron or permanent magnet volumes, the memory requirement \
grows proportionaly to P^2 and the cpu time proportionaly to P. Two identical \
structures can be created and solved with or without the symmetries, but the \
solving time and memory requirement may be dramatically different.   With a \
permanent magnet undulator or wiggler which typically presents a P = 8 \
symmetry , one can therefore save a factor 64 of memory and a factor 8 of \
solving time by making use of the symmetries. The gain is even more \
significant with an  ideal quadrupole (sextupole) which has  P = 16 ( 24). \n\
\nIn the following computation, we create two identically subdivided \
geometries, one of which makes use a 4th order  symmetry. The field plot from \
both structures are identical but the cpu time and memory requirements differ \
by a factor 4 and 16. ",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["\<\
(* Load Radia *)
<<Radia`;\
\>", "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"\<\"Radia Version: \"\>", "\[InvisibleSpace]", 
        StyleBox["4.0940000000000003`",
          StyleBoxAutoDelete->True,
          PrintPrecision->4], "\[InvisibleSpace]", "\<\" is loaded\"\>"}],
      SequenceForm[ "Radia Version: ", 4.0940000000000003, " is loaded"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("Radia is copyright ESRF, Grenoble France \nPortions copyright 1997 \
Wolfram Research, Inc."\)], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
  \(radUtiDelAll[]; \ \  (*\ to\ recover\ all\ memory\ *) \n\nw = {1, 1, 2}; 
    p = w/2 + {0, 0, 1}; np = {5, 5, 4}; c = {0, 0, 0}; jp = 3; \n
    \n (*\ create\ the\ coil\ \ *) \n
    coil = radObjRaceTrk[{0, 0, 2}, {1, 2}, {1, 1}, 1, 12, jp]; \n
    radObjDrwAtr[coil, {1, 0, 0}]; \n\n (*\ create\ the\ iron\ yoke\ *) \n\n
    m1 = radObjRecMag[p, w]; \niron = RadMatSteel37[]; radMatApl[m1, iron]; \n
    radObjDrwAtr[m1, {0, 0.5, 1}]; \nradObjDivMag[m1, np]; \n
    \n (*\ apply\ the\ symmetries\ *) \ng = radObjCnt[{m1, coil}]; \n
    RadTrfZerPerp[g, c, {1, 0, 0}]; \nRadTrfZerPerp[g, c, {0, 1, 0}]; \n
    \n (*\ solve\ *) \nt0 = AbsoluteTime[]; \ns = RadSolve[g, 0.00001, 100]; 
    \nt1 = AbsoluteTime[]; \n\n
    Print["\<Solved  in : \>", Round[t1 - t0], "\<  seconds\>"]; \n
    Print[\ "\<Number of elements : \>", radObjDegFre[g]/3]\), 
    RowBox[{\(Print[\ "\<Solved in \>", s[\([4]\)], "\< iterations\>"]\), 
      "\n", "\n", 
      \( (*\ display\ the\ greometry\ in\ Mathematica\ Graphics\ *) \)}], 
    RowBox[{
    \(RadPlot3DOptions[]\), ";", "\n", \(Show[Graphics3D[radObjDrw[g]]]\), 
      ";", "\n", "\n", \( (*\ Field\ Plot\ *) \), "\n", "\t\t", 
      RowBox[{
        StyleBox["RadPlotOptions",
          FontColor->RGBColor[1, 0, 0]], "[", "]"}], ";", "\n", 
      \(Plot[radFld[g, "\<Bz\>", {x, 0, 0.6}], {x, \(-3\), 3}\n\t\t\t, \ 
        PlotRange -> All\n\ , AxesOrigin -> {0, 0}\n, 
        FrameLabel -> {"\<X [mm]\>", "\<Bz [T]\>", "\<Y = 0  Z = 0.7\>", 
            "\<\>"}]\), ";"}]}], "Input"],

Cell[BoxData[
    InterpretationBox[
      \("Solved  in : "\[InvisibleSpace]2\[InvisibleSpace]"  seconds"\),
      SequenceForm[ "Solved  in : ", 2, "  seconds"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Number of elements : "\[InvisibleSpace]100\),
      SequenceForm[ "Number of elements : ", 100],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("Solved in "\[InvisibleSpace]52\[InvisibleSpace]" iterations"\),
      SequenceForm[ "Solved in ", 52, " iterations"],
      Editable->False]], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.64829 .74765 -8.95579 0 ]
[.64829 .74765 9.29421 14 ]
[.78087 .68946 -4.8231 0 ]
[.78087 .68946 5.1769 14 ]
[.93325 .62258 -4.72481 0 ]
[.93325 .62258 5.27519 14 ]
[.78308 .75192 -7.5361 0 ]
[.78308 .75192 8.0889 14 ]
[.43714 .1793 -9.04779 -14 ]
[.43714 .1793 9.20221 0 ]
[.68015 .24102 -5.12026 -14 ]
[.68015 .24102 4.87974 0 ]
[.90238 .29748 -5.26659 -14 ]
[.90238 .29748 4.73341 0 ]
[.67865 .17854 -8.0004 -14 ]
[.67865 .17854 7.6246 0 ]
[.98124 .33568 0 -5.23351 ]
[.98124 .33568 10 8.76649 ]
[.98502 .39607 0 -5.31844 ]
[.98502 .39607 19 8.68156 ]
[.98886 .45744 0 -5.40487 ]
[.98886 .45744 10 8.59513 ]
[.99276 .5198 0 -5.49284 ]
[.99276 .5198 19 8.50716 ]
[.99672 .58318 0 -5.58239 ]
[.99672 .58318 10 8.41761 ]
[1.0498 .47133 0 -5.40487 ]
[1.0498 .47133 14.3125 8.59513 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.003 w
[ ] 0 setdash
.61014 .75181 m
.98487 .58711 L
s
.25 Mabswid
.64806 .73515 m
.64794 .7289 L
s
gsave
.64829 .74765 -69.9558 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.78043 .67697 m
.78021 .67072 L
s
gsave
.78087 .68946 -65.8231 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.93256 .6101 m
.93222 .60386 L
s
gsave
.93325 .62258 -65.7248 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.67951 .72132 m
.67943 .71758 L
s
.71202 .70704 m
.71192 .70329 L
s
.74564 .69226 m
.74553 .68851 L
s
.81645 .66114 m
.8163 .65739 L
s
.85376 .64474 m
.85359 .64099 L
s
.89244 .62774 m
.89225 .62399 L
s
.61761 .74853 m
.61755 .74478 L
s
.97421 .5918 m
.97398 .58805 L
s
gsave
.78308 .75192 -68.5361 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(X) show
74.625000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.003 w
.35623 .17131 m
.96875 .32662 L
s
.25 Mabswid
.43704 .1918 m
.43698 .19805 L
s
gsave
.43714 .1793 -70.0478 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.68045 .25352 m
.6806 .25977 L
s
gsave
.68015 .24102 -66.1203 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.90304 .30996 m
.90338 .3162 L
s
gsave
.90238 .29748 -66.2666 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.5 .20776 m
.5 .21151 L
s
.56153 .22336 m
.56156 .22711 L
s
.62166 .23861 m
.62172 .24236 L
s
.73794 .2681 m
.73806 .27184 L
s
.79418 .28235 m
.79433 .2861 L
s
.8492 .29631 m
.84937 .30005 L
s
.37258 .17546 m
.37252 .1792 L
s
.95575 .32332 m
.95597 .32706 L
s
gsave
.67865 .17854 -69.0004 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Y) show
74.625000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.003 w
.96875 .32662 m
.98487 .58711 L
s
.25 Mabswid
.96912 .33262 m
.96306 .33109 L
s
gsave
.98124 .33568 -61 -9.23351 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.97287 .39315 m
.96679 .39169 L
s
gsave
.98502 .39607 -61 -9.31844 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.97667 .45466 m
.97058 .45327 L
s
gsave
.98886 .45744 -61 -9.40487 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.98054 .51717 m
.97443 .51585 L
s
gsave
.99276 .5198 -61 -9.49284 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2.5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.98447 .5807 m
.97834 .57946 L
s
gsave
.99672 .58318 -61 -9.58239 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.96986 .34465 m
.96623 .34374 L
s
.97061 .35672 m
.96697 .35582 L
s
.97136 .36882 m
.96772 .36793 L
s
.97211 .38097 m
.96847 .38009 L
s
.97362 .40538 m
.96997 .40451 L
s
.97438 .41764 m
.97073 .41678 L
s
.97514 .42994 m
.97149 .42909 L
s
.97591 .44228 m
.97225 .44144 L
s
.97744 .46708 m
.97378 .46626 L
s
.97821 .47954 m
.97455 .47873 L
s
.97898 .49205 m
.97532 .49124 L
s
.97976 .50459 m
.9761 .50379 L
s
.98132 .52979 m
.97765 .52901 L
s
.9821 .54246 m
.97843 .54169 L
s
.98289 .55516 m
.97922 .5544 L
s
.98368 .56791 m
.98001 .56716 L
s
gsave
1.0498 .47133 -61 -9.40487 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Z) show
73.312500 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.001 w
[ .01 .01 ] 0 setdash
.06722 .42225 m
.05351 .66515 L
s
.05351 .66515 m
.61014 .75181 L
s
.61014 .75181 m
.60708 .52904 L
s
.60708 .52904 m
.06722 .42225 L
s
.35623 .17131 m
.96875 .32662 L
s
.96875 .32662 m
.98487 .58711 L
s
.98487 .58711 m
.35065 .45949 L
s
.35065 .45949 m
.35623 .17131 L
s
.06722 .42225 m
.05351 .66515 L
s
.05351 .66515 m
.35065 .45949 L
s
.35065 .45949 m
.35623 .17131 L
s
.35623 .17131 m
.06722 .42225 L
s
.60708 .52904 m
.96875 .32662 L
s
.96875 .32662 m
.98487 .58711 L
s
.98487 .58711 m
.61014 .75181 L
s
.61014 .75181 m
.60708 .52904 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.52256 .66246 m .55206 .55257 L .52225 .55327 L .794 0 0 r
F
.52258 .51399 m .52225 .55327 L .55206 .55257 L .71 0 0 r
F
.49234 .66191 m .52225 .55327 L .49244 .55266 L .814 0 0 r
F
.49234 .66191 m .52256 .66246 L .52225 .55327 L F
.50711 .51366 m .52225 .55327 L .52258 .51399 L .71 0 0 r
F
.50711 .51366 m .49244 .55266 L .52225 .55327 L F
.52225 .55327 m .49234 .66191 L .52256 .66246 L .814 0 0 r
F
0 g
[ ] 0 setdash
.52225 .55327 m
.52225 .55327 L
s
.52225 .55327 m
.52225 .55327 L
s
.52225 .55327 m .49244 .55266 L .49234 .66191 L .814 0 0 r
F
.52258 .51399 m .49244 .55266 L .52225 .55327 L .71 0 0 r
F
.55206 .55257 m .52225 .55327 L .52256 .66246 L .794 0 0 r
F
.53805 .51362 m .52225 .55327 L .55206 .55257 L .71 0 0 r
F
.53805 .51362 m .52258 .51399 L .52225 .55327 L F
.52225 .55327 m .49234 .66191 L .52256 .66246 L .814 0 0 r
F
0 g
.52225 .55327 m
.52225 .55327 L
s
.52225 .55327 m
.52225 .55327 L
s
.52225 .55327 m .49244 .55266 L .49234 .66191 L .814 0 0 r
F
.52258 .51399 m .49244 .55266 L .52225 .55327 L .71 0 0 r
F
.55206 .55257 m .52225 .55327 L .52256 .66246 L .794 0 0 r
F
.53805 .51362 m .52225 .55327 L .55206 .55257 L .71 0 0 r
F
.53805 .51362 m .52258 .51399 L .52225 .55327 L F
.52256 .66246 m .55206 .55257 L .52225 .55327 L .794 0 0 r
F
0 g
.52225 .55327 m
.52225 .55327 L
s
.52258 .51399 m .52225 .55327 L .55206 .55257 L .71 0 0 r
F
.49234 .66191 m .52225 .55327 L .49244 .55266 L .814 0 0 r
F
.49234 .66191 m .52256 .66246 L .52225 .55327 L F
.50711 .51366 m .52225 .55327 L .52258 .51399 L .71 0 0 r
F
.50711 .51366 m .49244 .55266 L .52225 .55327 L F
.46254 .6602 m .49244 .55266 L .46305 .55077 L .835 0 0 r
F
.46254 .6602 m .49234 .66191 L .49244 .55266 L F
.49188 .51264 m .49244 .55266 L .50711 .51366 L .71 0 0 r
F
.49188 .51264 m .46305 .55077 L .49244 .55266 L F
.49244 .55266 m .46254 .6602 L .49234 .66191 L .835 0 0 r
F
.49244 .55266 m .46305 .55077 L .46254 .6602 L F
.50711 .51366 m .46305 .55077 L .49244 .55266 L .71 0 0 r
F
.52258 .51399 m .50711 .51366 L .49244 .55266 L F
0 g
.49244 .55266 m
.49244 .55266 L
s
.49244 .55266 m .46254 .6602 L .49234 .66191 L .835 0 0 r
F
.49244 .55266 m .46305 .55077 L .46254 .6602 L F
.50711 .51366 m .46305 .55077 L .49244 .55266 L .71 0 0 r
F
.52258 .51399 m .50711 .51366 L .49244 .55266 L F
.46254 .6602 m .49244 .55266 L .46305 .55077 L .835 0 0 r
F
.46254 .6602 m .49234 .66191 L .49244 .55266 L F
.49188 .51264 m .49244 .55266 L .50711 .51366 L .71 0 0 r
F
.49188 .51264 m .46305 .55077 L .49244 .55266 L F
0 g
.49244 .55266 m
.52225 .55327 L
s
.55279 .66183 m .58149 .55059 L .55206 .55257 L .773 0 0 r
F
.53805 .51362 m .55206 .55257 L .58149 .55059 L .71 0 0 r
F
.52256 .66246 m .55279 .66183 L .55206 .55257 L .794 0 0 r
F
.52258 .51399 m .55206 .55257 L .53805 .51362 L .71 0 0 r
F
.55206 .55257 m .52256 .66246 L .55279 .66183 L .794 0 0 r
F
.58149 .55059 m .55206 .55257 L .55279 .66183 L .773 0 0 r
F
.5533 .51255 m .55206 .55257 L .58149 .55059 L .71 0 0 r
F
.5533 .51255 m .53805 .51362 L .55206 .55257 L F
.55206 .55257 m .52256 .66246 L .55279 .66183 L .794 0 0 r
F
.58149 .55059 m .55206 .55257 L .55279 .66183 L .773 0 0 r
F
.5533 .51255 m .55206 .55257 L .58149 .55059 L .71 0 0 r
F
.5533 .51255 m .53805 .51362 L .55206 .55257 L F
0 g
.55206 .55257 m
.55206 .55257 L
s
.55279 .66183 m .58149 .55059 L .55206 .55257 L .773 0 0 r
F
.53805 .51362 m .55206 .55257 L .58149 .55059 L .71 0 0 r
F
.52256 .66246 m .55279 .66183 L .55206 .55257 L .794 0 0 r
F
.52258 .51399 m .55206 .55257 L .53805 .51362 L .71 0 0 r
F
0 g
.52225 .55327 m
.55206 .55257 L
s
.43355 .65733 m .46305 .55077 L .43447 .54761 L .855 0 0 r
F
.43355 .65733 m .46254 .6602 L .46305 .55077 L F
.47712 .51094 m .46305 .55077 L .49188 .51264 L .71 0 0 r
F
.47712 .51094 m .43447 .54761 L .46305 .55077 L F
.46305 .55077 m .43355 .65733 L .46254 .6602 L .855 0 0 r
F
.46305 .55077 m .43447 .54761 L .43355 .65733 L F
.49188 .51264 m .43447 .54761 L .46305 .55077 L .71 0 0 r
F
.50711 .51366 m .49188 .51264 L .46305 .55077 L F
0 g
.46305 .55077 m
.46305 .55077 L
s
.46305 .55077 m .43355 .65733 L .46254 .6602 L .855 0 0 r
F
.46305 .55077 m .43447 .54761 L .43355 .65733 L F
.49188 .51264 m .43447 .54761 L .46305 .55077 L .71 0 0 r
F
.50711 .51366 m .49188 .51264 L .46305 .55077 L F
.43355 .65733 m .46305 .55077 L .43447 .54761 L .855 0 0 r
F
.43355 .65733 m .46254 .6602 L .46305 .55077 L F
.47712 .51094 m .46305 .55077 L .49188 .51264 L .71 0 0 r
F
.47712 .51094 m .43447 .54761 L .46305 .55077 L F
0 g
.46305 .55077 m
.49244 .55266 L
s
.58264 .66004 m .61014 .54734 L .58149 .55059 L .75 0 0 r
F
.5533 .51255 m .58149 .55059 L .61014 .54734 L .71 0 0 r
F
.55279 .66183 m .58264 .66004 L .58149 .55059 L .773 0 0 r
F
.53805 .51362 m .58149 .55059 L .5533 .51255 L .71 0 0 r
F
.58149 .55059 m .55279 .66183 L .58264 .66004 L .773 0 0 r
F
.61014 .54734 m .58149 .55059 L .58264 .66004 L .75 0 0 r
F
.61014 .54734 m .58149 .55059 L .58264 .66004 L F
.56809 .5108 m .58149 .55059 L .61014 .54734 L .71 0 0 r
F
.56809 .5108 m .5533 .51255 L .58149 .55059 L F
.58149 .55059 m .55279 .66183 L .58264 .66004 L .773 0 0 r
F
.56809 .5108 m .58149 .55059 L .61014 .54734 L .71 0 0 r
F
.56809 .5108 m .5533 .51255 L .58149 .55059 L F
.58264 .66004 m .61014 .54734 L .58149 .55059 L .75 0 0 r
F
.5533 .51255 m .58149 .55059 L .61014 .54734 L .71 0 0 r
F
.55279 .66183 m .58264 .66004 L .58149 .55059 L .773 0 0 r
F
.53805 .51362 m .58149 .55059 L .5533 .51255 L .71 0 0 r
F
0 g
.55206 .55257 m
.58149 .55059 L
s
.40578 .65334 m .43447 .54761 L .40709 .5432 L .876 0 0 r
F
.40578 .65334 m .43355 .65733 L .43447 .54761 L F
.46306 .50859 m .43447 .54761 L .47712 .51094 L .71 0 0 r
F
.46306 .50859 m .40709 .5432 L .43447 .54761 L F
.43447 .54761 m .40578 .65334 L .43355 .65733 L .876 0 0 r
F
.30055 .63568 m .40578 .65334 L .40709 .5432 L p .887 0 0 r
F P
0 g
s
.40578 .65334 m .40709 .5432 L .40578 .65334 L .876 0 0 r
F
.43447 .54761 m .40709 .5432 L .40578 .65334 L F
.40709 .5432 m .40709 .5432 L .40578 .65334 L F
.43447 .54761 m .40578 .65334 L .43355 .65733 L F
.43447 .54761 m .40709 .5432 L .40578 .65334 L F
.40709 .5432 m .40578 .65334 L .40578 .65334 L p .481 0 0 r
F P
0 g
s
.40709 .5432 m .40578 .65334 L .40709 .5432 L .481 0 0 r
F
.40578 .65334 m .40709 .5432 L .30338 .5237 L p .887 0 0 r
F P
0 g
s
.30338 .5237 m .30055 .63568 L .40578 .65334 L p .887 0 0 r
F P
0 g
s
.30055 .63568 m .40578 .65334 L .40709 .5432 L p .887 0 0 r
F P
0 g
s
.40578 .65334 m .40578 .65334 L .40709 .5432 L .876 0 0 r
F
.40578 .65334 m .43447 .54761 L .40709 .5432 L F
.40709 .5432 m .40578 .65334 L .40709 .5432 L .481 0 0 r
F
.40578 .65334 m .43355 .65733 L .43447 .54761 L .876 0 0 r
F
.46252 .62198 m .40578 .65334 L .40709 .5432 L .481 0 0 r
F
.40578 .65334 m .40578 .65334 L .40709 .5432 L F
.40578 .65334 m .40709 .5432 L .40709 .5432 L .876 0 0 r
F
.40578 .65334 m .46252 .62198 L p .40709 .5432 L .481 0 0 r
F P
0 g
s
.47712 .51094 m .40709 .5432 L .43447 .54761 L .71 0 0 r
F
.49188 .51264 m .47712 .51094 L .43447 .54761 L F
.47712 .51094 m .40709 .5432 L .43447 .54761 L F
.49188 .51264 m .47712 .51094 L .43447 .54761 L F
.46306 .50859 m .43447 .54761 L .47712 .51094 L F
.46306 .50859 m .40709 .5432 L .43447 .54761 L F
.47712 .51094 m .46306 .50859 L .40709 .5432 L F
.47712 .51094 m .46306 .50859 L .40709 .5432 L F
.46252 .62198 m .46306 .50859 L .40709 .5432 L p .481 0 0 r
F P
0 g
s
.46286 .55075 m
.46305 .55077 L
s
.61169 .65709 m .63761 .54286 L .61014 .54734 L .725 0 0 r
F
.56809 .5108 m .61014 .54734 L .63761 .54286 L .71 0 0 r
F
.58264 .66004 m .61169 .65709 L .61014 .54734 L .75 0 0 r
F
.5533 .51255 m .61014 .54734 L .56809 .5108 L .71 0 0 r
F
.61014 .54734 m .58264 .66004 L .61169 .65709 L .75 0 0 r
F
.61014 .54734 m .58264 .66004 L .61169 .65709 L F
.63761 .54286 m .61014 .54734 L .61169 .65709 L .725 0 0 r
F
.63761 .54286 m .61014 .54734 L .61169 .65709 L F
.58219 .5084 m .61014 .54734 L .63761 .54286 L .71 0 0 r
F
.58219 .5084 m .56809 .5108 L .61014 .54734 L F
.58219 .5084 m .61014 .54734 L .63761 .54286 L F
.58219 .5084 m .56809 .5108 L .61014 .54734 L F
.61169 .65709 m .63761 .54286 L .61014 .54734 L .725 0 0 r
F
.56809 .5108 m .61014 .54734 L .63761 .54286 L .71 0 0 r
F
.58264 .66004 m .61169 .65709 L .61014 .54734 L .75 0 0 r
F
.5533 .51255 m .61014 .54734 L .56809 .5108 L .71 0 0 r
F
0 g
.58149 .55059 m
.61014 .54734 L
s
.40709 .5432 m .30338 .5237 L .30055 .63568 L p .887 0 0 r
F P
0 g
s
.3569 .48774 m .30338 .5237 L .40709 .5432 L p .71 0 0 r
F P
0 g
s
.40709 .5432 m .46306 .50859 L .3569 .48774 L p .71 0 0 r
F P
0 g
s
.46252 .62198 m .40709 .5432 L .46306 .50859 L .481 0 0 r
F
.46306 .50859 m .40578 .65334 L .40709 .5432 L F
.46306 .50859 m .40709 .5432 L .40578 .65334 L p F P
0 g
s
.46306 .50859 m .46252 .62198 L .40578 .65334 L .481 0 0 r
F
.40578 .65334 m .46252 .62198 L .46306 .50859 L p F P
0 g
s
.46252 .62198 m .46306 .50859 L .40709 .5432 L p .481 0 0 r
F P
0 g
s
.40709 .5432 m .40578 .65334 L .46252 .62198 L p .481 0 0 r
F P
0 g
s
.30338 .5237 m .40709 .5432 L .46306 .50859 L p .71 0 0 r
F P
0 g
s
.46306 .50859 m .40578 .65334 L .40709 .5432 L .481 0 0 r
F
.40709 .5432 m .30338 .5237 L .30055 .63568 L p .887 0 0 r
F P
0 g
s
.30338 .5237 m .40709 .5432 L .46306 .50859 L p .71 0 0 r
F P
0 g
s
.40578 .65334 m .40709 .5432 L .30338 .5237 L p .887 0 0 r
F P
0 g
s
.3569 .48774 m .30338 .5237 L .40709 .5432 L p .71 0 0 r
F P
0 g
s
.30338 .5237 m .2733 .63041 L .30055 .63568 L .898 0 0 r
F
.2733 .63041 m .30055 .63568 L .30338 .5237 L F
.30338 .5237 m .30055 .63568 L .30055 .63568 L p .887 0 0 r
F P
0 g
s
.30055 .63568 m .40578 .65334 L p .30338 .5237 L .887 0 0 r
F P
0 g
s
.30055 .63568 m .30338 .5237 L p .30338 .5237 L .449 0 0 r
F P
0 g
s
.30055 .63568 m .30055 .63568 L p .30338 .5237 L .449 0 0 r
F P
0 g
s
.35476 .60308 m .30338 .5237 L .30055 .63568 L .449 0 0 r
F
.30338 .5237 m .30055 .63568 L .30338 .5237 L .887 0 0 r
F
.35476 .60308 m .30055 .63568 L p .30338 .5237 L .449 0 0 r
F P
0 g
s
.46306 .50859 m .3569 .48774 L .30338 .5237 L p .71 0 0 r
F P
0 g
s
.46306 .50859 m .3569 .48774 L .30338 .5237 L p .71 0 0 r
F P
0 g
s
.30338 .5237 m .3569 .48774 L .35476 .60308 L p .449 0 0 r
F P
0 g
s
.46306 .50859 m .40709 .5432 L .40578 .65334 L p .481 0 0 r
F P
0 g
s
.40709 .5432 m .46306 .50859 L .3569 .48774 L p .71 0 0 r
F P
0 g
s
.46306 .50859 m .46252 .62198 L .46252 .62198 L p .891 0 0 r
F P
0 g
s
.46306 .50859 m .46252 .62198 L .46306 .50859 L .891 0 0 r
F
.46252 .62198 m .46306 .50859 L .47712 .51094 L .879 0 0 r
F
.47712 .51094 m .46252 .62198 L .46306 .50859 L F
.46252 .62198 m .46252 .62198 L .46306 .50859 L .481 0 0 r
F
.46252 .62198 m .40709 .5432 L .46306 .50859 L F
.46252 .62198 m .46306 .50859 L .46306 .50859 L F
.46252 .62198 m .40578 .65334 L .40709 .5432 L F
.46306 .50859 m .46252 .62198 L .40578 .65334 L F
.40578 .65334 m .46252 .62198 L .46306 .50859 L p F P
0 g
s
.46252 .62198 m .35476 .60308 L p .46306 .50859 L .891 0 0 r
F P
0 g
s
.35476 .60308 m .3569 .48774 L .46306 .50859 L p .891 0 0 r
F P
0 g
s
.63956 .65303 m .66351 .53718 L .63761 .54286 L .696 0 0 r
F
.58219 .5084 m .63761 .54286 L .66351 .53718 L .71 0 0 r
F
.61169 .65709 m .63956 .65303 L .63761 .54286 L .725 0 0 r
F
.56809 .5108 m .63761 .54286 L .58219 .5084 L .71 0 0 r
F
.63761 .54286 m .61169 .65709 L .63956 .65303 L .725 0 0 r
F
.63761 .54286 m .61169 .65709 L .63956 .65303 L F
.66351 .53718 m .63761 .54286 L .63956 .65303 L .696 0 0 r
F
.66351 .53718 m .63761 .54286 L .63956 .65303 L F
.59538 .50538 m .63761 .54286 L .66351 .53718 L .71 0 0 r
F
.59538 .50538 m .58219 .5084 L .63761 .54286 L F
.59538 .50538 m .63761 .54286 L .66351 .53718 L F
.59538 .50538 m .58219 .5084 L .63761 .54286 L F
.63956 .65303 m .66351 .53718 L .63761 .54286 L .696 0 0 r
F
.58219 .5084 m .63761 .54286 L .66351 .53718 L .71 0 0 r
F
.61169 .65709 m .63956 .65303 L .63761 .54286 L .725 0 0 r
F
.56809 .5108 m .63761 .54286 L .58219 .5084 L .71 0 0 r
F
0 g
.61014 .54734 m
.63761 .54286 L
s
.5229 .62687 m .55279 .66183 L .52256 .66246 L .688 0 0 r
F
.50721 .62658 m .52256 .66246 L .49234 .66191 L F
.50721 .62658 m .5229 .62687 L .52256 .66246 L F
0 g
.52256 .66246 m
.52256 .66246 L
s
.5229 .62687 m .52256 .66246 L .49234 .66191 L .688 0 0 r
F
.53861 .62654 m .52256 .66246 L .5229 .62687 L F
.53861 .62654 m .55279 .66183 L .52256 .66246 L F
0 g
.52256 .66246 m
.52256 .66246 L
s
.52256 .66246 m
.52256 .66246 L
s
.5229 .62687 m .52256 .66246 L .49234 .66191 L .688 0 0 r
F
0 g
.52256 .66246 m
.52256 .66246 L
s
.53861 .62654 m .52256 .66246 L .5229 .62687 L .688 0 0 r
F
.53861 .62654 m .55279 .66183 L .52256 .66246 L F
0 g
.52256 .66246 m
.52256 .66246 L
s
.5229 .62687 m .55279 .66183 L .52256 .66246 L .688 0 0 r
F
.50721 .62658 m .52256 .66246 L .49234 .66191 L F
.50721 .62658 m .5229 .62687 L .52256 .66246 L F
.49176 .62566 m .49234 .66191 L .46254 .6602 L F
.49176 .62566 m .50721 .62658 L .49234 .66191 L F
0 g
.49234 .66191 m
.49234 .66191 L
s
.50721 .62658 m .49234 .66191 L .46254 .6602 L .688 0 0 r
F
.5229 .62687 m .49234 .66191 L .50721 .62658 L F
0 g
.49234 .66191 m
.52256 .66246 L
s
.50721 .62658 m .49234 .66191 L .46254 .6602 L .688 0 0 r
F
.5229 .62687 m .49234 .66191 L .50721 .62658 L F
0 g
.49234 .66191 m
.49234 .66191 L
s
.49176 .62566 m .49234 .66191 L .46254 .6602 L .688 0 0 r
F
.49176 .62566 m .50721 .62658 L .49234 .66191 L F
0 g
.49234 .66191 m
.52256 .66246 L
s
.53861 .62654 m .58264 .66004 L .55279 .66183 L .688 0 0 r
F
.5229 .62687 m .53861 .62654 L .55279 .66183 L F
.55408 .62557 m .55279 .66183 L .53861 .62654 L F
.55408 .62557 m .58264 .66004 L .55279 .66183 L F
.55408 .62557 m .55279 .66183 L .53861 .62654 L F
.55408 .62557 m .58264 .66004 L .55279 .66183 L F
0 g
.55279 .66183 m
.55279 .66183 L
s
.53861 .62654 m .58264 .66004 L .55279 .66183 L .688 0 0 r
F
.5229 .62687 m .53861 .62654 L .55279 .66183 L F
0 g
.52256 .66246 m
.55279 .66183 L
s
.66583 .64789 m .68744 .53037 L .66351 .53718 L .663 0 0 r
F
.59538 .50538 m .66351 .53718 L .68744 .53037 L .71 0 0 r
F
.63956 .65303 m .66583 .64789 L .66351 .53718 L .696 0 0 r
F
.58219 .5084 m .66351 .53718 L .59538 .50538 L .71 0 0 r
F
.66351 .53718 m .63956 .65303 L .66583 .64789 L .696 0 0 r
F
.66351 .53718 m .63956 .65303 L .66583 .64789 L F
.68744 .53037 m .66351 .53718 L .66583 .64789 L .663 0 0 r
F
.68744 .53037 m .66351 .53718 L .66583 .64789 L F
.60744 .50177 m .66351 .53718 L .68744 .53037 L .71 0 0 r
F
.60744 .50177 m .59538 .50538 L .66351 .53718 L F
.60744 .50177 m .66351 .53718 L .68744 .53037 L F
.60744 .50177 m .59538 .50538 L .66351 .53718 L F
.66583 .64789 m .68744 .53037 L .66351 .53718 L .663 0 0 r
F
.59538 .50538 m .66351 .53718 L .68744 .53037 L .71 0 0 r
F
.63956 .65303 m .66583 .64789 L .66351 .53718 L .696 0 0 r
F
.58219 .5084 m .66351 .53718 L .59538 .50538 L .71 0 0 r
F
0 g
.63761 .54286 m
.66351 .53718 L
s
.47679 .62412 m .46254 .6602 L .43355 .65733 L .688 0 0 r
F
.47679 .62412 m .49176 .62566 L .46254 .6602 L F
0 g
.46254 .6602 m
.46254 .6602 L
s
.49176 .62566 m .46254 .6602 L .43355 .65733 L .688 0 0 r
F
.50721 .62658 m .46254 .6602 L .49176 .62566 L F
0 g
.46254 .6602 m
.49234 .66191 L
s
.49176 .62566 m .46254 .6602 L .43355 .65733 L .688 0 0 r
F
.50721 .62658 m .46254 .6602 L .49176 .62566 L F
0 g
.46254 .6602 m
.46254 .6602 L
s
.47679 .62412 m .46254 .6602 L .43355 .65733 L .688 0 0 r
F
.47679 .62412 m .49176 .62566 L .46254 .6602 L F
0 g
.46254 .6602 m
.49234 .66191 L
s
.55408 .62557 m .61169 .65709 L .58264 .66004 L .688 0 0 r
F
.53861 .62654 m .55408 .62557 L .58264 .66004 L F
.56908 .62399 m .58264 .66004 L .55408 .62557 L F
.56908 .62399 m .61169 .65709 L .58264 .66004 L F
0 g
.58264 .66004 m
.58264 .66004 L
s
.56908 .62399 m .58264 .66004 L .55408 .62557 L .688 0 0 r
F
.56908 .62399 m .61169 .65709 L .58264 .66004 L F
.55408 .62557 m .61169 .65709 L .58264 .66004 L F
.53861 .62654 m .55408 .62557 L .58264 .66004 L F
0 g
.55279 .66183 m
.58264 .66004 L
s
.46252 .62198 m .43355 .65733 L .40578 .65334 L .688 0 0 r
F
.46252 .62198 m .47679 .62412 L .43355 .65733 L F
.47679 .62412 m .43355 .65733 L .40578 .65334 L F
.49176 .62566 m .43355 .65733 L .47679 .62412 L F
0 g
.43355 .65733 m
.46254 .6602 L
s
.47679 .62412 m .43355 .65733 L .40578 .65334 L .688 0 0 r
F
.49176 .62566 m .43355 .65733 L .47679 .62412 L F
.46252 .62198 m .43355 .65733 L .40578 .65334 L F
0 g
.40578 .65334 m
.40578 .65334 L
s
.40578 .65334 m
.43355 .65733 L
s
.40578 .65334 m
.43355 .65733 L
s
.4096 .65389 m
.43355 .65733 L
s
.46252 .62198 m .47679 .62412 L .43355 .65733 L .688 0 0 r
F
0 g
.43355 .65733 m
.46254 .6602 L
s
.40986 .65393 m
.43355 .65733 L
s
.56908 .62399 m .63956 .65303 L .61169 .65709 L .688 0 0 r
F
.55408 .62557 m .56908 .62399 L .61169 .65709 L F
.58339 .62181 m .61169 .65709 L .56908 .62399 L F
.58339 .62181 m .63956 .65303 L .61169 .65709 L F
.58339 .62181 m .61169 .65709 L .56908 .62399 L F
.58339 .62181 m .63956 .65303 L .61169 .65709 L F
.56908 .62399 m .63956 .65303 L .61169 .65709 L F
.55408 .62557 m .56908 .62399 L .61169 .65709 L F
0 g
.58264 .66004 m
.61169 .65709 L
s
.69013 .64172 m .70903 .5225 L .68744 .53037 L .621 0 0 r
F
.60744 .50177 m .68744 .53037 L .70903 .5225 L .71 0 0 r
F
.66583 .64789 m .69013 .64172 L .68744 .53037 L .663 0 0 r
F
.59538 .50538 m .68744 .53037 L .60744 .50177 L .71 0 0 r
F
.68744 .53037 m .66583 .64789 L .69013 .64172 L .663 0 0 r
F
.68744 .53037 m .66583 .64789 L .69013 .64172 L F
.70903 .5225 m .68744 .53037 L .69013 .64172 L .621 0 0 r
F
.70903 .5225 m .68744 .53037 L .69013 .64172 L F
.61818 .49764 m .68744 .53037 L .70903 .5225 L .71 0 0 r
F
.61818 .49764 m .60744 .50177 L .68744 .53037 L F
.61818 .49764 m .68744 .53037 L .70903 .5225 L F
.61818 .49764 m .60744 .50177 L .68744 .53037 L F
.69013 .64172 m .70903 .5225 L .68744 .53037 L .621 0 0 r
F
.60744 .50177 m .68744 .53037 L .70903 .5225 L .71 0 0 r
F
.66583 .64789 m .69013 .64172 L .68744 .53037 L .663 0 0 r
F
.59538 .50538 m .68744 .53037 L .60744 .50177 L .71 0 0 r
F
0 g
.66351 .53718 m
.68744 .53037 L
s
.47712 .51094 m .46252 .62198 L .46306 .50859 L .879 0 0 r
F
.46252 .62198 m .46306 .50859 L .47712 .51094 L F
.3569 .48774 m .46306 .50859 L .46252 .62198 L p .891 0 0 r
F P
0 g
s
.46252 .62198 m .35476 .60308 L .3569 .48774 L p .891 0 0 r
F P
0 g
s
.35476 .60308 m .3569 .48774 L .46306 .50859 L p .891 0 0 r
F P
0 g
s
.46306 .50859 m .46252 .62198 L .35476 .60308 L p .891 0 0 r
F P
0 g
s
.3569 .48774 m .46306 .50859 L .46252 .62198 L p .891 0 0 r
F P
0 g
s
.5229 .62687 m .52258 .51399 L .53805 .51362 L .793 0 0 r
F
.50721 .62658 m .52258 .51399 L .5229 .62687 L .815 0 0 r
F
.50721 .62658 m .50711 .51366 L .52258 .51399 L F
.52258 .51399 m .50721 .62658 L .50711 .51366 L F
.52258 .51399 m .5229 .62687 L .50721 .62658 L F
.53805 .51362 m .5229 .62687 L .52258 .51399 L .793 0 0 r
F
.52258 .51399 m .50721 .62658 L .50711 .51366 L .815 0 0 r
F
.52258 .51399 m .5229 .62687 L .50721 .62658 L F
.53805 .51362 m .5229 .62687 L .52258 .51399 L .793 0 0 r
F
.5229 .62687 m .52258 .51399 L .53805 .51362 L F
.50721 .62658 m .52258 .51399 L .5229 .62687 L .815 0 0 r
F
.50721 .62658 m .50711 .51366 L .52258 .51399 L F
.49176 .62566 m .50711 .51366 L .50721 .62658 L .836 0 0 r
F
.49176 .62566 m .49188 .51264 L .50711 .51366 L F
.50711 .51366 m .49176 .62566 L .49188 .51264 L F
.50711 .51366 m .50721 .62658 L .49176 .62566 L F
.50711 .51366 m .49176 .62566 L .49188 .51264 L F
.50711 .51366 m .50721 .62658 L .49176 .62566 L F
.49176 .62566 m .50711 .51366 L .50721 .62658 L F
.49176 .62566 m .49188 .51264 L .50711 .51366 L F
.53861 .62654 m .53805 .51362 L .5533 .51255 L .771 0 0 r
F
.5229 .62687 m .53805 .51362 L .53861 .62654 L .793 0 0 r
F
.53805 .51362 m .53861 .62654 L .5229 .62687 L F
.5533 .51255 m .53861 .62654 L .53805 .51362 L .771 0 0 r
F
.53805 .51362 m .53861 .62654 L .5229 .62687 L .793 0 0 r
F
.5533 .51255 m .53861 .62654 L .53805 .51362 L .771 0 0 r
F
.53861 .62654 m .53805 .51362 L .5533 .51255 L F
.5229 .62687 m .53805 .51362 L .53861 .62654 L .793 0 0 r
F
.47679 .62412 m .49188 .51264 L .49176 .62566 L .857 0 0 r
F
.47679 .62412 m .47712 .51094 L .49188 .51264 L F
.49188 .51264 m .47679 .62412 L .47712 .51094 L F
.49188 .51264 m .49176 .62566 L .47679 .62412 L F
.49188 .51264 m .47679 .62412 L .47712 .51094 L F
.49188 .51264 m .49176 .62566 L .47679 .62412 L F
.47679 .62412 m .49188 .51264 L .49176 .62566 L F
.47679 .62412 m .47712 .51094 L .49188 .51264 L F
.53861 .62654 m .5533 .51255 L .55408 .62557 L .771 0 0 r
F
.5533 .51255 m .55408 .62557 L .53861 .62654 L F
.5533 .51255 m .55408 .62557 L .53861 .62654 L F
.53861 .62654 m .5533 .51255 L .55408 .62557 L F
.46252 .62198 m .47712 .51094 L .47679 .62412 L .879 0 0 r
F
.47712 .51094 m .47679 .62412 L .46252 .62198 L F
.47712 .51094 m .47679 .62412 L .46252 .62198 L F
.46252 .62198 m .47712 .51094 L .47679 .62412 L F
.54564 .6733 m .54432 .44504 L .43975 .42295 L p 0 .35 .741 r
F P
0 g
s
.5 .38214 m .43975 .42295 L .54432 .44504 L p 0 .442 1 r
F P
0 g
s
.46252 .62198 m .35476 .60308 L .3569 .48774 L p .891 0 0 r
F P
0 g
s
.46252 .62198 m .40578 .65334 L p .38095 .62888 L .688 0 0 r
F P
0 g
s
.40917 .61262 m .46252 .62198 L p .38095 .62888 L .688 0 0 r
F P
0 g
s
.46252 .62198 m .40578 .65334 L .30055 .63568 L p .688 0 0 r
F P
0 g
s
.47679 .62412 m .40578 .65334 L .46252 .62198 L .688 0 0 r
F
.47679 .62412 m .40578 .65334 L .46252 .62198 L F
.46252 .62198 m .40578 .65334 L .30055 .63568 L p F P
0 g
s
.46252 .62198 m .40578 .65334 L p .38095 .62888 L .688 0 0 r
F P
0 g
s
.35476 .60308 m .40917 .61262 L p .38095 .62888 L .688 0 0 r
F P
0 g
s
.40917 .61262 m .46252 .62198 L p .38095 .62888 L .688 0 0 r
F P
0 g
s
.30055 .63568 m .35476 .60308 L .46252 .62198 L p .688 0 0 r
F P
0 g
s
.30055 .63568 m .35476 .60308 L .46252 .62198 L p .688 0 0 r
F P
0 g
s
.43975 .42295 m .43792 .65515 L .54564 .6733 L p 0 .35 .741 r
F P
0 g
s
.5 .38214 m .43975 .42295 L .43839 .59579 L p 0 .177 .691 r
F P
0 g
s
.5 .38214 m .43839 .59579 L .45338 .58716 L 0 .177 .691 r
F
.4729 .50133 m .45338 .58716 L .43975 .42295 L F
.43975 .42295 m .5 .38214 L p .4729 .50133 L F P
0 g
s
.43839 .59579 m .43792 .65515 L p .45338 .58716 L 0 .177 .691 r
F P
0 g
s
.43792 .65515 m .43839 .59579 L p .45338 .58716 L 0 .177 .691 r
F P
0 g
s
.43839 .59579 m .43975 .42295 L p .45338 .58716 L 0 .177 .691 r
F P
0 g
s
.35476 .60308 m .40917 .61262 L p .38095 .62888 L .688 0 0 r
F P
0 g
s
.40578 .65334 m
.4096 .65389 L
s
.40578 .65334 m
.40578 .65334 L
s
.40578 .65334 m
.40578 .65334 L
s
.40578 .65334 m
.40986 .65393 L
s
.40578 .65334 m .30055 .63568 L .35476 .60308 L p .688 0 0 r
F P
0 g
s
.40578 .65334 m
.40578 .65334 L
s
.40578 .65334 m
.43808 .63549 L
s
.40578 .65334 m
.40578 .65334 L
s
.40578 .65334 m
.40578 .65334 L
s
.40578 .65334 m .30055 .63568 L .35476 .60308 L p .688 0 0 r
F P
0 g
s
.40578 .65334 m
.43808 .63549 L
s
.40578 .65334 m
.40578 .65334 L
s
.58339 .62181 m .66583 .64789 L .63956 .65303 L .688 0 0 r
F
.56908 .62399 m .58339 .62181 L .63956 .65303 L F
.59678 .61907 m .63956 .65303 L .58339 .62181 L F
.59678 .61907 m .66583 .64789 L .63956 .65303 L F
.59678 .61907 m .63956 .65303 L .58339 .62181 L F
.59678 .61907 m .66583 .64789 L .63956 .65303 L F
.58339 .62181 m .66583 .64789 L .63956 .65303 L F
.56908 .62399 m .58339 .62181 L .63956 .65303 L F
0 g
.61169 .65709 m
.63956 .65303 L
s
.35476 .60308 m .3569 .48774 L .30338 .5237 L .449 0 0 r
F
.30338 .5237 m .27653 .51789 L .2733 .63041 L .898 0 0 r
F
.2733 .63041 m .30338 .5237 L .27653 .51789 L F
.3432 .48464 m .30338 .5237 L .3569 .48774 L .71 0 0 r
F
.3432 .48464 m .27653 .51789 L .30338 .5237 L F
.3569 .48774 m .30338 .5237 L .30055 .63568 L .449 0 0 r
F
.30055 .63568 m .30338 .5237 L .3569 .48774 L p F P
0 g
s
.3569 .48774 m .30055 .63568 L .35476 .60308 L .449 0 0 r
F
.3569 .48774 m .35476 .60308 L .30055 .63568 L p F P
0 g
s
.35476 .60308 m .30055 .63568 L .30338 .5237 L p .449 0 0 r
F P
0 g
s
.30338 .5237 m .3569 .48774 L .35476 .60308 L p .449 0 0 r
F P
0 g
s
.3569 .48774 m .27653 .51789 L .30338 .5237 L .71 0 0 r
F
.3569 .48774 m .30338 .5237 L .30055 .63568 L .449 0 0 r
F
.2733 .63041 m .30055 .63568 L .30338 .5237 L .898 0 0 r
F
.30338 .5237 m .2733 .63041 L .30055 .63568 L F
.2733 .63041 m .30338 .5237 L .27653 .51789 L F
.30338 .5237 m .27653 .51789 L .2733 .63041 L F
.3569 .48774 m .27653 .51789 L .30338 .5237 L .71 0 0 r
F
.30055 .63568 m .30338 .5237 L .3569 .48774 L p .449 0 0 r
F P
0 g
s
.35476 .60308 m .30338 .5237 L .30055 .63568 L .449 0 0 r
F
.35476 .60308 m .3569 .48774 L .35476 .60308 L .902 0 0 r
F
.3569 .48774 m .3569 .48774 L .35476 .60308 L F
.35476 .60308 m .3569 .48774 L .30338 .5237 L .449 0 0 r
F
.3569 .48774 m .30055 .63568 L .35476 .60308 L F
.3569 .48774 m .35476 .60308 L .30055 .63568 L p F P
0 g
s
.3569 .48774 m .35476 .60308 L .34086 .60026 L .902 0 0 r
F
.34086 .60026 m .3569 .48774 L .35476 .60308 L F
.3432 .48464 m .30338 .5237 L .3569 .48774 L .71 0 0 r
F
.3569 .48774 m .3432 .48464 L .27653 .51789 L F
.3569 .48774 m .3432 .48464 L .27653 .51789 L F
.3569 .48774 m .34086 .60026 L .3432 .48464 L .902 0 0 r
F
.34086 .60026 m .3432 .48464 L .3569 .48774 L F
.3432 .48464 m .27653 .51789 L .30338 .5237 L .71 0 0 r
F
.71205 .63459 m .7279 .51367 L .70903 .5225 L .566 0 0 r
F
.61818 .49764 m .70903 .5225 L .7279 .51367 L .71 0 0 r
F
.69013 .64172 m .71205 .63459 L .70903 .5225 L .621 0 0 r
F
.60744 .50177 m .70903 .5225 L .61818 .49764 L .71 0 0 r
F
.70903 .5225 m .69013 .64172 L .71205 .63459 L .621 0 0 r
F
.70903 .5225 m .69013 .64172 L .71205 .63459 L F
.7279 .51367 m .70903 .5225 L .71205 .63459 L .566 0 0 r
F
.7279 .51367 m .70903 .5225 L .71205 .63459 L F
.71205 .63459 m .7279 .51367 L .70903 .5225 L F
.71205 .63459 m .73122 .62659 L .7279 .51367 L F
.7279 .51367 m .73122 .62659 L .80111 .59334 L p .532 0 0 r
F P
0 g
s
.7279 .51367 m .7279 .51367 L .73122 .62659 L .566 0 0 r
F
.7279 .51367 m .71205 .63459 L .73122 .62659 L F
.7279 .51367 m .73122 .62659 L .73122 .62659 L F
.69013 .64172 m .71205 .63459 L .70903 .5225 L .621 0 0 r
F
.7279 .51367 m .71205 .63459 L .73122 .62659 L .566 0 0 r
F
.7279 .51367 m .7279 .51367 L .73122 .62659 L .894 0 0 r
F
.73122 .62659 m .7279 .51367 L p .7279 .51367 L F P
0 g
s
.73122 .62659 m .7279 .51367 L .73122 .62659 L .894 0 0 r
F
.73122 .62659 m .73122 .62659 L p .7279 .51367 L F P
0 g
s
.79664 .47701 m .7279 .51367 L .73122 .62659 L p .532 0 0 r
F P
0 g
s
.73122 .62659 m .80111 .59334 L .79664 .47701 L p .532 0 0 r
F P
0 g
s
.7279 .51367 m .73122 .62659 L .80111 .59334 L p .532 0 0 r
F P
0 g
s
.7279 .51367 m .73122 .62659 L .7279 .51367 L .566 0 0 r
F
.71205 .63459 m .73122 .62659 L .7279 .51367 L F
.73122 .62659 m .73122 .62659 L .7279 .51367 L F
.62931 .60787 m .7279 .51367 L .73122 .62659 L .894 0 0 r
F
.62931 .60787 m .73122 .62659 L p .7279 .51367 L F P
0 g
s
.62742 .49303 m .70903 .5225 L .7279 .51367 L .71 0 0 r
F
.62742 .49303 m .61818 .49764 L .70903 .5225 L F
.62742 .49303 m .70903 .5225 L .7279 .51367 L F
.62742 .49303 m .61818 .49764 L .70903 .5225 L F
.61818 .49764 m .70903 .5225 L .7279 .51367 L F
.60744 .50177 m .70903 .5225 L .61818 .49764 L F
0 g
.68744 .53037 m
.70903 .5225 L
s
.59678 .61907 m .69013 .64172 L .66583 .64789 L .688 0 0 r
F
.58339 .62181 m .59678 .61907 L .66583 .64789 L F
.60902 .6158 m .66583 .64789 L .59678 .61907 L F
.60902 .6158 m .69013 .64172 L .66583 .64789 L F
.60902 .6158 m .66583 .64789 L .59678 .61907 L F
.60902 .6158 m .69013 .64172 L .66583 .64789 L F
.59678 .61907 m .69013 .64172 L .66583 .64789 L F
.58339 .62181 m .59678 .61907 L .66583 .64789 L F
0 g
.63956 .65303 m
.66583 .64789 L
s
.27653 .51789 m .25158 .51089 L .24796 .62407 L .922 0 0 r
F
.24796 .62407 m .27653 .51789 L .25158 .51089 L F
.27653 .51789 m .24796 .62407 L .2733 .63041 L F
.24796 .62407 m .2733 .63041 L .27653 .51789 L F
.3306 .48093 m .27653 .51789 L .3432 .48464 L .71 0 0 r
F
.3306 .48093 m .25158 .51089 L .27653 .51789 L F
.3432 .48464 m .25158 .51089 L .27653 .51789 L F
.24796 .62407 m .2733 .63041 L .27653 .51789 L .922 0 0 r
F
.27653 .51789 m .24796 .62407 L .2733 .63041 L F
.24796 .62407 m .27653 .51789 L .25158 .51089 L F
.27653 .51789 m .25158 .51089 L .24796 .62407 L F
.3432 .48464 m .25158 .51089 L .27653 .51789 L .71 0 0 r
F
0 g
.27653 .51789 m
.30338 .5237 L
s
.3306 .48093 m .27653 .51789 L .3432 .48464 L .71 0 0 r
F
.3306 .48093 m .25158 .51089 L .27653 .51789 L F
.60902 .6158 m .71205 .63459 L .69013 .64172 L .688 0 0 r
F
.59678 .61907 m .60902 .6158 L .69013 .64172 L F
.61993 .61205 m .69013 .64172 L .60902 .6158 L F
.61993 .61205 m .71205 .63459 L .69013 .64172 L F
.61993 .61205 m .69013 .64172 L .60902 .6158 L F
.61993 .61205 m .71205 .63459 L .69013 .64172 L F
.60902 .6158 m .71205 .63459 L .69013 .64172 L F
.59678 .61907 m .60902 .6158 L .69013 .64172 L F
0 g
.66583 .64789 m
.69013 .64172 L
s
.61818 .49764 m .7279 .51367 L .62742 .49303 L .71 0 0 r
F
.61818 .49764 m .7279 .51367 L .62742 .49303 L F
.7279 .51367 m .62742 .49303 L .62931 .60787 L p .894 0 0 r
F P
0 g
s
.80111 .59334 m .79664 .47701 L .7279 .51367 L p .532 0 0 r
F P
0 g
s
.69399 .4549 m .62742 .49303 L .7279 .51367 L p .71 0 0 r
F P
0 g
s
.7279 .51367 m .79664 .47701 L .69399 .4549 L p .71 0 0 r
F P
0 g
s
.62931 .60787 m .62742 .49303 L .7279 .51367 L .894 0 0 r
F
0 g
.7279 .51367 m
.7279 .51367 L
s
.7279 .51367 m
.7279 .51367 L
s
.80111 .59334 m .79664 .47701 L .7279 .51367 L p .532 0 0 r
F P
0 g
s
.73122 .62659 m .7279 .51367 L .62742 .49303 L p .894 0 0 r
F P
0 g
s
.62742 .49303 m .7279 .51367 L .79664 .47701 L p .71 0 0 r
F P
0 g
s
.62742 .49303 m .7279 .51367 L .73122 .62659 L .894 0 0 r
F
.62742 .49303 m .62931 .60787 L .73122 .62659 L p F P
0 g
s
.62742 .49303 m .73122 .62659 L .62931 .60787 L .894 0 0 r
F
.62931 .60787 m .73122 .62659 L .7279 .51367 L p F P
0 g
s
.7279 .51367 m .62742 .49303 L .62931 .60787 L p .894 0 0 r
F P
0 g
s
.62742 .49303 m .7279 .51367 L .79664 .47701 L p .71 0 0 r
F P
0 g
s
.62742 .49303 m .7279 .51367 L .73122 .62659 L .894 0 0 r
F
.62931 .60787 m .62742 .49303 L p .62742 .49303 L .509 0 0 r
F P
0 g
s
.73122 .62659 m .7279 .51367 L .62742 .49303 L p .894 0 0 r
F P
0 g
s
.62931 .60787 m .7279 .51367 L .73122 .62659 L .894 0 0 r
F
.69399 .4549 m .62742 .49303 L .7279 .51367 L p .71 0 0 r
F P
0 g
s
.62931 .60787 m .62931 .60787 L p .62742 .49303 L .509 0 0 r
F P
0 g
s
.62931 .60787 m .62742 .49303 L .7279 .51367 L .894 0 0 r
F
.79664 .47701 m .69399 .4549 L .62742 .49303 L p .71 0 0 r
F P
0 g
s
.79664 .47701 m .69399 .4549 L .62742 .49303 L p .71 0 0 r
F P
0 g
s
.62742 .49303 m .69399 .4549 L .69697 .57327 L p .509 0 0 r
F P
0 g
s
.62742 .49303 m .73122 .62659 L .62931 .60787 L .894 0 0 r
F
.62742 .49303 m .62931 .60787 L .73122 .62659 L p F P
0 g
s
.69697 .57327 m .62931 .60787 L p .62742 .49303 L .509 0 0 r
F P
0 g
s
.79664 .47701 m .7279 .51367 L .73122 .62659 L p .532 0 0 r
F P
0 g
s
.7279 .51367 m .79664 .47701 L .69399 .4549 L p .71 0 0 r
F P
0 g
s
.69697 .57327 m .79664 .47701 L .69399 .4549 L .899 0 0 r
F
.55408 .62557 m .5533 .51255 L .56809 .5108 L .747 0 0 r
F
.56809 .5108 m .55408 .62557 L .5533 .51255 L F
.56809 .5108 m .55408 .62557 L .5533 .51255 L F
.55408 .62557 m .5533 .51255 L .56809 .5108 L F
0 g
.54471 .51315 m
.5533 .51255 L
s
.25158 .51089 m .22893 .50279 L .22494 .61673 L .949 0 0 r
F
.22494 .61673 m .25158 .51089 L .22893 .50279 L F
.25158 .51089 m .22494 .61673 L .24796 .62407 L F
.22494 .61673 m .24796 .62407 L .25158 .51089 L F
.31931 .47667 m .25158 .51089 L .3306 .48093 L .71 0 0 r
F
.31931 .47667 m .22893 .50279 L .25158 .51089 L F
.3306 .48093 m .22893 .50279 L .25158 .51089 L F
.3432 .48464 m .3306 .48093 L .25158 .51089 L F
.22494 .61673 m .24796 .62407 L .25158 .51089 L .949 0 0 r
F
.25158 .51089 m .22494 .61673 L .24796 .62407 L F
.22494 .61673 m .25158 .51089 L .22893 .50279 L F
.25158 .51089 m .22893 .50279 L .22494 .61673 L F
.3306 .48093 m .22893 .50279 L .25158 .51089 L .71 0 0 r
F
.3432 .48464 m .3306 .48093 L .25158 .51089 L F
0 g
.25158 .51089 m
.27653 .51789 L
s
.31931 .47667 m .25158 .51089 L .3306 .48093 L .71 0 0 r
F
.31931 .47667 m .22893 .50279 L .25158 .51089 L F
.56908 .62399 m .56809 .5108 L .58219 .5084 L .721 0 0 r
F
.55408 .62557 m .56809 .5108 L .56908 .62399 L .747 0 0 r
F
.56809 .5108 m .56908 .62399 L .55408 .62557 L F
.56809 .5108 m .56908 .62399 L .55408 .62557 L F
.58219 .5084 m .56908 .62399 L .56809 .5108 L .721 0 0 r
F
.58219 .5084 m .56908 .62399 L .56809 .5108 L F
.56908 .62399 m .56809 .5108 L .58219 .5084 L F
.55408 .62557 m .56809 .5108 L .56908 .62399 L .747 0 0 r
F
0 g
.5533 .51255 m
.56809 .5108 L
s
.34086 .60026 m .30055 .63568 L .2733 .63041 L .688 0 0 r
F
.34086 .60026 m .35476 .60308 L .30055 .63568 L F
.35476 .60308 m .30055 .63568 L .2733 .63041 L F
0 g
.30055 .63568 m
.30055 .63568 L
s
.35476 .60308 m .30055 .63568 L .2733 .63041 L .688 0 0 r
F
.34086 .60026 m .30055 .63568 L .2733 .63041 L F
.34086 .60026 m .35476 .60308 L .30055 .63568 L F
0 g
.30055 .63568 m
.30088 .63548 L
s
.30055 .63568 m
.30055 .63568 L
s
.30055 .63568 m
.30055 .63568 L
s
.30055 .63568 m
.30088 .63548 L
s
.58339 .62181 m .58219 .5084 L .59538 .50538 L .69 0 0 r
F
.56908 .62399 m .58219 .5084 L .58339 .62181 L .721 0 0 r
F
.58219 .5084 m .58339 .62181 L .56908 .62399 L F
.58219 .5084 m .58339 .62181 L .56908 .62399 L F
.59538 .50538 m .58339 .62181 L .58219 .5084 L .69 0 0 r
F
.59538 .50538 m .58339 .62181 L .58219 .5084 L F
.58339 .62181 m .58219 .5084 L .59538 .50538 L F
.56908 .62399 m .58219 .5084 L .58339 .62181 L .721 0 0 r
F
.60702 .40581 m .54432 .44504 L .54564 .6733 L p 0 .19 .704 r
F P
0 g
s
.54432 .44504 m .60702 .40581 L .5 .38214 L p 0 .442 1 r
F P
0 g
s
.61993 .61205 m .73122 .62659 L .71205 .63459 L .688 0 0 r
F
.60902 .6158 m .61993 .61205 L .71205 .63459 L F
.62931 .60787 m .71205 .63459 L .61993 .61205 L F
.62931 .60787 m .73122 .62659 L .71205 .63459 L F
.62931 .60787 m .71205 .63459 L .61993 .61205 L F
.62931 .60787 m .73122 .62659 L .71205 .63459 L F
.61993 .61205 m .73122 .62659 L .71205 .63459 L F
0 g
.73082 .62676 m
.73122 .62659 L
s
.60902 .6158 m .61993 .61205 L .71205 .63459 L .688 0 0 r
F
0 g
.69013 .64172 m
.71205 .63459 L
s
.71205 .63459 m
.73082 .62676 L
s
.59678 .61907 m .59538 .50538 L .60744 .50177 L .654 0 0 r
F
.58339 .62181 m .59538 .50538 L .59678 .61907 L .69 0 0 r
F
.59538 .50538 m .59678 .61907 L .58339 .62181 L F
.59538 .50538 m .59678 .61907 L .58339 .62181 L F
.60744 .50177 m .59678 .61907 L .59538 .50538 L .654 0 0 r
F
.60744 .50177 m .59678 .61907 L .59538 .50538 L F
.59678 .61907 m .59538 .50538 L .60744 .50177 L F
.58339 .62181 m .59538 .50538 L .59678 .61907 L .69 0 0 r
F
0 g
.58355 .50809 m
.59538 .50538 L
s
.22893 .50279 m .20895 .49368 L .20463 .60847 L .979 0 0 r
F
.20463 .60847 m .22893 .50279 L .20895 .49368 L F
.22893 .50279 m .20463 .60847 L .22494 .61673 L F
.20463 .60847 m .22494 .61673 L .22893 .50279 L F
.30951 .4719 m .22893 .50279 L .31931 .47667 L .71 0 0 r
F
.30951 .4719 m .20895 .49368 L .22893 .50279 L F
.31931 .47667 m .20895 .49368 L .22893 .50279 L F
.3306 .48093 m .31931 .47667 L .22893 .50279 L F
.20463 .60847 m .22494 .61673 L .22893 .50279 L .979 0 0 r
F
.22893 .50279 m .20463 .60847 L .22494 .61673 L F
.20463 .60847 m .22893 .50279 L .20895 .49368 L F
.22893 .50279 m .20895 .49368 L .20463 .60847 L F
.31931 .47667 m .20895 .49368 L .22893 .50279 L .71 0 0 r
F
.3306 .48093 m .31931 .47667 L .22893 .50279 L F
0 g
.22893 .50279 m
.25158 .51089 L
s
.30951 .4719 m .22893 .50279 L .31931 .47667 L .71 0 0 r
F
.30951 .4719 m .20895 .49368 L .22893 .50279 L F
0 g
.30338 .5237 m
.34295 .49711 L
s
.34086 .60026 m .3432 .48464 L .3569 .48774 L .902 0 0 r
F
.3569 .48774 m .34086 .60026 L .3432 .48464 L F
.34086 .60026 m .3569 .48774 L .35476 .60308 L F
.3569 .48774 m .35476 .60308 L .34086 .60026 L F
.32806 .5969 m .2733 .63041 L .24971 .62451 L .688 0 0 r
F
.32806 .5969 m .24971 .62451 L .25328 .62227 L F
.32806 .5969 m .34086 .60026 L .2733 .63041 L F
.34086 .60026 m .2733 .63041 L .24796 .62407 L F
.35476 .60308 m .2733 .63041 L .34086 .60026 L F
.34086 .60026 m .2733 .63041 L .24796 .62407 L F
.35476 .60308 m .2733 .63041 L .34086 .60026 L F
.32806 .5969 m .2733 .63041 L .24796 .62407 L F
.32806 .5969 m .34086 .60026 L .2733 .63041 L F
.31659 .59303 m .32806 .5969 L .24796 .62407 L F
.32806 .5969 m .24796 .62407 L .22494 .61673 L F
.34086 .60026 m .24796 .62407 L .32806 .5969 L F
.32806 .5969 m .24796 .62407 L .22494 .61673 L F
.34086 .60026 m .24796 .62407 L .32806 .5969 L F
.31659 .59303 m .32806 .5969 L .24796 .62407 L F
.32806 .5969 m .22494 .61673 L .31659 .59303 L F
.32806 .5969 m .22494 .61673 L .31659 .59303 L F
.3432 .48464 m .34086 .60026 L .32806 .5969 L .928 0 0 r
F
.32806 .5969 m .3432 .48464 L .34086 .60026 L F
.3432 .48464 m .32806 .5969 L .3306 .48093 L F
.32806 .5969 m .3306 .48093 L .3432 .48464 L F
.32806 .5969 m .3306 .48093 L .3432 .48464 L F
.3432 .48464 m .32806 .5969 L .3306 .48093 L F
.32806 .5969 m .3432 .48464 L .34086 .60026 L F
.3432 .48464 m .34086 .60026 L .32806 .5969 L F
.3306 .48093 m .32806 .5969 L .31659 .59303 L .956 0 0 r
F
.31659 .59303 m .3306 .48093 L .32806 .5969 L F
.3306 .48093 m .31659 .59303 L .31931 .47667 L F
.31659 .59303 m .31931 .47667 L .3306 .48093 L F
.31659 .59303 m .31931 .47667 L .3306 .48093 L F
.3306 .48093 m .31659 .59303 L .31931 .47667 L F
.31659 .59303 m .3306 .48093 L .32806 .5969 L F
.3306 .48093 m .32806 .5969 L .31659 .59303 L F
.43975 .42295 m .33099 .39998 L .32577 .63625 L p 0 .35 .741 r
F P
0 g
s
.33099 .39998 m .43975 .42295 L .5 .38214 L p 0 .442 1 r
F P
0 g
s
.5 .38214 m .38855 .35749 L .33099 .39998 L p 0 .442 1 r
F P
0 g
s
.33099 .39998 m .38855 .35749 L p .34141 .56683 L 0 .16 .674 r
F P
0 g
s
.32577 .63625 m .32711 .57583 L p .34141 .56683 L 0 .16 .674 r
F P
0 g
s
.32711 .57583 m .33099 .39998 L p .34141 .56683 L 0 .16 .674 r
F P
0 g
s
.25328 .62227 m .24971 .62451 L .24796 .62407 L .688 0 0 r
F
0 g
.2733 .63041 m
.2733 .63041 L
s
.2733 .63041 m
.30055 .63568 L
s
.24796 .62407 m
.2733 .63041 L
s
.24796 .62407 m
.24796 .62407 L
s
.24796 .62407 m
.2733 .63041 L
s
.60902 .6158 m .60744 .50177 L .61818 .49764 L .608 0 0 r
F
.59678 .61907 m .60744 .50177 L .60902 .6158 L .654 0 0 r
F
.60744 .50177 m .60902 .6158 L .59678 .61907 L F
.60744 .50177 m .60902 .6158 L .59678 .61907 L F
.61818 .49764 m .60902 .6158 L .60744 .50177 L .608 0 0 r
F
.61818 .49764 m .60902 .6158 L .60744 .50177 L F
.60902 .6158 m .60744 .50177 L .61818 .49764 L F
.59678 .61907 m .60744 .50177 L .60902 .6158 L .654 0 0 r
F
0 g
.59538 .50538 m
.60744 .50177 L
s
.79664 .47701 m .80111 .59334 L .79664 .47701 L .899 0 0 r
F
.73122 .62659 m .80111 .59334 L p .79664 .47701 L .532 0 0 r
F P
0 g
s
.79664 .47701 m .80111 .59334 L .69697 .57327 L p .899 0 0 r
F P
0 g
s
.80111 .59334 m .79664 .47701 L p .79664 .47701 L .532 0 0 r
F P
0 g
s
.80111 .59334 m .80111 .59334 L .79664 .47701 L .899 0 0 r
F
.80111 .59334 m .80111 .59334 L p .79664 .47701 L .532 0 0 r
F P
0 g
s
.69697 .57327 m .80111 .59334 L .79664 .47701 L .899 0 0 r
F
.69697 .57327 m .80111 .59334 L .73122 .62659 L p .688 0 0 r
F P
0 g
s
.73122 .62659 m .62931 .60787 L .69697 .57327 L p .688 0 0 r
F P
0 g
s
.61993 .61205 m .62931 .60787 L .73122 .62659 L .688 0 0 r
F
0 g
.73122 .62659 m
.73122 .62659 L
s
.73122 .62659 m
.73122 .62659 L
s
.80111 .59334 m .73122 .62659 L .62931 .60787 L p .688 0 0 r
F P
0 g
s
.73122 .62659 m
.73122 .62659 L
s
.80111 .59334 m .73122 .62659 L .62931 .60787 L p .688 0 0 r
F P
0 g
s
.73122 .62659 m
.73122 .62659 L
s
.73122 .62659 m .62931 .60787 L .69697 .57327 L p .688 0 0 r
F P
0 g
s
.69697 .57327 m .80111 .59334 L .73122 .62659 L p .688 0 0 r
F P
0 g
s
.61993 .61205 m .62931 .60787 L .73122 .62659 L .688 0 0 r
F
0 g
.73122 .62659 m
.73122 .62659 L
s
.73122 .62659 m
.73122 .62659 L
s
.73094 .62654 m
.73122 .62659 L
s
.73094 .62654 m
.73122 .62659 L
s
.61993 .61205 m .61818 .49764 L .62742 .49303 L .548 0 0 r
F
.60902 .6158 m .61818 .49764 L .61993 .61205 L .608 0 0 r
F
.61818 .49764 m .61993 .61205 L .60902 .6158 L F
.61818 .49764 m .61993 .61205 L .60902 .6158 L F
.62742 .49303 m .61993 .61205 L .61818 .49764 L .548 0 0 r
F
.62742 .49303 m .61993 .61205 L .61818 .49764 L F
.61993 .61205 m .61818 .49764 L .62742 .49303 L F
.60902 .6158 m .61818 .49764 L .61993 .61205 L .608 0 0 r
F
0 g
.60744 .50177 m
.61818 .49764 L
s
.55665 .6253 m
.56908 .62399 L
s
.31659 .59303 m .24796 .62407 L .22494 .61673 L .688 0 0 r
F
0 g
.24796 .62407 m
.24796 .62407 L
s
.24796 .62407 m
.24796 .62407 L
s
.24796 .62407 m
.2733 .63041 L
s
.31659 .59303 m .24796 .62407 L .22494 .61673 L .688 0 0 r
F
0 g
.22494 .61673 m
.24796 .62407 L
s
.22494 .61673 m
.22494 .61673 L
s
.22494 .61673 m
.24796 .62407 L
s
.30055 .63568 m
.32612 .6203 L
s
.30088 .63548 m
.32612 .6203 L
s
.30088 .63548 m
.32612 .6203 L
s
.56908 .62399 m
.58339 .62181 L
s
.20895 .49368 m .19202 .48367 L .18741 .59938 L 1 0 0 r
F
.18741 .59938 m .20895 .49368 L .19202 .48367 L F
.20895 .49368 m .18741 .59938 L .20463 .60847 L F
.18741 .59938 m .20463 .60847 L .20895 .49368 L F
.30138 .46672 m .20895 .49368 L .30951 .4719 L .71 0 0 r
F
.30138 .46672 m .19202 .48367 L .20895 .49368 L F
.30951 .4719 m .19202 .48367 L .20895 .49368 L F
.31931 .47667 m .30951 .4719 L .20895 .49368 L F
.18741 .59938 m .20463 .60847 L .20895 .49368 L 1 0 0 r
F
.20895 .49368 m .18741 .59938 L .20463 .60847 L F
.18741 .59938 m .20895 .49368 L .19202 .48367 L F
.20895 .49368 m .19202 .48367 L .18741 .59938 L F
.30951 .4719 m .19202 .48367 L .20895 .49368 L .71 0 0 r
F
.31931 .47667 m .30951 .4719 L .20895 .49368 L F
0 g
.20895 .49368 m
.22893 .50279 L
s
.30138 .46672 m .20895 .49368 L .30951 .4719 L .71 0 0 r
F
.30138 .46672 m .19202 .48367 L .20895 .49368 L F
.61993 .61205 m .62742 .49303 L .62931 .60787 L .548 0 0 r
F
.62931 .60787 m .62742 .49303 L .69399 .4549 L p .509 0 0 r
F P
0 g
s
.69399 .4549 m .69697 .57327 L .62931 .60787 L p .509 0 0 r
F P
0 g
s
.69697 .57327 m .62931 .60787 L .62742 .49303 L p .509 0 0 r
F P
0 g
s
.62742 .49303 m .69399 .4549 L .69697 .57327 L p .509 0 0 r
F P
0 g
s
.62742 .49303 m .62931 .60787 L .61993 .61205 L .548 0 0 r
F
.62742 .49303 m .62931 .60787 L .61993 .61205 L F
0 g
.61818 .49764 m
.62742 .49303 L
s
.62931 .60787 m
.73094 .62654 L
s
.62931 .60787 m
.73094 .62654 L
s
.61993 .61205 m .62742 .49303 L .62931 .60787 L .548 0 0 r
F
0 g
.62931 .60787 m
.62931 .60787 L
s
.62931 .60787 m .62742 .49303 L .69399 .4549 L p .509 0 0 r
F P
0 g
s
.62742 .49303 m
.62742 .49303 L
s
.58339 .62181 m
.59678 .61907 L
s
.59678 .61907 m
.60902 .6158 L
s
.32577 .63625 m .43792 .65515 L .43975 .42295 L p 0 .35 .741 r
F P
0 g
s
.30663 .58871 m .22494 .61673 L .20463 .60847 L .688 0 0 r
F
.30663 .58871 m .31659 .59303 L .22494 .61673 L F
0 g
.22494 .61673 m
.22494 .61673 L
s
.31659 .59303 m .22494 .61673 L .20463 .60847 L .688 0 0 r
F
0 g
.22494 .61673 m
.22494 .61673 L
s
.31659 .59303 m .22494 .61673 L .20463 .60847 L .688 0 0 r
F
0 g
.22494 .61673 m
.24796 .62407 L
s
.30663 .58871 m .22494 .61673 L .20463 .60847 L .688 0 0 r
F
0 g
.20463 .60847 m
.20463 .60847 L
s
.20463 .60847 m
.22494 .61673 L
s
.30663 .58871 m .31659 .59303 L .22494 .61673 L .688 0 0 r
F
0 g
.20463 .60847 m
.22494 .61673 L
s
.60902 .6158 m
.61993 .61205 L
s
.19202 .48367 m .17848 .47289 L .17362 .5896 L 1 0 0 r
F
.17362 .5896 m .19202 .48367 L .17848 .47289 L F
.19202 .48367 m .17362 .5896 L .18741 .59938 L F
.17362 .5896 m .18741 .59938 L .19202 .48367 L F
.29509 .46119 m .19202 .48367 L .30138 .46672 L .71 0 0 r
F
.29509 .46119 m .17848 .47289 L .19202 .48367 L F
.30138 .46672 m .17848 .47289 L .19202 .48367 L F
.30951 .4719 m .30138 .46672 L .19202 .48367 L F
.17362 .5896 m .18741 .59938 L .19202 .48367 L 1 0 0 r
F
.19202 .48367 m .17362 .5896 L .18741 .59938 L F
.17362 .5896 m .19202 .48367 L .17848 .47289 L F
.19202 .48367 m .17848 .47289 L .17362 .5896 L F
.30138 .46672 m .17848 .47289 L .19202 .48367 L .71 0 0 r
F
.30951 .4719 m .30138 .46672 L .19202 .48367 L F
0 g
.19202 .48367 m
.20895 .49368 L
s
.29509 .46119 m .19202 .48367 L .30138 .46672 L .71 0 0 r
F
.29509 .46119 m .17848 .47289 L .19202 .48367 L F
0 g
.61993 .61205 m
.62931 .60787 L
s
0 0 0 r
.34218 .39172 m
.34218 .39172 L
s
.34218 .39172 m
.34218 .39172 L
s
.45036 .5889 m
.45146 .41502 L
s
.32971 .45771 m
.32972 .45771 L
s
.32972 .45771 m
.32972 .45771 L
s
.29837 .584 m .20463 .60847 L .18741 .59938 L .688 0 0 r
F
.29837 .584 m .30663 .58871 L .20463 .60847 L F
0 g
.20463 .60847 m
.20463 .60847 L
s
.30663 .58871 m .20463 .60847 L .18741 .59938 L .688 0 0 r
F
.31659 .59303 m .20463 .60847 L .30663 .58871 L F
0 g
.20463 .60847 m
.20463 .60847 L
s
.30663 .58871 m .20463 .60847 L .18741 .59938 L .688 0 0 r
F
.31659 .59303 m .20463 .60847 L .30663 .58871 L F
0 g
.20463 .60847 m
.22494 .61673 L
s
.29837 .584 m .20463 .60847 L .18741 .59938 L .688 0 0 r
F
0 g
.18741 .59938 m
.20463 .60847 L
s
.29837 .584 m .30663 .58871 L .20463 .60847 L .688 0 0 r
F
0 g
.18741 .59938 m
.20463 .60847 L
s
.62931 .60787 m .69697 .57327 L .80111 .59334 L p .688 0 0 r
F P
0 g
s
.81364 .46664 m .79664 .47701 L .80111 .59334 L .493 0 0 r
F
.80111 .59334 m .81364 .46664 L .79664 .47701 L F
.69399 .4549 m .79664 .47701 L .81364 .46664 L .71 0 0 r
F
.69697 .57327 m .69399 .4549 L .79664 .47701 L p .899 0 0 r
F P
0 g
s
.79664 .47701 m
.79664 .47701 L
s
.62931 .60787 m .69697 .57327 L .80111 .59334 L p .688 0 0 r
F P
0 g
s
.62931 .60787 m
.73122 .62659 L
s
.62931 .60787 m
.62931 .60787 L
s
.62931 .60787 m
.62931 .60787 L
s
.69399 .4549 m .79664 .47701 L .80111 .59334 L p .899 0 0 r
F P
0 g
s
.69399 .4549 m .80111 .59334 L .79664 .47701 L .899 0 0 r
F
.80111 .59334 m .81364 .46664 L .79664 .47701 L .493 0 0 r
F
.81364 .46664 m .79664 .47701 L .80111 .59334 L F
.70213 .44953 m .79664 .47701 L .81364 .46664 L .71 0 0 r
F
.70213 .44953 m .69399 .4549 L .79664 .47701 L F
.69399 .4549 m .69697 .57327 L .62931 .60787 L p .509 0 0 r
F P
0 g
s
.62931 .60787 m
.62931 .60787 L
s
.62742 .49303 m
.62931 .60787 L
s
.62931 .60787 m
.62931 .60787 L
s
.80111 .59334 m .69697 .57327 L .69399 .4549 L p .899 0 0 r
F P
0 g
s
.69399 .4549 m .69697 .57327 L .80111 .59334 L .899 0 0 r
F
.69697 .57327 m .69399 .4549 L .79664 .47701 L p F P
0 g
s
.79664 .47701 m .80111 .59334 L .69697 .57327 L p .899 0 0 r
F P
0 g
s
.69399 .4549 m .80111 .59334 L .79664 .47701 L .899 0 0 r
F
.70213 .44953 m .79664 .47701 L .81364 .46664 L .71 0 0 r
F
.70213 .44953 m .69399 .4549 L .79664 .47701 L F
.54564 .6733 m .6103 .64105 L .60702 .40581 L p 0 .19 .704 r
F P
0 g
s
.54564 .6733 m .43792 .65515 L .5 .62156 L p 0 .453 1 r
F P
0 g
s
0 0 0 r
.45981 .65884 m
.45981 .65884 L
s
.45981 .65884 m
.45981 .65884 L
s
.48153 .6625 m
.48153 .6625 L
s
.48153 .6625 m
.48153 .6625 L
s
.5 .62156 m .6103 .64105 L .54564 .6733 L p 0 .453 1 r
F P
0 g
s
0 0 0 r
.52444 .66973 m
.52444 .66973 L
s
.52444 .66973 m
.52444 .66973 L
s
.50307 .66613 m
.50307 .66613 L
s
.50307 .66613 m
.50307 .66613 L
s
.55821 .66703 m
.55821 .66703 L
s
.55821 .66703 m
.55821 .66703 L
s
.57096 .66067 m
.57096 .66067 L
s
.57096 .66067 m
.57096 .66067 L
s
.58389 .65422 m
.58389 .65423 L
s
.58389 .65422 m
.58389 .65422 L
s
.597 .64768 m
.597 .64768 L
s
.597 .64768 m
.597 .64768 L
s
.69697 .57327 m .69399 .4549 L .69399 .4549 L .464 0 0 r
F
.69399 .4549 m .79664 .47701 L .80111 .59334 L p .899 0 0 r
F P
0 g
s
.69399 .4549 m .79664 .47701 L .81364 .46664 L .71 0 0 r
F
.69697 .57327 m .69399 .4549 L .69697 .57327 L .464 0 0 r
F
.69697 .57327 m .69697 .57327 L .69399 .4549 L .899 0 0 r
F
.69697 .57327 m .79664 .47701 L .69399 .4549 L F
.69697 .57327 m .69399 .4549 L .69399 .4549 L F
.69697 .57327 m .80111 .59334 L .79664 .47701 L F
.69399 .4549 m .81364 .46664 L .70213 .44953 L .71 0 0 r
F
.69399 .4549 m .81364 .46664 L .70213 .44953 L F
.69399 .4549 m .69697 .57327 L .80111 .59334 L .899 0 0 r
F
.80111 .59334 m .69697 .57327 L .69399 .4549 L p F P
0 g
s
.70213 .44953 m .70525 .56839 L .69697 .57327 L .464 0 0 r
F
.69697 .57327 m .70213 .44953 L .70525 .56839 L F
.70213 .44953 m .69697 .57327 L .69399 .4549 L F
.69697 .57327 m .69399 .4549 L .70213 .44953 L F
.31931 .47667 m .31659 .59303 L .30663 .58871 L .988 0 0 r
F
.30663 .58871 m .31931 .47667 L .31659 .59303 L F
.31931 .47667 m .30663 .58871 L .30951 .4719 L F
.30663 .58871 m .30951 .4719 L .31931 .47667 L F
.30663 .58871 m .30951 .4719 L .31931 .47667 L F
.31931 .47667 m .30663 .58871 L .30951 .4719 L F
.30663 .58871 m .31931 .47667 L .31659 .59303 L F
.31931 .47667 m .31659 .59303 L .30663 .58871 L F
0 g
.31931 .47667 m
.32922 .48041 L
s
.17848 .47289 m .16866 .46149 L .1636 .57926 L 1 0 0 r
F
.1636 .57926 m .17848 .47289 L .16866 .46149 L F
.1636 .57926 m .17848 .47289 L .16866 .46149 L F
.17848 .47289 m .1636 .57926 L .17362 .5896 L F
.1636 .57926 m .17362 .5896 L .17848 .47289 L F
.1636 .57926 m .17362 .5896 L .17848 .47289 L F
.29076 .45539 m .17848 .47289 L .29509 .46119 L .71 0 0 r
F
.29076 .45539 m .16866 .46149 L .17848 .47289 L F
.29509 .46119 m .16866 .46149 L .17848 .47289 L F
.30138 .46672 m .29509 .46119 L .17848 .47289 L F
.17848 .47289 m .1636 .57926 L .17362 .5896 L 1 0 0 r
F
.17848 .47289 m .16866 .46149 L .1636 .57926 L F
.29509 .46119 m .16866 .46149 L .17848 .47289 L .71 0 0 r
F
.30138 .46672 m .29509 .46119 L .17848 .47289 L F
0 g
.17848 .47289 m
.19202 .48367 L
s
.29076 .45539 m .17848 .47289 L .29509 .46119 L .71 0 0 r
F
.29076 .45539 m .16866 .46149 L .17848 .47289 L F
0 0 0 r
.52444 .66973 m
.52444 .66973 L
s
.35353 .38335 m
.35353 .38335 L
s
.35353 .38335 m
.35353 .38335 L
s
.30951 .4719 m .30663 .58871 L .29837 .584 L 1 0 0 r
F
.29837 .584 m .30951 .4719 L .30663 .58871 L F
.30951 .4719 m .29837 .584 L .30138 .46672 L F
.29837 .584 m .30138 .46672 L .30951 .4719 L F
.29837 .584 m .30138 .46672 L .30951 .4719 L F
.30951 .4719 m .29837 .584 L .30138 .46672 L F
.29837 .584 m .30951 .4719 L .30663 .58871 L F
.30951 .4719 m .30663 .58871 L .29837 .584 L F
0 g
.30951 .4719 m
.31931 .47667 L
s
0 0 0 r
.32842 .51632 m
.32842 .51632 L
s
.32842 .51632 m
.32842 .51632 L
s
.43792 .65515 m .5 .62156 L .5 .38214 L p 0 .177 .691 r
F P
0 g
s
.5 .38214 m .60702 .40581 L .6103 .64105 L p 0 .351 .737 r
F P
0 g
s
.67558 .42299 m .67423 .36375 L p .62431 .45349 L 0 .19 .704 r
F P
0 g
s
.67423 .36375 m .60702 .40581 L p .62431 .45349 L 0 .19 .704 r
F P
0 g
s
.67978 .6064 m .67558 .42299 L p .62431 .45349 L 0 .19 .704 r
F P
0 g
s
.60702 .40581 m .6103 .64105 L .67978 .6064 L p 0 .19 .704 r
F P
0 g
s
.38498 .60123 m .38855 .35749 L .5 .38214 L p 0 .351 .737 r
F P
0 g
s
.5 .38214 m .5 .62156 L .43792 .65515 L p 0 .177 .691 r
F P
0 g
s
.5 .38214 m .5 .62156 L .38498 .60123 L p 0 .351 .737 r
F P
0 g
s
.6103 .64105 m .60702 .40581 L .5 .38214 L p 0 .351 .737 r
F P
0 g
s
.5 .38214 m .60702 .40581 L .67423 .36375 L p 0 .442 1 r
F P
0 g
s
.67423 .36375 m .56469 .33832 L .5 .38214 L p 0 .442 1 r
F P
0 g
s
.56469 .33832 m .67423 .36375 L .67978 .6064 L p 0 .351 .733 r
F P
0 g
s
.67002 .39288 m .68238 .39721 L .77652 .36297 L .71 0 0 r
F
.77831 .3619 m .77652 .36297 L .78362 .36038 L F
.67002 .39288 m .77652 .36297 L .77831 .3619 L F
0 0 0 r
.55821 .66703 m
.55821 .66703 L
s
.50307 .66613 m
.50307 .66613 L
s
.29196 .57898 m .18741 .59938 L .17362 .5896 L .688 0 0 r
F
.29196 .57898 m .29837 .584 L .18741 .59938 L F
.29837 .584 m .18741 .59938 L .17362 .5896 L F
.30663 .58871 m .18741 .59938 L .29837 .584 L F
0 g
.18741 .59938 m
.18741 .59938 L
s
.29837 .584 m .18741 .59938 L .17362 .5896 L .688 0 0 r
F
.30663 .58871 m .18741 .59938 L .29837 .584 L F
0 g
.18741 .59938 m
.20463 .60847 L
s
.29196 .57898 m .18741 .59938 L .17362 .5896 L .688 0 0 r
F
0 g
.17362 .5896 m
.18741 .59938 L
s
.29196 .57898 m .29837 .584 L .18741 .59938 L .688 0 0 r
F
0 g
.18741 .59938 m
.18741 .59938 L
s
0 0 0 r
.65268 .35875 m
.65268 .35875 L
s
.65268 .35875 m
.65268 .35875 L
s
.30138 .46672 m .29837 .584 L .29196 .57898 L 1 0 0 r
F
.29196 .57898 m .30138 .46672 L .29837 .584 L F
.30138 .46672 m .29196 .57898 L .29509 .46119 L F
.29196 .57898 m .29509 .46119 L .30138 .46672 L F
.29196 .57898 m .29509 .46119 L .30138 .46672 L F
.30138 .46672 m .29196 .57898 L .29509 .46119 L F
.29196 .57898 m .30138 .46672 L .29837 .584 L F
.30138 .46672 m .29837 .584 L .29196 .57898 L F
0 g
.30138 .46672 m
.30951 .4719 L
s
.82718 .45548 m .81364 .46664 L .81841 .58393 L .389 0 0 r
F
.81841 .58393 m .82718 .45548 L .81364 .46664 L F
.70213 .44953 m .81364 .46664 L .82718 .45548 L .71 0 0 r
F
.81364 .46664 m .80111 .59334 L .81841 .58393 L .493 0 0 r
F
.80111 .59334 m .81841 .58393 L .81364 .46664 L F
0 g
.81364 .46664 m
.81364 .46664 L
s
.80111 .59334 m .81841 .58393 L .81364 .46664 L .493 0 0 r
F
.81364 .46664 m .80111 .59334 L .81841 .58393 L F
.81841 .58393 m .82718 .45548 L .81364 .46664 L .389 0 0 r
F
.82718 .45548 m .81364 .46664 L .81841 .58393 L F
.7084 .4438 m .81364 .46664 L .82718 .45548 L .71 0 0 r
F
.7084 .4438 m .70213 .44953 L .81364 .46664 L F
0 g
.79664 .47701 m
.81364 .46664 L
s
.7084 .4438 m .81364 .46664 L .82718 .45548 L .71 0 0 r
F
.7084 .4438 m .70213 .44953 L .81364 .46664 L F
.70213 .44953 m .81364 .46664 L .82718 .45548 L F
0 g
.70232 .45669 m
.79664 .47701 L
s
0 0 0 r
.36503 .37485 m
.36504 .37485 L
s
.36504 .37485 m
.36504 .37485 L
s
0 g
.31659 .59303 m
.32665 .59642 L
s
.31659 .59303 m
.31659 .59303 L
s
.31659 .59303 m
.32665 .59642 L
s
.31659 .59303 m
.32665 .59642 L
s
.31659 .59303 m
.31659 .59303 L
s
0 0 0 r
.48153 .6625 m
.48153 .6625 L
s
.3271 .57583 m
.32711 .57583 L
s
.32711 .57583 m
.32711 .57583 L
s
.67559 .42299 m
.67559 .42299 L
s
.67558 .423 m
.67559 .42299 L
s
.63096 .35371 m
.63096 .3537 L
s
.63096 .35371 m
.63096 .35371 L
s
.57096 .66067 m
.57096 .66067 L
s
.16866 .46149 m .16283 .44964 L .15762 .5685 L 1 0 0 r
F
.15762 .5685 m .16866 .46149 L .16283 .44964 L F
.15762 .5685 m .16866 .46149 L .16283 .44964 L F
.16866 .46149 m .15762 .5685 L .1636 .57926 L F
.15762 .5685 m .1636 .57926 L .16866 .46149 L F
.15762 .5685 m .1636 .57926 L .16866 .46149 L F
.2885 .44943 m .16866 .46149 L .29076 .45539 L .71 0 0 r
F
.2885 .44943 m .16283 .44964 L .16866 .46149 L F
0 g
.16866 .46149 m
.16866 .46149 L
s
.29076 .45539 m .16283 .44964 L .16866 .46149 L .71 0 0 r
F
.29509 .46119 m .29076 .45539 L .16866 .46149 L F
.16866 .46149 m .15762 .5685 L .1636 .57926 L 1 0 0 r
F
.16866 .46149 m .16283 .44964 L .15762 .5685 L F
.29076 .45539 m .16283 .44964 L .16866 .46149 L .71 0 0 r
F
.29509 .46119 m .29076 .45539 L .16866 .46149 L F
0 g
.16866 .46149 m
.17848 .47289 L
s
.2885 .44943 m .16866 .46149 L .29076 .45539 L .71 0 0 r
F
.2885 .44943 m .16283 .44964 L .16866 .46149 L F
.29509 .46119 m .29196 .57898 L .28755 .57372 L 1 0 0 r
F
.28755 .57372 m .29509 .46119 L .29196 .57898 L F
.28755 .57372 m .29509 .46119 L .29196 .57898 L F
.29509 .46119 m .28755 .57372 L .29076 .45539 L F
.28755 .57372 m .29076 .45539 L .29509 .46119 L F
.28755 .57372 m .29076 .45539 L .29509 .46119 L F
.29509 .46119 m .28755 .57372 L .29076 .45539 L F
.29509 .46119 m .29196 .57898 L .28755 .57372 L F
0 g
.29509 .46119 m
.30138 .46672 L
s
.69697 .57327 m .81841 .58393 L .80111 .59334 L .688 0 0 r
F
.70525 .56839 m .80111 .59334 L .69697 .57327 L F
.70525 .56839 m .81841 .58393 L .80111 .59334 L F
.70525 .56839 m .80111 .59334 L .69697 .57327 L F
.70525 .56839 m .81841 .58393 L .80111 .59334 L F
.69697 .57327 m .81841 .58393 L .80111 .59334 L F
0 g
.80111 .59334 m
.80111 .59334 L
s
.80111 .59334 m
.80111 .59334 L
s
.80111 .59334 m
.80111 .59334 L
s
.31659 .59303 m
.31659 .59303 L
s
.30663 .58871 m
.31659 .59303 L
s
.30663 .58871 m
.30663 .58871 L
s
.30663 .58871 m
.31659 .59303 L
s
.30663 .58871 m
.31659 .59303 L
s
.30663 .58871 m
.30663 .58871 L
s
0 0 0 r
.45981 .65884 m
.45981 .65884 L
s
.60905 .34862 m
.60905 .34862 L
s
.60905 .34862 m
.60905 .34862 L
s
.34218 .39172 m
.34218 .39172 L
s
.32971 .45771 m
.32972 .45771 L
s
.37671 .36623 m
.37671 .36623 L
s
.37671 .36623 m
.37671 .36623 L
s
.28755 .57372 m .17362 .5896 L .1636 .57926 L .688 0 0 r
F
.28755 .57372 m .29196 .57898 L .17362 .5896 L F
.29196 .57898 m .17362 .5896 L .1636 .57926 L F
.29837 .584 m .17362 .5896 L .29196 .57898 L F
0 g
.17362 .5896 m
.17362 .5896 L
s
.17362 .5896 m
.18741 .59938 L
s
.29196 .57898 m .17362 .5896 L .1636 .57926 L .688 0 0 r
F
.29837 .584 m .17362 .5896 L .29196 .57898 L F
0 g
.17362 .5896 m
.18741 .59938 L
s
.28755 .57372 m .17362 .5896 L .1636 .57926 L .688 0 0 r
F
0 g
.1636 .57926 m
.17362 .5896 L
s
.28755 .57372 m .29196 .57898 L .17362 .5896 L .688 0 0 r
F
.83694 .4437 m .82718 .45548 L .83221 .5738 L .227 0 0 r
F
.83221 .5738 m .83694 .4437 L .82718 .45548 L F
.7084 .4438 m .82718 .45548 L .83694 .4437 L .71 0 0 r
F
.82718 .45548 m .81841 .58393 L .83221 .5738 L .389 0 0 r
F
.81841 .58393 m .83221 .5738 L .82718 .45548 L F
.70213 .44953 m .82718 .45548 L .7084 .4438 L .71 0 0 r
F
0 g
.82718 .45548 m
.82718 .45548 L
s
.81841 .58393 m .83221 .5738 L .82718 .45548 L .389 0 0 r
F
.82718 .45548 m .81841 .58393 L .83221 .5738 L F
.83221 .5738 m .83694 .4437 L .82718 .45548 L .227 0 0 r
F
.83694 .4437 m .82718 .45548 L .83221 .5738 L F
.71268 .43782 m .82718 .45548 L .83694 .4437 L .71 0 0 r
F
.71268 .43782 m .7084 .4438 L .82718 .45548 L F
0 g
.81364 .46664 m
.82718 .45548 L
s
.71268 .43782 m .82718 .45548 L .83694 .4437 L .71 0 0 r
F
.71268 .43782 m .7084 .4438 L .82718 .45548 L F
.7084 .4438 m .82718 .45548 L .83694 .4437 L F
.70213 .44953 m .82718 .45548 L .7084 .4438 L F
.29076 .45539 m .28755 .57372 L .28523 .56831 L 1 0 0 r
F
.28523 .56831 m .29076 .45539 L .28755 .57372 L F
.28523 .56831 m .29076 .45539 L .28755 .57372 L F
.29076 .45539 m .2885 .44943 L .16283 .44964 L .71 0 0 r
F
.29076 .45539 m .2885 .44943 L .16283 .44964 L F
.29076 .45539 m .28523 .56831 L .2885 .44943 L 1 0 0 r
F
.28523 .56831 m .2885 .44943 L .29076 .45539 L F
.28523 .56831 m .2885 .44943 L .29076 .45539 L F
0 g
.29076 .45539 m
.29076 .45539 L
s
.29076 .45539 m .28523 .56831 L .2885 .44943 L 1 0 0 r
F
.29076 .45539 m .28755 .57372 L .28523 .56831 L F
0 g
.29076 .45539 m
.29509 .46119 L
s
.30663 .58871 m
.30663 .58871 L
s
.29837 .584 m
.30663 .58871 L
s
.29837 .584 m
.29837 .584 L
s
.29837 .584 m
.30663 .58871 L
s
.29837 .584 m
.30663 .58871 L
s
.29837 .584 m
.29837 .584 L
s
0 0 0 r
.67696 .48317 m
.67696 .48317 L
s
.67696 .48317 m
.67696 .48317 L
s
.69697 .57327 m .69399 .4549 L .70213 .44953 L .464 0 0 r
F
.70213 .44953 m .69697 .57327 L .69399 .4549 L F
0 g
.69399 .4549 m
.69399 .4549 L
s
.69399 .4549 m
.69503 .49626 L
s
.5 .62156 m .43792 .65515 L .32577 .63625 L p 0 .453 1 r
F P
0 g
s
0 0 0 r
.46222 .642 m
.57096 .66067 L
s
.46222 .642 m
.46222 .642 L
s
.46222 .642 m
.46222 .642 L
s
.44998 .64862 m
.55821 .66703 L
s
.44998 .64862 m
.44998 .64862 L
s
.44998 .64862 m
.44998 .64862 L
s
.34857 .64009 m
.34857 .64009 L
s
.34857 .64009 m
.34857 .64009 L
s
.46222 .642 m
.46222 .642 L
s
.46222 .642 m
.46222 .642 L
s
.37118 .64391 m
.37118 .6439 L
s
.37118 .6439 m
.37118 .6439 L
s
.44998 .64863 m
.44998 .64862 L
s
.45013 .62576 m
.45021 .61276 L
s
.44998 .64862 m
.44998 .64862 L
s
.39361 .64768 m
.39361 .64768 L
s
.39361 .64768 m
.39361 .64768 L
s
.41586 .65143 m
.41586 .65143 L
s
.41586 .65143 m
.41586 .65143 L
s
.58389 .65423 m
.58389 .65423 L
s
.58696 .34349 m
.58696 .34349 L
s
.58696 .34349 m
.58696 .34349 L
s
.41586 .65143 m
.41586 .65143 L
s
.35353 .38335 m
.35353 .38335 L
s
0 g
.29196 .57898 m
.29837 .584 L
s
.70525 .56839 m .83221 .5738 L .81841 .58393 L .688 0 0 r
F
.69697 .57327 m .70525 .56839 L .81841 .58393 L F
0 g
.80111 .59334 m
.81841 .58393 L
s
.71164 .5632 m .81841 .58393 L .70525 .56839 L .688 0 0 r
F
.71164 .5632 m .83221 .5738 L .81841 .58393 L F
0 g
.80111 .59334 m
.81841 .58393 L
s
.71164 .5632 m .81841 .58393 L .70525 .56839 L .688 0 0 r
F
.71164 .5632 m .83221 .5738 L .81841 .58393 L F
.70525 .56839 m .83221 .5738 L .81841 .58393 L F
.69697 .57327 m .70525 .56839 L .81841 .58393 L F
0 g
.69697 .57327 m
.69697 .57327 L
s
.16283 .44964 m .16122 .43752 L .15593 .55749 L .963 0 0 r
F
.15593 .55749 m .16283 .44964 L .16122 .43752 L F
.15593 .55749 m .16283 .44964 L .16122 .43752 L F
.16283 .44964 m .15593 .55749 L .15762 .5685 L F
.15593 .55749 m .15762 .5685 L .16283 .44964 L F
.15593 .55749 m .15762 .5685 L .16283 .44964 L F
.28837 .44341 m .16283 .44964 L .2885 .44943 L .71 0 0 r
F
.28837 .44341 m .16122 .43752 L .16283 .44964 L F
0 g
.16283 .44964 m
.16283 .44964 L
s
.2885 .44943 m .16122 .43752 L .16283 .44964 L .71 0 0 r
F
.16283 .44964 m .15593 .55749 L .15762 .5685 L .963 0 0 r
F
.16283 .44964 m .16122 .43752 L .15593 .55749 L F
.2885 .44943 m .16122 .43752 L .16283 .44964 L .71 0 0 r
F
0 g
.16283 .44964 m
.16866 .46149 L
s
.28837 .44341 m .16283 .44964 L .2885 .44943 L .71 0 0 r
F
.28837 .44341 m .16122 .43752 L .16283 .44964 L F
.7084 .4438 m .70525 .56839 L .70213 .44953 L .342 0 0 r
F
.70525 .56839 m .70213 .44953 L .7084 .4438 L F
0 g
.70213 .44953 m
.70213 .44953 L
s
.69697 .57327 m .70213 .44953 L .70525 .56839 L .464 0 0 r
F
.70213 .44953 m .70525 .56839 L .69697 .57327 L F
0 g
.69503 .49626 m
.69697 .57327 L
s
.70525 .56839 m .70213 .44953 L .7084 .4438 L .342 0 0 r
F
.7084 .4438 m .70525 .56839 L .70213 .44953 L F
0 g
.69399 .4549 m
.70213 .44953 L
s
.2885 .44943 m .28523 .56831 L .28508 .56284 L .856 0 0 r
F
.28508 .56284 m .2885 .44943 L .28523 .56831 L F
.28508 .56284 m .2885 .44943 L .28523 .56831 L F
.2885 .44943 m .28837 .44341 L .16122 .43752 L .71 0 0 r
F
.2885 .44943 m .28837 .44341 L .16122 .43752 L F
.2885 .44943 m .28508 .56284 L .28837 .44341 L .856 0 0 r
F
.28508 .56284 m .28837 .44341 L .2885 .44943 L F
.28508 .56284 m .28837 .44341 L .2885 .44943 L F
0 g
.2885 .44943 m
.2885 .44943 L
s
.2885 .44943 m .28508 .56284 L .28837 .44341 L .856 0 0 r
F
.2885 .44943 m .28523 .56831 L .28508 .56284 L F
0 g
.2885 .44943 m
.29076 .45539 L
s
0 0 0 r
.32842 .51632 m
.32842 .51632 L
s
.6103 .64105 m .5 .62156 L .5 .38214 L p 0 .351 .737 r
F P
0 g
s
.38498 .60123 m .5 .62156 L .5 .38214 L p 0 .351 .737 r
F P
0 g
s
0 0 0 r
.4623 .62474 m
.46235 .6149 L
s
.47467 .62369 m
.47469 .61708 L
s
.5 .38214 m .38855 .35749 L .38498 .60123 L p 0 .351 .737 r
F P
0 g
s
0 0 0 r
.5 .56031 m
.5 .56031 L
s
.5 .5 m
.5 .5 L
s
.5 .44062 m
.5 .44062 L
s
.5 .38214 m .5 .62156 L .6103 .64105 L p 0 .351 .737 r
F P
0 g
s
.56469 .33832 m .5 .38214 L p .51586 .4304 L 0 .177 .691 r
F P
0 g
s
.5652 .39862 m .56469 .33832 L p .51586 .4304 L 0 .177 .691 r
F P
0 g
s
.5 .38214 m .56469 .33832 L .5652 .39862 L p 0 .177 .691 r
F P
0 g
s
.51586 .4304 m .54923 .53195 L .5652 .39862 L 0 .177 .691 r
F
.56679 .58541 m .56625 .52214 L p .54923 .53195 L F P
0 g
s
.56625 .52214 m .5652 .39862 L p .54923 .53195 L 0 .177 .691 r
F P
0 g
s
.5652 .39862 m .56625 .52214 L p .51586 .4304 L 0 .177 .691 r
F P
0 g
s
.56625 .52214 m .56679 .58541 L p .54923 .53195 L 0 .177 .691 r
F P
0 g
s
.51586 .4304 m .56625 .52214 L .54923 .53195 L 0 .177 .691 r
F
.7084 .4438 m .83694 .4437 L .71268 .43782 L .71 0 0 r
F
.7084 .4438 m .83694 .4437 L .71268 .43782 L F
.71268 .43782 m .71164 .5632 L .7084 .4438 L .147 0 0 r
F
.71164 .5632 m .7084 .4438 L .71268 .43782 L F
.7084 .4438 m .71164 .5632 L .70525 .56839 L .342 0 0 r
F
.70525 .56839 m .7084 .4438 L .71164 .5632 L F
.70525 .56839 m .7084 .4438 L .71164 .5632 L F
.7084 .4438 m .71164 .5632 L .70525 .56839 L F
.71164 .5632 m .7084 .4438 L .71268 .43782 L .147 0 0 r
F
.71268 .43782 m .71164 .5632 L .7084 .4438 L F
.71268 .43782 m .83694 .4437 L .84263 .43145 L .71 0 0 r
F
.71485 .43166 m .71268 .43782 L .83694 .4437 L F
.71485 .43166 m .71268 .43782 L .83694 .4437 L F
.71268 .43782 m .83694 .4437 L .84263 .43145 L F
.71268 .43782 m .84263 .43145 L .71485 .43166 L F
.71268 .43782 m .84263 .43145 L .71485 .43166 L F
.71485 .43166 m .716 .55776 L .71268 .43782 L .1 0 0 r
F
.716 .55776 m .71268 .43782 L .71485 .43166 L F
.71268 .43782 m .716 .55776 L .71164 .5632 L .147 0 0 r
F
.71164 .5632 m .71268 .43782 L .716 .55776 L F
.71164 .5632 m .71268 .43782 L .716 .55776 L F
.71268 .43782 m .716 .55776 L .71164 .5632 L F
.716 .55776 m .71268 .43782 L .71485 .43166 L .1 0 0 r
F
.71485 .43166 m .716 .55776 L .71268 .43782 L F
.71485 .43166 m .83694 .4437 L .84263 .43145 L .71 0 0 r
F
.71485 .43166 m .83694 .4437 L .84263 .43145 L F
.71485 .43166 m .84403 .41895 L .71485 .42545 L F
.71485 .43166 m .84263 .43145 L .84403 .41895 L F
.71485 .42545 m .71485 .43166 L .84263 .43145 L F
.71485 .42545 m .71485 .43166 L .84263 .43145 L F
.71485 .43166 m .84403 .41895 L .71485 .42545 L F
.71485 .43166 m .84263 .43145 L .84403 .41895 L F
.71485 .42545 m .71822 .55217 L .71485 .43166 L .1 0 0 r
F
.71822 .55217 m .71485 .43166 L .71485 .42545 L F
.71485 .43166 m .71822 .55217 L .716 .55776 L F
.716 .55776 m .71485 .43166 L .71822 .55217 L F
.716 .55776 m .71485 .43166 L .71822 .55217 L F
.71485 .43166 m .71822 .55217 L .716 .55776 L F
.71822 .55217 m .71485 .43166 L .71485 .42545 L F
.71485 .42545 m .71822 .55217 L .71485 .43166 L F
.71485 .42545 m .71824 .54652 L .71822 .55217 L F
.71822 .55217 m .71485 .42545 L .71824 .54652 L F
.71822 .55217 m .71485 .42545 L .71824 .54652 L F
.71485 .42545 m .71824 .54652 L .71822 .55217 L F
.71263 .41928 m .71824 .54652 L .71485 .42545 L 1 0 0 r
F
.71824 .54652 m .71485 .42545 L .71263 .41928 L F
.71824 .54652 m .71485 .42545 L .71263 .41928 L F
.71263 .41928 m .71824 .54652 L .71485 .42545 L F
.70821 .41326 m .71601 .54092 L .71263 .41928 L F
.71601 .54092 m .71263 .41928 L .70821 .41326 L F
.71263 .41928 m .71601 .54092 L .71824 .54652 L F
.71824 .54652 m .71263 .41928 L .71601 .54092 L F
.71824 .54652 m .71263 .41928 L .71601 .54092 L F
.71263 .41928 m .71601 .54092 L .71824 .54652 L F
.71601 .54092 m .71263 .41928 L .70821 .41326 L F
.70821 .41326 m .71601 .54092 L .71263 .41928 L F
.70163 .4075 m .71153 .53545 L .70821 .41326 L F
.71153 .53545 m .70821 .41326 L .70163 .4075 L F
.70821 .41326 m .71153 .53545 L .71601 .54092 L F
.71601 .54092 m .70821 .41326 L .71153 .53545 L F
.71601 .54092 m .70821 .41326 L .71153 .53545 L F
.70821 .41326 m .71153 .53545 L .71601 .54092 L F
.71153 .53545 m .70821 .41326 L .70163 .4075 L F
.70163 .4075 m .71153 .53545 L .70821 .41326 L F
.67978 .6064 m .56679 .58541 L .56469 .33832 L p 0 .351 .733 r
F P
0 g
s
.69298 .40212 m .70487 .53021 L .70163 .4075 L 1 0 0 r
F
.70487 .53021 m .70163 .4075 L .69298 .40212 L F
.70163 .4075 m .70487 .53021 L .71153 .53545 L F
.71153 .53545 m .70163 .4075 L .70487 .53021 L F
.71153 .53545 m .70163 .4075 L .70487 .53021 L F
.70163 .4075 m .70487 .53021 L .71153 .53545 L F
.70487 .53021 m .70163 .4075 L .69298 .40212 L F
.69298 .40212 m .70487 .53021 L .70163 .4075 L F
.68238 .39721 m .69609 .52532 L .69298 .40212 L .984 0 0 r
F
.69609 .52532 m .69298 .40212 L .68238 .39721 L F
.69298 .40212 m .69609 .52532 L .70487 .53021 L 1 0 0 r
F
.70487 .53021 m .69298 .40212 L .69609 .52532 L F
.70487 .53021 m .69298 .40212 L .69609 .52532 L F
.69298 .40212 m .69609 .52532 L .70487 .53021 L F
.69609 .52532 m .69298 .40212 L .68238 .39721 L .984 0 0 r
F
.68238 .39721 m .69609 .52532 L .69298 .40212 L F
.67002 .39288 m .68533 .52086 L .68238 .39721 L .949 0 0 r
F
.68533 .52086 m .68238 .39721 L .67002 .39288 L F
.68238 .39721 m .68533 .52086 L .69609 .52532 L .984 0 0 r
F
.69609 .52532 m .68238 .39721 L .68533 .52086 L F
.69609 .52532 m .68238 .39721 L .68533 .52086 L F
.68238 .39721 m .68533 .52086 L .69609 .52532 L F
.68533 .52086 m .68238 .39721 L .67002 .39288 L .949 0 0 r
F
.67002 .39288 m .68533 .52086 L .68238 .39721 L F
.65609 .38922 m .67278 .51692 L .67002 .39288 L .917 0 0 r
F
.67278 .51692 m .67002 .39288 L .65609 .38922 L F
.67002 .39288 m .67278 .51692 L .68533 .52086 L .949 0 0 r
F
.68533 .52086 m .67002 .39288 L .67278 .51692 L F
.68533 .52086 m .67002 .39288 L .67278 .51692 L F
.67002 .39288 m .67278 .51692 L .68533 .52086 L F
.67278 .51692 m .67002 .39288 L .65609 .38922 L .917 0 0 r
F
.65609 .38922 m .65864 .51359 L .67278 .51692 L F
.67278 .51692 m .65609 .38922 L .65864 .51359 L F
.65864 .51359 m .65609 .38922 L .65609 .38922 L .481 0 0 r
F
.65609 .38922 m .67278 .51692 L .67002 .39288 L .917 0 0 r
F
.70821 .41326 m .82115 .38207 L .70163 .4075 L .71 0 0 r
F
.70163 .4075 m .70821 .41326 L .83333 .39402 L F
.70163 .4075 m .70821 .41326 L .83333 .39402 L F
.70821 .41326 m .82115 .38207 L .70163 .4075 L F
.70163 .4075 m .80451 .37077 L .69298 .40212 L F
.70163 .4075 m .82115 .38207 L .80451 .37077 L F
.70163 .4075 m .83333 .39402 L .82115 .38207 L F
.69298 .40212 m .70163 .4075 L .82115 .38207 L F
.70163 .4075 m .83333 .39402 L .82115 .38207 L F
.69298 .40212 m .70163 .4075 L .82115 .38207 L F
.70163 .4075 m .80451 .37077 L .69298 .40212 L F
.70163 .4075 m .82115 .38207 L .80451 .37077 L F
.69298 .40212 m .78362 .36038 L .68238 .39721 L F
.69298 .40212 m .80451 .37077 L .78362 .36038 L F
.69298 .40212 m .82115 .38207 L .80451 .37077 L F
.68238 .39721 m .69298 .40212 L .80451 .37077 L F
.69298 .40212 m .82115 .38207 L .80451 .37077 L F
.68238 .39721 m .69298 .40212 L .80451 .37077 L F
.69298 .40212 m .78362 .36038 L .68238 .39721 L F
.69298 .40212 m .80451 .37077 L .78362 .36038 L F
.68238 .39721 m .75878 .35114 L .67002 .39288 L F
.68238 .39721 m .78362 .36038 L .75878 .35114 L F
.68238 .39721 m .80451 .37077 L .78362 .36038 L F
.68238 .39721 m .80451 .37077 L .78362 .36038 L F
.67002 .39288 m .68238 .39721 L .78362 .36038 L F
.68238 .39721 m .75878 .35114 L .67002 .39288 L F
.68238 .39721 m .78362 .36038 L .75878 .35114 L F
.67002 .39288 m .73043 .34324 L .65609 .38922 L F
.67002 .39288 m .75878 .35114 L .73043 .34324 L F
.67002 .39288 m .78362 .36038 L .75878 .35114 L F
.65609 .38922 m .67002 .39288 L .75878 .35114 L F
.67002 .39288 m .78362 .36038 L .75878 .35114 L F
.65609 .38922 m .67002 .39288 L .75878 .35114 L F
.67002 .39288 m .73043 .34324 L .65609 .38922 L F
.67002 .39288 m .75878 .35114 L .73043 .34324 L F
.65609 .38922 m .75878 .35114 L .73043 .34324 L F
.65864 .51359 m .65609 .38922 L .65864 .51359 L .481 0 0 r
F
.65609 .38922 m .65864 .51359 L .65864 .51359 L p F P
0 g
s
.65864 .51359 m .65609 .38922 L .65864 .51359 L .917 0 0 r
F
.67278 .51692 m .65609 .38922 L .65864 .51359 L F
.65609 .38922 m .65864 .51359 L .65609 .38922 L .481 0 0 r
F
.65609 .38922 m .65609 .38922 L .65864 .51359 L .917 0 0 r
F
.65609 .38922 m .65864 .51359 L .67278 .51692 L F
.65864 .51359 m .73433 .47175 L p .65609 .38922 L .481 0 0 r
F P
0 g
s
.65609 .38922 m .75878 .35114 L .73043 .34324 L .71 0 0 r
F
.65864 .51359 m .65609 .38922 L .73043 .34324 L .481 0 0 r
F
.5 .38214 m .5652 .39862 L .51586 .4304 L 0 .177 .691 r
F
.5 .38214 m .5 .62156 L .56679 .58541 L p F P
0 g
s
.56679 .58541 m .5 .62156 L .5 .38214 L p 0 .177 .691 r
F P
0 g
s
.56469 .33832 m .56679 .58541 L .44879 .5635 L p 0 .351 .733 r
F P
0 g
s
.54267 .49008 m .65864 .51359 L .65609 .38922 L p .903 0 0 r
F P
0 g
s
.65609 .38922 m .73433 .47175 L .65864 .51359 L .481 0 0 r
F
.73043 .34324 m .65609 .38922 L .65864 .51359 L p F P
0 g
s
.71485 .42545 m .84263 .43145 L .84403 .41895 L .71 0 0 r
F
.71485 .42545 m .84263 .43145 L .84403 .41895 L F
.71485 .42545 m .84096 .40639 L .71263 .41928 L F
.71485 .42545 m .84403 .41895 L .84096 .40639 L F
.71263 .41928 m .71485 .42545 L .84403 .41895 L F
.71263 .41928 m .71485 .42545 L .84403 .41895 L F
.71485 .42545 m .84096 .40639 L .71263 .41928 L F
.71485 .42545 m .84403 .41895 L .84096 .40639 L F
.71263 .41928 m .83333 .39402 L .70821 .41326 L F
.71263 .41928 m .84096 .40639 L .83333 .39402 L F
.71263 .41928 m .84403 .41895 L .84096 .40639 L F
.70821 .41326 m .71263 .41928 L .84096 .40639 L F
.71263 .41928 m .84403 .41895 L .84096 .40639 L F
.70821 .41326 m .71263 .41928 L .84096 .40639 L F
.71263 .41928 m .83333 .39402 L .70821 .41326 L F
.71263 .41928 m .84096 .40639 L .83333 .39402 L F
.70821 .41326 m .83333 .39402 L .82115 .38207 L F
.70821 .41326 m .84096 .40639 L .83333 .39402 L F
.70821 .41326 m .84096 .40639 L .83333 .39402 L F
.70821 .41326 m .83333 .39402 L .82115 .38207 L F
.65864 .51359 m .73043 .34324 L .73433 .47175 L .481 0 0 r
F
.65864 .51359 m .73433 .47175 L .73043 .34324 L p F P
0 g
s
.65609 .38922 m .65864 .51359 L .73433 .47175 L p .481 0 0 r
F P
0 g
s
.45044 .31181 m .38855 .35749 L .5 .38214 L p 0 .442 1 r
F P
0 g
s
.5 .38214 m .56469 .33832 L .45044 .31181 L p 0 .442 1 r
F P
0 g
s
.44879 .5635 m .45044 .31181 L .56469 .33832 L p 0 .351 .733 r
F P
0 g
s
.65864 .51359 m .65609 .38922 L .54197 .36338 L p .903 0 0 r
F P
0 g
s
.65609 .38922 m .73433 .47175 L .65864 .51359 L .481 0 0 r
F
.54197 .36338 m .54267 .49008 L .65864 .51359 L p .903 0 0 r
F P
0 g
s
.54267 .49008 m .65864 .51359 L .65609 .38922 L p .903 0 0 r
F P
0 g
s
.73433 .47175 m .73043 .34324 L .65609 .38922 L p .481 0 0 r
F P
0 g
s
.65609 .38922 m .73043 .34324 L .73433 .47175 L .481 0 0 r
F
.65864 .51359 m .65609 .38922 L .73043 .34324 L F
.59965 .37644 m .65609 .38922 L p .63543 .35339 L .71 0 0 r
F P
0 g
s
.63543 .35339 m .61347 .31534 L .59965 .37644 L .71 0 0 r
F
.65609 .38922 m .54197 .36338 L .54267 .49008 L p .903 0 0 r
F P
0 g
s
.65609 .38922 m .73043 .34324 L .61347 .31534 L p .71 0 0 r
F P
0 g
s
.73433 .47175 m .73043 .34324 L .65609 .38922 L p .481 0 0 r
F P
0 g
s
.54197 .36338 m .65609 .38922 L .73043 .34324 L p .71 0 0 r
F P
0 g
s
.65609 .38922 m .73043 .34324 L .73433 .47175 L .481 0 0 r
F
.65609 .38922 m .54197 .36338 L .54267 .49008 L p .903 0 0 r
F P
0 g
s
.54197 .36338 m .65609 .38922 L .73043 .34324 L p .71 0 0 r
F P
0 g
s
.65864 .51359 m .65609 .38922 L .54197 .36338 L p .903 0 0 r
F P
0 g
s
.54267 .49008 m .54197 .36338 L p .54197 .36338 L .449 0 0 r
F P
0 g
s
.54267 .49008 m .54267 .49008 L p .54197 .36338 L .449 0 0 r
F P
0 g
s
.54267 .49008 m .54267 .49008 L .54197 .36338 L .449 0 0 r
F
.54267 .49008 m .54197 .36338 L .54197 .36338 L F
.54267 .49008 m .54197 .36338 L .52613 .36032 L .89 0 0 r
F
.52613 .36032 m .54267 .49008 L .54197 .36338 L F
.52613 .36032 m .54267 .49008 L .54197 .36338 L F
.54197 .36338 m .54267 .49008 L .54267 .49008 L p .903 0 0 r
F P
0 g
s
.54267 .49008 m .65864 .51359 L p .54197 .36338 L .903 0 0 r
F P
0 g
s
.54197 .36338 m .54267 .49008 L .54197 .36338 L .903 0 0 r
F
.61347 .31534 m .54197 .36338 L .59965 .37644 L p .71 0 0 r
F P
0 g
s
.61347 .31534 m .54197 .36338 L .65609 .38922 L p .71 0 0 r
F P
0 g
s
.73043 .34324 m .61347 .31534 L .54197 .36338 L p .71 0 0 r
F P
0 g
s
.73043 .34324 m .61347 .31534 L .54197 .36338 L p .71 0 0 r
F P
0 g
s
.54267 .49008 m .61347 .31534 L .54197 .36338 L .449 0 0 r
F
.61543 .44633 m .54267 .49008 L p .54197 .36338 L F P
0 g
s
.73043 .34324 m .65609 .38922 L .65864 .51359 L p .481 0 0 r
F P
0 g
s
.73043 .34324 m .76314 .47893 L .73433 .47175 L .923 0 0 r
F
.73043 .34324 m .73433 .47175 L .73433 .47175 L p .908 0 0 r
F P
0 g
s
.73043 .34324 m .73433 .47175 L .73043 .34324 L .908 0 0 r
F
.65864 .51359 m .73043 .34324 L .73433 .47175 L .481 0 0 r
F
.65864 .51359 m .73433 .47175 L .73043 .34324 L p F P
0 g
s
.73433 .47175 m .61543 .44633 L p .73043 .34324 L .908 0 0 r
F P
0 g
s
.65609 .38922 m .73043 .34324 L .61347 .31534 L p .71 0 0 r
F P
0 g
s
.61543 .44633 m .61347 .31534 L .73043 .34324 L p .908 0 0 r
F P
0 g
s
.73433 .47175 m .65864 .51359 L .60129 .50196 L p .688 0 0 r
F P
0 g
s
.60129 .50196 m .54267 .49008 L p .6377 .48099 L .688 0 0 r
F P
0 g
s
.6377 .48099 m .73433 .47175 L .60129 .50196 L .688 0 0 r
F
.54267 .49008 m .61543 .44633 L p .6377 .48099 L F P
0 g
s
.65864 .51359 m .60129 .50196 L p .6377 .48099 L .688 0 0 r
F P
0 g
s
.60129 .50196 m .54267 .49008 L p .6377 .48099 L .688 0 0 r
F P
0 g
s
0 0 0 r
.44998 .64862 m
.44998 .64863 L
s
.67836 .5443 m
.67836 .5443 L
s
.67836 .5443 m
.67836 .5443 L
s
.39361 .64768 m
.39361 .64768 L
s
.597 .64768 m
.597 .64768 L
s
.54222 .33311 m
.54223 .33311 L
s
.54222 .33311 m
.54222 .33311 L
s
.28523 .56831 m .1636 .57926 L .15762 .5685 L .688 0 0 r
F
.28523 .56831 m .28755 .57372 L .1636 .57926 L F
0 g
.1636 .57926 m
.17362 .5896 L
s
.28755 .57372 m .1636 .57926 L .15762 .5685 L .688 0 0 r
F
.29196 .57898 m .1636 .57926 L .28755 .57372 L F
0 g
.1636 .57926 m
.1636 .57926 L
s
.28755 .57372 m .1636 .57926 L .15762 .5685 L .688 0 0 r
F
.29196 .57898 m .1636 .57926 L .28755 .57372 L F
0 g
.1636 .57926 m
.17362 .5896 L
s
.29196 .57898 m
.29196 .57898 L
s
.29196 .57898 m
.29837 .584 L
s
.29196 .57898 m
.29837 .584 L
s
.28523 .56831 m .1636 .57926 L .15762 .5685 L .688 0 0 r
F
.28523 .56831 m .28755 .57372 L .1636 .57926 L F
0 g
.28755 .57372 m
.29196 .57898 L
s
.28755 .57372 m
.29196 .57898 L
s
.84263 .43145 m .83694 .4437 L .84217 .5631 L .1 0 0 r
F
.84217 .5631 m .84263 .43145 L .83694 .4437 L F
.83694 .4437 m .83221 .5738 L .84217 .5631 L .227 0 0 r
F
.83221 .5738 m .84217 .5631 L .83694 .4437 L F
0 g
.83694 .4437 m
.83694 .4437 L
s
.83221 .5738 m .84217 .5631 L .83694 .4437 L .227 0 0 r
F
.83694 .4437 m .83221 .5738 L .84217 .5631 L F
.84217 .5631 m .84263 .43145 L .83694 .4437 L .1 0 0 r
F
.84263 .43145 m .83694 .4437 L .84217 .5631 L F
0 g
.82718 .45548 m
.83694 .4437 L
s
.28837 .44341 m .28508 .56284 L .28715 .5574 L .1 0 0 r
F
.28715 .5574 m .28837 .44341 L .28508 .56284 L F
0 g
.28837 .44341 m
.28837 .44341 L
s
.28837 .44341 m
.28837 .44341 L
s
.28837 .44341 m
.28837 .44341 L
s
.28837 .44341 m
.28837 .44341 L
s
.28837 .44341 m
.28837 .44341 L
s
.28837 .44341 m .28715 .5574 L .29042 .43742 L .1 0 0 r
F
.28715 .5574 m .29042 .43742 L .28837 .44341 L F
.29042 .43742 m .16122 .43752 L .28837 .44341 L .71 0 0 r
F
.28715 .5574 m .29042 .43742 L .28837 .44341 L .1 0 0 r
F
.28837 .44341 m .28715 .5574 L .29042 .43742 L F
.28715 .5574 m .28837 .44341 L .28508 .56284 L F
.28837 .44341 m .28508 .56284 L .28715 .5574 L F
.28837 .44341 m .16399 .42535 L .16122 .43752 L .71 0 0 r
F
.28837 .44341 m .29042 .43742 L .16399 .42535 L F
.28837 .44341 m .16399 .42535 L .16122 .43752 L F
.28837 .44341 m .29042 .43742 L .16399 .42535 L F
.29042 .43742 m .16122 .43752 L .28837 .44341 L F
0 g
.28837 .44341 m
.28837 .44341 L
s
0 0 0 r
.36503 .37485 m
.36503 .37485 L
s
.37118 .64391 m
.37118 .6439 L
s
.3271 .57583 m
.32711 .57583 L
s
.51957 .32785 m
.51957 .32785 L
s
.51957 .32785 m
.51957 .32785 L
s
.46222 .642 m
.46222 .642 L
s
.71164 .5632 m .84217 .5631 L .83221 .5738 L .688 0 0 r
F
.70525 .56839 m .71164 .5632 L .83221 .5738 L F
0 g
.81841 .58393 m
.83221 .5738 L
s
.716 .55776 m .83221 .5738 L .71164 .5632 L .688 0 0 r
F
.716 .55776 m .84217 .5631 L .83221 .5738 L F
0 g
.81841 .58393 m
.83221 .5738 L
s
.716 .55776 m .83221 .5738 L .71164 .5632 L .688 0 0 r
F
.716 .55776 m .84217 .5631 L .83221 .5738 L F
.71164 .5632 m .84217 .5631 L .83221 .5738 L F
.70525 .56839 m .71164 .5632 L .83221 .5738 L F
0 g
.69697 .57327 m
.80111 .59334 L
s
.69697 .57327 m
.80111 .59334 L
s
.28755 .57372 m .15762 .5685 L .28523 .56831 L .688 0 0 r
F
0 g
.28755 .57372 m
.28755 .57372 L
s
.28755 .57372 m .15762 .5685 L .28523 .56831 L .688 0 0 r
F
0 g
.15762 .5685 m
.1636 .57926 L
s
.15762 .5685 m
.1636 .57926 L
s
.28755 .57372 m
.29196 .57898 L
s
.69697 .57327 m
.70525 .56839 L
s
.69697 .57327 m
.70525 .56839 L
s
.69697 .57327 m
.69697 .57327 L
s
.67978 .6064 m .6103 .64105 L .5 .62156 L p 0 .453 1 r
F P
0 g
s
0 0 0 r
.52444 .66973 m
.58861 .63722 L
s
.58861 .63722 m
.58861 .63722 L
s
.58861 .63722 m
.58861 .63722 L
s
.56673 .63335 m
.56673 .63335 L
s
.56673 .63335 m
.56673 .63335 L
s
.50307 .66613 m
.56673 .63335 L
s
.58861 .63721 m
.58861 .63722 L
s
.58861 .63721 m
.58861 .63722 L
s
.58807 .58936 m
.58835 .61411 L
s
.54467 .62945 m
.54467 .62945 L
s
.54467 .62945 m
.54467 .62945 L
s
.56673 .63335 m
.56673 .63335 L
s
.56673 .63335 m
.56673 .63335 L
s
.52243 .62552 m
.52243 .62552 L
s
.52243 .62552 m
.52243 .62552 L
s
.54467 .62945 m
.54467 .62945 L
s
.54467 .62945 m
.54467 .62945 L
s
.52243 .62552 m
.52243 .62552 L
s
.52243 .62552 m
.52243 .62552 L
s
.56633 .58566 m
.56658 .61594 L
s
.54449 .59748 m
.54461 .6178 L
s
.52238 .60944 m
.52241 .61967 L
s
.63749 .62749 m
.63749 .62749 L
s
.63749 .62749 m
.63749 .62749 L
s
.6238 .63432 m
.6238 .63432 L
s
.6238 .63432 m
.6238 .63432 L
s
.29042 .43742 m .16399 .42535 L .16122 .43752 L .71 0 0 r
F
.29042 .43742 m .16399 .42535 L .16122 .43752 L F
.16122 .43752 m .16399 .42535 L .15869 .54644 L .1 0 0 r
F
.15869 .54644 m .16122 .43752 L .16399 .42535 L F
0 g
.16122 .43752 m
.16122 .43752 L
s
.16122 .43752 m
.16122 .43752 L
s
.16122 .43752 m .15869 .54644 L .15593 .55749 L .1 0 0 r
F
.15869 .54644 m .15593 .55749 L .16122 .43752 L F
.15869 .54644 m .15593 .55749 L .16122 .43752 L F
.16122 .43752 m .15869 .54644 L .15593 .55749 L F
0 g
.16122 .43752 m
.16122 .43752 L
s
.15869 .54644 m .16122 .43752 L .16399 .42535 L .1 0 0 r
F
.16122 .43752 m .16399 .42535 L .15869 .54644 L F
0 g
.16122 .43752 m
.16122 .43752 L
s
.29042 .43742 m .28715 .5574 L .29142 .55208 L .115 0 0 r
F
.29142 .55208 m .29042 .43742 L .28715 .5574 L F
0 g
.29042 .43742 m
.29042 .43742 L
s
.29042 .43742 m
.29042 .43742 L
s
.28837 .44341 m
.29042 .43742 L
s
.29042 .43742 m .29142 .55208 L .29464 .43157 L .115 0 0 r
F
.29142 .55208 m .29464 .43157 L .29042 .43742 L F
.29464 .43157 m .16399 .42535 L .29042 .43742 L .71 0 0 r
F
0 g
.29042 .43742 m
.29042 .43742 L
s
.29142 .55208 m .29464 .43157 L .29042 .43742 L .115 0 0 r
F
.29042 .43742 m .29142 .55208 L .29464 .43157 L F
.29142 .55208 m .29042 .43742 L .28715 .5574 L F
.29042 .43742 m .28715 .5574 L .29142 .55208 L F
0 g
.29042 .43742 m
.29042 .43742 L
s
.29042 .43742 m .17125 .41334 L .16399 .42535 L .71 0 0 r
F
.29042 .43742 m .29464 .43157 L .17125 .41334 L F
0 g
.29042 .43742 m
.29042 .43742 L
s
.29042 .43742 m .17125 .41334 L .16399 .42535 L .71 0 0 r
F
.29042 .43742 m .29464 .43157 L .17125 .41334 L F
.29464 .43157 m .16399 .42535 L .29042 .43742 L F
0 g
.29042 .43742 m
.29042 .43742 L
s
.29042 .43742 m
.29042 .43742 L
s
0 0 0 r
.34857 .64009 m
.34857 .64009 L
s
.49672 .32255 m
.49672 .32255 L
s
.49672 .32255 m
.49672 .32255 L
s
.37671 .36623 m
.37671 .36623 L
s
.58861 .63722 m
.58861 .63722 L
s
.28508 .56284 m .15762 .5685 L .15593 .55749 L .688 0 0 r
F
.28508 .56284 m .28523 .56831 L .15762 .5685 L F
0 g
.15762 .5685 m
.1636 .57926 L
s
.28523 .56831 m .15762 .5685 L .15593 .55749 L .688 0 0 r
F
0 g
.15762 .5685 m
.15762 .5685 L
s
.28523 .56831 m .15762 .5685 L .15593 .55749 L .688 0 0 r
F
0 g
.15762 .5685 m
.1636 .57926 L
s
.28523 .56831 m
.28755 .57372 L
s
.28523 .56831 m
.28755 .57372 L
s
.28523 .56831 m
.28755 .57372 L
s
.28508 .56284 m .15762 .5685 L .15593 .55749 L .688 0 0 r
F
.28508 .56284 m .28523 .56831 L .15762 .5685 L F
0 g
.70525 .56839 m
.71164 .5632 L
s
.28523 .56831 m .15593 .55749 L .28508 .56284 L .688 0 0 r
F
0 g
.28523 .56831 m
.28523 .56831 L
s
.28523 .56831 m .15593 .55749 L .28508 .56284 L .688 0 0 r
F
0 g
.28508 .56284 m
.28523 .56831 L
s
.28523 .56831 m
.28755 .57372 L
s
.28508 .56284 m
.28523 .56831 L
s
.38855 .35749 m .38498 .60123 L .32577 .63625 L p 0 .16 .674 r
F P
0 g
s
.32577 .63625 m .38498 .60123 L .5 .62156 L p 0 .453 1 r
F P
0 g
s
0 0 0 r
.33727 .62945 m
.33727 .62945 L
s
.34893 .62255 m
.34893 .62255 L
s
.33727 .62945 m
.33727 .62945 L
s
.33727 .62945 m
.44998 .64862 L
s
.36077 .61555 m
.36077 .61555 L
s
.36077 .61555 m
.36503 .37485 L
s
.34894 .62255 m
.46222 .642 L
s
.34893 .62255 m
.34894 .62255 L
s
.37279 .60845 m
.37279 .60844 L
s
.37279 .60844 m
.37671 .36623 L
s
.47463 .63529 m
.58389 .65423 L
s
.48153 .6625 m
.54467 .62945 L
s
.45981 .65884 m
.52243 .62552 L
s
.48722 .62847 m
.597 .64768 L
s
.48722 .62847 m
.48722 .62847 L
s
.48722 .62847 m
.48722 .62847 L
s
.47463 .63529 m
.47463 .63529 L
s
.47463 .63529 m
.47463 .63529 L
s
.47463 .63529 m
.47463 .63529 L
s
.47463 .63529 m
.47463 .63529 L
s
.48722 .62847 m
.48722 .62847 L
s
.48722 .62847 m
.48722 .62847 L
s
.29464 .43157 m .17125 .41334 L .16399 .42535 L .71 0 0 r
F
.29464 .43157 m .29142 .55208 L .29785 .547 L .335 0 0 r
F
.29785 .547 m .29464 .43157 L .29142 .55208 L F
0 g
.29464 .43157 m
.29464 .43157 L
s
.29464 .43157 m
.29464 .43157 L
s
.29042 .43742 m
.29464 .43157 L
s
.29464 .43157 m .29785 .547 L .30099 .42597 L .335 0 0 r
F
.29785 .547 m .30099 .42597 L .29464 .43157 L F
.30099 .42597 m .17125 .41334 L .29464 .43157 L .71 0 0 r
F
0 g
.29464 .43157 m
.29464 .43157 L
s
.29785 .547 m .30099 .42597 L .29464 .43157 L .335 0 0 r
F
.29464 .43157 m .29785 .547 L .30099 .42597 L F
.29785 .547 m .29785 .547 L .30099 .42597 L .894 0 0 r
F
.29785 .547 m .29464 .43157 L .29142 .55208 L .335 0 0 r
F
.29464 .43157 m .29142 .55208 L .29785 .547 L F
.29464 .43157 m .18298 .40173 L .17125 .41334 L .71 0 0 r
F
.29464 .43157 m .30099 .42597 L .18298 .40173 L F
.29464 .43157 m .18298 .40173 L .17125 .41334 L F
.29464 .43157 m .30099 .42597 L .18298 .40173 L F
.29464 .43157 m .17125 .41334 L .16399 .42535 L F
.30099 .42597 m .17125 .41334 L .29464 .43157 L F
.30099 .42597 m .18298 .40173 L .17125 .41334 L F
.30099 .42597 m .18298 .40173 L .17125 .41334 L F
.29785 .547 m .18298 .40173 L .30099 .42597 L .894 0 0 r
F
.29785 .547 m .30099 .42597 L .30099 .42597 L .335 0 0 r
F
.29785 .547 m .30099 .42597 L .30099 .42597 L .894 0 0 r
F
.29785 .547 m .29785 .547 L p .30099 .42597 L F P
0 g
s
.29785 .547 m .30099 .42597 L .29785 .547 L .335 0 0 r
F
.29785 .547 m .30099 .42597 L p .30099 .42597 L .894 0 0 r
F P
0 g
s
.17788 .52496 m .29785 .547 L p .30099 .42597 L .894 0 0 r
F P
0 g
s
.84403 .41895 m .84263 .43145 L .84801 .55198 L .1 0 0 r
F
.84801 .55198 m .84403 .41895 L .84263 .43145 L F
.84263 .43145 m .84217 .5631 L .84801 .55198 L F
.84217 .5631 m .84801 .55198 L .84263 .43145 L F
0 g
.84263 .43145 m
.84263 .43145 L
s
.84217 .5631 m .84801 .55198 L .84263 .43145 L .1 0 0 r
F
.84263 .43145 m .84217 .5631 L .84801 .55198 L F
.84801 .55198 m .84403 .41895 L .84263 .43145 L F
.84403 .41895 m .84263 .43145 L .84801 .55198 L F
0 g
.83694 .4437 m
.84263 .43145 L
s
0 0 0 r
.36077 .61555 m
.36078 .61555 L
s
.47463 .63529 m
.47463 .63529 L
s
.47368 .3172 m
.47368 .3172 L
s
.47368 .3172 m
.47368 .3172 L
s
.6238 .63432 m
.6238 .63432 L
s
.56673 .63335 m
.56673 .63335 L
s
.65578 .51301 m
.65632 .53994 L
s
.71164 .5632 m .716 .55776 L .84217 .5631 L .688 0 0 r
F
0 g
.70525 .56839 m
.71164 .5632 L
s
.71164 .5632 m .716 .55776 L .84217 .5631 L .688 0 0 r
F
0 g
.71164 .5632 m
.716 .55776 L
s
.83221 .5738 m
.84217 .5631 L
s
.84217 .5631 m
.84217 .5631 L
s
.84217 .5631 m
.84217 .5631 L
s
.716 .55776 m .84801 .55198 L .84217 .5631 L .688 0 0 r
F
0 g
.83221 .5738 m
.84217 .5631 L
s
.71822 .55217 m .84217 .5631 L .716 .55776 L .688 0 0 r
F
0 g
.71164 .5632 m
.716 .55776 L
s
.716 .55776 m
.716 .55776 L
s
.71822 .55217 m .84801 .55198 L .84217 .5631 L .688 0 0 r
F
0 g
.83221 .5738 m
.84217 .5631 L
s
.71822 .55217 m .84217 .5631 L .716 .55776 L .688 0 0 r
F
.71822 .55217 m .84801 .55198 L .84217 .5631 L F
.716 .55776 m .84801 .55198 L .84217 .5631 L F
0 g
.716 .55776 m
.716 .55776 L
s
.30099 .42597 m .18298 .40173 L .17788 .52496 L p .894 0 0 r
F P
0 g
s
.35729 .50781 m .35959 .38286 L .30099 .42597 L p .41 0 0 r
F P
0 g
s
0 0 0 r
.35345 .38738 m
.35353 .38335 L
s
.3421 .39573 m
.34218 .39172 L
s
.32842 .51632 m
.35223 .50046 L
s
.30099 .42597 m .29785 .547 L .35729 .50781 L p .41 0 0 r
F P
0 g
s
.23833 .35674 m .18298 .40173 L .30099 .42597 L p .71 0 0 r
F P
0 g
s
.30099 .42597 m .35959 .38286 L .23833 .35674 L p .71 0 0 r
F P
0 g
s
.30099 .42597 m .17788 .52496 L .18298 .40173 L .894 0 0 r
F
.30099 .42597 m .29785 .547 L .17788 .52496 L F
.35959 .38286 m .30099 .42597 L .29785 .547 L p .41 0 0 r
F P
0 g
s
.29785 .547 m .35729 .50781 L .35959 .38286 L p .41 0 0 r
F P
0 g
s
.35729 .50781 m .35959 .38286 L .30099 .42597 L p .41 0 0 r
F P
0 g
s
.30099 .42597 m .29785 .547 L .35729 .50781 L p .41 0 0 r
F P
0 g
s
.29785 .547 m .30099 .42597 L .18298 .40173 L p .894 0 0 r
F P
0 g
s
.18298 .40173 m .30099 .42597 L .35959 .38286 L p .71 0 0 r
F P
0 g
s
.29785 .547 m .17788 .52496 L .18298 .40173 L .894 0 0 r
F
.18298 .40173 m .17788 .52496 L .29785 .547 L p F P
0 g
s
.30099 .42597 m .17788 .52496 L .18298 .40173 L .894 0 0 r
F
.30099 .42597 m .29785 .547 L .17788 .52496 L F
.17788 .52496 m .29785 .547 L .30099 .42597 L p F P
0 g
s
.30099 .42597 m .18298 .40173 L .17788 .52496 L p .894 0 0 r
F P
0 g
s
.18298 .40173 m .30099 .42597 L .35959 .38286 L p .71 0 0 r
F P
0 g
s
.44879 .5635 m .38498 .60123 L .38855 .35749 L p 0 .16 .674 r
F P
0 g
s
0 0 0 r
.3868 .47744 m
.3868 .47744 L
s
.38768 .417 m
.38768 .417 L
s
.38768 .417 m
.38768 .417 L
s
.3868 .47744 m
.3868 .47744 L
s
.3868 .47744 m
.3868 .47744 L
s
.38768 .417 m
.38768 .417 L
s
.3859 .53885 m
.3859 .53885 L
s
.3859 .53885 m
.3859 .53885 L
s
.38768 .417 m
.38768 .417 L
s
.38679 .47744 m
.3868 .47744 L
s
.38855 .35749 m .45044 .31181 L .44879 .5635 L p 0 .16 .674 r
F P
0 g
s
0 0 0 r
.41276 .33962 m
.41276 .33962 L
s
.41276 .33962 m
.41276 .33962 L
s
.40057 .34862 m
.40057 .34862 L
s
.40057 .34862 m
.40057 .34862 L
s
.29785 .547 m .30099 .42597 L .18298 .40173 L p .894 0 0 r
F P
0 g
s
.23833 .35674 m .18298 .40173 L .30099 .42597 L p .71 0 0 r
F P
0 g
s
.29785 .547 m .18298 .40173 L .30099 .42597 L .894 0 0 r
F
.17125 .41334 m .18298 .40173 L .17788 .52496 L .273 0 0 r
F
.17827 .51543 m .17125 .41334 L .18298 .40173 L F
.18298 .40173 m .17788 .52496 L .17788 .52496 L p .894 0 0 r
F P
0 g
s
.17788 .52496 m .29785 .547 L p .18298 .40173 L .894 0 0 r
F P
0 g
s
.17788 .52496 m .18298 .40173 L p .18298 .40173 L .363 0 0 r
F P
0 g
s
.17788 .52496 m .17788 .52496 L p .18298 .40173 L .363 0 0 r
F P
0 g
s
.18298 .40173 m .17788 .52496 L .18298 .40173 L .894 0 0 r
F
.29785 .547 m .17788 .52496 L .18298 .40173 L F
.23395 .48404 m .17788 .52496 L p .18298 .40173 L .363 0 0 r
F P
0 g
s
.35959 .38286 m .23833 .35674 L .18298 .40173 L p .71 0 0 r
F P
0 g
s
.35959 .38286 m .23833 .35674 L .18298 .40173 L p .71 0 0 r
F P
0 g
s
.18298 .40173 m .23833 .35674 L .23395 .48404 L p .363 0 0 r
F P
0 g
s
.35959 .38286 m .30099 .42597 L .29785 .547 L p .41 0 0 r
F P
0 g
s
.30099 .42597 m .35959 .38286 L .23833 .35674 L p .71 0 0 r
F P
0 g
s
.23395 .48404 m .23833 .35674 L .35959 .38286 L p .899 0 0 r
F P
0 g
s
0 0 0 r
.35858 .43743 m
.38768 .417 L
s
.33727 .62945 m
.33954 .51951 L
s
.34893 .62255 m
.35106 .51191 L
s
.28715 .5574 m .28508 .56284 L .15593 .55749 L .688 0 0 r
F
0 g
.28508 .56284 m
.28523 .56831 L
s
.28508 .56284 m .15869 .54644 L .28715 .5574 L .688 0 0 r
F
.28508 .56284 m .15593 .55749 L .15869 .54644 L F
.28508 .56284 m .15869 .54644 L .28715 .5574 L F
.28508 .56284 m .15593 .55749 L .15869 .54644 L F
0 g
.28508 .56284 m
.28523 .56831 L
s
.28715 .5574 m .28508 .56284 L .15593 .55749 L .688 0 0 r
F
0 g
.15593 .55749 m
.15762 .5685 L
s
.15593 .55749 m
.15762 .5685 L
s
.28508 .56284 m
.28508 .56284 L
s
.16399 .42535 m .17125 .41334 L .166 .53552 L .1 0 0 r
F
.166 .53552 m .16399 .42535 L .17125 .41334 L F
0 g
.16399 .42535 m
.16399 .42535 L
s
.16399 .42535 m .166 .53552 L .15869 .54644 L .1 0 0 r
F
.166 .53552 m .15869 .54644 L .16399 .42535 L F
0 g
.16399 .42535 m
.16399 .42535 L
s
.16399 .42535 m
.16399 .42535 L
s
.16399 .42535 m
.16399 .42535 L
s
.16122 .43752 m
.16399 .42535 L
s
.166 .53552 m .15869 .54644 L .16399 .42535 L .1 0 0 r
F
.16399 .42535 m .166 .53552 L .15869 .54644 L F
0 g
.16399 .42535 m
.16399 .42535 L
s
.166 .53552 m .16399 .42535 L .17125 .41334 L .1 0 0 r
F
.16399 .42535 m .17125 .41334 L .166 .53552 L F
0 g
.16399 .42535 m
.16399 .42535 L
s
.16399 .42535 m
.16399 .42535 L
s
.16399 .42535 m
.16399 .42535 L
s
0 0 0 r
.42514 .33049 m
.42514 .33049 L
s
.42514 .33049 m
.42514 .33049 L
s
.54467 .62945 m
.54467 .62945 L
s
.3859 .53885 m
.3859 .53885 L
s
.56626 .52214 m
.56626 .52214 L
s
.56625 .52214 m
.56626 .52214 L
s
.3859 .53885 m
.3859 .53885 L
s
.37279 .60845 m
.37279 .60845 L
s
.48722 .62847 m
.48722 .62847 L
s
.63363 .50852 m
.63409 .53555 L
s
.63749 .62749 m
.63749 .62749 L
s
.716 .55776 m .71822 .55217 L .84801 .55198 L .688 0 0 r
F
0 g
.71164 .5632 m
.716 .55776 L
s
.716 .55776 m .71822 .55217 L .84801 .55198 L .688 0 0 r
F
0 g
.716 .55776 m
.71822 .55217 L
s
.28715 .5574 m .15593 .55749 L .15869 .54644 L .688 0 0 r
F
0 g
.15593 .55749 m
.15762 .5685 L
s
.15593 .55749 m
.15762 .5685 L
s
.15593 .55749 m
.15593 .55749 L
s
.28715 .5574 m .15593 .55749 L .15869 .54644 L .688 0 0 r
F
.29142 .55208 m .28715 .5574 L .15869 .54644 L F
0 g
.28508 .56284 m
.28715 .5574 L
s
.28715 .5574 m .166 .53552 L .29142 .55208 L .688 0 0 r
F
.28715 .5574 m .15869 .54644 L .166 .53552 L F
0 g
.28508 .56284 m
.28715 .5574 L
s
.15593 .55749 m
.15869 .54644 L
s
.28715 .5574 m .166 .53552 L .29142 .55208 L .688 0 0 r
F
.28715 .5574 m .15869 .54644 L .166 .53552 L F
.29142 .55208 m .28715 .5574 L .15869 .54644 L F
0 g
.28715 .5574 m
.28715 .5574 L
s
.28715 .5574 m
.28715 .5574 L
s
.84403 .41895 m .84801 .55198 L .84948 .54062 L .1 0 0 r
F
.84801 .55198 m .84948 .54062 L .84403 .41895 L F
.84801 .55198 m .84948 .54062 L .84403 .41895 L F
.84403 .41895 m .84801 .55198 L .84948 .54062 L F
.84096 .40639 m .84403 .41895 L .84948 .54062 L .976 0 0 r
F
.84948 .54062 m .84096 .40639 L .84403 .41895 L F
.84948 .54062 m .84096 .40639 L .84403 .41895 L F
0 g
.84403 .41895 m
.84403 .41895 L
s
.84403 .41895 m
.84403 .41895 L
s
.84096 .40639 m .84403 .41895 L .84948 .54062 L .976 0 0 r
F
0 g
.84403 .41895 m
.84403 .41895 L
s
0 0 0 r
.52243 .62552 m
.52243 .62552 L
s
.40057 .34862 m
.40057 .34862 L
s
.61128 .50399 m
.61167 .53112 L
s
.45004 .3732 m
.45004 .3732 L
s
.38768 .417 m
.45004 .3732 L
s
.38768 .417 m
.38768 .417 L
s
.43769 .32122 m
.4377 .32122 L
s
.4377 .32122 m
.4377 .32122 L
s
.44879 .5635 m .56679 .58541 L .5 .62156 L p 0 .453 1 r
F P
0 g
s
.5 .62156 m .38498 .60123 L .44879 .5635 L p 0 .453 1 r
F P
0 g
s
0 0 0 r
.45458 .61353 m
.45458 .61353 L
s
.45457 .61353 m
.45457 .61353 L
s
.47738 .61756 m
.47738 .61756 L
s
.47738 .61756 m
.47738 .61756 L
s
.39361 .64768 m
.45458 .61353 L
s
.45458 .61353 m
.45458 .61353 L
s
.45458 .61353 m
.45458 .61353 L
s
.47738 .61756 m
.47738 .61756 L
s
.47738 .61756 m
.47738 .61756 L
s
.41586 .65143 m
.47738 .61756 L
s
.36078 .61555 m
.47463 .63529 L
s
.37279 .60845 m
.48722 .62847 L
s
.39736 .59391 m
.39736 .59391 L
s
.39736 .59391 m
.40057 .34862 L
s
.40838 .60537 m
.40838 .60537 L
s
.40838 .60537 m
.40838 .60537 L
s
.43157 .60947 m
.43157 .60947 L
s
.43157 .60947 m
.43157 .60947 L
s
.40838 .60537 m
.40838 .60537 L
s
.40838 .60537 m
.40838 .60537 L
s
.43157 .60947 m
.43157 .60947 L
s
.43157 .60947 m
.43157 .60947 L
s
.34857 .64009 m
.40838 .60537 L
s
.37118 .6439 m
.43157 .60947 L
s
.5 .62156 m .56679 .58541 L .67978 .6064 L p 0 .453 1 r
F P
0 g
s
0 0 0 r
.51296 .61454 m
.51296 .61454 L
s
.51297 .61454 m
.51297 .61454 L
s
.52612 .60742 m
.52612 .60742 L
s
.52612 .60742 m
.52612 .60742 L
s
.51296 .61454 m
.51296 .61454 L
s
.51296 .61454 m
.51296 .61454 L
s
.51296 .61454 m
.6238 .63432 L
s
.56673 .63335 m
.63517 .59811 L
s
.53948 .60019 m
.53948 .6002 L
s
.53948 .60019 m
.53948 .6002 L
s
.54467 .62945 m
.61257 .59391 L
s
.52612 .60742 m
.52612 .60742 L
s
.52612 .60742 m
.52612 .60742 L
s
.52612 .60742 m
.63749 .62749 L
s
.52243 .62552 m
.58978 .58968 L
s
.55303 .59286 m
.55303 .59286 L
s
.55303 .59286 m
.55303 .59286 L
s
.61257 .59391 m
.61257 .59391 L
s
.61167 .53112 m
.61257 .59391 L
s
.58978 .58968 m
.58978 .58968 L
s
.63517 .59811 m
.63517 .59811 L
s
.63409 .53555 m
.63517 .59811 L
s
.61257 .59391 m
.61257 .59391 L
s
.65757 .60227 m
.65757 .60227 L
s
.65632 .53994 m
.65757 .60227 L
s
.63517 .59811 m
.63517 .59811 L
s
.58861 .63722 m
.65757 .60227 L
s
.65757 .60227 m
.65757 .60227 L
s
.65138 .62056 m
.65138 .62056 L
s
.65138 .62056 m
.65138 .62056 L
s
.66548 .61353 m
.66548 .61353 L
s
.66548 .61353 m
.66548 .61353 L
s
.71822 .55217 m .84948 .54062 L .84801 .55198 L .688 0 0 r
F
.71822 .55217 m .71824 .54652 L .84948 .54062 L F
0 g
.716 .55776 m
.71822 .55217 L
s
.71824 .54652 m .84801 .55198 L .71822 .55217 L .688 0 0 r
F
0 g
.716 .55776 m
.71822 .55217 L
s
.71824 .54652 m .84801 .55198 L .71822 .55217 L .688 0 0 r
F
.71822 .55217 m .84948 .54062 L .84801 .55198 L F
.71822 .55217 m .71824 .54652 L .84948 .54062 L F
0 g
.84217 .5631 m
.84801 .55198 L
s
.84217 .5631 m
.84801 .55198 L
s
.29142 .55208 m .15869 .54644 L .166 .53552 L .688 0 0 r
F
.29785 .547 m .29142 .55208 L .166 .53552 L F
0 g
.29142 .55208 m
.29142 .55208 L
s
.29142 .55208 m .17788 .52496 L .29785 .547 L .688 0 0 r
F
.29142 .55208 m .166 .53552 L .17788 .52496 L F
0 g
.28715 .5574 m
.29142 .55208 L
s
.29142 .55208 m .17788 .52496 L .29785 .547 L .688 0 0 r
F
.29142 .55208 m .166 .53552 L .17788 .52496 L F
.29142 .55208 m .15869 .54644 L .166 .53552 L F
0 g
.15593 .55749 m
.15869 .54644 L
s
.15593 .55749 m
.15869 .54644 L
s
.15593 .55749 m
.15869 .54644 L
s
.29785 .547 m .29142 .55208 L .166 .53552 L .688 0 0 r
F
0 g
.29142 .55208 m
.29142 .55208 L
s
.29142 .55208 m
.29142 .55208 L
s
.29142 .55208 m
.29785 .547 L
s
.71824 .54652 m .84948 .54062 L .84801 .55198 L .688 0 0 r
F
0 g
.71822 .55217 m
.71824 .54652 L
s
.84217 .5631 m
.84801 .55198 L
s
.71824 .54652 m .84948 .54062 L .84801 .55198 L .688 0 0 r
F
0 g
.71822 .55217 m
.71824 .54652 L
s
.84801 .55198 m
.84801 .55198 L
s
.84801 .55198 m
.84801 .55198 L
s
.17125 .41334 m .17788 .52496 L .166 .53552 L .273 0 0 r
F
.17788 .52496 m .166 .53552 L .17125 .41334 L F
0 g
.17125 .41334 m
.17125 .41334 L
s
.17125 .41334 m
.17125 .41334 L
s
.17125 .41334 m
.17125 .41334 L
s
.16399 .42535 m
.17125 .41334 L
s
.17788 .52496 m .166 .53552 L .17125 .41334 L .273 0 0 r
F
.17125 .41334 m .17788 .52496 L .166 .53552 L F
0 g
.17125 .41334 m
.17125 .41334 L
s
.17788 .52496 m .17125 .41334 L .18298 .40173 L .273 0 0 r
F
.17125 .41334 m .18298 .40173 L .17788 .52496 L F
0 g
.17125 .41334 m
.17125 .41334 L
s
.17125 .41334 m
.17125 .41334 L
s
.17125 .41334 m
.18298 .40173 L
s
.17125 .41334 m
.17125 .41334 L
s
0 0 0 r
.53948 .6002 m
.53948 .6002 L
s
.53948 .6002 m
.53948 .6002 L
s
.53948 .6002 m
.65138 .62056 L
s
.65138 .62056 m
.65138 .62056 L
s
.58978 .58968 m
.58978 .58968 L
s
.58906 .52665 m
.58978 .58968 L
s
.58875 .49942 m
.58906 .52665 L
s
.54361 .58111 m
.54361 .58111 L
s
.47738 .61756 m
.54361 .58111 L
s
.47738 .61756 m
.47738 .61756 L
s
.40992 .58648 m
.40992 .58648 L
s
.40992 .58648 m
.41276 .33962 L
s
.41276 .33962 m
.41276 .33962 L
s
.35959 .38286 m .35729 .50781 L .35959 .38286 L .899 0 0 r
F
.29785 .547 m .35729 .50781 L p .35959 .38286 L .41 0 0 r
F P
0 g
s
.35729 .50781 m .35959 .38286 L .23833 .35674 L .899 0 0 r
F
.35959 .38286 m .35729 .50781 L .35729 .50781 L p F P
0 g
s
.36642 .50267 m .35959 .38286 L .35729 .50781 L .468 0 0 r
F
.35959 .38286 m .35729 .50781 L .36642 .50267 L F
.35959 .38286 m .35729 .50781 L .36642 .50267 L F
.35729 .50781 m .35959 .38286 L p .35959 .38286 L .41 0 0 r
F P
0 g
s
.35729 .50781 m .35729 .50781 L p .35959 .38286 L .41 0 0 r
F P
0 g
s
.35729 .50781 m .23395 .48404 L p .35959 .38286 L .899 0 0 r
F P
0 g
s
.23395 .48404 m .35729 .50781 L .29785 .547 L p .688 0 0 r
F P
0 g
s
.29785 .547 m .17788 .52496 L .23395 .48404 L p .688 0 0 r
F P
0 g
s
.29785 .547 m .166 .53552 L .17788 .52496 L .688 0 0 r
F
0 g
.29785 .547 m
.29785 .547 L
s
.29785 .547 m
.29785 .547 L
s
.35729 .50781 m .29785 .547 L .17788 .52496 L p .688 0 0 r
F P
0 g
s
.29142 .55208 m
.29785 .547 L
s
.35729 .50781 m .29785 .547 L .17788 .52496 L p .688 0 0 r
F P
0 g
s
0 0 0 r
.36578 .49144 m
.3868 .47744 L
s
.29785 .547 m .17788 .52496 L .23395 .48404 L p .688 0 0 r
F P
0 g
s
.23395 .48404 m .35729 .50781 L .29785 .547 L p .688 0 0 r
F P
0 g
s
0 0 0 r
.32711 .57583 m
.3859 .53885 L
s
.29785 .547 m .166 .53552 L .17788 .52496 L .688 0 0 r
F
0 g
.17788 .52496 m
.29785 .547 L
s
.29785 .547 m
.29785 .547 L
s
.17788 .52496 m
.17788 .52496 L
s
0 0 0 r
.44963 .43559 m
.44963 .43559 L
s
.38679 .47744 m
.3868 .47744 L
s
.71824 .54652 m .84643 .52921 L .84948 .54062 L .688 0 0 r
F
.71824 .54652 m .71601 .54092 L .84643 .52921 L F
0 g
.71822 .55217 m
.71824 .54652 L
s
.71601 .54092 m .84948 .54062 L .71824 .54652 L .688 0 0 r
F
0 g
.71822 .55217 m
.71824 .54652 L
s
.71601 .54092 m .84948 .54062 L .71824 .54652 L .688 0 0 r
F
.71824 .54652 m .84643 .52921 L .84948 .54062 L F
.71824 .54652 m .71601 .54092 L .84643 .52921 L F
0 g
.71824 .54652 m
.71824 .54652 L
s
.15869 .54644 m
.166 .53552 L
s
.15869 .54644 m
.15869 .54644 L
s
.15869 .54644 m
.15869 .54644 L
s
.15869 .54644 m
.166 .53552 L
s
.83333 .39402 m .84096 .40639 L .84643 .52921 L 1 0 0 r
F
.84643 .52921 m .83333 .39402 L .84096 .40639 L F
0 g
.84096 .40639 m
.84096 .40639 L
s
.84096 .40639 m
.84096 .40639 L
s
.84096 .40639 m
.84403 .41895 L
s
.84096 .40639 m .84948 .54062 L .84643 .52921 L .976 0 0 r
F
.84948 .54062 m .84643 .52921 L .84096 .40639 L F
.84948 .54062 m .84643 .52921 L .84096 .40639 L F
0 g
.84096 .40639 m
.84096 .40639 L
s
.84096 .40639 m
.84096 .40639 L
s
.84096 .40639 m .84948 .54062 L .84643 .52921 L .976 0 0 r
F
.84643 .52921 m .83333 .39402 L .84096 .40639 L 1 0 0 r
F
.83333 .39402 m .84096 .40639 L .84643 .52921 L F
0 g
.84096 .40639 m
.84096 .40639 L
s
.84096 .40639 m
.84096 .40639 L
s
.84096 .40639 m
.84096 .40639 L
s
0 0 0 r
.39736 .59391 m
.39736 .59391 L
s
.39736 .59391 m
.51296 .61454 L
s
.51296 .61454 m
.51297 .61454 L
s
.56626 .52214 m
.56626 .52214 L
s
.56626 .52214 m
.56626 .52214 L
s
.56626 .52214 m
.67836 .5443 L
s
.67836 .5443 m
.67836 .5443 L
s
.52021 .57676 m
.52021 .57676 L
s
.45458 .61353 m
.52021 .57676 L
s
.45457 .61353 m
.45458 .61353 L
s
.55303 .59286 m
.55303 .59286 L
s
.55303 .59286 m
.55303 .59286 L
s
.55303 .59286 m
.66548 .61353 L
s
.66548 .61353 m
.66548 .61353 L
s
.54223 .33311 m
.54239 .3631 L
s
.54223 .33311 m
.54223 .33311 L
s
.54361 .5811 m
.54361 .58111 L
s
.54325 .5176 m
.54361 .5811 L
s
.5431 .49017 m
.54325 .5176 L
s
.17788 .52496 m .18298 .40173 L .23833 .35674 L p .363 0 0 r
F P
0 g
s
.23833 .35674 m .23395 .48404 L .17788 .52496 L p .363 0 0 r
F P
0 g
s
.23395 .48404 m .17788 .52496 L .18298 .40173 L p .363 0 0 r
F P
0 g
s
.18298 .40173 m .23833 .35674 L .23395 .48404 L p .363 0 0 r
F P
0 g
s
.18298 .40173 m
.18298 .40173 L
s
.17788 .52496 m .18298 .40173 L .23833 .35674 L p .363 0 0 r
F P
0 g
s
.1802 .46899 m
.18298 .40173 L
s
.71601 .54092 m .83874 .51796 L .84643 .52921 L .688 0 0 r
F
.71601 .54092 m .71153 .53545 L .83874 .51796 L F
0 g
.71601 .54092 m
.71824 .54652 L
s
.71601 .54092 m .84643 .52921 L .84948 .54062 L .688 0 0 r
F
.71153 .53545 m .84643 .52921 L .71601 .54092 L F
0 g
.71601 .54092 m
.71824 .54652 L
s
.71601 .54092 m
.71601 .54092 L
s
.71601 .54092 m .84643 .52921 L .84948 .54062 L .688 0 0 r
F
0 g
.84801 .55198 m
.84948 .54062 L
s
.84801 .55198 m
.84948 .54062 L
s
.84801 .55198 m
.84948 .54062 L
s
.84801 .55198 m
.84948 .54062 L
s
.84948 .54062 m
.84948 .54062 L
s
.71153 .53545 m .84643 .52921 L .71601 .54092 L .688 0 0 r
F
0 g
.71601 .54092 m
.71824 .54652 L
s
.71601 .54092 m .83874 .51796 L .84643 .52921 L .688 0 0 r
F
.71601 .54092 m .71153 .53545 L .83874 .51796 L F
0 g
.71601 .54092 m
.71601 .54092 L
s
.71153 .53545 m
.71601 .54092 L
s
.84948 .54062 m
.84948 .54062 L
s
0 0 0 r
.42268 .57894 m
.42268 .57894 L
s
.42268 .57894 m
.42514 .33049 L
s
.42514 .33049 m
.42514 .33049 L
s
.49662 .57238 m
.49662 .57238 L
s
.43157 .60947 m
.49662 .57238 L
s
.43157 .60947 m
.43157 .60947 L
s
.44921 .49902 m
.44921 .49902 L
s
.3859 .53885 m
.44921 .49902 L
s
.3859 .53885 m
.3859 .53885 L
s
.45004 .3732 m
.45004 .3732 L
s
.45004 .3732 m
.50824 .38605 L
s
.50824 .38605 m
.53002 .39085 L
s
.52021 .57676 m
.52021 .57676 L
s
.51957 .32785 m
.51957 .32785 L
s
.40992 .58648 m
.40993 .58648 L
s
.40993 .58648 m
.52612 .60742 L
s
.52612 .60742 m
.52612 .60742 L
s
0 g
.166 .53552 m
.166 .53552 L
s
.166 .53552 m
.17788 .52496 L
s
.166 .53552 m
.166 .53552 L
s
.166 .53552 m
.166 .53552 L
s
.71153 .53545 m .82641 .50708 L .83874 .51796 L .688 0 0 r
F
.71153 .53545 m .70487 .53021 L .82641 .50708 L F
.71153 .53545 m .83874 .51796 L .84643 .52921 L F
.70487 .53021 m .83874 .51796 L .71153 .53545 L F
0 g
.71153 .53545 m
.71601 .54092 L
s
.71153 .53545 m .83874 .51796 L .84643 .52921 L .688 0 0 r
F
.70487 .53021 m .83874 .51796 L .71153 .53545 L F
0 g
.71153 .53545 m
.71601 .54092 L
s
.71153 .53545 m .82641 .50708 L .83874 .51796 L .688 0 0 r
F
.71153 .53545 m .70487 .53021 L .82641 .50708 L F
0 g
.71153 .53545 m
.71153 .53545 L
s
0 0 0 r
.47281 .56796 m
.47281 .56796 L
s
.40838 .60537 m
.47281 .56796 L
s
.40838 .60537 m
.40838 .60537 L
s
.82115 .38207 m .83333 .39402 L .83874 .51796 L 1 0 0 r
F
.83874 .51796 m .82115 .38207 L .83333 .39402 L F
0 g
.83333 .39402 m
.83333 .39402 L
s
.83333 .39402 m
.83333 .39402 L
s
.83333 .39402 m
.84096 .40639 L
s
.83333 .39402 m .84643 .52921 L .83874 .51796 L 1 0 0 r
F
.84643 .52921 m .83874 .51796 L .83333 .39402 L F
0 g
.84643 .52921 m
.84948 .54062 L
s
.84643 .52921 m
.84948 .54062 L
s
.84643 .52921 m
.84948 .54062 L
s
.84643 .52921 m .83874 .51796 L .83333 .39402 L 1 0 0 r
F
.83333 .39402 m .84643 .52921 L .83874 .51796 L F
0 g
.84643 .52921 m
.84948 .54062 L
s
.83874 .51796 m .82115 .38207 L .83333 .39402 L 1 0 0 r
F
.82115 .38207 m .83333 .39402 L .83874 .51796 L F
0 g
.83333 .39402 m
.83333 .39402 L
s
.83333 .39402 m
.83333 .39402 L
s
.83333 .39402 m
.83333 .39402 L
s
0 0 0 r
.49662 .57238 m
.49662 .57238 L
s
.49672 .32255 m
.49672 .32255 L
s
.43564 .57128 m
.43564 .57127 L
s
.43769 .32122 m
.43769 .32122 L
s
0 g
.65651 .40951 m
.65793 .47906 L
s
0 0 0 r
.44963 .43559 m
.44963 .43559 L
s
.44963 .43559 m
.50831 .44787 L
s
.50831 .44787 m
.53808 .4541 L
s
.70487 .53021 m .80955 .49681 L .82641 .50708 L .688 0 0 r
F
.70487 .53021 m .69609 .52532 L .80955 .49681 L F
.70487 .53021 m .82641 .50708 L .83874 .51796 L F
.69609 .52532 m .82641 .50708 L .70487 .53021 L F
0 g
.70487 .53021 m
.71153 .53545 L
s
.70487 .53021 m .82641 .50708 L .83874 .51796 L .688 0 0 r
F
.69609 .52532 m .82641 .50708 L .70487 .53021 L F
0 g
.70487 .53021 m
.71153 .53545 L
s
.70487 .53021 m .80955 .49681 L .82641 .50708 L .688 0 0 r
F
.70487 .53021 m .69609 .52532 L .80955 .49681 L F
0 g
.70487 .53021 m
.70487 .53021 L
s
.70487 .53021 m
.70487 .53021 L
s
0 0 0 r
.42268 .57894 m
.42268 .57894 L
s
.42268 .57894 m
.53948 .6002 L
s
.53948 .6002 m
.53948 .6002 L
s
.47281 .56796 m
.47281 .56796 L
s
.47368 .3172 m
.47368 .3172 L
s
0 g
.84643 .52921 m
.84643 .52921 L
s
.84643 .52921 m
.84643 .52921 L
s
.83874 .51796 m
.84643 .52921 L
s
.69609 .52532 m .78835 .48735 L .80955 .49681 L .688 0 0 r
F
.69609 .52532 m .68533 .52086 L .78835 .48735 L F
.69609 .52532 m .80955 .49681 L .82641 .50708 L F
.68533 .52086 m .80955 .49681 L .69609 .52532 L F
.69609 .52532 m .80955 .49681 L .82641 .50708 L F
.68533 .52086 m .80955 .49681 L .69609 .52532 L F
0 g
.69609 .52532 m
.70487 .53021 L
s
.69609 .52532 m .78835 .48735 L .80955 .49681 L .688 0 0 r
F
.69609 .52532 m .68533 .52086 L .78835 .48735 L F
0 g
.69609 .52532 m
.69609 .52532 L
s
.17788 .52496 m .23395 .48404 L .35729 .50781 L p .688 0 0 r
F P
0 g
s
.166 .53552 m
.17788 .52496 L
s
.17788 .52496 m
.1802 .46899 L
s
.36642 .50267 m .36858 .37721 L .35959 .38286 L .468 0 0 r
F
.36858 .37721 m .23833 .35674 L .35959 .38286 L .71 0 0 r
F
0 g
.35959 .38286 m
.35959 .38286 L
s
.35959 .38286 m
.35959 .38286 L
s
.17788 .52496 m .23395 .48404 L .35729 .50781 L p .688 0 0 r
F P
0 g
s
.17788 .52496 m
.29785 .547 L
s
.23833 .35674 m .35959 .38286 L .35729 .50781 L p .899 0 0 r
F P
0 g
s
.35959 .38286 m .36642 .50267 L .36858 .37721 L .468 0 0 r
F
.35959 .38286 m .36642 .50267 L .36858 .37721 L F
.35959 .38286 m .25562 .34489 L .23833 .35674 L .71 0 0 r
F
.35959 .38286 m .36858 .37721 L .25562 .34489 L F
.35959 .38286 m .23395 .48404 L .35729 .50781 L .899 0 0 r
F
.35959 .38286 m .23833 .35674 L .23395 .48404 L F
.23833 .35674 m .23395 .48404 L .17788 .52496 L p .363 0 0 r
F P
0 g
s
.35729 .50781 m .23833 .35674 L .23395 .48404 L .899 0 0 r
F
.35729 .50781 m .23395 .48404 L .23833 .35674 L p F P
0 g
s
.23395 .48404 m .23833 .35674 L .35959 .38286 L p .899 0 0 r
F P
0 g
s
.35959 .38286 m .35729 .50781 L .23395 .48404 L p .899 0 0 r
F P
0 g
s
.23833 .35674 m .23395 .48404 L .23833 .35674 L .431 0 0 r
F
.35959 .38286 m .23395 .48404 L .35729 .50781 L .899 0 0 r
F
.35959 .38286 m .23833 .35674 L .23395 .48404 L F
.23395 .48404 m .23395 .48404 L .23833 .35674 L .431 0 0 r
F
.35729 .50781 m .23395 .48404 L .23833 .35674 L p .899 0 0 r
F P
0 g
s
.23833 .35674 m .23833 .35674 L .23395 .48404 L .431 0 0 r
F
.35729 .50781 m .23833 .35674 L .23395 .48404 L .899 0 0 r
F
.35959 .38286 m .25562 .34489 L .23833 .35674 L .71 0 0 r
F
.23833 .35674 m .35959 .38286 L .35729 .50781 L p .899 0 0 r
F P
0 g
s
.35729 .50781 m .35959 .38286 L .23833 .35674 L .899 0 0 r
F
.36858 .37721 m .23833 .35674 L .35959 .38286 L .71 0 0 r
F
.36858 .37721 m .25562 .34489 L .23833 .35674 L F
.36858 .37721 m .25562 .34489 L .23833 .35674 L F
.25149 .47325 m .23833 .35674 L .25562 .34489 L .431 0 0 r
F
.23833 .35674 m .25562 .34489 L .25149 .47325 L F
.23833 .35674 m .25562 .34489 L .25149 .47325 L F
.25149 .47325 m .23395 .48404 L .23833 .35674 L F
.23833 .35674 m .25149 .47325 L .23395 .48404 L F
.23833 .35674 m .25149 .47325 L .23395 .48404 L F
.23833 .35674 m .23395 .48404 L .23395 .48404 L F
.35959 .38286 m .36858 .37721 L .25562 .34489 L .71 0 0 r
F
.36642 .50267 m .35959 .38286 L .35729 .50781 L .468 0 0 r
F
.36642 .50267 m .36858 .37721 L .35959 .38286 L F
0 g
.35765 .48828 m
.35959 .38286 L
s
.80451 .37077 m .82115 .38207 L .82641 .50708 L 1 0 0 r
F
.82641 .50708 m .80451 .37077 L .82115 .38207 L F
0 g
.82115 .38207 m
.82115 .38207 L
s
.82115 .38207 m
.83333 .39402 L
s
.82115 .38207 m .83874 .51796 L .82641 .50708 L 1 0 0 r
F
.83874 .51796 m .82641 .50708 L .82115 .38207 L F
0 g
.83874 .51796 m
.84643 .52921 L
s
.83874 .51796 m .82641 .50708 L .82115 .38207 L 1 0 0 r
F
.82115 .38207 m .83874 .51796 L .82641 .50708 L F
0 g
.83874 .51796 m
.83874 .51796 L
s
.83874 .51796 m
.84643 .52921 L
s
.82641 .50708 m .80451 .37077 L .82115 .38207 L 1 0 0 r
F
.80451 .37077 m .82115 .38207 L .82641 .50708 L F
0 g
.82115 .38207 m
.82115 .38207 L
s
.82115 .38207 m
.82115 .38207 L
s
.82115 .38207 m
.82115 .38207 L
s
0 0 0 r
.44921 .49902 m
.44922 .49902 L
s
.56626 .52214 m
.56626 .52214 L
s
.43564 .57128 m
.43564 .57128 L
s
.43564 .57128 m
.55303 .59286 L
s
.55303 .59286 m
.55303 .59286 L
s
.68533 .52086 m .76314 .47893 L .78835 .48735 L .688 0 0 r
F
.68533 .52086 m .67278 .51692 L .76314 .47893 L F
.68533 .52086 m .78835 .48735 L .80955 .49681 L F
.67278 .51692 m .78835 .48735 L .68533 .52086 L F
.68533 .52086 m .78835 .48735 L .80955 .49681 L F
.67278 .51692 m .78835 .48735 L .68533 .52086 L F
0 g
.68533 .52086 m
.69609 .52532 L
s
.68533 .52086 m .76314 .47893 L .78835 .48735 L .688 0 0 r
F
.68533 .52086 m .67278 .51692 L .76314 .47893 L F
0 g
.68533 .52086 m
.68533 .52086 L
s
.37756 .49798 m .36858 .37721 L .36642 .50267 L .554 0 0 r
F
0 g
.36858 .37721 m
.36858 .37721 L
s
.35959 .38286 m
.36858 .37721 L
s
.37756 .49798 m .37955 .37206 L .36858 .37721 L .554 0 0 r
F
.37955 .37206 m .25562 .34489 L .36858 .37721 L .71 0 0 r
F
.36858 .37721 m .37756 .49798 L .37955 .37206 L .554 0 0 r
F
.36858 .37721 m .37756 .49798 L .37955 .37206 L F
0 g
.36858 .37721 m
.36858 .37721 L
s
.36858 .37721 m .36642 .50267 L .37756 .49798 L .554 0 0 r
F
.36858 .37721 m .36642 .50267 L .37756 .49798 L F
.36858 .37721 m .27724 .33396 L .25562 .34489 L .71 0 0 r
F
.36858 .37721 m .37955 .37206 L .27724 .33396 L F
.36858 .37721 m .27724 .33396 L .25562 .34489 L F
.36858 .37721 m .37955 .37206 L .27724 .33396 L F
.37756 .49798 m .36858 .37721 L .36642 .50267 L .554 0 0 r
F
.37756 .49798 m .37955 .37206 L .36858 .37721 L F
.37955 .37206 m .25562 .34489 L .36858 .37721 L .71 0 0 r
F
0 g
.36858 .37721 m
.36858 .37721 L
s
.83874 .51796 m
.83874 .51796 L
s
.83874 .51796 m
.83874 .51796 L
s
.67278 .51692 m .73433 .47175 L .76314 .47893 L .688 0 0 r
F
.67278 .51692 m .65864 .51359 L .73433 .47175 L F
.67278 .51692 m .76314 .47893 L .78835 .48735 L F
.65864 .51359 m .76314 .47893 L .67278 .51692 L F
0 g
.67278 .51692 m
.67278 .51692 L
s
.67278 .51692 m .76314 .47893 L .78835 .48735 L .688 0 0 r
F
.65864 .51359 m .76314 .47893 L .67278 .51692 L F
0 g
.67278 .51692 m
.68533 .52086 L
s
.67278 .51692 m .73433 .47175 L .76314 .47893 L .688 0 0 r
F
.67278 .51692 m .65864 .51359 L .73433 .47175 L F
0 g
.67278 .51692 m
.67278 .51692 L
s
.37955 .37206 m .27724 .33396 L .25562 .34489 L .71 0 0 r
F
.39052 .49382 m .37955 .37206 L .37756 .49798 L .617 0 0 r
F
0 g
.36858 .37721 m
.37955 .37206 L
s
.39052 .49382 m .3923 .36749 L .37955 .37206 L .617 0 0 r
F
.3923 .36749 m .27724 .33396 L .37955 .37206 L .71 0 0 r
F
.37955 .37206 m .39052 .49382 L .3923 .36749 L .617 0 0 r
F
.37955 .37206 m .39052 .49382 L .3923 .36749 L F
0 g
.37955 .37206 m
.37955 .37206 L
s
.37955 .37206 m .37756 .49798 L .39052 .49382 L .617 0 0 r
F
.37955 .37206 m .37756 .49798 L .39052 .49382 L F
.37955 .37206 m .30287 .3242 L .27724 .33396 L .71 0 0 r
F
.37955 .37206 m .3923 .36749 L .30287 .3242 L F
.37955 .37206 m .30287 .3242 L .27724 .33396 L F
.37955 .37206 m .3923 .36749 L .30287 .3242 L F
.37955 .37206 m .27724 .33396 L .25562 .34489 L F
.39052 .49382 m .37955 .37206 L .37756 .49798 L .617 0 0 r
F
.39052 .49382 m .3923 .36749 L .37955 .37206 L F
.3923 .36749 m .27724 .33396 L .37955 .37206 L .71 0 0 r
F
0 g
.37955 .37206 m
.37955 .37206 L
s
.78362 .36038 m .80451 .37077 L .80955 .49681 L .995 0 0 r
F
.80955 .49681 m .78362 .36038 L .80451 .37077 L F
0 g
.80451 .37077 m
.80451 .37077 L
s
.80451 .37077 m
.82115 .38207 L
s
.80451 .37077 m .82641 .50708 L .80955 .49681 L 1 0 0 r
F
.82641 .50708 m .80955 .49681 L .80451 .37077 L F
0 g
.82641 .50708 m
.83874 .51796 L
s
.82641 .50708 m .80955 .49681 L .80451 .37077 L 1 0 0 r
F
.80451 .37077 m .82641 .50708 L .80955 .49681 L F
0 g
.82641 .50708 m
.82641 .50708 L
s
.82641 .50708 m
.83874 .51796 L
s
.80955 .49681 m .78362 .36038 L .80451 .37077 L .995 0 0 r
F
.78362 .36038 m .80451 .37077 L .80955 .49681 L F
0 g
.80451 .37077 m
.80451 .37077 L
s
.80451 .37077 m
.80451 .37077 L
s
.80451 .37077 m
.80451 .37077 L
s
.61543 .44633 m .73433 .47175 L .65864 .51359 L p .688 0 0 r
F P
0 g
s
.65864 .51359 m .73433 .47175 L .76314 .47893 L .688 0 0 r
F
.65864 .51359 m .73433 .47175 L .76314 .47893 L F
.73433 .47175 m .65864 .51359 L .54267 .49008 L p F P
0 g
s
.65864 .51359 m
.67278 .51692 L
s
.65864 .51359 m .54267 .49008 L .61543 .44633 L p .688 0 0 r
F P
0 g
s
0 0 0 r
.44922 .49902 m
.56626 .52214 L
s
.61543 .44633 m .73433 .47175 L .65864 .51359 L p .688 0 0 r
F P
0 g
s
.65864 .51359 m
.65864 .51359 L
s
.65864 .51359 m
.65864 .51359 L
s
.65864 .51359 m
.65864 .51359 L
s
.65864 .51359 m
.6588 .5135 L
s
.65864 .51359 m
.65865 .51358 L
s
.3923 .36749 m .30287 .3242 L .27724 .33396 L .71 0 0 r
F
.40508 .49029 m .3923 .36749 L .39052 .49382 L .664 0 0 r
F
0 g
.37955 .37206 m
.3923 .36749 L
s
.40508 .49029 m .40663 .36361 L .3923 .36749 L .664 0 0 r
F
.40663 .36361 m .30287 .3242 L .3923 .36749 L .71 0 0 r
F
.3923 .36749 m .40508 .49029 L .40663 .36361 L .664 0 0 r
F
.3923 .36749 m .40508 .49029 L .40663 .36361 L F
0 g
.3923 .36749 m
.3923 .36749 L
s
.3923 .36749 m .39052 .49382 L .40508 .49029 L .664 0 0 r
F
.3923 .36749 m .39052 .49382 L .40508 .49029 L F
.3923 .36749 m .33206 .31585 L .30287 .3242 L .71 0 0 r
F
.3923 .36749 m .40663 .36361 L .33206 .31585 L F
.3923 .36749 m .33206 .31585 L .30287 .3242 L F
.3923 .36749 m .40663 .36361 L .33206 .31585 L F
.3923 .36749 m .30287 .3242 L .27724 .33396 L F
.40508 .49029 m .3923 .36749 L .39052 .49382 L .664 0 0 r
F
.40508 .49029 m .40663 .36361 L .3923 .36749 L F
.40663 .36361 m .30287 .3242 L .3923 .36749 L .71 0 0 r
F
0 g
.3923 .36749 m
.3923 .36749 L
s
.40663 .36361 m .33206 .31585 L .30287 .3242 L .71 0 0 r
F
.42098 .48746 m .40663 .36361 L .40508 .49029 L .703 0 0 r
F
0 g
.3923 .36749 m
.40663 .36361 L
s
.42098 .48746 m .42227 .3605 L .40663 .36361 L .703 0 0 r
F
.42227 .3605 m .33206 .31585 L .40663 .36361 L .71 0 0 r
F
.40663 .36361 m .42098 .48746 L .42227 .3605 L .703 0 0 r
F
.40663 .36361 m .42098 .48746 L .42227 .3605 L F
0 g
.40663 .36361 m
.40663 .36361 L
s
.40663 .36361 m .40508 .49029 L .42098 .48746 L .703 0 0 r
F
.40663 .36361 m .40508 .49029 L .42098 .48746 L F
.40663 .36361 m .36427 .3091 L .33206 .31585 L .71 0 0 r
F
.40663 .36361 m .42227 .3605 L .36427 .3091 L F
.40663 .36361 m .36427 .3091 L .33206 .31585 L F
.40663 .36361 m .42227 .3605 L .36427 .3091 L F
.40663 .36361 m .33206 .31585 L .30287 .3242 L F
.42098 .48746 m .40663 .36361 L .40508 .49029 L .703 0 0 r
F
.42098 .48746 m .42227 .3605 L .40663 .36361 L F
0 0 0 r
.42131 .45445 m
.44963 .43559 L
s
.42227 .3605 m .33206 .31585 L .40663 .36361 L .71 0 0 r
F
0 g
.40663 .36361 m
.40663 .36361 L
s
.36642 .50267 m .35729 .50781 L .23395 .48404 L .688 0 0 r
F
.54197 .36338 m .61347 .31534 L .61543 .44633 L p .449 0 0 r
F P
0 g
s
.54197 .36338 m .5808 .3087 L .52613 .36032 L .71 0 0 r
F
.54197 .36338 m .61347 .31534 L .5808 .3087 L F
.35729 .50781 m .25149 .47325 L .36642 .50267 L .688 0 0 r
F
.35729 .50781 m .23395 .48404 L .25149 .47325 L F
.54197 .36338 m .54267 .49008 L .61543 .44633 L .449 0 0 r
F
.54267 .49008 m .54197 .36338 L .61347 .31534 L p F P
0 g
s
.54267 .49008 m .61543 .44633 L .61347 .31534 L .449 0 0 r
F
.61347 .31534 m .61543 .44633 L .54267 .49008 L p F P
0 g
s
.61543 .44633 m .54267 .49008 L .54197 .36338 L p .449 0 0 r
F P
0 g
s
.54197 .36338 m .61543 .44633 L .61347 .31534 L .449 0 0 r
F
.54197 .36338 m .61347 .31534 L .61543 .44633 L p F P
0 g
s
.61543 .44633 m .61543 .44633 L .61347 .31534 L .894 0 0 r
F
.54197 .36338 m .61543 .44633 L .61347 .31534 L .449 0 0 r
F
.52613 .36032 m .54197 .36338 L .61347 .31534 L .71 0 0 r
F
.52613 .36032 m .54197 .36338 L .61347 .31534 L F
.54267 .49008 m .54197 .36338 L .61347 .31534 L p .449 0 0 r
F P
0 g
s
.61543 .44633 m .61347 .31534 L .61347 .31534 L .894 0 0 r
F
.73433 .47175 m .61543 .44633 L .61347 .31534 L p .908 0 0 r
F P
0 g
s
.61543 .44633 m .61347 .31534 L .61543 .44633 L .894 0 0 r
F
.54197 .36338 m .61347 .31534 L .5808 .3087 L .71 0 0 r
F
.54267 .49008 m .61347 .31534 L .54197 .36338 L .449 0 0 r
F
.52613 .36032 m .61347 .31534 L .5808 .3087 L .71 0 0 r
F
.52613 .36032 m .61347 .31534 L .5808 .3087 L F
.54267 .49008 m .61543 .44633 L .61347 .31534 L .449 0 0 r
F
.54197 .36338 m .54267 .49008 L .61543 .44633 L F
.61347 .31534 m .61543 .44633 L .54267 .49008 L p F P
0 g
s
.61543 .44633 m .5822 .44028 L .5808 .3087 L .894 0 0 r
F
.5808 .3087 m .61543 .44633 L .5822 .44028 L F
.5808 .3087 m .61543 .44633 L .5822 .44028 L F
.61543 .44633 m .5808 .3087 L .61347 .31534 L F
.5808 .3087 m .61347 .31534 L .61543 .44633 L F
.5808 .3087 m .61347 .31534 L .61543 .44633 L F
.61347 .31534 m .61347 .31534 L .61543 .44633 L F
.35729 .50781 m .25149 .47325 L .36642 .50267 L .688 0 0 r
F
.35729 .50781 m .23395 .48404 L .25149 .47325 L F
0 g
.35729 .50781 m
.35729 .50781 L
s
.36642 .50267 m .35729 .50781 L .23395 .48404 L .688 0 0 r
F
0 g
.35729 .50781 m
.35729 .50781 L
s
.35729 .50781 m
.36642 .50267 L
s
.35585 .50753 m
.35729 .50781 L
s
.35585 .50753 m
.35729 .50781 L
s
.54267 .49008 m .54197 .36338 L .52613 .36032 L .89 0 0 r
F
.54197 .36338 m .5808 .3087 L .52613 .36032 L .71 0 0 r
F
0 g
.82641 .50708 m
.82641 .50708 L
s
.82641 .50708 m
.82641 .50708 L
s
.42227 .3605 m .36427 .3091 L .33206 .31585 L .71 0 0 r
F
.43792 .48538 m .42227 .3605 L .42098 .48746 L .735 0 0 r
F
0 g
.40663 .36361 m
.42227 .3605 L
s
0 0 0 r
.43644 .47358 m
.43769 .32122 L
s
.43792 .48538 m .43894 .35822 L .42227 .3605 L .735 0 0 r
F
.43894 .35822 m .36427 .3091 L .42227 .3605 L .71 0 0 r
F
.42227 .3605 m .43792 .48538 L .43894 .35822 L .735 0 0 r
F
.42227 .3605 m .43792 .48538 L .43894 .35822 L F
0 g
.42227 .3605 m
.42227 .3605 L
s
.42227 .3605 m .42098 .48746 L .43792 .48538 L .735 0 0 r
F
.42227 .3605 m .42098 .48746 L .43792 .48538 L F
.42227 .3605 m .39886 .30413 L .36427 .3091 L .71 0 0 r
F
.42227 .3605 m .43894 .35822 L .39886 .30413 L F
.42227 .3605 m .39886 .30413 L .36427 .3091 L F
.42227 .3605 m .43894 .35822 L .39886 .30413 L F
0 g
.42227 .3605 m
.42227 .3605 L
s
.42227 .3605 m .36427 .3091 L .33206 .31585 L .71 0 0 r
F
0 g
.25513 .36036 m
.35959 .38286 L
s
.43792 .48538 m .42227 .3605 L .42098 .48746 L .735 0 0 r
F
0 0 0 r
.43564 .57127 m
.43634 .48558 L
s
.43792 .48538 m .43894 .35822 L .42227 .3605 L .735 0 0 r
F
.43894 .35822 m .36427 .3091 L .42227 .3605 L .71 0 0 r
F
0 g
.42227 .3605 m
.42227 .3605 L
s
.75878 .35114 m .78362 .36038 L .78835 .48735 L .957 0 0 r
F
.78835 .48735 m .75878 .35114 L .78362 .36038 L F
0 g
.78362 .36038 m
.78362 .36038 L
s
.78362 .36038 m
.80451 .37077 L
s
.78362 .36038 m .80955 .49681 L .78835 .48735 L .995 0 0 r
F
.80955 .49681 m .78835 .48735 L .78362 .36038 L F
0 g
.80955 .49681 m
.82641 .50708 L
s
.80955 .49681 m .78835 .48735 L .78362 .36038 L .995 0 0 r
F
.78362 .36038 m .80955 .49681 L .78835 .48735 L F
0 g
.80955 .49681 m
.80955 .49681 L
s
.80955 .49681 m
.82641 .50708 L
s
.78835 .48735 m .75878 .35114 L .78362 .36038 L .957 0 0 r
F
.75878 .35114 m .78362 .36038 L .78835 .48735 L F
0 g
.78362 .36038 m
.78362 .36038 L
s
.78362 .36038 m
.78362 .36038 L
s
.78362 .36038 m
.78362 .36038 L
s
.75878 .35114 m
.78362 .36038 L
s
.52656 .48729 m .52613 .36032 L .50931 .35809 L .864 0 0 r
F
0 g
.52613 .36032 m
.54197 .36338 L
s
0 0 0 r
.51957 .32785 m
.51965 .35946 L
s
.52613 .36032 m .54587 .30386 L .50931 .35809 L .71 0 0 r
F
.52613 .36032 m .5808 .3087 L .54587 .30386 L F
.54267 .49008 m .52613 .36032 L .52656 .48729 L .89 0 0 r
F
.52613 .36032 m .52656 .48729 L .54267 .49008 L F
.50931 .35809 m .52656 .48729 L .52613 .36032 L .864 0 0 r
F
0 g
.52613 .36032 m
.52613 .36032 L
s
.50931 .35809 m .52613 .36032 L .5808 .3087 L .71 0 0 r
F
0 g
.52613 .36032 m
.52613 .36032 L
s
.52613 .36032 m .52656 .48729 L .54267 .49008 L .89 0 0 r
F
.50931 .35809 m .52656 .48729 L .52613 .36032 L .864 0 0 r
F
0 g
.52613 .36032 m
.52613 .36032 L
s
.50931 .35809 m .52613 .36032 L .5808 .3087 L .71 0 0 r
F
.52656 .48729 m .52613 .36032 L .50931 .35809 L .864 0 0 r
F
0 0 0 r
.51985 .43707 m
.52021 .57676 L
s
.52613 .36032 m .54587 .30386 L .50931 .35809 L .71 0 0 r
F
.52613 .36032 m .5808 .3087 L .54587 .30386 L F
.54267 .49008 m .52613 .36032 L .52656 .48729 L .89 0 0 r
F
0 g
.52613 .36032 m
.52613 .36032 L
s
.43894 .35822 m .39886 .30413 L .36427 .3091 L .71 0 0 r
F
.45558 .48411 m .43894 .35822 L .43792 .48538 L .764 0 0 r
F
0 g
.42227 .3605 m
.43894 .35822 L
s
.45558 .48411 m .45631 .35682 L .43894 .35822 L .764 0 0 r
F
.45631 .35682 m .39886 .30413 L .43894 .35822 L .71 0 0 r
F
.43894 .35822 m .45558 .48411 L .45631 .35682 L .764 0 0 r
F
0 g
.43894 .35822 m
.43894 .35822 L
s
.43894 .35822 m .43792 .48538 L .45558 .48411 L .764 0 0 r
F
.43894 .35822 m .43511 .30107 L .39886 .30413 L .71 0 0 r
F
.43894 .35822 m .45631 .35682 L .43511 .30107 L F
.43894 .35822 m .45558 .48411 L .45631 .35682 L .764 0 0 r
F
.43894 .35822 m .43792 .48538 L .45558 .48411 L F
0 g
.43894 .35822 m
.43894 .35822 L
s
.43894 .35822 m .43511 .30107 L .39886 .30413 L .71 0 0 r
F
.43894 .35822 m .45631 .35682 L .43511 .30107 L F
0 g
.43894 .35822 m
.43894 .35822 L
s
.43894 .35822 m .39886 .30413 L .36427 .3091 L .71 0 0 r
F
.45558 .48411 m .43894 .35822 L .43792 .48538 L .764 0 0 r
F
.45558 .48411 m .45631 .35682 L .43894 .35822 L F
.45631 .35682 m .39886 .30413 L .43894 .35822 L .71 0 0 r
F
0 g
.43894 .35822 m
.43894 .35822 L
s
.50946 .48527 m .50931 .35809 L .49184 .35675 L .84 0 0 r
F
0 g
.50931 .35809 m
.52613 .36032 L
s
0 0 0 r
.49671 .35713 m
.49672 .32255 L
s
.50931 .35809 m .50942 .30093 L .49184 .35675 L .71 0 0 r
F
.50931 .35809 m .54587 .30386 L .50942 .30093 L F
.52656 .48729 m .50931 .35809 L .50946 .48527 L .864 0 0 r
F
.50931 .35809 m .50946 .48527 L .52656 .48729 L F
.50931 .35809 m .5808 .3087 L .54587 .30386 L .71 0 0 r
F
.49184 .35675 m .50946 .48527 L .50931 .35809 L .84 0 0 r
F
0 g
.50931 .35809 m
.50931 .35809 L
s
.49184 .35675 m .50931 .35809 L .54587 .30386 L .71 0 0 r
F
0 g
.50931 .35809 m
.50931 .35809 L
s
.50931 .35809 m .50946 .48527 L .52656 .48729 L .864 0 0 r
F
.50931 .35809 m .5808 .3087 L .54587 .30386 L .71 0 0 r
F
.49184 .35675 m .50946 .48527 L .50931 .35809 L .84 0 0 r
F
0 g
.50931 .35809 m
.50931 .35809 L
s
.49184 .35675 m .50931 .35809 L .54587 .30386 L .71 0 0 r
F
.50946 .48527 m .50931 .35809 L .49184 .35675 L .84 0 0 r
F
.50931 .35809 m .50942 .30093 L .49184 .35675 L .71 0 0 r
F
.50931 .35809 m .54587 .30386 L .50942 .30093 L F
.52656 .48729 m .50931 .35809 L .50946 .48527 L .864 0 0 r
F
0 g
.50931 .35809 m
.50931 .35809 L
s
.36642 .50267 m .23395 .48404 L .25149 .47325 L .688 0 0 r
F
.37756 .49798 m .36642 .50267 L .25149 .47325 L F
0 g
.35729 .50781 m
.36642 .50267 L
s
.36642 .50267 m .27345 .46329 L .37756 .49798 L .688 0 0 r
F
.36642 .50267 m .25149 .47325 L .27345 .46329 L F
.36642 .50267 m .27345 .46329 L .37756 .49798 L F
.36642 .50267 m .25149 .47325 L .27345 .46329 L F
.36642 .50267 m .23395 .48404 L .25149 .47325 L F
0 g
.23395 .48404 m
.23395 .48404 L
s
.23395 .48404 m
.23395 .48404 L
s
.23395 .48404 m
.23395 .48404 L
s
.37756 .49798 m .36642 .50267 L .25149 .47325 L .688 0 0 r
F
0 g
.36642 .50267 m
.36642 .50267 L
s
.36642 .50267 m
.37756 .49798 L
s
.36642 .50267 m
.37756 .49798 L
s
.37756 .49798 m
.37756 .49798 L
s
.45631 .35682 m .43511 .30107 L .39886 .30413 L .71 0 0 r
F
.47363 .48366 m .45631 .35682 L .45558 .48411 L .791 0 0 r
F
0 g
.43894 .35822 m
.45631 .35682 L
s
0 0 0 r
.47312 .47991 m
.47368 .3172 L
s
.47363 .48366 m .47406 .35632 L .45631 .35682 L .791 0 0 r
F
.47406 .35632 m .43511 .30107 L .45631 .35682 L .71 0 0 r
F
.45631 .35682 m .47363 .48366 L .47406 .35632 L .791 0 0 r
F
0 g
.45631 .35682 m
.45631 .35682 L
s
.45631 .35682 m .45558 .48411 L .47363 .48366 L .791 0 0 r
F
.45631 .35682 m .47223 .29999 L .43511 .30107 L .71 0 0 r
F
.45631 .35682 m .47406 .35632 L .47223 .29999 L F
.45631 .35682 m .47363 .48366 L .47406 .35632 L .791 0 0 r
F
.45631 .35682 m .45558 .48411 L .47363 .48366 L F
0 g
.45631 .35682 m
.45631 .35682 L
s
.45631 .35682 m .47223 .29999 L .43511 .30107 L .71 0 0 r
F
.45631 .35682 m .47406 .35632 L .47223 .29999 L F
0 g
.45631 .35682 m
.45631 .35682 L
s
.45631 .35682 m .43511 .30107 L .39886 .30413 L .71 0 0 r
F
.47363 .48366 m .45631 .35682 L .45558 .48411 L .791 0 0 r
F
0 0 0 r
.47281 .56796 m
.4731 .48367 L
s
.47363 .48366 m .47406 .35632 L .45631 .35682 L .791 0 0 r
F
.47406 .35632 m .43511 .30107 L .45631 .35682 L .71 0 0 r
F
0 g
.45631 .35682 m
.45631 .35682 L
s
.49171 .48405 m .49184 .35675 L .47406 .35632 L .815 0 0 r
F
0 g
.49184 .35675 m
.50931 .35809 L
s
.49184 .35675 m .47223 .29999 L .47406 .35632 L .71 0 0 r
F
.49184 .35675 m .50942 .30093 L .47223 .29999 L F
.50946 .48527 m .49184 .35675 L .49171 .48405 L .84 0 0 r
F
.49184 .35675 m .49171 .48405 L .50946 .48527 L F
.49184 .35675 m .54587 .30386 L .50942 .30093 L .71 0 0 r
F
.47406 .35632 m .49171 .48405 L .49184 .35675 L .815 0 0 r
F
.47406 .35632 m .49184 .35675 L .50942 .30093 L .71 0 0 r
F
0 g
.49184 .35675 m
.49184 .35675 L
s
.49184 .35675 m .49171 .48405 L .50946 .48527 L .84 0 0 r
F
.49184 .35675 m .54587 .30386 L .50942 .30093 L .71 0 0 r
F
0 g
.54197 .36338 m
.5811 .33709 L
s
.47406 .35632 m .49171 .48405 L .49184 .35675 L .815 0 0 r
F
0 g
.49184 .35675 m
.49184 .35675 L
s
.47406 .35632 m .49184 .35675 L .50942 .30093 L .71 0 0 r
F
.49171 .48405 m .49184 .35675 L .47406 .35632 L .815 0 0 r
F
.49184 .35675 m .47223 .29999 L .47406 .35632 L .71 0 0 r
F
.49184 .35675 m .50942 .30093 L .47223 .29999 L F
.50946 .48527 m .49184 .35675 L .49171 .48405 L .84 0 0 r
F
0 g
.49184 .35675 m
.49184 .35675 L
s
0 0 0 r
.49662 .57238 m
.49665 .48439 L
s
.25149 .47325 m .23833 .35674 L .25562 .34489 L .431 0 0 r
F
.25149 .47325 m .23395 .48404 L .23833 .35674 L F
0 g
.23395 .48404 m
.23833 .35674 L
s
.23395 .48404 m
.23833 .35674 L
s
.47406 .35632 m .47223 .29999 L .43511 .30107 L .71 0 0 r
F
.49171 .48405 m .47406 .35632 L .47363 .48366 L .815 0 0 r
F
.47406 .35632 m .47363 .48366 L .49171 .48405 L F
.47406 .35632 m .50942 .30093 L .47223 .29999 L .71 0 0 r
F
0 g
.45631 .35682 m
.47406 .35632 L
s
.47406 .35632 m
.49184 .35675 L
s
.47406 .35632 m .47363 .48366 L .49171 .48405 L .815 0 0 r
F
.47406 .35632 m .50942 .30093 L .47223 .29999 L .71 0 0 r
F
0 g
.47406 .35632 m
.47406 .35632 L
s
.47406 .35632 m
.47406 .35632 L
s
.47406 .35632 m
.47406 .35632 L
s
.47406 .35632 m .47223 .29999 L .43511 .30107 L .71 0 0 r
F
.49171 .48405 m .47406 .35632 L .47363 .48366 L .815 0 0 r
F
0 g
.47406 .35632 m
.47406 .35632 L
s
.47406 .35632 m
.47406 .35632 L
s
.37756 .49798 m .25149 .47325 L .27345 .46329 L .688 0 0 r
F
.39052 .49382 m .37756 .49798 L .27345 .46329 L F
0 g
.37756 .49798 m
.37756 .49798 L
s
.37756 .49798 m .29948 .4544 L .39052 .49382 L .688 0 0 r
F
.37756 .49798 m .27345 .46329 L .29948 .4544 L F
.37756 .49798 m .29948 .4544 L .39052 .49382 L F
.37756 .49798 m .27345 .46329 L .29948 .4544 L F
0 g
.37756 .49798 m
.37756 .49798 L
s
.37756 .49798 m .25149 .47325 L .27345 .46329 L .688 0 0 r
F
.39052 .49382 m .37756 .49798 L .27345 .46329 L F
0 g
.37756 .49798 m
.37756 .49798 L
s
.37756 .49798 m
.39052 .49382 L
s
.37756 .49798 m
.39052 .49382 L
s
.39052 .49382 m
.39052 .49382 L
s
.73043 .34324 m .75878 .35114 L .76314 .47893 L .923 0 0 r
F
.76314 .47893 m .73043 .34324 L .75878 .35114 L F
0 g
.75878 .35114 m
.75878 .35114 L
s
.75878 .35114 m .78835 .48735 L .76314 .47893 L .957 0 0 r
F
.78835 .48735 m .76314 .47893 L .75878 .35114 L F
0 g
.75878 .35114 m
.75878 .35114 L
s
.78835 .48735 m .76314 .47893 L .75878 .35114 L .957 0 0 r
F
.75878 .35114 m .78835 .48735 L .76314 .47893 L F
.76314 .47893 m .73043 .34324 L .75878 .35114 L .923 0 0 r
F
.73043 .34324 m .75878 .35114 L .76314 .47893 L F
0 g
.75878 .35114 m
.75878 .35114 L
s
.75878 .35114 m
.75878 .35114 L
s
.75878 .35114 m
.75878 .35114 L
s
.73043 .34324 m
.75878 .35114 L
s
.80955 .49681 m
.80955 .49681 L
s
.80955 .49681 m
.80955 .49681 L
s
.78835 .48735 m
.80955 .49681 L
s
.39052 .49382 m .27345 .46329 L .29948 .4544 L .688 0 0 r
F
.40508 .49029 m .39052 .49382 L .29948 .4544 L F
0 g
.39052 .49382 m
.39052 .49382 L
s
.39052 .49382 m .32915 .44679 L .40508 .49029 L .688 0 0 r
F
.39052 .49382 m .29948 .4544 L .32915 .44679 L F
0 g
.39052 .49382 m
.39052 .49382 L
s
.39052 .49382 m .32915 .44679 L .40508 .49029 L .688 0 0 r
F
.39052 .49382 m .29948 .4544 L .32915 .44679 L F
.39052 .49382 m .27345 .46329 L .29948 .4544 L F
.40508 .49029 m .39052 .49382 L .29948 .4544 L F
0 g
.39052 .49382 m
.39052 .49382 L
s
.39052 .49382 m
.40508 .49029 L
s
.39052 .49382 m
.40508 .49029 L
s
.40508 .49029 m
.40508 .49029 L
s
.27345 .46329 m .25562 .34489 L .27724 .33396 L .531 0 0 r
F
0 g
.25562 .34489 m
.25562 .34489 L
s
.27345 .46329 m .25149 .47325 L .25562 .34489 L .531 0 0 r
F
0 g
.23833 .35674 m
.25562 .34489 L
s
.25562 .34489 m .27345 .46329 L .25149 .47325 L .531 0 0 r
F
.25562 .34489 m .27345 .46329 L .25149 .47325 L F
0 g
.25562 .34489 m
.25562 .34489 L
s
.25562 .34489 m
.25562 .34489 L
s
.25562 .34489 m .27724 .33396 L .27345 .46329 L .531 0 0 r
F
.25562 .34489 m .27724 .33396 L .27345 .46329 L F
.27345 .46329 m .25562 .34489 L .27724 .33396 L F
.27345 .46329 m .25149 .47325 L .25562 .34489 L F
0 g
.25562 .34489 m
.25562 .34489 L
s
.40508 .49029 m .29948 .4544 L .32915 .44679 L .688 0 0 r
F
.42098 .48746 m .40508 .49029 L .32915 .44679 L F
0 g
.40508 .49029 m
.40508 .49029 L
s
.40508 .49029 m .36191 .44064 L .42098 .48746 L .688 0 0 r
F
.40508 .49029 m .32915 .44679 L .36191 .44064 L F
0 g
.40508 .49029 m
.40508 .49029 L
s
.40508 .49029 m .36191 .44064 L .42098 .48746 L .688 0 0 r
F
.40508 .49029 m .32915 .44679 L .36191 .44064 L F
.40508 .49029 m .29948 .4544 L .32915 .44679 L F
.42098 .48746 m .40508 .49029 L .32915 .44679 L F
0 g
.40508 .49029 m
.40508 .49029 L
s
.40508 .49029 m
.42098 .48746 L
s
.40508 .49029 m
.42098 .48746 L
s
.76314 .47893 m .73433 .47175 L .73043 .34324 L .923 0 0 r
F
.61347 .31534 m .73043 .34324 L .73433 .47175 L p .908 0 0 r
F P
0 g
s
.54267 .49008 m .5822 .44028 L .61543 .44633 L .688 0 0 r
F
.54267 .49008 m .52656 .48729 L .5822 .44028 L F
0 g
.54197 .36338 m
.54258 .47376 L
s
.61543 .44633 m .61347 .31534 L .73043 .34324 L p .908 0 0 r
F P
0 g
s
.73043 .34324 m .73433 .47175 L .61543 .44633 L p .908 0 0 r
F P
0 g
s
.76314 .47893 m .73433 .47175 L .73043 .34324 L .923 0 0 r
F
.73043 .34324 m .76314 .47893 L .73433 .47175 L F
0 g
.73043 .34324 m
.73043 .34324 L
s
.54267 .49008 m .61543 .44633 L .73433 .47175 L p .688 0 0 r
F P
0 g
s
.52656 .48729 m .61543 .44633 L .54267 .49008 L .688 0 0 r
F
.61347 .31534 m .73043 .34324 L .73433 .47175 L p .908 0 0 r
F P
0 g
s
.73043 .34324 m
.73249 .41088 L
s
.73043 .34324 m
.73249 .41088 L
s
.52656 .48729 m .61543 .44633 L .54267 .49008 L .688 0 0 r
F
.54267 .49008 m .61543 .44633 L .73433 .47175 L p F P
0 g
s
.73249 .41088 m
.73433 .47175 L
s
.65865 .51358 m
.73433 .47175 L
s
.65864 .51359 m
.73433 .47175 L
s
.65864 .51359 m
.73433 .47175 L
s
.6588 .5135 m
.73433 .47175 L
s
.73433 .47175 m
.73433 .47175 L
s
.54267 .49008 m .5822 .44028 L .61543 .44633 L .688 0 0 r
F
.54267 .49008 m .52656 .48729 L .5822 .44028 L F
0 g
.52656 .48729 m
.54267 .49008 L
s
.42098 .48746 m .32915 .44679 L .36191 .44064 L .688 0 0 r
F
.43792 .48538 m .42098 .48746 L .36191 .44064 L F
0 g
.42098 .48746 m
.42098 .48746 L
s
.42098 .48746 m
.42098 .48746 L
s
.42098 .48746 m .39709 .43611 L .43792 .48538 L .688 0 0 r
F
.42098 .48746 m .36191 .44064 L .39709 .43611 L F
.42098 .48746 m .39709 .43611 L .43792 .48538 L F
.42098 .48746 m .36191 .44064 L .39709 .43611 L F
0 g
.42098 .48746 m
.42098 .48746 L
s
.42098 .48746 m .32915 .44679 L .36191 .44064 L .688 0 0 r
F
0 g
.23395 .48404 m
.35729 .50781 L
s
.23395 .48404 m
.35585 .50753 L
s
.23395 .48404 m
.35585 .50753 L
s
.43792 .48538 m .42098 .48746 L .36191 .44064 L .688 0 0 r
F
0 g
.42098 .48746 m
.42098 .48746 L
s
.42098 .48746 m
.43792 .48538 L
s
.78835 .48735 m
.78835 .48735 L
s
.76314 .47893 m
.78835 .48735 L
s
.78835 .48735 m
.78835 .48735 L
s
.76314 .47893 m
.78835 .48735 L
s
.52656 .48729 m .54667 .43587 L .5822 .44028 L .688 0 0 r
F
.52656 .48729 m .50946 .48527 L .54667 .43587 L F
.52656 .48729 m .5822 .44028 L .61543 .44633 L F
.50946 .48527 m .5822 .44028 L .52656 .48729 L F
0 g
.52656 .48729 m
.52656 .48729 L
s
.52656 .48729 m
.52656 .48729 L
s
.52656 .48729 m .5822 .44028 L .61543 .44633 L .688 0 0 r
F
.50946 .48527 m .5822 .44028 L .52656 .48729 L F
.52656 .48729 m .54667 .43587 L .5822 .44028 L F
.52656 .48729 m .50946 .48527 L .54667 .43587 L F
0 g
.52656 .48729 m
.52656 .48729 L
s
.50946 .48527 m
.52656 .48729 L
s
.43792 .48538 m .36191 .44064 L .39709 .43611 L .688 0 0 r
F
.45558 .48411 m .43792 .48538 L .39709 .43611 L F
0 g
.43792 .48538 m
.43792 .48538 L
s
.43792 .48538 m .43397 .43332 L .45558 .48411 L .688 0 0 r
F
.43792 .48538 m .39709 .43611 L .43397 .43332 L F
.43792 .48538 m .43397 .43332 L .45558 .48411 L F
.43792 .48538 m .39709 .43611 L .43397 .43332 L F
0 g
.43792 .48538 m
.43792 .48538 L
s
.43792 .48538 m .36191 .44064 L .39709 .43611 L .688 0 0 r
F
.45558 .48411 m .43792 .48538 L .39709 .43611 L F
0 g
.43792 .48538 m
.43792 .48538 L
s
.43792 .48538 m
.45558 .48411 L
s
.50946 .48527 m .50958 .4332 L .54667 .43587 L .688 0 0 r
F
.50946 .48527 m .49171 .48405 L .50958 .4332 L F
.50946 .48527 m .54667 .43587 L .5822 .44028 L F
.49171 .48405 m .54667 .43587 L .50946 .48527 L F
0 g
.50946 .48527 m
.50946 .48527 L
s
.50946 .48527 m
.50946 .48527 L
s
.50946 .48527 m .54667 .43587 L .5822 .44028 L .688 0 0 r
F
.49171 .48405 m .54667 .43587 L .50946 .48527 L F
.50946 .48527 m .50958 .4332 L .54667 .43587 L F
.50946 .48527 m .49171 .48405 L .50958 .4332 L F
0 g
.50946 .48527 m
.50946 .48527 L
s
.49171 .48405 m
.50946 .48527 L
s
.45558 .48411 m .39709 .43611 L .43397 .43332 L .688 0 0 r
F
.47363 .48366 m .45558 .48411 L .43397 .43332 L F
0 g
.43792 .48538 m
.45558 .48411 L
s
.45558 .48411 m
.45558 .48411 L
s
.45558 .48411 m
.45558 .48411 L
s
.45558 .48411 m .47174 .43234 L .47363 .48366 L .688 0 0 r
F
.45558 .48411 m .43397 .43332 L .47174 .43234 L F
0 g
.45558 .48411 m
.45558 .48411 L
s
.45558 .48411 m .47174 .43234 L .47363 .48366 L .688 0 0 r
F
.45558 .48411 m .43397 .43332 L .47174 .43234 L F
0 g
.45558 .48411 m
.45558 .48411 L
s
.45558 .48411 m .39709 .43611 L .43397 .43332 L .688 0 0 r
F
.47363 .48366 m .45558 .48411 L .43397 .43332 L F
0 g
.45558 .48411 m
.45558 .48411 L
s
.49171 .48405 m .47174 .43234 L .50958 .4332 L .688 0 0 r
F
0 g
.49171 .48405 m
.49171 .48405 L
s
.49171 .48405 m .47363 .48366 L .47174 .43234 L .688 0 0 r
F
.49171 .48405 m .50958 .4332 L .54667 .43587 L F
.47363 .48366 m .50958 .4332 L .49171 .48405 L F
0 g
.49171 .48405 m
.49171 .48405 L
s
.49171 .48405 m
.49171 .48405 L
s
.49171 .48405 m .50958 .4332 L .54667 .43587 L .688 0 0 r
F
.47363 .48366 m .50958 .4332 L .49171 .48405 L F
.49171 .48405 m .47174 .43234 L .50958 .4332 L F
.49171 .48405 m .47363 .48366 L .47174 .43234 L F
0 g
.49171 .48405 m
.49171 .48405 L
s
.23395 .48404 m
.23433 .48381 L
s
.25149 .47325 m
.25149 .47325 L
s
.23433 .48381 m
.25149 .47325 L
s
.23395 .48404 m
.23497 .48341 L
s
.25149 .47325 m
.25149 .47325 L
s
.23497 .48341 m
.25149 .47325 L
s
.47363 .48366 m .43397 .43332 L .47174 .43234 L .688 0 0 r
F
0 g
.45558 .48411 m
.47363 .48366 L
s
.47363 .48366 m .47174 .43234 L .50958 .4332 L .688 0 0 r
F
0 g
.47363 .48366 m
.47363 .48366 L
s
.47363 .48366 m
.47363 .48366 L
s
.47363 .48366 m
.47363 .48366 L
s
.47363 .48366 m
.49171 .48405 L
s
.47363 .48366 m .47174 .43234 L .50958 .4332 L .688 0 0 r
F
0 g
.47363 .48366 m
.47363 .48366 L
s
.45558 .48411 m
.47363 .48366 L
s
.47363 .48366 m .43397 .43332 L .47174 .43234 L .688 0 0 r
F
0 g
.47363 .48366 m
.47363 .48366 L
s
.47363 .48366 m
.47363 .48366 L
s
.29948 .4544 m .27724 .33396 L .30287 .3242 L .601 0 0 r
F
.29948 .4544 m .27345 .46329 L .27724 .33396 L F
0 g
.25562 .34489 m
.27724 .33396 L
s
.27724 .33396 m .29948 .4544 L .27345 .46329 L .601 0 0 r
F
.27724 .33396 m .29948 .4544 L .27345 .46329 L F
0 g
.27724 .33396 m
.27724 .33396 L
s
.27724 .33396 m
.27724 .33396 L
s
.27724 .33396 m .30287 .3242 L .29948 .4544 L .601 0 0 r
F
.27724 .33396 m .30287 .3242 L .29948 .4544 L F
.29948 .4544 m .27724 .33396 L .30287 .3242 L F
.29948 .4544 m .27345 .46329 L .27724 .33396 L F
0 g
.27724 .33396 m
.27724 .33396 L
s
.76314 .47893 m
.76314 .47893 L
s
.73433 .47175 m
.76314 .47893 L
s
.76314 .47893 m
.76314 .47893 L
s
.73433 .47175 m
.76314 .47893 L
s
.32915 .44679 m .30287 .3242 L .33206 .31585 L .654 0 0 r
F
.32915 .44679 m .29948 .4544 L .30287 .3242 L F
0 g
.27724 .33396 m
.30287 .3242 L
s
.30287 .3242 m .32915 .44679 L .29948 .4544 L .654 0 0 r
F
.30287 .3242 m .32915 .44679 L .29948 .4544 L F
0 g
.30287 .3242 m
.30287 .3242 L
s
.30287 .3242 m
.30287 .3242 L
s
.30287 .3242 m .33206 .31585 L .32915 .44679 L .654 0 0 r
F
.30287 .3242 m .33206 .31585 L .32915 .44679 L F
.32915 .44679 m .30287 .3242 L .33206 .31585 L F
.32915 .44679 m .29948 .4544 L .30287 .3242 L F
0 g
.30287 .3242 m
.30287 .3242 L
s
.25149 .47325 m
.25149 .47325 L
s
.25149 .47325 m
.25149 .47325 L
s
.27345 .46329 m
.27345 .46329 L
s
.25149 .47325 m
.27345 .46329 L
s
.27345 .46329 m
.27345 .46329 L
s
.25149 .47325 m
.27345 .46329 L
s
.73433 .47175 m .61543 .44633 L .61347 .31534 L p .908 0 0 r
F P
0 g
s
.54267 .49008 m
.61543 .44633 L
s
.54267 .49008 m
.61543 .44633 L
s
.61543 .44633 m
.61543 .44633 L
s
.36191 .44064 m .33206 .31585 L .36427 .3091 L .696 0 0 r
F
.36191 .44064 m .32915 .44679 L .33206 .31585 L F
0 g
.30287 .3242 m
.33206 .31585 L
s
.33206 .31585 m .36191 .44064 L .32915 .44679 L .696 0 0 r
F
.33206 .31585 m .36191 .44064 L .32915 .44679 L F
0 g
.33206 .31585 m
.33206 .31585 L
s
.33206 .31585 m
.33206 .31585 L
s
.33206 .31585 m .36427 .3091 L .36191 .44064 L .696 0 0 r
F
.33206 .31585 m .36427 .3091 L .36191 .44064 L F
.36191 .44064 m .33206 .31585 L .36427 .3091 L F
.36191 .44064 m .32915 .44679 L .33206 .31585 L F
0 g
.33206 .31585 m
.33206 .31585 L
s
.61543 .44633 m
.61543 .44633 L
s
.61543 .44633 m .5808 .3087 L .61347 .31534 L .894 0 0 r
F
0 g
.27345 .46329 m
.27345 .46329 L
s
.27345 .46329 m
.27345 .46329 L
s
.29948 .4544 m
.29948 .4544 L
s
.27345 .46329 m
.29948 .4544 L
s
.29948 .4544 m
.29948 .4544 L
s
.27345 .46329 m
.29948 .4544 L
s
.39709 .43611 m .36427 .3091 L .39886 .30413 L .731 0 0 r
F
.39709 .43611 m .36191 .44064 L .36427 .3091 L F
0 g
.33206 .31585 m
.36427 .3091 L
s
.36427 .3091 m .39709 .43611 L .36191 .44064 L .731 0 0 r
F
.36427 .3091 m .39709 .43611 L .36191 .44064 L F
0 g
.36427 .3091 m
.36427 .3091 L
s
.36427 .3091 m
.36427 .3091 L
s
.36427 .3091 m .39886 .30413 L .39709 .43611 L .731 0 0 r
F
.36427 .3091 m .39886 .30413 L .39709 .43611 L F
0 g
.36427 .3091 m
.36427 .3091 L
s
.39709 .43611 m .36427 .3091 L .39886 .30413 L .731 0 0 r
F
.39709 .43611 m .36191 .44064 L .36427 .3091 L F
0 g
.36427 .3091 m
.36427 .3091 L
s
.5822 .44028 m .54587 .30386 L .5808 .3087 L .867 0 0 r
F
0 g
.5808 .3087 m
.61347 .31534 L
s
.54587 .30386 m .5808 .3087 L .5822 .44028 L .867 0 0 r
F
0 g
.5808 .3087 m
.5808 .3087 L
s
.5808 .3087 m
.5808 .3087 L
s
.54587 .30386 m .5808 .3087 L .5822 .44028 L .867 0 0 r
F
0 g
.5808 .3087 m
.5808 .3087 L
s
.5822 .44028 m .54587 .30386 L .5808 .3087 L .867 0 0 r
F
.61543 .44633 m .5822 .44028 L .5808 .3087 L .894 0 0 r
F
0 g
.5808 .3087 m
.5808 .3087 L
s
.61543 .44633 m
.61543 .44633 L
s
.61347 .31534 m
.61543 .44633 L
s
.61347 .31534 m
.61543 .44633 L
s
.43397 .43332 m .39886 .30413 L .43511 .30107 L .762 0 0 r
F
.43397 .43332 m .39709 .43611 L .39886 .30413 L F
0 g
.36427 .3091 m
.39886 .30413 L
s
.39886 .30413 m .43397 .43332 L .39709 .43611 L .762 0 0 r
F
0 g
.39886 .30413 m
.39886 .30413 L
s
.39886 .30413 m .43511 .30107 L .43397 .43332 L .762 0 0 r
F
0 g
.39886 .30413 m
.39886 .30413 L
s
.39886 .30413 m .43397 .43332 L .39709 .43611 L .762 0 0 r
F
0 g
.39886 .30413 m
.39886 .30413 L
s
.39886 .30413 m .43511 .30107 L .43397 .43332 L .762 0 0 r
F
0 g
.39886 .30413 m
.39886 .30413 L
s
.43397 .43332 m .39886 .30413 L .43511 .30107 L .762 0 0 r
F
.43397 .43332 m .39709 .43611 L .39886 .30413 L F
0 g
.39886 .30413 m
.39886 .30413 L
s
.54667 .43587 m .50942 .30093 L .54587 .30386 L .841 0 0 r
F
0 g
.54587 .30386 m
.5808 .3087 L
s
.5822 .44028 m .54667 .43587 L .54587 .30386 L .867 0 0 r
F
.54587 .30386 m .5822 .44028 L .54667 .43587 L F
.50942 .30093 m .54587 .30386 L .54667 .43587 L .841 0 0 r
F
0 g
.54587 .30386 m
.54587 .30386 L
s
.54587 .30386 m
.54587 .30386 L
s
.54587 .30386 m .5822 .44028 L .54667 .43587 L .867 0 0 r
F
.50942 .30093 m .54587 .30386 L .54667 .43587 L .841 0 0 r
F
0 g
.54587 .30386 m
.54587 .30386 L
s
.54667 .43587 m .50942 .30093 L .54587 .30386 L .841 0 0 r
F
.5822 .44028 m .54667 .43587 L .54587 .30386 L .867 0 0 r
F
0 g
.54587 .30386 m
.54587 .30386 L
s
.29948 .4544 m
.29948 .4544 L
s
.29948 .4544 m
.29948 .4544 L
s
.32915 .44679 m
.32915 .44679 L
s
.29948 .4544 m
.32915 .44679 L
s
.32915 .44679 m
.32915 .44679 L
s
.29948 .4544 m
.32915 .44679 L
s
.47174 .43234 m .43511 .30107 L .47223 .29999 L .79 0 0 r
F
.47174 .43234 m .43397 .43332 L .43511 .30107 L F
0 g
.39886 .30413 m
.43511 .30107 L
s
.43511 .30107 m .47174 .43234 L .43397 .43332 L .79 0 0 r
F
0 g
.43511 .30107 m
.43511 .30107 L
s
.43511 .30107 m .47223 .29999 L .47174 .43234 L .79 0 0 r
F
.43511 .30107 m .47174 .43234 L .43397 .43332 L F
0 g
.43511 .30107 m
.43511 .30107 L
s
.43511 .30107 m .47223 .29999 L .47174 .43234 L .79 0 0 r
F
0 g
.43511 .30107 m
.43511 .30107 L
s
.47174 .43234 m .43511 .30107 L .47223 .29999 L .79 0 0 r
F
.47174 .43234 m .43397 .43332 L .43511 .30107 L F
0 g
.43511 .30107 m
.43511 .30107 L
s
.50958 .4332 m .47223 .29999 L .50942 .30093 L .816 0 0 r
F
0 g
.50942 .30093 m
.54587 .30386 L
s
.54667 .43587 m .50958 .4332 L .50942 .30093 L .841 0 0 r
F
.50942 .30093 m .54667 .43587 L .50958 .4332 L F
.47223 .29999 m .50942 .30093 L .50958 .4332 L .816 0 0 r
F
0 g
.50942 .30093 m
.50942 .30093 L
s
.50942 .30093 m
.50942 .30093 L
s
.50942 .30093 m .54667 .43587 L .50958 .4332 L .841 0 0 r
F
.47223 .29999 m .50942 .30093 L .50958 .4332 L .816 0 0 r
F
0 g
.50942 .30093 m
.50942 .30093 L
s
.50958 .4332 m .47223 .29999 L .50942 .30093 L .816 0 0 r
F
.54667 .43587 m .50958 .4332 L .50942 .30093 L .841 0 0 r
F
0 g
.50942 .30093 m
.50942 .30093 L
s
.50958 .4332 m .47174 .43234 L .47223 .29999 L .816 0 0 r
F
.47223 .29999 m .50958 .4332 L .47174 .43234 L F
0 g
.43511 .30107 m
.47223 .29999 L
s
.47223 .29999 m
.50942 .30093 L
s
.47223 .29999 m .50958 .4332 L .47174 .43234 L .816 0 0 r
F
0 g
.47223 .29999 m
.47223 .29999 L
s
.47223 .29999 m
.47223 .29999 L
s
.47223 .29999 m
.47223 .29999 L
s
.50958 .4332 m .47174 .43234 L .47223 .29999 L .816 0 0 r
F
0 g
.47223 .29999 m
.47223 .29999 L
s
.47223 .29999 m
.47223 .29999 L
s
.32915 .44679 m
.32915 .44679 L
s
.32915 .44679 m
.32915 .44679 L
s
.36191 .44064 m
.36191 .44064 L
s
.32915 .44679 m
.36191 .44064 L
s
.36191 .44064 m
.36191 .44064 L
s
.32915 .44679 m
.36191 .44064 L
s
.5822 .44028 m
.5822 .44028 L
s
.5822 .44028 m
.61503 .44625 L
s
.61503 .44625 m
.61543 .44633 L
s
.5822 .44028 m
.5822 .44028 L
s
.5822 .44028 m
.5822 .44028 L
s
.5822 .44028 m
.61543 .44633 L
s
.36191 .44064 m
.36191 .44064 L
s
.36191 .44064 m
.36191 .44064 L
s
.39709 .43611 m
.39709 .43611 L
s
.39709 .43611 m
.39709 .43611 L
s
.36191 .44064 m
.39709 .43611 L
s
.54667 .43587 m
.54667 .43587 L
s
.54667 .43587 m
.5822 .44028 L
s
.54667 .43587 m
.54667 .43587 L
s
.54667 .43587 m
.54667 .43587 L
s
.54667 .43587 m
.5822 .44028 L
s
.39709 .43611 m
.43397 .43332 L
s
.39709 .43611 m
.39709 .43611 L
s
.39709 .43611 m
.39709 .43611 L
s
.43397 .43332 m
.43397 .43332 L
s
.43397 .43332 m
.43397 .43332 L
s
.39709 .43611 m
.43397 .43332 L
s
.43397 .43332 m
.43397 .43332 L
s
.39709 .43611 m
.43397 .43332 L
s
.50958 .4332 m
.50958 .4332 L
s
.50958 .4332 m
.50958 .4332 L
s
.50958 .4332 m
.50958 .4332 L
s
.50958 .4332 m
.54667 .43587 L
s
.43397 .43332 m
.47174 .43234 L
s
.43397 .43332 m
.43397 .43332 L
s
.47174 .43234 m
.47174 .43234 L
s
.47174 .43234 m
.47174 .43234 L
s
.43397 .43332 m
.47174 .43234 L
s
.47174 .43234 m
.47174 .43234 L
s
.43397 .43332 m
.47174 .43234 L
s
.47174 .43234 m
.47174 .43234 L
s
.47174 .43234 m
.47174 .43234 L
s
.47174 .43234 m
.47174 .43234 L
s
.47174 .43234 m
.50958 .4332 L
s
[ .01 .01 ] 0 setdash
.35623 .17131 m
.96875 .32662 L
s
.96875 .32662 m
.98487 .58711 L
s
.98487 .58711 m
.35065 .45949 L
s
.35065 .45949 m
.35623 .17131 L
s
.06722 .42225 m
.05351 .66515 L
s
.05351 .66515 m
.35065 .45949 L
s
.35065 .45949 m
.35623 .17131 L
s
.35623 .17131 m
.06722 .42225 L
s
.003 w
[ ] 0 setdash
.96875 .32662 m
.98487 .58711 L
s
.25 Mabswid
.96912 .33262 m
.96306 .33109 L
s
gsave
.98124 .33568 -61 -9.23351 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.97287 .39315 m
.96679 .39169 L
s
gsave
.98502 .39607 -61 -9.31844 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.97667 .45466 m
.97058 .45327 L
s
gsave
.98886 .45744 -61 -9.40487 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.98054 .51717 m
.97443 .51585 L
s
gsave
.99276 .5198 -61 -9.49284 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2.5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.98447 .5807 m
.97834 .57946 L
s
gsave
.99672 .58318 -61 -9.58239 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.96986 .34465 m
.96623 .34374 L
s
.97061 .35672 m
.96697 .35582 L
s
.97136 .36882 m
.96772 .36793 L
s
.97211 .38097 m
.96847 .38009 L
s
.97362 .40538 m
.96997 .40451 L
s
.97438 .41764 m
.97073 .41678 L
s
.97514 .42994 m
.97149 .42909 L
s
.97591 .44228 m
.97225 .44144 L
s
.97744 .46708 m
.97378 .46626 L
s
.97821 .47954 m
.97455 .47873 L
s
.97898 .49205 m
.97532 .49124 L
s
.97976 .50459 m
.9761 .50379 L
s
.98132 .52979 m
.97765 .52901 L
s
.9821 .54246 m
.97843 .54169 L
s
.98289 .55516 m
.97922 .5544 L
s
.98368 .56791 m
.98001 .56716 L
s
gsave
1.0498 .47133 -61 -9.40487 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Z) show
73.312500 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{336, 336},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005@0001D1000`40O003h00OogooDGoo003oOomA
Ool00?mooe5oo`00ogooDGoo003oOomAOol00?mooe5oo`00ogooDGoo003oOomAOol00?mooe5oo`00
ogooDGoo003oOomAOol00?mooe5oo`00ogooDGoo003oOomAOol00?mooe5oo`00ogooDGoo003oOomA
Ool00?mooe5oo`00ogooDGoo003oOomAOol00?mooe5oo`00ogooDGoo003oOomAOol00?mooe5oo`00
ogooDGoo003oOomAOol00?mooe5oo`00ogooDGoo003oOomAOol00?mooe5oo`00ogooDGoo003oOomA
Ool00?mooe5oo`00ogooDGoo003oOomAOol00?mooe5oo`00ogooDGoo003oOomAOol00?mooe5oo`00
ogooDGoo003oOomAOol00?mooe5oo`00ogooDGoo003oOomAOol00?mooe5oo`00ogooDGoo003oOomA
Ool00?mooe5oo`00ogooDGoo003oOomAOol00?mooe5oo`00ogooDGoo003oOomAOol00?mooe5oo`00
ogooDGoo003oOomAOol00?mooe5oo`00ogooDGoo003oOomAOol00?mooe5oo`00ogooDGoo0026Ool4
0011Ool30022Ool008Ioo`05001oogooOol00011Ool00`00Oomoo`21Ool008Moo`03001oogoo049o
o`03001oogoo085oo`00Ogoo1`000Woo00<007ooOol0@Goo00<007ooOol0PGoo0029Ool00`00Oomo
o`0oOol00`00Ool00022Ool008Uoo`03001oogoo03moo`03001oo`00089oo`00QWoo00@007ooOol0
041oo`05001oogooOol00021Ool006aoo`@001Moo`80041oo`<00004Ool000000020Ool006]oo`80
009oo`H00=]oo`00JWoo00<007oo000017oo00<007oo00000`00fGoo001gOol5003DOol006Moo`80
019oo`H00<moo`00IWoo00<007ooOol00goo00<007ooOol047oo1000cGoo001UOol00`00Oomoo`04
Ool00`00Oomoo`0DOol50038Ool006aoo`03001oogoo01Ioo`03001oo`0000D00<=oo`00Hgoo00<0
07ooOol01Woo00<007ooOol05Woo00<007ooOol00goo1000`Goo001ROol00`00Oomoo`0ZOol5002l
Ool0065oo`03001oogoo02moo`H00;Moo`00K7oo00<007ooOol0:7oo1000]Goo001NOol00`00Oomo
o`0;Ool00`00Oomoo`0YOol00`00Oomoo`05000]Ool30020Ool005eoo`03001oogoo00aoo`03001o
ogoo031oo`H002Moo`05001oogooOol0001oOol005aoo`03001oogoo00eoo`03001oogoo03Aoo`@0
02Eoo`05001oogooOol0001oOol00:Moo`D0021oo`05001oogooOol0001oOol005Yoo`03001oogoo
04ioo`D001aoo`05001oogooOol0001oOol005Uoo`03001oogoo011oo`03001oogoo03aoo`04001o
ogooOol4000IOol01@00Oomoogoo0000Ogoo001HOol00`00Oomoo`0AOol00`00Oomoo`14Ool4000E
Ool01@00Oomoogoo0000Ogoo001/Ool00`00Oomoo`18Ool5000AOol30020Ool005Eoo`03001oogoo
01Aoo`03001oogoo04aoo`@0095oo`00E7oo00<007ooOol0IWoo00<007oo00000`00SGoo001COol0
0`00Oomoo`1]Ool50028Ool006aoo`03001oogoo05Qoo`@008Eoo`00D7oo0P006Woo00<007ooOol0
G7oo1000PGoo001?Ool00`00Oomoo`0JOol00`00Oomoo`1OOol6001lOol004ioo`03001oogoo01]o
o`03001oogoo061oo`03001oogoo00@007Yoo`00K7oo00<007ooOol0H7oo00<007ooOol017oo1@00
MGoo001<Ool00`00Oomoo`2;Ool6001`Ool004]oo`03001oogoo091oo`@002ioo`@003aoo`00BWoo
00<007ooOol07goo00<007ooOol0LWoo1P00:Goo00D007ooOomoo`0003]oo`00K7oo00<007ooOol0
Mgoo1P009Goo00<007ooOol0?7oo0017Ool00`00Oomoo`0ROol00`00Oomoo`1kOol4000TOol00`00
Oomoo`0kOol004Ioo`03001oogoo02=oo`03001oogoo07moo`D0021oo`03001oogoo03Yoo`00AGoo
00<007ooOol0ZWoo1@0077oo00<007ooOol0>Woo003bOol01000Oomoogoo10005Woo00@007ooOol0
03aoo`00@Woo0P00:7oo00<007ooOol0Rgoo10004goo0P00?Goo0011Ool00`00Oomoo`0XOol00`00
Oomoo`2?Ool5001=Ool0041oo`03001oogoo02Uoo`03001oogoo09=oo`@004Yoo`00K7oo00<007oo
Ool047oo8`00HGoo00<007ooOol01000AWoo000nOol00`00Oomoo`0fOol80005H00<I00BJ008001P
Ool50011Ool003eoo`03001oogoo02moo`03001oogoo00D0009L00]P00aT01IX00A/00D0009oo`03
001oogoo05Yoo`@003ioo`00?7oo00<007ooOol0;7oo00<007oo000010001e`02f0036@05VP02F`0
1P00GGoo1000>Woo001UOol00`00Oomoo`050002F00:G00;H00<I00FJ00;K004L005001IOol00`00
Oomoo`05000eOol003Uoo`8002Qoo`D000=H0004001H05P0F00:G00;H00<I00FJ00;K009L004001E
Ool00`00Oomoo`04Ool4000bOol003Qoo`03001oogoo02=oo`D0009@00IH0004001H05P0F00:G00;
H00<I00FJ00;K00:L0000`00M01d0005001KOol4000^Ool003Moo`03001oogoo025oo`<000M@00YH
00YL00]P00aT01IX00]/00Y`0003001d07@000Ed00@005]oo`D002Uoo`00F7oo0`0000=<0500D000
1e002UP02U`02f0036@05VP02f`02W0000<007@0M0002G@01@00F7oo00@007oo000002Qoo`00=Goo
00<007ooOol07Goo0`0014`02E001UP000@005P0F01H00YL00]P00aT01IX00]/00Y`0003001d07@0
00id00@005Eoo`<002Qoo`00=7oo00<007ooOol077oo0`001T`02E001UP000@005P0F01H00YL00]P
00aT01IX00]/00Y`0003001d07@0019d00D004moo`03001oogoo008002Moo`00<goo00<007ooOol0
77oo00<00400C0001d`02E001UP000@005P0F01H00YL00]P00aT01IX00]/00Y`0003001d07@001Md
00@004ioo`8000Ioo`<001ioo`00D7oo0P000T0024`02E001UP000@005P0F01H00YL00]P00aT01IX
00]/00Y`0003001d07@001]d00D0049oo`8000Eoo`03001oogoo00Ioo`03001oogoo01eoo`00<7oo
00<007ooOol06goo0P00140024`02E002UP02U`02f0036@05VP02f`02W0000<007@0M00087@00`00
?Goo0P001goo00<007ooOol01Woo00<007ooOol07Goo000_Ool00`00Oomoo`0KOol20005@008C009
D00:F00:G00;H00<I00FJ00;K00:L0000`00M01d000QM0000`00M00000020013Ool20007Ool00`00
Oomoo`0MOol002ioo`03001oogoo01Yoo`800003=010040000A000Q<00U@00IH0004001H05P0F00:
G00;H00<I00FJ00;K00:L0000`00M01d000QM0000`00M01d0002M00300000goo001oo`0aOol2000:
Ool20007Ool00`00Oomoo`0MOol004Uoo`8000<d00I000Q<00U@00IH0004001H05P0F00:G00;H00<
I00FJ00;K00:L0000`00M01d000QM0000`00M01d0005M003000_Ool2000<Ool20007Ool00`00Oomo
o`0MOol002]oo`8001Yoo`8000Dd00I000Q<00U@00IH0004001H05P0F00:G00;H00<I00FJ00;K00:
L0000`00M01d000QM0000`00M01d0005M003N004000iOol20007Ool00`00Oomoo`0MOol002Yoo`03
001oogoo01Uoo`03000/000000Dd00I000Q<00U@00IH0004001H05P0F00:G00;H00<I00FJ00;K00:
L0000`00M01d000QM0000`00M01d0005M007N003000TOol2000AOol00`00Oomoo`04Ool2000OOol0
02Uoo`03001oogoo01Uoo`04000/02`00005=006@008C009D00:F00:G00;H00<I00FJ00;K00:L000
0`00M01d000QM0000`00M01d0005M008N002O0000`00Oomoo`0POol00`00Oomoo`0AOol00`00Oomo
o`0UOol004Aoo`05000/02`0;0000005=006@008C009D00:F00:G00;H00<I00FJ00;K00:L0000`00
M01d000QM0000`00M01d0005M008N003O002000dOol00`00Oomoo`0UOol002Moo`03001oogoo01Uo
o`03000/02`0008/0003000d03@000<d00I000Q<00U@00IH0004001H05P0F00:G00;H00<I00FJ00;
K00:L0000`00M01d000QM0000`00M01d0005M008N005O0000`00Ool0000IOol2000EOol2000WOol0
02Ioo`03001oogoo01Qoo`8000D/0003000d03@000<d00I000Q<00U@00IH0004001H05P0F00:G00;
H00<I00FJ00;K00:L0000`00M01d000QM0000`00M01d0005M008N006O002000GOol2000HOol00`00
Oomoo`0UOol002Eoo`03001oogoo01Qoo`03000/02`000D/0003000d03@000<d00I000Q<00U@00IH
0004001H05P0F00:G00;H00<I00FJ00;K00:L0000`00M01d000QM0000`00M01d0005M008N008O002
000_Ool00`00Oomoo`0UOol003moo`03000/02`000H/0003000d03@000<d00I000Q<00U@00IH0004
001H05P0F00:G00;H00<I00FJ00;K00:L0000`00M01d000QM0000`00M01d0005M008N00:O0000`00
Oomoo`0?Ool2000JOol2000WOol0029oo`03001oogoo01Uoo`03000/02`000L/0003000d03@000<d
00I000Q<00U@00UH00]L00]P00aT01IX00]/00Y`0003001d07@0025d0003001d07@000Ed00Qh00]l
008000eoo`8001eoo`03001oogoo02Eoo`008Goo00<007ooOol067oo0P002R`000<003@0=0000S@0
1d0024`02E002EP02e`02f0036@05VP02f`02g0000<007@0M00087@000<007@0M0001G@027P037`0
00<007ooOol0:Woo0P009Woo000POol00`00Oomoo`0HOol00`00;00/000:;0000`00=00d0002=007
@008C008D007F0000`00F01H000;G00;H00<I00FJ00;K00;L0000`00M01d000PM0000`00M01d0006
M007N00=O0000`00Oomoo`06Ool2000QOol2000VOol003Yoo`03000/02`000//0003000d03@0008d
00M000Q<00Q@00MH0003001H05P000]L00]P00aT01IX00]/00]`0003001d07@0021d0003001d07@0
00Id00Mh00il008000Eoo`03001oogoo021oo`<002Ioo`007Woo00<007ooOol067oo00<002`0;000
32`000<003@0=0000S@01d001d`02E001eP000<005P0F0002e`02f0036@05VP02f`02g0000<007@0
M00087@000<007@0M0001W@01gP03g`000<007ooOol09goo0P001Woo0`000Woo00<007oo00000`00
5Goo000MOol00`00Oomoo`0HOol00`00;00/000=;0000`00=00d0002=007@007C009D007F0000`00
F01H000;G00;H00<I00FJ00;K00;L0000`00M01d000PM0000`00M01d0006M007N00?O0001000Ool0
00009Woo00<007ooOol01Woo00<007ooOol01goo00<007ooOol04Woo000LOol00`00Oomoo`0HOol0
0`00;00/000>;0000`00=00d0002=007@007C009D00:F00;G00;H00<I00FJ00;K00;L0000`00M01d
000PM0000`00M01d0006M007N00@O0000`00Oomoo`0VOol00`00Oomoo`06Ool00`00Oomoo`07Ool0
0`00Oomoo`0BOol003Moo`03000/02`000h/0003000d03@0008d00I000Q<00U@00YH00]L00]P00aT
01IX00]/00]`0003001d07@0021d0003001d07@000Id00Mh015l008002Ioo`8000Moo`03001oogoo
00Moo`03001oogoo019oo`006Goo00<007ooOol06Woo0P0042`000<003@0=0000S@01T0024`02E00
1eP000<005P0F0002e`02f0036@05VP02f`02g0000<007@0M00087@00P001g@01gP04G`000<007oo
Ool09Woo00<007ooOol01Goo00<007ooOol01goo00<007ooOol04Woo000HOol00`00Oomoo`0IOol2
00000b00000/000?;0000`00=00d0002=006@008C009D007F0000`00F01H000;G00;H00<I00FJ00;
K00;L0000`00M01d000PM0020007M007N00AO0000`00Oomoo`0VOol00`00Oomoo`05Ool00`00Oomo
o`03Ool4000EOol001Moo`03001oogoo01Yoo`04000P0200000@;0000`00=00d0002=006@008C009
D007F0000`00F01H000;G00;H00<I00FJ00;K00;L0000`00M01d000PM0020007M007N00BO0000`00
Oomoo`0UOol00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`0EOol003Aoo`<P0003000/02`0
00h/0003000d03@0008d00I000Q<00U@00MH0003001H05P000]L00]P00aT01IX00]/00]`0003001d
07@0021d008000Md00Mh019l008002Eoo`8000Ioo`8000Ioo`@001Aoo`0057oo0`0077oo00D00200
800P000000l/0003000d03@000<d00I000Q<00U@00YH00]L00]P00aT01IX00]/00]`0003001d07@0
021d008000Md00Mh019l02Qoo`03001oogoo02Aoo`0057oo00@007ooOol0009oo`<001Eoo`03000<
0200008P0003000/02`000d/0003000d03@000<d00I000Q<00U@00YH00]L00]P00aT01IX00]/00]`
0003001d07@0021d008000Md00Qh015l02Qoo`03001oogoo02Aoo`0057oo00<007ooOol01Woo00<0
07ooOol04Woo0P`00b0000<002`0;0003B`000<003@0=0000c@01T0024`02E001eP000<005P0F000
2e`02f0036@05VP02f`02g0000<007@0M00087@00P001g@027P04G`09goo0P009Woo000DOol00`00
Oomoo`09Ool4000>Ool2300380000`00;00/000=;0000`00=00d0003=006@008C009D007F0000`00
F01H000;G00;H0000`00I01T0003I00=0005J0000`00J01X0007J00;K00;L0000`00M01d000PM002
0007M008N00AO0000`00Oomoo`0UOol00`00Oomoo`0TOol002Ioo`@000Moo`03000<00`000<P0003
000/02`000d/0003000d03@000<d00I000Q<00U@00MH0003001H05P000QL01@000eH01<000M/00]`
0003001d07@0021d008000Md00Qh015l0003001oogoo02Eoo`03001oogoo02Aoo`00;7oo0`000Woo
00<000`030000b0000<002`0;0003B`000<003@0=0000c@01T0024`02E001eP000@005P0F000009L
00D003AH00D0009/0003L000070000Q`0003001d07@0021d008000Md00Qh015l02Qoo`03001oogoo
02Aoo`0057oo00<007ooOol067oo00<007oo30000P`00b0000<002`0;0003B`000<003@0=0000c@0
1T0024`02E001eP01P00?UP01P001g0000<007@0M00087@00P001g@027P04G`09goo0`009Goo000D
Ool00`00Oomoo`0JOol3300380000`00;00/000=;0000`00=00d0003=006@008C009D0000`00F01H
00050019F0050002L0000`00M01d000QM0000`00M01d0005M008N00AO00XOol00`00Oomoo`0TOol0
01=oo`03001oogoo01]oo`<<00<P0003000/02`000d/0003000d03@0008d00M000Q<00M@00D005=H
00H0021d0003001d07@000Ed00Qh015l02Qoo`8002Eoo`004goo00<007ooOol06goo0P`0120000<0
02`0;0003B`000<003@0=0000S@01d0024`00U001@002EP000<005P0F000BeP00P001EP01@006g@0
00<007@0M0001W@01gP04W`09goo0P009Goo000aOol2300480000`00;00/000=;0000`00=00d0002
=007@007C003000>F0000`00F01H001:F0000`00F01H000:F005000FM0000`00M01d0006M007N00B
O00VOol3000UOol0035oo`8<00@P0003000/02`000d/0003000d03@0008d00M000A<00<0015H0003
001H05P004QH0080019H00D0015d0003001d07@000Id00Mh019l02Moo`8000Eoo`@001aoo`004goo
00<007ooOol06goo0P`0120000<002`0;0003B`000<003@0=0000S@01d0010004eP01000AUP00P00
6EP01@0037@000<007@0M0001W@01gP04W`0:7oo00<007ooOol00goo00D007ooOomoo`0001]oo`00
4goo00<007ooOol06goo0P`0120000<002`0;0003B`000<003@0=0000S@01T000P0075P01000?UP0
0P0085P01@001g@000<007@0M0001W@01gP04W`0:7oo00<007ooOol017oo00<007ooOol077oo000C
Ool00`00Oomoo`0KOol230038002000?;0000`00=00d0002=003@003000EF002000=F004000fF002
000WF0050002M0000`00M01d0006M007N00BO00WOol20007Ool00`00Oomoo`0KOol001=oo`03001o
ogoo01]oo`8<00<P008000l/0003000d03@0008d0003@000000001IH008001EH00<0031H0003001H
05P002aH00D000Id00Mh019l02Qoo`03001oogoo00Ioo`03001oogoo00aoo`H000Qoo`00<7oo0``0
0b000P003b`000@003@0=00d0080039H0003001H05P000<002QH008002iH008000AH00<000=d00Mh
019l02Qoo`03001oogoo00Ioo`03001oogoo00eoo`05001oogooOol00008Ool0031oo`<<00<P0080
00l/0004000d0000000GF002000QF0000`00F01H0003000PF002000_F0000`00F01H0007F0040006
N00BO00XOol00`00Oomoo`03Ool01000Oomoo`003goo00<007ooOol02Woo000`Ool330038002000?
;002000HF0000`00F01H000WF0000`00F01H000KF002000_F002000=F0030004N00BO00WOol20006
Ool2000AOol00`00Oomoo`09Ool001=oo`03001oogoo01Yoo`<<00<P008000h/00D001EH0003001H
05P002=H0003001H000001H000UH0003001H05P002eH0080019H00<00003N01l07`0011l02Qoo`03
001oogoo01Qoo`03001oogoo00Qoo`004goo00<007ooOol06Woo0``00b000P003B`000<005P0F000
0eP01@00;UP02P0000<0]@000GL01@5g00@0005g0GL1M`@000H1M`H0009H008002iH008001MH00<0
011l02Qoo`03001oogoo01Uoo`03001oogoo00Moo`004goo00<007ooOol06Woo0``00b000P0032`0
00<005P0F0002EP01P001eP00P006UP01@000`2e00D0002e0;D0]@0000<0]@030001M`5g00@1M`03
0001M`5g00@1M`030001M`5g00<000030GL0005g00@1M`8002iH008001aH00<000el02Moo`8001Mo
o`05001oogooOol00009Ool001=oo`03001oogoo01Yoo`<<00<P008000X/0080015H00P001QH0003
001H0000008000<0]@050000]@2e0;D000030;D01@000;D0]@2e00001P5g00<0005g0GL0105g00<0
005g0GL00`5g0P0000@1M`0000000081M`030001M`5g00H002EH0003001H05P001mH008000]l02Qo
o`8001Ioo`H000Qoo`00<7oo0``00b000P002B`000<005P0F0005eP01@004eP00`000`2e00D0002e
0;D0]@0000<0]@050000]@2e0;D000030;D00`000GL1M`040GL00`000GL1M`040GL00`000GL1M`04
0GL00`000GL1M`020GL00`000GL0000300040GL6000NF002000TF0020009O00XOol2000TOol0031o
o`<<00<P0003000/02`000L/0003001H05P001EH008000IH00H000YH00<00080]@050000]@2e0;D0
00030;D01@000;D0]@2e00000`2e00<0002e0;D01@000`5g00<0005g0GL0105g00<0005g0GL0105g
00<0005g0GL0105g00D0005g0GL1M`0000<1M`040001M`5g0GL7000GF002000XF0020007O00XOol0
0`00Oomoo`0SOol001=oo`03001oogoo01Yoo`<<00<P0003000/02`000D/008001MH0003001H05P0
00]H00H000AH00040000]@2e00020;D01@000;D0]@2e00000`2e00D0002e0;D0]@0000<0]@<00003
0;D0005g0081M`D000D1M`030001M`5g00@1M`030001M`5g00@1M`030001M`5g00@1M`@000<1M`03
0001M`5g00L0011H008002aH0003001l07`000Al02Qoo`8002Aoo`004goo00<007ooOol06Woo0``0
0b0000<002`0;00012`000<005P0F0005UP000<005P0F0004EP01@000`2e00@0002e0;D000<0]@05
0000]@2e0;D000030;D01@000;D0]@2e00000`2e00<0005g0GL0105g00<0005g00001@001P5g00<0
005g0GL0105g00<0005g0GL01@5g00<0005g0GL00P5g0`001@5g20002UP000<005P0F000;EP00P00
17`0:7oo0P0097oo000BOol00`00Oomoo`0KOol3300380000`00;00/0003;0000`00F01H000/F000
10000;D0]@000`2e00@0002e0;D000<0]@050000]@2e0;D000030;D00`000;D0000200030;D00`00
0GL1M`040GL00`000GL1M`040GL500020GL00`000GL1M`040GL00`000GL1M`050GL00`000GL1M`03
0GL00`000GL000020GL300060GL60003F002000bF0001000O01l07`0:7oo0P0097oo000BOol00`00
Oomoo`0KOol2300480000`00;00/0002;0000`00F01H000EF002000DF00300020;D01@000;D0]@2e
00000P2e00D0002e0;D0]@0000<0]@040000]@2e0;D200020;D01@000;D0]@2e00001P5g00<0005g
0GL0105g00<0005g0GL00P5g1@00105g00<0005g0GL01@5g00<0005g0GL00`5g00<0005g0GL0105g
0P000P5g10001@5g1@00<eP000@007`0O01l02Qoo`03001oogoo029oo`00<7oo0P`0120000<002`0
;0000P005UP00P0055P00P000P2e00@0002e0;D000<0]@040000]@2e00030;D01@000;D0]@2e0000
0P2e0P000`2e00D0002e0;D0]@0000H1M`030001M`5g00@1M`030001M`5g00@1M`030001M`5g00D0
00L1M`030001M`5g00<1M`030001M`5g00@1M`030001M`5g00@1M`030001M`5g00@1M`040001M`5g
0GL4000`F0000`00O01l000VOol3000TOol0031oo`8<00@P0003000/000002eH008000<0]@040000
]@2e00030;D010000;D0]@000`2e00@0002e0;D0]@<000030;D0002e0080]@050000]@2e0;D00006
0GL00`000GL1M`040GL00`000GL1M`040GL00`000GL1M`040GL600020GL00`000GL1M`030GL00`00
0GL1M`040GL00`000GL1M`040GL00`000GL1M`0300000`5g0001M`040GL4000^F0000`00O01l000X
Ool00`00Oomoo`03Ool40003Ool00`00Ool00003000BOol0019oo`03001oogoo01]oo`8<00@P0080
01IH008001AH008000030;D0002e0080]@040000]@2e00030;D010000;D0]@000`2e00<0002e0;D0
0P000`2e00D0002e0;D0]@0000<0]@030001M`5g00@1M`030001M`5g00@1M`030001M`5g00@1M`03
0001M`5g00@1M`030001M`5g00<1M`D000<1M`030001M`5g00@1M`030001M`5g00@1M`030001M`5g
00@1M`D000030GL0000000=00003001H000002]H0003001l07oo02Moo`03001oogoo00=oo`05001o
ogooOol00008Ool00`00Oomoo`0?Ool0019oo`03001oogoo01]oo`8<00<P00D001=H0003001H05P0
01=H00800080]@050000]@2e0;D000020;D01@000;D0]@2e00000P2e00T0002e0;D0]@000;D0002e
00000`2e00D0002e0;D0]@0000<0]@030001M`5g00@1M`030001M`5g00@1M`030001M`5g00@1M`03
0001M`5g00@1M`030001M`5g00D1M`030001M`5g00D000D1M`030001M`5g00@1M`030001M`5g00@1
M`030001M`5g00<1M`@000900003001H000002YH0003001l07oo02Moo`03001oogoo00Aoo`03001o
ogoo00Uoo`03001oogoo00moo`004Woo00<007ooOol06goo0P`00R0000<005P0F0000eP01P0035P0
00<005P0F0004UP00P0000Eh00000;D0]@0000<0]@040000]@2e00030;D010000;D0]@000`2e0P00
0P2e00D0002e0;D0]@0000<0]@050000]@2e0;D000060GL00`000GL1M`040GL00`000GL1M`040GL0
0`000GL1M`040GL00`000GL1M`050GL00`000GL1M`030GL00`000GL0000500060GL00`000GL1M`04
0GL00`000GL1M`030GL20002@0000`00@0000003000ZF0000`00Oomoo`0UOol20007Ool00`00Oomo
o`08Ool00`00Oomoo`0?Ool0019oo`03001oogoo01]oo`8<0003800005P000]H00H000=H008001EH
0004001h07P000030;D01@000;D0]@2e00000P2e00D0002e0;D0]@000080]@030000]@00008000<0
]@050000]@2e0;D000030;D01@000;D0]@2e00001P5g00<0005g0GL0105g00<0005g0GL0105g00<0
005g0GL0105g00<0005g0GL01@5g00<0005g0GL00`5g00<0005g0GL0105g1@000P5g00<0005g0GL0
105g00<0005g0GL00`5g0P00140000@003P0>00X00800004F0000000000TF0000`00Oomoo`0VOol0
0`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`0?Ool002moo`<<0003001H05P0015H00H0019H
00800004O01h07P000030;D01@000;D0]@2e00000P2e00D0002e0;D0]@000080]@800080]@050000
]@2e0;D000030;D01@000;D0]@2e00000`2e00<0005g0GL0105g00<0005g0GL0105g00<0005g0GL0
105g00<0005g0GL0105g00<0005g0GL01@5g00<0005g0GL00`5g00<0005g0GL0105g00<0005g0GL0
0P5g1@00105g00<0005g0GL00`5g0P00140000<003P0>0000RP000<005P0F0000UP000<005P0F000
8UP000<007ooOol09Goo00<007ooOol01Woo00<007ooOol00goo10004Woo000_Ool330000`00F01H
000BF0000`00F01H0002F006000:F0020002O003N0001@000;D0]@2e00000`2e00@0002e0;D000<0
]@040000]@0000030;D01@000;D0]@2e00000`2e00D0002e0;D0]@0000<0]@030001M`5g00@1M`03
0001M`5g00@1M`030001M`5g00@1M`030001M`5g00@1M`030001M`5g00D1M`030001M`5g00<1M`03
0001M`5g00@1M`030001M`5g00@1M`030001M`5g00D000D1M`8000A00003000h03P0008X00034000
000000EH00@001iH0003001oogoo02Eoo`03001oogoo00=oo`04001oogoo0006Ool00`00Oomoo`0B
Ool0019oo`03001oogoo01Yoo`8<0003001H05P001iH00H000=H0003001l07`0009l00=h00050000
]@2e0;D000030;D010000;D0]@000`2e0P0000<0]@000;D00P2e00D0002e0;D0]@0000<0]@050000
]@2e0;D000030;D00`000GL1M`040GL00`000GL1M`040GL00`000GL1M`040GL00`000GL1M`040GL0
0`000GL1M`050GL00`000GL1M`030GL00`000GL1M`040GL00`000GL1M`040GL00`000GL1M`040GL8
0004@0000`00>00h0002:0000a00001H000;F004000HF0000`00Oomoo`0TOol30005Ool20007Ool4
000AOol0019oo`03001oogoo01Yoo`03300005P0019H0080019H00@000Al00=h00050000]@2e0;D0
00030;D010000;D0]@000P2e0P000P2e00D0002e0;D0]@0000<0]@050000]@2e0;D000030;D01@00
0;D0]@2e00001P5g00<0005g0GL0105g00<0005g0GL0105g00<0005g0GL0105g00<0005g0GL01@5g
00<0005g0GL00`5g00<0005g0GL0105g00<0005g0GL0105g00<0005g0GL0105g00<0005g0GL00`5g
0P00140000<003P0>0000RP000<@00`000004EP00`004eP000<007ooOol09Goo0P008goo000BOol0
0`00Oomoo`0JOol00``0001H000AF0000`00F01H000DF0000`00O01l0003O003N0001@000;D0]@2e
00000`2e00<0002e0;D010000`2e00D0002e0;D0]@0000<0]@050000]@2e0;D000030;D01@000;D0
]@2e00001P5g00<0005g0GL0105g00<0005g0GL0105g00<0005g0GL0105g00<0005g0GL01@5g00<0
005g0GL00`5g00<0005g0GL0105g00<0005g0GL0105g00<0005g0GL0105g00<0005g0GL0105g00<0
0400@0000T0000<003P0>0000RP000<@00`0000055P000<005P0F0000`003EP000<007ooOol09Goo
0P008goo000BOol00`00Oomoo`0JOol00``0001H000@F0000`00F01H000DF0000`00O01l0004O003
N0001@000;D0]@2e00000`2e00@0002e0;D00080]@050000]@2e0;D000030;D01@000;D0]@2e0000
0`2e00D0002e0;D0]@0000<0]@030001M`5g00@1M`030001M`5g00@1M`030001M`5g00@1M`030001
M`5g00D1M`030001M`5g00@1M`030001M`5g00<1M`030001M`5g00@1M`030001M`5g00@1M`030001
M`5g00@1M`030001M`5g00@1M`030010040000900003000h03P0008X0003400<000001YH0003001H
05P000<000MH0003001oogoo02Eoo`8002=oo`00;goo00<005P0F0003EP00P005eP000<007`0O000
1G`00gP000D0002e0;D0]@0000<0]@@00080]@050000]@2e0;D000030;D01@000;D0]@2e00000`2e
00D0002e0;D0]@0000<0]@030001M`5g00@1M`030001M`5g00@1M`030001M`5g00@1M`030001M`5g
00D1M`030001M`5g00@1M`030001M`5g00<1M`030001M`5g00@1M`030001M`5g00@1M`030001M`5g
00@1M`030001M`5g00@1M`030010040000900003000h03P0008X0003400<0000021H0003001H05P0
00AH0003001oogoo02Eoo`8002=oo`00;goo00<005P0F00035P000<005P0F0005UP000<007`0O000
1W`00gP000D0002e0;D0]@000080]@800080]@040000]@2e00030;D01@000;D0]@2e00000`2e00D0
002e0;D0]@0000<0]@050000]@2e0;D000060GL00`000GL1M`040GL00`000GL1M`040GL00`000GL1
M`050GL00`000GL1M`040GL00`000GL1M`040GL00`000GL1M`030GL00`000GL1M`040GL00`000GL1
M`040GL00`000GL1M`040GL00`00@0100002@0000`00>00h0002:0000a00001H000SF004000XOol0
0`00Oomoo`0ROol0019oo`03001oogoo01Yoo`03001H05P000]H0003001H05P001MH0003001l07`0
00Il00=h00090000]@2e0;D0002e0000]@000080]@040000]@2e00030;D01@000;D0]@2e00000`2e
00D0002e0;D0]@0000<0]@030000]@2e00D000<1M`030001M`5g00@1M`030001M`5g00@1M`030001
M`5g00D1M`030001M`5g00@1M`030001M`5g00@1M`030001M`5g00<1M`030001M`5g00@1M`030001
M`5g00@1M`030001M`5g00@1M`030010040000900003000h03P0008X0003001H05P002EH0004001o
ogooOol4000ROol00`00Oomoo`0ROol0019oo`03001oogoo01]oo`03001H05P002AH0003001l07`0
00Il00=h00040000]@2e0;D200020;D010000;D0]@000P2e00D0002e0;D0]@0000<0]@050000]@2e
0;D000030;D010000;D0]@2e0`001@7O1@001@5g00<0005g0GL0105g00<0005g0GL01@5g00<0005g
0GL0105g00<0005g0GL0105g00<0005g0GL0105g00<0005g0GL00`5g00<0005g0GL0105g00<0005g
0GL0105g00<00400@0000T0000D003P0>00X000002QH0003001oogoo00Moo`<001ioo`03001oogoo
025oo`004Goo00<007ooOol077oo00<005P0F0001eP00P006eP000<007`0O0001W`00gP000<0002e
00000P000P2e00D0002e0;D0]@000080]@050000]@2e0;D000030;D01@000;D0]@2e00000`2e00D0
002e0;D0]@0000T1g`8000030Ml0000000@000H1M`030001M`5g00D1M`030001M`5g00@1M`030001
M`5g00@1M`030001M`5g00@1M`030001M`5g00@1M`030001M`5g00<1M`030001M`5g00@1M`030010
040000900004000h0000000XF0000`00Oomoo`0;Ool00`00Oomoo`03000GOol2000SOol0015oo`03
001oogoo01aoo`03001H05P000IH0003001H05P001]H008000Ml00=h00800080]@040000]@2e0003
0;D010000;D0]@000`2e00D0002e0;D0]@0000<0]@060000]@2e0;D0002e1P00107O0P001`7O1P00
0P5g00<0005g0GL01@5g00<0005g0GL0105g00<0005g0GL0105g00<0005g0GL0105g00<0005g0GL0
105g00<0005g0GL00`5g00<0005g0GL0105g00@00400@01000@002QH0003001oogoo019oo`03001o
ogoo00<0019oo`03001oogoo025oo`00<Goo00<005P0F00015P000<005P0F00075P00P001g`00gP0
0P000P2e00@0002e0;D000<0]@040000]@2e00030;D01@000;D0]@2e00000`2e00@0002e0;D0]@80
00H1g`H000D1g`8000H1g`D000D1M`030001M`5g00@1M`030001M`5g00@1M`030001M`5g00@1M`03
0001M`5g00@1M`030001M`5g00<1M`030001M`5g00@1M`04001000000004F005000RF0000`00Oomo
o`0IOol00`00Oomoo`0?Ool00`00Oomoo`0QOol0035oo`05001H05P0F000000SF0000`00O01l0004
O003N0001@000;D0]@2e00000P2e00D0002e0;D0]@000080]@050000]@2e0;D000030;D01@000;D0
]@2e00000P2e1@001@7O00<0007O0Ml00P7O1P001P7O0P00107O1P001P5g00<0005g0GL0105g00<0
005g0GL0105g00<0005g0GL0105g00<0005g0GL00`5g00<0005g0GL0105g0P002eP0100075P000<0
07ooOol07Woo10002Goo0`008goo000AOol00`00Oomoo`0OOol2000UF0020004O003N0001@000;D0
]@2e00000P2e00D0002e0;D0]@000080]@050000]@2e0;D000030;D010000;D0]@2e0`001@7O1@00
1`7O00@0007O0Ml1g`H000X1g`H00081M`030001M`5g00@1M`030001M`5g00@1M`030001M`5g00@1
M`030001M`5g00<1M`030001M`5g00@1M`03001H05P000iH00D001IH0003001oogoo02Eoo`@000Eo
o`03001oogoo00=oo`@001Yoo`004Goo00<007ooOol07goo0P009UP00P000g`00gP000D0002e0;D0
]@000080]@050000]@2e0;D000020;D01@000;D0]@2e00000`2e00<0002e0;D01@001@7O0P000P7O
1`001`7O20000`7O0P001P7O1@00105g00<0005g0GL0105g00<0005g0GL0105g00<0005g0GL00`5g
00<0005g0GL0105g00<005P0F0004eP01@0045P000<007ooOol0;7oo10002Goo00<007ooOol05goo
000AOol00`00Oomoo`0QOol00`00F01H000UF0030003N0001@000;D0]@2e00000P2e00D0002e0;D0
]@000080]@050000]@2e0;D000030;D00`000;D000050Ml500070Ml700020Ml200080Ml600040Ml2
00040Ml500060GL00`000GL1M`040GL00`000GL1M`030GL00`000GL1M`040GL00`00F01H000HF004
0009F002000`Ool01000Ool000002Goo00<007ooOol05goo000AOol00`00Oomoo`0LOol00`00Oomo
o`04Ool00`00F01H000VF00400030;D010000;D0]@000`2e00@0002e0;D000<0]@040000]@2e0;D2
00070Ml200020Ml700070Ml500060Ml200050Ml600050Ml200020Ml500000`5g0001M`050GL00`00
0GL1M`030GL00`000GL1M`040GL00`00F01H000LF0050002F002000bOol2000;Ool00`00Oomoo`0G
Ool002moo`03001oogoo00Ioo`03001H05P002MH0003N000002e0080]@040000]@2e00030;D01000
0;D0]@000`2e00<0002e00001@00107O00<0007O0Ml01@7O1`000`7O0P00107O1P001`7O0P00107O
1@002@7O1@000`5g00<0005g0GL00`5g00<0005g0GL0105g00<005P0F0008EP00P00<Goo0`002Woo
0`006Woo000^Ool00`00Oomoo`08Ool00`00F01H000WF0001@000;D0]@2e00000P2e00D0002e0;D0
]@000080]@040000]@2e0;D200060Ml600050Ml00`000Ml1g`050Ml500060Ml200000`7O00000003
00000`7O000000070Ml200020Ml500020Ml200050Ml500040GL00`000GL1M`040GL00`00F01H000O
F002000aOol2000?Ool00`00Oomoo`0HOol0015oo`03001oogoo01Moo`03001oogoo00eoo`8002IH
00050000]@2e0;D000020;D01@000;D0]@2e00000P2e00<0002e0;D01@00107O0P00107O1P001`7O
00<0007O0Ml00P7O1P001`7O1P000`7O0P002@7O1@00107O0P000`7O1P001@5g00<005P0F0007EP0
0P00<Goo0P003Woo00D007ooOomoo`0001Uoo`004Goo00<007ooOol05Woo00<007ooOol047oo00<0
05P0F0008eP000D0002e0;D0]@000080]@050000]@2e0;D000020;D00`000;D000050Ml600050Ml2
00030Ml700080Ml700020Ml00`000Ml1g`040Ml600060Ml200050Ml500050Ml200020Ml500000`5g
001H000LF002000]Ool00`00Oomoo`03000AOol3000JOol0015oo`03001oogoo01Eoo`03001oogoo
019oo`03001H05P0029H00050000]@2e0;D000020;D01@000;D0]@2e00000P2e10001@7O00<0007O
0Ml00P7O1P001`7O20000P7O0P001`7O1@00107O00<0007O0Ml00`7O1P001`7O0P000`7O1@002@7O
0P006eP00P00;goo1000<7oo000AOol00`00Oomoo`0/Ool2000QF0001@000;D0]@2e00000P2e00@0
002e0;D0]@<000@1g`H000H1g`040001g`7O0Ml500000`7O0001g`070Ml600030Ml200050Ml60006
0Ml200000`7O0000000600060Ml200020Ml50000107O000000006UP00`00<7oo0P00<goo000VOol0
0`00Oomoo`0IOol2000OF0001@000;D0]@2e00000P2e00@0002e0;D0]@@000@1g`8000<1g`H000P1
g`L00081g`8000H1g`H000@1g`8000@1g`H000L1g`X000T1g`@001QH0080035oo`8003Eoo`009Goo
00<007ooOol077oo00<005P0000075P000D0002e0;D0]@000080]@040000]@0000040Ml600050Ml2
00020Ml500000`7O000000070Ml600030Ml200050Ml600070Ml800000`7O0001g`050Ml700030Ml3
0004F005000AF002000_Ool4000gOol0015oo`03001oogoo011oo`03001oogoo021oo`<001QH0080
00<0]@030000]@2e00@000D1g`8000<1g`D000P1g`L00081g`8000H1g`<000H1g`<000@1g`L000L1
g`L000030Ml0007O00H1g`@000]H00D000YH0080031oo`8003Yoo`004Goo00<007ooOol03Goo00<0
07ooOol09Woo10004UP00P0000=H00000;D00P2e00<0002e0000107O1P001P7O0P0000<1g`000000
100000<1g`000Ml01P7O1P000`7O0P001@7O1P001`7O200000<1g`0000001P7O1P000`7O0`004UP0
1@000UP00`00;Woo00@007oo000003aoo`0047oo00<007ooOol03Goo00<007ooOol0:goo100000=H
0000F0002EP00P000eP000@0002e0;D0]@8000L1g`040001g`7O0Ml600080Ml700020Ml00`000Ml1
g`040Ml600040Ml200040Ml700070Ml700000`7O000000060Ml4000IF003000_Ool3000nOol0011o
o`03001oogoo00aoo`03001oogoo031oo`H000AH008000EH00030000]@0000D000<1g`8000L1g`03
0001g`7O00D000030Ml0000000L1g`D000<1g`8000D1g`H000L1g`/000H1g`H000<1g`8001YH00<0
02moo`80045oo`00F7oo1`0015P00P001P7O1`000`7O0P001`7O1`000P7O0P001@7O1P001@7O0P00
0`7O1`001`7O1`0000<1g`0000001P7O0`0065P01000;goo0`00@goo000LOol00`00Oomoo`10Ool5
00060Ml200060Ml700030Ml200070Ml600030Ml00`000Ml1g`030Ml600070Ml800000`7O00000006
0Ml600030Ml2000GF003000bOol2000?Ool4000bOol0011oo`03001oogoo00Qoo`03001oogoo04Io
o`X000@1g`030001g`7O00@1g`L000<1g`8000H1g`H000@1g`8000<1g`L000L1g`L000030Ml00000
00H1g`<001EH00@0031oo`03001oo`000080015oo`05001oogooOol0000aOol0011oo`03001oogoo
00Moo`03001oogoo04aoo``000@1g`8000D1g`L000<1g`8000D1g`D000L1g`P000030Ml0000000H1
g`H000<1g`8001AH00<003Aoo`8001Eoo`03001oogoo039oo`0047oo00<007ooOol017oo00<007oo
Ool0EGoo1@0000=H000000001@00107O0P001@7O1P001@7O0P000P7O1`001`7O1`0000<1g`000000
1P7O0`004UP01000=Goo0P0067oo00<007ooOol0<Goo000@Ool00`00Oomoo`03Ool00`00Oomoo`1K
Ool50003F00700030Ml200050Ml500080Ml700000`7O000000060Ml600030Ml2000@F004000fOol3
000KOol00`00Oomoo`0`Ool001Eoo`03001oogoo065oo`T00003F000000000@000H1g`030001g`7O
00P000H1g`L00081g`030001g`7O00@1g`<000aH00H003Qoo`<001eoo`03001oogoo031oo`00PGoo
3P001`7O1`0000<1g`0000001`7O1@000`7O0P001EP02@00>Woo00<007oo00000P0077oo00@007oo
Ool0039oo`0047oo0`00Mgoo30001P7O1`000P7O0P001@7O2P000goo00<007ooOol0?Goo0P0087oo
0P00<goo000@Ool30020Ool600000`7O000000070Ml500030Ml2000<Ool00`00Oomoo`0jOol3001G
Ool001=oo`03001oogoo00<0081oo`H000040Ml0000000050Ml3000>Ool00`00Oomoo`0gOol3001J
Ool001Uoo`03001oogoo00<0081oo`D000<1g`80015oo`03001oogoo035oo`04001oogooOol2001L
Ool001moo`03001oogoo00<007moo`<001=oo`03001oogoo035oo`04001oo`00001NOol002Eoo`03
001oogoo00<00<9oo`<0061oo`00:goo00<007ooOol00`00^Woo0`00HWoo000aOol00`00Oomoo`03
0023Ool00`00Oomoo`0[Ool3001UOol003Moo`03001oogoo00<007eoo`03001oogoo02Uoo`<006Mo
o`00?Goo00<007ooOol01000MWoo00<007ooOol09Woo0`00JWoo0016Ool4001`Ool00`00Oomoo`0U
Ool3001[Ool004aoo`@0091oo`<006eoo`00DWoo1000Qgoo0`00L7oo001HOol4001NOol00`00Oomo
o`0LOol01000Ool00000Lgoo001NOol4001HOol00`00Oomoo`0LOol2000AOol3001QOol006Aoo`@0
059oo`03001oogoo01Uoo`<0019oo`05001oogooOol0001POol006Yoo`@004aoo`03001oogoo01Mo
o`<001Aoo`05001oogooOol0001POol0071oo`@0009oo`<005Ioo`03001oogoo008001Moo`05001o
ogooOol0001POol007Uoo`03001oogoo00<0051oo`<001Uoo`05001oogooOol0001POol007moo`04
001oogooOol3000dOol00`00Oomoo`0?Ool4000KOol01@00Oomoogoo0000H7oo0026Ool00`00Oomo
o`03000^Ool00`00Oomoo`0>Ool2000NOol01@00Oomoogoo0000H7oo002<Ool00`00Oomoo`03000X
Ool00`00Oomoo`08Ool01000Oomoogoo0P008Goo0`00HGoo002BOol00`00Oomoo`03000ROol00`00
Oomoo`08Ool01000Ool00000Qgoo002HOol00`00Oomoo`03000VOol30029Ool009ioo`03001oogoo
00@001aoo`<008aoo`00Ygoo10003goo00<007ooOol00goo0P00SWoo002]Ool40009Ool00`00Ool0
0003002@Ool00;=oo`@000=oo`<009=oo`00^Goo0P00UGoo003oOomAOol00?mooe5oo`00ogooDGoo
0037Ool40025Ool00<Moo`05001oogooOol0000MOol30002Ool3001OOol00<Qoo`03001oogoo021o
o`04001oogoo001QOol00<1oo`L0009oo`03001oogoo01moo`04001oogoo001QOol00<Yoo`03001o
ogoo01moo`80069oo`00bWoo00<007ooOol07goo0P00HWoo0037Ool01000Oomoo`0087oo00@007oo
Ool0065oo`00b7oo0P008Goo00@007ooOol0065oo`00jGoo0`000Woo0`00Ggoo003oOomAOol00?mo
oe5oo`00ogooDGoo003oOomAOol00?mooe5oo`00ogooDGoo003oOomAOol00?mooe5oo`00ogooDGoo
003oOomAOol00?mooe5oo`00ogooDGoo003oOomAOol00?mooe5oo`00ogooDGoo003oOomAOol00?mo
oe5oo`00ogooDGoo003oOomAOol00?mooe5oo`00ogooDGoo003oOomAOol00?mooe5oo`00ogooDGoo
003oOomAOol00?mooe5oo`00ogooDGoo003oOomAOol00?mooe5oo`00ogooDGoo003oOomAOol00?mo
oe5oo`00ogooDGoo003oOomAOol00?mooe5oo`00ogooDGoo003oOomAOol00?mooe5oo`00ogooDGoo
003oOomAOol00?mooe5oo`00ogooDGoo003oOomAOol00?mooe5oo`00ogooDGoo003oOomAOol00?mo
oe5oo`00ogooDGoo003oOomAOol00?mooe5oo`00ogooDGoo003oOomAOol00?mooe5oo`00ogooDGoo
003oOomAOol00?mooe5oo`00ogooDGoo003oOomAOol00?mooe5oo`00ogooDGoo003oOomAOol00?mo
oe5oo`00ogooDGoo003oOomAOol00?mooe5oo`00ogooDGoo003oOomAOol00?mooe5oo`00ogooDGoo
003oOomAOol00?mooe5oo`00ogooDGoo003oOomAOol00?mooe5oo`00ogooDGoo003oOomAOol00?mo
oe5oo`00ogooDGoo0000\
\>"],
  ImageRangeCache->{{{0, 335}, {335, 0}} -> {-5.24905*^-6, -0.0483321, 
  0.00327362, 0.00327362}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0339004 139.57 [
[.02381 -0.0125 -9.125 -14 ]
[.02381 -0.0125 9.125 0 ]
[.18254 -0.0125 -9.125 -14 ]
[.18254 -0.0125 9.125 0 ]
[.34127 -0.0125 -9.125 -14 ]
[.34127 -0.0125 9.125 0 ]
[.5 -0.0125 -5 -14 ]
[.5 -0.0125 5 0 ]
[.65873 -0.0125 -5 -14 ]
[.65873 -0.0125 5 0 ]
[.81746 -0.0125 -5 -14 ]
[.81746 -0.0125 5 0 ]
[.97619 -0.0125 -5 -14 ]
[.97619 -0.0125 5 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -21.0625 -28 ]
[.5 -0.0125 21.0625 -14 ]
[-0.0125 .0339 -10 -7 ]
[-0.0125 .0339 0 7 ]
[-0.0125 .17347 -31 -7 ]
[-0.0125 .17347 0 7 ]
[-0.0125 .31304 -31 -7 ]
[-0.0125 .31304 0 7 ]
[-0.0125 .45261 -31 -7 ]
[-0.0125 .45261 0 7 ]
[-0.0125 .59218 -31 -7 ]
[-0.0125 .59218 0 7 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -66.5 -7 ]
[-0.01875 .30902 -31 7 ]
[ 0 .61803 .125 0 ]
[.5 .63053 -37.1562 0 ]
[.5 .63053 37.1562 14 ]
[ 1 0 .125 0 ]
[ -0.0005 -0.0005 0 0 ]
[ 1.0005 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.18254 0 m
.18254 .61803 L
s
.34127 0 m
.34127 .61803 L
s
.5 0 m
.5 .61803 L
s
.65873 0 m
.65873 .61803 L
s
.81746 0 m
.81746 .61803 L
s
0 .17347 m
1 .17347 L
s
0 .31304 m
1 .31304 L
s
0 .45261 m
1 .45261 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -70.125 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.18254 0 m
.18254 .00625 L
s
gsave
.18254 -0.0125 -70.125 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.34127 0 m
.34127 .00625 L
s
gsave
.34127 -0.0125 -70.125 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.65873 0 m
.65873 .00625 L
s
gsave
.65873 -0.0125 -66 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.81746 0 m
.81746 .00625 L
s
gsave
.81746 -0.0125 -66 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -82.0625 -32 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(X) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
74.625000 14.000000 moveto
(@) show
78.562500 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(mm) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
97.187500 14.000000 moveto
(D) show
101.125000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2
%%+ font Times-Roman
grestore
0 .0339 m
.00625 .0339 L
s
gsave
-0.0125 .0339 -71 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .17347 m
.00625 .17347 L
s
gsave
-0.0125 .17347 -92 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.001) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .31304 m
.00625 .31304 L
s
gsave
-0.0125 .31304 -92 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.002) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .45261 m
.00625 .45261 L
s
gsave
-0.0125 .45261 -92 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.003) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .59218 m
.00625 .59218 L
s
gsave
-0.0125 .59218 -92 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.004) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .06181 m
.00375 .06181 L
s
0 .08973 m
.00375 .08973 L
s
0 .11764 m
.00375 .11764 L
s
0 .14556 m
.00375 .14556 L
s
0 .20138 m
.00375 .20138 L
s
0 .2293 m
.00375 .2293 L
s
0 .25721 m
.00375 .25721 L
s
0 .28513 m
.00375 .28513 L
s
0 .34095 m
.00375 .34095 L
s
0 .36887 m
.00375 .36887 L
s
0 .39678 m
.00375 .39678 L
s
0 .4247 m
.00375 .4247 L
s
0 .48052 m
.00375 .48052 L
s
0 .50844 m
.00375 .50844 L
s
0 .53635 m
.00375 .53635 L
s
0 .56427 m
.00375 .56427 L
s
0 .00599 m
.00375 .00599 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -127.5 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Bz) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
79.312500 14.000000 moveto
(@) show
83.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(T) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
90.562500 14.000000 moveto
(D) show
94.500000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2
%%+ font Times-Roman
grestore
.02381 .61178 m
.02381 .61803 L
s
.18254 .61178 m
.18254 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05556 .61428 m
.05556 .61803 L
s
.0873 .61428 m
.0873 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.15079 .61428 m
.15079 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.24603 .61428 m
.24603 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.37302 .61428 m
.37302 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.43651 .61428 m
.43651 .61803 L
s
.46825 .61428 m
.46825 .61803 L
s
.53175 .61428 m
.53175 .61803 L
s
.56349 .61428 m
.56349 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.62698 .61428 m
.62698 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.75397 .61428 m
.75397 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.84921 .61428 m
.84921 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.9127 .61428 m
.9127 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
gsave
.5 .63053 -98.1562 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Y) show
74.625000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(=) show
85.312500 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
97.312500 14.000000 moveto
(Z) show
107.625000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(=) show
118.312500 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.7) show
133.312500 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.99375 .0339 m
1 .0339 L
s
.99375 .17347 m
1 .17347 L
s
.99375 .31304 m
1 .31304 L
s
.99375 .45261 m
1 .45261 L
s
.99375 .59218 m
1 .59218 L
s
.125 Mabswid
.99625 .06181 m
1 .06181 L
s
.99625 .08973 m
1 .08973 L
s
.99625 .11764 m
1 .11764 L
s
.99625 .14556 m
1 .14556 L
s
.99625 .20138 m
1 .20138 L
s
.99625 .2293 m
1 .2293 L
s
.99625 .25721 m
1 .25721 L
s
.99625 .28513 m
1 .28513 L
s
.99625 .34095 m
1 .34095 L
s
.99625 .36887 m
1 .36887 L
s
.99625 .39678 m
1 .39678 L
s
.99625 .4247 m
1 .4247 L
s
.99625 .48052 m
1 .48052 L
s
.99625 .50844 m
1 .50844 L
s
.99625 .53635 m
1 .53635 L
s
.99625 .56427 m
1 .56427 L
s
.99625 .00599 m
1 .00599 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.001 w
0 .0339 m
1 .0339 L
s
.5 0 m
.5 .61803 L
s
.002 w
.02381 .01472 m
.04262 .02187 L
.06244 .03195 L
.08255 .04524 L
.10458 .06369 L
.14509 .10861 L
.18408 .16451 L
.22553 .23695 L
.26546 .32435 L
.30387 .43773 L
.32332 .50555 L
.33364 .5398 L
.33933 .55666 L
.34474 .5707 L
.34981 .58174 L
.35535 .59118 L
.35778 .59444 L
.36038 .59732 L
.36282 .59947 L
.36505 .601 L
.36752 .60222 L
.36882 .60267 L
.36949 .60285 L
.37019 .60301 L
.37139 .6032 L
.3725 .6033 L
.37318 .60332 L
.37383 .60331 L
.37504 .60323 L
.37613 .60309 L
.37729 .60288 L
.37937 .60233 L
.38161 .60155 L
.38409 .60048 L
.40506 .58793 L
.42429 .57725 L
.44433 .5681 L
.4541 .56441 L
.46298 .56164 L
.47213 .55944 L
.47716 .55852 L
.4819 .55782 L
.48441 .55753 L
.48707 .55726 L
.48937 .55707 L
.49184 .55691 L
.49322 .55684 L
.49448 .55679 L
.49576 .55675 L
.49696 .55672 L
Mistroke
.49764 .5567 L
.49836 .55669 L
.49966 .55669 L
.50046 .55669 L
.50121 .55669 L
.50188 .5567 L
.5026 .55671 L
.50385 .55674 L
.50498 .55677 L
.50753 .55688 L
.5099 .55702 L
.51213 .55719 L
.51714 .5577 L
.52258 .55847 L
.5279 .55944 L
.53354 .56072 L
.54366 .56365 L
.56317 .57131 L
.58146 .58022 L
.59998 .59107 L
.61046 .59758 L
.61557 .60031 L
.61798 .60138 L
.6202 .6022 L
.62135 .60254 L
.6226 .60285 L
.62387 .60309 L
.62456 .60319 L
.6252 .60326 L
.62639 .60332 L
.62748 .6033 L
.62873 .60319 L
.62992 .60299 L
.63116 .60267 L
.63249 .60221 L
.63488 .60104 L
.63744 .59927 L
.64028 .59664 L
.64552 .58989 L
.65117 .57978 L
.66139 .55463 L
.7025 .41652 L
.74209 .30593 L
.78017 .22611 L
.8207 .15704 L
.85971 .10256 L
.8796 .07955 L
.90118 .05846 L
.92057 .04296 L
.94113 .02992 L
Mistroke
.95782 .02168 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{427.375, 264.125},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006[000121000`40O003h00Oogoo[7oo003oOon/
Ool00?moojaoo`00lWoo0`0057oo0`00Wgoo003bOol00`00Oomoo`0FOol00`00Oomoo`2MOol00>Io
o`<0009oo`<000Aoo`04001oogooOol3000017oo000007oo1@0000Aoo`00001oo`8000=oo`03001o
ogoo09eoo`00j7oo00@007ooOol000Ioo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
0Woo00@007ooOol000Aoo`03001oogoo09eoo`00j7oo00@007ooOol000Ioo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo09eoo`00jGoo0P001goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol0
WGoo003YOol20007Ool00`00Oomoo`02Ool200001Goo000007oo00000Woo0P0000Eoo`00001oo`00
00Aoo`03001oogoo09eoo`00j7oo00@007ooOol000Ioo`04001oogooOol200001Goo001oogoo0000
0Woo0P0000Eoo`00Oomoo`0000Eoo`03001oogoo09eoo`00j7oo00@007ooOol000Ioo`03001oogoo
01Ioo`03001oogoo09eoo`00iWoo0`000Woo0`0017oo0`0057oo0`00Wgoo003oOon/Ool00?moojao
o`00ogoo[7oo003oOon/Ool00?moojaoo`00ogoo[7oo001FOol4000cOol4000eOol3000^Ool3000e
Ool3000aOol4000cOol4000=Ool005Yoo`03001oogoo031oo`05001oogooOol0000eOol00`00Oomo
o`0/Ool01@00Oomoogoo0000=Goo00<007ooOol0<7oo00D007ooOomoo`0003Ioo`03001oogoo00Yo
o`00FWoo00<007ooOol0<Goo00<007ooOol0=Woo00<007ooOol0;7oo00D007ooOomoo`0003Eoo`03
001oogoo035oo`03001oogoo03Moo`03001oogoo00Yoo`00Cgoo1`0017oo00<007ooOol0:Goo1`00
0Woo00<007ooOol0:Woo1`0017oo00<007ooOol0;7oo00D007ooOomoo`0003Eoo`03001oogoo039o
o`03001oogoo03Ioo`03001oogoo00Yoo`00Egoo0`00=Woo00<007ooOol0=7oo00<007ooOol0;7oo
00D007ooOomoo`0003Eoo`03001oogoo03=oo`03001oogoo039oo`<000eoo`00FGoo00<007ooOol0
=7oo00<007ooOol0=7oo00<007ooOol0;7oo00D007ooOomoo`0003Eoo`03001oogoo03=oo`03001o
ogoo03Aoo`03001oogoo00]oo`00EWoo00D007ooOomoo`00039oo`04001oogoo000fOol00`00Oomo
o`0/Ool01@00Oomoogoo0000=Goo00<007ooOol0<7oo00@007ooOol003=oo`05001oogooOol0000<
Ool005Moo`<003Aoo`8003Ioo`8002moo`<003Eoo`8003=oo`8003Eoo`<000eoo`00ogoo[7oo003o
Oon/Ool00?moojaoo`00ogoo[7oo003oOon/Ool00?moojaoo`00CGooo`00FP001Goo001=Ool00`00
Oomoo`05Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00
Oomoo`08Ool00`00Oomoo`05Ool00`00Oomoo`03Ool004eoo`8000Ioo`03001oogoo03Aoo`03001o
ogoo03=oo`03001oogoo03Aoo`03001oogoo03Aoo`03001oogoo03=oo`03001oogoo03Aoo`03001o
ogoo00Aoo`8000Eoo`00CGoo00<007ooOol0?7oo00<03gooOol0<goo00<03gooOol0=7oo00<007oo
Ool0=7oo00<03gooOol0<goo00<03gooOol0?7oo00<007ooOol00goo001=Ool00`00Oomoo`0lOol0
0`0?Oomoo`0cOol00`0?Oomoo`0dOol00`00Oomoo`0dOol00`0?Oomoo`0cOol00`0?Oomoo`0lOol0
0`00Oomoo`03Ool004eoo`03001oogoo00Eoo`<003Aoo`0300moogoo03=oo`0300moogoo03Aoo`03
001oogoo03Aoo`0300moogoo03=oo`0300moogoo03=oo`8000Moo`03001oogoo00=oo`00CGoo00<0
07ooOol027oo0`00<Goo00<03gooOol0<goo00<03gooOol0=7oo00<007ooOol0=7oo00<03gooOol0
<goo00<03gooOol0<7oo0`002Goo00<007ooOol00goo001=Ool00`00Oomoo`0;Ool3000^Ool00`0?
Oomoo`0cOol00`0?Oomoo`0dOol00`00Oomoo`0dOol00`0?Oomoo`0cOol00`0?Oomoo`0]Ool3000<
Ool00`00Oomoo`03Ool004eoo`03001oogoo00ioo`8002aoo`0300moogoo03=oo`0300moogoo03Ao
o`03001oogoo03Aoo`0300moogoo03=oo`0300moogoo02]oo`8000moo`03001oogoo00=oo`00@Woo
0`0027oo00<007ooOol047oo00<007ooOol0:Goo00<03gooOol0<goo00<03gooOol0=7oo00<007oo
Ool0=7oo00<03gooOol0<goo00<03gooOol0:Goo0P004Goo00<007ooOol00goo0011Ool01@00Oomo
ogoo00001goo00<007ooOol04Goo0P00:Goo00<03gooOol0<goo00<03gooOol0=7oo00<007ooOol0
=7oo00<03gooOol0<goo00<03gooOol09goo0P004goo00<007ooOol00goo0011Ool01@00Oomoogoo
00001gooo`00FP001Goo0011Ool01@00Oomoogoo00001goo00<007ooOol05Goo0P009Goo00<03goo
Ool0<goo00<03gooOol0=7oo00<007ooOol0=7oo00<03gooOol0<goo00<03gooOol097oo00<007oo
Ool05Goo00<007ooOol00goo0011Ool01@00Oomoogoo00001goo00<007ooOol05goo00<007ooOol0
8Woo00<03gooOol0<goo00<03gooOol0=7oo00<007ooOol0=7oo00<03gooOol0<goo00<03gooOol0
8Woo0P0067oo00<007ooOol00goo0011Ool01@00Oomoogoo00001goo00<007ooOol067oo0P008Woo
00<03gooOol0<goo00<03gooOol0=7oo00<007ooOol0=7oo00<03gooOol0<goo00<03gooOol087oo
0P006Woo00<007ooOol00goo0011Ool01@00Oomoogoo00001goo00<007ooOol06Woo00<007ooOol0
7goo00<03gooOol0<goo00<03gooOol0=7oo00<007ooOol0=7oo00<03gooOol0<goo00<03gooOol0
7goo00<007ooOol06Woo00<007ooOol00goo0012Ool30008Ool00`00Oomoo`0KOol00`00Oomoo`0N
Ool00`0?Oomoo`0cOol00`0?Oomoo`0dOol00`00Oomoo`0dOol00`0?Oomoo`0cOol00`0?Oomoo`0N
Ool00`00Oomoo`0KOol00`00Oomoo`03Ool004eoo`03001oogoo01aoo`03001oogoo01eoo`0300mo
ogoo03=oo`0300moogoo03Aoo`03001oogoo03Aoo`0300moogoo03=oo`0300moogoo01eoo`03001o
ogoo01aoo`03001oogoo00=oo`00CGoo00<007ooOol07Goo00<007ooOol077oo00<03gooOol0<goo
00<03gooOol0=7oo00<007ooOol0=7oo00<03gooOol0<goo00<03gooOol077oo00<007ooOol07Goo
00<007ooOol00goo001=Ool00`00Oomoo`0NOol00`00Oomoo`0KOol00`0?Oomoo`0cOol00`0?Oomo
o`0dOol00`00Oomoo`0dOol00`0?Oomoo`0cOol00`0?Oomoo`0KOol00`00Oomoo`0NOol00`00Oomo
o`03Ool004eoo`03001oogoo01moo`03001oogoo01Yoo`0300moogoo03=oo`0300moogoo03Aoo`03
001oogoo03Aoo`0300moogoo03=oo`0300moogoo01Yoo`03001oogoo01moo`03001oogoo00=oo`00
CGoo0P008Goo00<007ooOol06Goo00<03gooOol0<goo00<03gooOol0=7oo00<007ooOol0=7oo00<0
3gooOol0<goo00<03gooOol06Goo00<007ooOol07goo0P001Goo001=Ool00`00Oomoo`0QOol00`00
Oomoo`0HOol00`0?Oomoo`0cOol00`0?Oomoo`0dOol00`00Oomoo`0dOol00`0?Oomoo`0cOol00`0?
Oomoo`0HOol00`00Oomoo`0QOol00`00Oomoo`03Ool004eoo`03001oogoo025oo`03001oogoo01Qo
o`0300moogoo03=oo`0300moogoo03Aoo`03001oogoo03Aoo`0300moogoo03=oo`0300moogoo01Mo
o`03001oogoo029oo`03001oogoo00=oo`00CGoo00<007ooOol08Woo00<007ooOol05goo00<03goo
Ool0<goo00<03gooOol0=7oo00<007ooOol0=7oo00<03gooOol0<goo00<03gooOol05Woo00<007oo
Ool08goo00<007ooOol00goo001=Ool00`00Oomoo`0SOol00`00Oomoo`0FOol00`0?Oomoo`0cOol0
0`0?Oomoo`0dOol00`00Oomoo`0dOol00`0?Oomoo`0cOol00`0?Oomoo`0EOol00`00Oomoo`0TOol0
0`00Oomoo`03Ool004eoo`03001oogoo02Aoo`03001oogoo01Eoo`0300moogoo03=oo`0300moogoo
03Aoo`03001oogoo03Aoo`0300moogoo03=oo`0300moogoo01Aoo`03001oogoo02Eoo`03001oogoo
00=oo`00CGoo00<007ooOol09Goo00<007ooOol057oo00<03gooOol0<goo00<03gooOol0=7oo00<0
07ooOol0=7oo00<03gooOol0<goo00<03gooOol04goo00<007ooOol09Woo00<007ooOol00goo001=
Ool00`00Oomoo`0VOol00`00Oomoo`0COol00`0?Oomoo`0cOol00`0?Oomoo`0dOol00`00Oomoo`0d
Ool00`0?Oomoo`0cOol00`0?Oomoo`0COol00`00Oomoo`0VOol00`00Oomoo`03Ool004eoo`03001o
ogoo02Moo`03001oogoo019oo`0300moogoo03=oo`0300moogoo03Aoo`03001oogoo03Aoo`0300mo
ogoo03=oo`0300moogoo019oo`03001oogoo02Moo`03001oogoo00=oo`00CGoo00<007ooOol0:7oo
00<007ooOol04Goo00<03gooOol0<goo00<03gooOol0=7oo00<007ooOol0=7oo00<03gooOol0<goo
00<03gooOol04Goo00<007ooOol0:7oo00<007ooOol00goo001=Ool2000ZOol00`00Oomoo`0@Ool0
0`0?Oomoo`0cOol00`0?Oomoo`0dOol00`00Oomoo`0dOol00`0?Oomoo`0cOol00`0?Oomoo`0@Ool0
0`00Oomoo`0XOol20005Ool004eoo`03001oogoo02Yoo`03001oogoo00moo`0300moogoo03=oo`03
00moogoo03Aoo`03001oogoo03Aoo`0300moogoo03=oo`0300moogoo00moo`03001oogoo02Yoo`03
001oogoo00=oo`00CGoo00<007ooOol0:goo00<007ooOol03Woo00<03gooOol0<goo00<03gooOol0
=7oo00<007ooOol0=7oo00<03gooOol0<goo00<03gooOol03Woo00<007ooOol0:goo00<007ooOol0
0goo001=Ool00`00Oomoo`0/Ool00`00Oomoo`0=Ool00`0?Oomoo`0cOol00`0?Oomoo`0dOol00`00
Oomoo`0dOol00`0?Oomoo`0cOol00`0?Oomoo`0=Ool00`00Oomoo`0/Ool00`00Oomoo`03Ool004eo
o`03001oogoo02eoo`03001oogoo00aoo`0300moogoo03=oo`0300moogoo03Aoo`03001oogoo03Ao
o`0300moogoo03=oo`0300moogoo00aoo`03001oogoo02eoo`03001oogoo00=oo`00CGoo00<007oo
Ool0;Woo00<007ooOol02goo00<03gooOol0<goo00<03gooOol0=7oo00<007ooOol0=7oo00<03goo
Ool0<goo00<03gooOol037oo00<007ooOol0;Goo00<007ooOol00goo001=Ool00`00Oomoo`0_Ool0
0`00Oomoo`0:Ool00`0?Oomoo`0cOol00`0?Oomoo`0dOol00`00Oomoo`0dOol00`0?Oomoo`0cOol0
0`0?Oomoo`0;Ool00`00Oomoo`0^Ool00`00Oomoo`03Ool004eoo`03001oogoo02moo`03001oogoo
00Yoo`0300moogoo03=oo`0300moogoo03Aoo`03001oogoo03Aoo`0300moogoo03=oo`0300moogoo
00Yoo`03001oogoo02moo`03001oogoo00=oo`00CGoo00<007ooOol0<7oo00<007ooOol02Goo00<0
3gooOol0<goo00<03gooOol0=7oo00<007ooOol0=7oo00<03gooOol0<goo00<03gooOol02Goo00<0
07ooOol0<7oo00<007ooOol00goo001=Ool2000bOol00`00Oomoo`08Ool00`0?Oomoo`0cOol00`0?
Oomoo`0dOol00`00Oomoo`0dOol00`0?Oomoo`0cOol00`0?Oomoo`09Ool00`00Oomoo`0_Ool20005
Ool004eoo`03001oogoo035oo`03001oogoo00Qoo`0300moogoo03=oo`0300moogoo03Aoo`03001o
ogoo03Aoo`0300moogoo03=oo`0300moogoo00Qoo`03001oogoo035oo`03001oogoo00=oo`00CGoo
00<007ooOol0<Woo00<007ooOol01goo00<03gooOol0<goo00<03gooOol0=7oo00<007ooOol0=7oo
00<03gooOol0<goo00<03gooOol01goo00<007ooOol0<Woo00<007ooOol00goo001=Ool00`00Oomo
o`0cOol00`00Oomoo`06Ool00`0?Oomoo`0cOol00`0?Oomoo`0dOol00`00Oomoo`0dOol00`0?Oomo
o`0cOol00`0?Oomoo`06Ool00`00Oomoo`0cOol00`00Oomoo`03Ool004eoo`03001oogoo03=oo`03
001oogoo00Ioo`0300moogoo03=oo`0300moogoo03Aoo`03001oogoo03Aoo`0300moogoo03=oo`03
00moogoo00Ioo`03001oogoo03=oo`03001oogoo00=oo`00CGoo00<007ooOol0=7oo00<007ooOol0
1Goo00<03gooOol0<goo00<03gooOol0=7oo00<007ooOol0=7oo00<03gooOol0<goo00<03gooOol0
1Goo00<007ooOol0=7oo00<007ooOol00goo001=Ool00`00Oomoo`0eOol00`00Oomoo`04Ool00`0?
Oomoo`0cOol00`0?Oomoo`0dOol00`00Oomoo`0dOol00`0?Oomoo`0cOol00`0?Oomoo`04Ool00`00
Oomoo`0eOol00`00Oomoo`03Ool004eoo`03001oogoo03Ioo`03001oogoo00=oo`0300moogoo03=o
o`0300moogoo03Aoo`03001oogoo03Aoo`0300moogoo03=oo`0300moogoo00Aoo`03001oogoo03Eo
o`03001oogoo00=oo`00CGoo00<007ooOol0=Woo00<007ooOol00goo00<03gooOol0<goo00<03goo
Ool0=7oo00<007ooOol0=7oo00<03gooOol0<goo00<03gooOol00goo00<007ooOol0=Woo00<007oo
Ool00goo001=Ool00`00Oomoo`0gOol00`00Oomoo`02Ool00`0?Oomoo`0cOol00`0?Oomoo`0dOol0
0`00Oomoo`0dOol00`0?Oomoo`0cOol00`0?Oomoo`02Ool00`00Oomoo`0gOol00`00Oomoo`03Ool0
04eoo`8003Uoo`05001oogooOol03`0eOol00`0?Oomoo`0dOol00`00Oomoo`0dOol00`0?Oomoo`0c
Ool01@0?Oomoogoo0000>Goo0P001Goo001=Ool00`00Oomoo`0hOol01@00Oomoogoo00l0=Goo00<0
3gooOol0=7oo00<007ooOol0=7oo00<03gooOol0<goo00D03gooOomoo`0003Yoo`03001oogoo00=o
o`00CGoo00<007ooOol0>Goo00@007ooOol03cEoo`0300moogoo03Aoo`03001oogoo03Aoo`0300mo
ogoo03=oo`0400moogoo000kOol00`00Oomoo`03Ool004eoo`03001oogoo03Yoo`03001oo`0?03Eo
o`0300moogoo03Aoo`03001oogoo03Aoo`0300moogoo03=oo`0300moo`0003aoo`03001oogoo00=o
o`00CGoo00<007ooOol0>Woo00<007oo00l0=Goo00<03gooOol0=7oo00<007ooOol0=7oo00<03goo
Ool0<goo00<03`00Ool0?7oo00<007ooOol00goo001=Ool00`00Oomoo`0kOol00`0000moo`0dOol0
0`0?Oomoo`0dOol00`00Oomoo`0dOol00`0?Oomoo`0cOol00`0?001oo`0lOol00`00Oomoo`03Ool0
04eoo`03001oogoo03aoo`03001oogoo03=oo`0300moogoo03Aoo`03001oogoo03Aoo`0300moogoo
03=oo`03001oogoo03aoo`03001oogoo00=oo`00;Goo0`000goo00<007ooOol00`000goo0`0017oo
0`001goo00<007ooOol0?7oo00<007ooOol0<goo00<03gooOol0=7oo00<007ooOol0=7oo00<03goo
Ool0<Woo00<0000?Ool0?Goo00<007ooOol00goo000/Ool01@00Oomoogoo000017oo00L007ooOomo
o`00Ool00003Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`0lOol00`0?001oo`0cOol0
0`0?Oomoo`0dOol00`00Oomoo`0dOol00`0?Oomoo`0bOol00`0000moo`0mOol00`00Oomoo`03Ool0
02aoo`05001oogooOol00004Ool01`00Oomoogoo001oo`0000=oo`03001oogoo009oo`03001oogoo
00Ioo`<003h03`0300003`0?06P03`0300003`0?06P03`0300003`0?03`03`<000Eoo`00;7oo00D0
07ooOomoo`0000Aoo`07001oogooOol007oo00000goo00<007ooOol00Woo00<007ooOol01Woo00<0
07ooOol0?7oo00<03goo0000<goo00<03gooOol0=7oo00<007ooOol0=7oo00<03gooOol0<Goo00<0
07oo00l0?Woo00<007ooOol00goo000/Ool01@00Oomoogoo000017oo00L007ooOomoo`00Ool00003
Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`0lOol0100?Oomoo`00<Woo00<03gooOol0
=7oo00<007ooOol0=7oo00<03gooOol0<7oo00@007ooOol03cioo`03001oogoo00=oo`00;7oo00D0
07ooOomoo`0000Aoo`07001oogooOol007oo00000goo00<007ooOol00Woo00<007ooOol01Woo00<0
07ooOol0?7oo00@03gooOol0039oo`0300moogoo03Aoo`03001oogoo03Aoo`0300moogoo02moo`05
001oogooOol03`0nOol00`00Oomoo`03Ool002aoo`05001oogooOol00004Ool01`00Oomoogoo001o
o`0000=oo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo03aoo`0500moogooOol0000aOol0
0`0?Oomoo`0dOol00`00Oomoo`0dOol00`0?Oomoo`0_Ool01@00Oomoogoo00l0?Woo00<007ooOol0
0goo000]Ool30006Ool30003Ool30004Ool20008Ool00`00Oomoo`0lOol00`0?Oomoo`02Ool00`00
Oomoo`0^Ool00`0?Oomoo`0dOol00`00Oomoo`0dOol00`0?Oomoo`0^Ool00`00Oomoo`02Ool00`0?
Oomoo`0lOol00`00Oomoo`03Ool004eoo`03001oogoo03aoo`0300moogoo009oo`03001oogoo02io
o`0300moogoo03Aoo`03001oogoo03Aoo`0300moogoo02ioo`03001oogoo009oo`0300moogoo03ao
o`03001oogoo00=oo`00CGoo00<007ooOol0?7oo00<03gooOol00goo00<007ooOol0;Goo00<03goo
Ool0=7oo00<007ooOol0=7oo00<03gooOol0;Goo00<007ooOol00goo00<03gooOol0?7oo00<007oo
Ool00goo001=Ool00`00Oomoo`0lOol00`0?Oomoo`03Ool00`00Oomoo`0]Ool00`0?Oomoo`0dOol0
0`00Oomoo`0dOol00`0?Oomoo`0/Ool00`00Oomoo`04Ool00`0?Oomoo`0lOol00`00Oomoo`03Ool0
04eoo`03001oogoo03aoo`0300moogoo00Aoo`03001oogoo02aoo`0300moogoo03Aoo`03001oogoo
03Aoo`0300moogoo02aoo`03001oogoo00Aoo`0300moogoo03aoo`03001oogoo00=oo`00CGoo0P00
?Goo00<03gooOol01Goo00<007ooOol0:goo00<03gooOol0=7oo00<007ooOol0=7oo00<03gooOol0
:goo00<007ooOol01Goo00<03gooOol0>goo0P001Goo001=Ool00`00Oomoo`0lOol00`0?Oomoo`05
Ool00`00Oomoo`0[Ool00`0?Oomoo`0dOol00`00Oomoo`0dOol00`0?Oomoo`0[Ool00`00Oomoo`05
Ool00`0?Oomoo`0lOol00`00Oomoo`03Ool004eoo`03001oogoo03aoo`0300moogoo00Ioo`03001o
ogoo02Yoo`0300moogoo03Aoo`03001oogoo03Aoo`0300moogoo02Yoo`03001oogoo00Ioo`0300mo
ogoo03aoo`03001oogoo00=oo`00CGoo00<007ooOol0?7oo00<03gooOol01Woo00<007ooOol0:Woo
00<03gooOol0=7oo00<007ooOol0=7oo00<03gooOol0:Goo00<007ooOol01goo00<03gooOol0?7oo
00<007ooOol00goo001=Ool00`00Oomoo`0lOol00`0?Oomoo`07Ool00`00Oomoo`0YOol00`0?Oomo
o`0dOol00`00Oomoo`0dOol00`0?Oomoo`0YOol00`00Oomoo`07Ool00`0?Oomoo`0lOol00`00Oomo
o`03Ool004eoo`03001oogoo03aoo`0300moogoo00Qoo`03001oogoo02Qoo`0300moogoo03Aoo`03
001oogoo03Aoo`0300moogoo02Qoo`03001oogoo00Qoo`0300moogoo03aoo`03001oogoo00=oo`00
CGoo00<007ooOol0?7oo00<03gooOol027oo00<007ooOol0:7oo00<03gooOol0=7oo00<007ooOol0
=7oo00<03gooOol0:7oo00<007ooOol027oo00<03gooOol0?7oo00<007ooOol00goo001=Ool00`00
Oomoo`0lOol00`0?Oomoo`09Ool00`00Oomoo`0WOol00`0?Oomoo`0dOol00`00Oomoo`0dOol00`0?
Oomoo`0WOol00`00Oomoo`09Ool00`0?Oomoo`0lOol00`00Oomoo`03Ool004eoo`03001oogoo03ao
o`0300moogoo00Uoo`03001oogoo02Moo`0300moogoo03Aoo`03001oogoo03Aoo`0300moogoo02Io
o`03001oogoo00Yoo`0300moogoo03aoo`03001oogoo00=oo`00CGoo00<007ooOol0?7oo00<03goo
Ool02Woo00<007ooOol09Woo00<03gooOol0=7oo00<007ooOol0=7oo00<03gooOol09Woo00<007oo
Ool02Woo00<03gooOol0?7oo00<007ooOol00goo001=Ool2000mOol00`0?Oomoo`0;Ool00`00Oomo
o`0UOol00`0?Oomoo`0dOol00`00Oomoo`0dOol00`0?Oomoo`0UOol00`00Oomoo`0;Ool00`0?Oomo
o`0kOol20005Ool004eoo`03001oogoo03aoo`0300moogoo00]oo`03001oogoo02Eoo`0300moogoo
03Aoo`03001oogoo03Aoo`0300moogoo02Eoo`03001oogoo00]oo`0300moogoo03aoo`03001oogoo
00=oo`00CGoo00<007ooOol0?7oo00<03gooOol037oo00<007ooOol097oo00<03gooOol0=7oo00<0
07ooOol0=7oo00<03gooOol097oo00<007ooOol037oo00<03gooOol0?7oo00<007ooOol00goo001=
Ool00`00Oomoo`0lOol00`0?Oomoo`0<Ool00`00Oomoo`0TOol00`0?Oomoo`0dOol00`00Oomoo`0d
Ool00`0?Oomoo`0TOol00`00Oomoo`0<Ool00`0?Oomoo`0lOol00`00Oomoo`03Ool004eoo`03001o
ogoo03aoo`0300moogoo00eoo`03001oogoo02=oo`0300moogoo03Aoo`03001oogoo03Aoo`0300mo
ogoo02=oo`03001oogoo00eoo`0300moogoo03aoo`03001oogoo00=oo`00CGoo00<007ooOol0?7oo
00<03gooOol03Goo00<007ooOol08goo00<03gooOol0=7oo00<007ooOol0=7oo00<03gooOol08goo
00<007ooOol03Goo00<03gooOol0?7oo00<007ooOol00goo001=Ool00`00Oomoo`0lOol00`0?Oomo
o`0>Ool00`00Oomoo`0ROol00`0?Oomoo`0dOol00`00Oomoo`0dOol00`0?Oomoo`0SOol00`00Oomo
o`0=Ool00`0?Oomoo`0lOol00`00Oomoo`03Ool004eoo`03001oogoo03aoo`0300moogoo00ioo`03
001oogoo029oo`0300moogoo03Aoo`03001oogoo03Aoo`0300moogoo029oo`03001oogoo00ioo`03
00moogoo03aoo`03001oogoo00=oo`00CGoo00<007ooOol0?7oo00<03gooOol03Woo00<007ooOol0
8Woo00<03gooOol0=7oo00<007ooOol0=7oo00<03gooOol08Woo00<007ooOol03Woo00<03gooOol0
?7oo00<007ooOol00goo001=Ool2000mOol00`0?Oomoo`0?Ool00`00Oomoo`0QOol00`0?Oomoo`0d
Ool00`00Oomoo`0dOol00`0?Oomoo`0QOol00`00Oomoo`0?Ool00`0?Oomoo`0kOol20005Ool004eo
o`03001oogoo03aoo`0300moogoo00moo`03001oogoo025oo`0300moogoo03Aoo`03001oogoo03Ao
o`0300moogoo025oo`03001oogoo00moo`0300moogoo03aoo`03001oogoo00=oo`00CGoo00<007oo
Ool0?7oo00<03gooOol047oo00<007ooOol087oo00<03gooOol0=7oo00<007ooOol0=7oo00<03goo
Ool087oo00<007ooOol047oo00<03gooOol0?7oo00<007ooOol00goo001=Ool00`00Oomoo`0lOol0
0`0?Oomoo`0@Ool00`00Oomoo`0POol00`0?Oomoo`0dOol00`00Oomoo`0dOol00`0?Oomoo`0POol0
0`00Oomoo`0@Ool00`0?Oomoo`0lOol00`00Oomoo`03Ool004eoo`03001oogoo03aoo`0300moogoo
015oo`03001oogoo01moo`0300moogoo03Aoo`03001oogoo03Aoo`0300moogoo01moo`03001oogoo
015oo`0300moogoo03aoo`03001oogoo00=oo`00CGoo00<007ooOol0?7oo00<03gooOol04Goo00<0
07ooOol07goo00<03gooOol0=7oo00<007ooOol0=7oo00<03gooOol07goo00<007ooOol04Goo00<0
3gooOol0?7oo00<007ooOol00goo001=Ool00`00Oomoo`0lOol00`0?Oomoo`0AOol00`00Oomoo`0O
Ool00`0?Oomoo`0dOol00`00Oomoo`0dOol00`0?Oomoo`0NOol00`00Oomoo`0BOol00`0?Oomoo`0l
Ool00`00Oomoo`03Ool004eoo`03001oogoo03aoo`0300moogoo019oo`03001oogoo01ioo`0300mo
ogoo03Aoo`03001oogoo03Aoo`0300moogoo01ioo`03001oogoo019oo`0300moogoo03aoo`03001o
ogoo00=oo`00CGoo00<007ooOol0?7oo00<03gooOol04Woo00<007ooOol07Woo00<03gooOol0=7oo
00<007ooOol0=7oo00<03gooOol07Goo00<007ooOol04goo00<03gooOol0?7oo00<007ooOol00goo
001=Ool00`00Oomoo`0lOol00`0?Oomoo`0COol00`00Oomoo`0MOol00`0?Oomoo`0dOol00`00Oomo
o`0dOol00`0?Oomoo`0MOol00`00Oomoo`0COol00`0?Oomoo`0lOol00`00Oomoo`03Ool004eoo`80
03eoo`0300moogoo01=oo`03001oogoo01eoo`0300moogoo03Aoo`03001oogoo03Aoo`0300moogoo
01aoo`03001oogoo01Aoo`0300moogoo03]oo`8000Eoo`00CGoo00<007ooOol0?7oo00<03gooOol0
57oo00<007ooOol077oo00<03gooOol0=7oo00<007ooOol0=7oo00<03gooOol077oo00<007ooOol0
57oo00<03gooOol0?7oo00<007ooOol00goo001=Ool00`00Oomoo`0lOol00`0?Oomoo`0DOol00`00
Oomoo`0LOol00`0?Oomoo`0dOol00`00Oomoo`0dOol00`0?Oomoo`0LOol00`00Oomoo`0DOol00`0?
Oomoo`0lOol00`00Oomoo`03Ool004eoo`03001oogoo03aoo`0300moogoo01Aoo`03001oogoo01ao
o`0300moogoo03Aoo`03001oogoo03Aoo`0300moogoo01]oo`03001oogoo01Eoo`0300moogoo03ao
o`03001oogoo00=oo`005goo0`002Goo0`009goo00<007ooOol0?7oo00<03gooOol05Goo00<007oo
Ool06goo00<03gooOol0=7oo00<007ooOol0=7oo00<03gooOol06goo00<007ooOol05Goo00<03goo
Ool0?7oo00<007ooOol00goo000GOol00`00Oomoo`0;Ool00`00Oomoo`0UOol00`00Oomoo`0lOol0
0`0?Oomoo`0EOol00`00Oomoo`0KOol00`0?Oomoo`0dOol00`00Oomoo`0dOol00`0?Oomoo`0JOol0
0`00Oomoo`0FOol00`0?Oomoo`0lOol00`00Oomoo`03Ool000Ioo`H0009oo`D000Aoo`03001oogoo
00=oo`<000Eoo`03001oogoo02Eoo`03001oogoo03aoo`0300moogoo01Ioo`03001oogoo01Yoo`03
00moogoo03Aoo`03001oogoo03Aoo`0300moogoo01Yoo`03001oogoo01Ioo`0300moogoo03aoo`03
001oogoo00=oo`001goo00<007ooOol00Woo00@007ooOol0009oo`03001oogoo009oo`03001oogoo
00Aoo`03001oogoo00Aoo`03001oogoo00Eoo`<000=oo`03001oogoo00<000=oo`<0009oo`@000Qo
o`03001oogoo03aoo`0300moogoo01Ioo`03001oogoo01Yoo`0300moogoo03Aoo`03001oogoo03Ao
o`0300moogoo01Uoo`03001oogoo01Moo`0300moogoo03aoo`03001oogoo00=oo`001goo00<007oo
Ool00Woo00D007ooOomoo`0000Ioo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`05
001oogooOol00004Ool01`00Oomoogoo001oo`0000=oo`03001oo`0000=oo`03001oogoo00Eoo`03
001oogoo03aoo`0300moogoo01Moo`03001oogoo01Uoo`0300moogoo03Aoo`03001oogoo03Aoo`03
00moogoo01Uoo`03001oogoo01Moo`0300moogoo03aoo`03001oogoo00=oo`001goo00<007ooOol0
0Woo00D007ooOomoo`0000Ioo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`05001o
ogooOol00004Ool01`00Oomoogoo001oo`0000=oo`04001oogoo000:Ool3001F00l00`0000l03`1@
00l00`0000l03`1?00l00`0000l03`1E00l30005Ool000Moo`D0009oo`04001oogoo0005Ool00`00
Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool01@00Oomoogoo000017oo00L007ooOomoo`00
Ool00003Ool01@00Oomoogoo00002Goo00<007ooOol0?7oo00<03gooOol05goo00<007ooOol06Goo
00<03gooOol0=7oo00<007ooOol0=7oo00<03gooOol067oo00<007ooOol067oo00<03gooOol0?7oo
00<007ooOol00goo0007Ool00`00Oomoo`02Ool00`00Ool000040004Ool01@00Oomoogoo00000Woo
00@007ooOol000=oo`03001oogoo00Aoo`05001oogooOol00004Ool01`00Oomoogoo001oo`0000=o
o`03001oogoo009oo`03001oogoo00Ioo`03001oogoo03aoo`0300moogoo01Qoo`03001oogoo01Qo
o`0300moogoo03Aoo`03001oogoo03Aoo`0300moogoo01Qoo`03001oogoo01Qoo`0300moogoo03ao
o`03001oogoo00=oo`001goo00<007ooOol00Woo00<007ooOol027oo00D007ooOomoo`00009oo`04
001oogoo0003Ool00`00Oomoo`04Ool01@00Oomoogoo000017oo00L007ooOomoo`00Ool00003Ool0
0`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`0lOol00`0?Oomoo`0HOol00`00Oomoo`0HOol0
0`0?Oomoo`0dOol00`00Oomoo`0dOol00`0?Oomoo`0GOol00`00Oomoo`0IOol00`0?Oomoo`0lOol0
0`00Oomoo`03Ool000Ioo`H000]oo`<00003Ool0000000D00004Ool000000006Ool01@00Oomoogoo
000017oo00L007ooOomoo`00Ool00003Ool00`00Ool00002Ool00`00Oomoo`06Ool00`00Oomoo`0l
Ool00`0?Oomoo`0IOol00`00Oomoo`0GOol00`0?Oomoo`0dOol00`00Oomoo`0dOol00`0?Oomoo`0G
Ool00`00Oomoo`0IOol00`0?Oomoo`0lOol00`00Oomoo`03Ool002eoo`<000Ioo`<000=oo`<000=o
o`8000Uoo`03001oogoo03aoo`0300moogoo01Uoo`03001oogoo01Moo`0300moogoo03Aoo`03001o
ogoo03Aoo`0300moogoo01Moo`03001oogoo01Uoo`0300moogoo03aoo`03001oogoo00=oo`00CGoo
00<007ooOol0?7oo00<03gooOol06Woo00<007ooOol05Woo00<03gooOol0=7oo00<007ooOol0=7oo
00<03gooOol05Woo00<007ooOol06Woo00<03gooOol0?7oo00<007ooOol00goo001=Ool00`00Oomo
o`0lOol00`0?Oomoo`0JOol00`00Oomoo`0FOol00`0?Oomoo`0dOol00`00Oomoo`0dOol00`0?Oomo
o`0FOol00`00Oomoo`0JOol00`0?Oomoo`0lOol00`00Oomoo`03Ool004eoo`03001oogoo03aoo`03
00moogoo01Yoo`03001oogoo01Ioo`0300moogoo03Aoo`03001oogoo03Aoo`0300moogoo01Ioo`03
001oogoo01Yoo`0300moogoo03aoo`03001oogoo00=oo`00CGoo00<007ooOol0?7oo00<03gooOol0
6goo00<007ooOol05Goo00<03gooOol0=7oo00<007ooOol0=7oo00<03gooOol05Goo00<007ooOol0
6goo00<03gooOol0?7oo00<007ooOol00goo001=Ool2000mOol00`0?Oomoo`0KOol00`00Oomoo`0E
Ool00`0?Oomoo`0dOol00`00Oomoo`0dOol00`0?Oomoo`0EOol00`00Oomoo`0KOol00`0?Oomoo`0k
Ool20005Ool004eoo`03001oogoo03aoo`0300moogoo01]oo`03001oogoo01Eoo`0300moogoo03Ao
o`03001oogoo03Aoo`0300moogoo01Eoo`03001oogoo01]oo`0300moogoo03aoo`03001oogoo00=o
o`00CGoo00<007ooOol0?7oo00<03gooOol077oo00<007ooOol057oo00<03gooOol0=7oo00<007oo
Ool0=7oo00<03gooOol057oo00<007ooOol077oo00<03gooOol0?7oo00<007ooOol00goo001=Ool0
0`00Oomoo`0lOol00`0?Oomoo`0LOol00`00Oomoo`0DOol00`0?Oomoo`0dOol00`00Oomoo`0dOol0
0`0?Oomoo`0DOol00`00Oomoo`0LOol00`0?Oomoo`0lOol00`00Oomoo`03Ool004eoo`03001oogoo
03aoo`0300moogoo01aoo`03001oogoo01Aoo`0300moogoo03Aoo`03001oogoo03Aoo`0300moogoo
01Aoo`03001oogoo01aoo`0300moogoo03aoo`03001oogoo00=oo`00CGoo00<007ooOol0?7oo00<0
3gooOol07Goo00<007ooOol04goo00<03gooOol0=7oo00<007ooOol0=7oo00<03gooOol04goo00<0
07ooOol07Goo00<03gooOol0?7oo00<007ooOol00goo001=Ool00`00Oomoo`0lOol00`0?Oomoo`0M
Ool00`00Oomoo`0COol00`0?Oomoo`0dOol00`00Oomoo`0dOol00`0?Oomoo`0COol00`00Oomoo`0M
Ool00`0?Oomoo`0lOol00`00Oomoo`03Ool004eoo`03001oogoo03aoo`0300moogoo01eoo`03001o
ogoo01=oo`0300moogoo03Aoo`03001oogoo03Aoo`0300moogoo01=oo`03001oogoo01eoo`0300mo
ogoo03aoo`03001oogoo00=oo`00CGoo00<007ooOol0?7oo00<03gooOol07Woo00<007ooOol04Woo
00<03gooOol0=7oo00<007ooOol0=7oo00<03gooOol04Woo00<007ooOol07Woo00<03gooOol0?7oo
00<007ooOol00goo001=Ool00`00Oomoo`0lOol00`0?Oomoo`0NOol00`00Oomoo`0BOol00`0?Oomo
o`0dOol00`00Oomoo`0dOol00`0?Oomoo`0BOol00`00Oomoo`0NOol00`0?Oomoo`0lOol00`00Oomo
o`03Ool004eoo`8003eoo`0300moogoo01moo`03001oogoo015oo`0300moogoo03Aoo`03001oogoo
03Aoo`0300moogoo019oo`03001oogoo01ioo`0300moogoo03]oo`8000Eoo`00CGoo00<007ooOol0
?7oo00<03gooOol07goo00<007ooOol04Goo00<03gooOol0=7oo00<007ooOol0=7oo00<03gooOol0
4Goo00<007ooOol07goo00<03gooOol0?7oo00<007ooOol00goo001=Ool00`00Oomoo`0lOol00`0?
Oomoo`0OOol00`00Oomoo`0AOol00`0?Oomoo`0dOol00`00Oomoo`0dOol00`0?Oomoo`0AOol00`00
Oomoo`0OOol00`0?Oomoo`0lOol00`00Oomoo`03Ool004eoo`03001oogoo03aoo`0300moogoo021o
o`03001oogoo011oo`0300moogoo03Aoo`03001oogoo03Aoo`0300moogoo015oo`03001oogoo01mo
o`0300moogoo03aoo`03001oogoo00=oo`00CGoo00<007ooOol0?7oo00<03gooOol087oo00<007oo
Ool047oo00<03gooOol0=7oo00<007ooOol0=7oo00<03gooOol047oo00<007ooOol087oo00<03goo
Ool0?7oo00<007ooOol00goo001=Ool00`00Oomoo`0lOol00`0?Oomoo`0POol00`00Oomoo`0@Ool0
0`0?Oomoo`0dOol00`00Oomoo`0dOol00`0?Oomoo`0@Ool00`00Oomoo`0POol00`0?Oomoo`0lOol0
0`00Oomoo`03Ool004eoo`03001oogoo03aoo`0300moogoo025oo`03001oogoo00moo`0300moogoo
03Aoo`03001oogoo03Aoo`0300moogoo011oo`03001oogoo021oo`0300moogoo03aoo`03001oogoo
00=oo`00CGoo00<007ooOol0?7oo00<03gooOol08Goo00<007ooOol03goo00<03gooOol0=7oo00<0
07ooOol0=7oo00<03gooOol03goo00<007ooOol08Goo00<03gooOol0?7oo00<007ooOol00goo001=
Ool00`00Oomoo`0lOol00`0?Oomoo`0QOol00`00Oomoo`0?Ool00`0?Oomoo`0dOol00`00Oomoo`0d
Ool00`0?Oomoo`0?Ool00`00Oomoo`0QOol00`0?Oomoo`0lOol00`00Oomoo`03Ool004eoo`8003eo
o`0300moogoo029oo`03001oogoo00ioo`0300moogoo03Aoo`03001oogoo03Aoo`0300moogoo00mo
o`03001oogoo025oo`0300moogoo03]oo`8000Eoo`00CGoo00<007ooOol0?7oo00<03gooOol08Woo
00<007ooOol03Woo00<03gooOol0=7oo00<007ooOol0=7oo00<03gooOol03Woo00<007ooOol08Woo
00<03gooOol0?7oo00<007ooOol00goo001=Ool00`00Oomoo`0lOol00`0?Oomoo`0SOol00`00Oomo
o`0=Ool00`0?Oomoo`0dOol00`00Oomoo`0dOol00`0?Oomoo`0>Ool00`00Oomoo`0ROol00`0?Oomo
o`0lOol00`00Oomoo`03Ool004eoo`03001oogoo03aoo`0300moogoo02=oo`03001oogoo00eoo`03
00moogoo03Aoo`03001oogoo03Aoo`0300moogoo00ioo`03001oogoo029oo`0300moogoo03aoo`03
001oogoo00=oo`00CGoo00<007ooOol0?7oo00<03gooOol08goo00<007ooOol03Goo00<03gooOol0
=7oo00<007ooOol0=7oo00<03gooOol03Goo00<007ooOol08goo00<03gooOol0?7oo00<007ooOol0
0goo001=Ool00`00Oomoo`0lOol00`0?Oomoo`0TOol00`00Oomoo`0<Ool00`0?Oomoo`0dOol00`00
Oomoo`0dOol00`0?Oomoo`0=Ool00`00Oomoo`0SOol00`0?Oomoo`0lOol00`00Oomoo`03Ool004eo
o`03001oogoo03aoo`0300moogoo02Aoo`03001oogoo00aoo`0300moogoo03Aoo`03001oogoo03Ao
o`0300moogoo00eoo`03001oogoo02=oo`0300moogoo03aoo`03001oogoo00=oo`00CGoo00<007oo
Ool0?7oo00<03gooOol097oo00<007ooOol037oo00<03gooOol0=7oo00<007ooOol0=7oo00<03goo
Ool037oo00<007ooOol097oo00<03gooOol0?7oo00<007ooOol00goo001=Ool00`00Oomoo`0lOol0
0`0?Oomoo`0UOol00`00Oomoo`0;Ool00`0?Oomoo`0dOol00`00Oomoo`0dOol00`0?Oomoo`0<Ool0
0`00Oomoo`0TOol00`0?Oomoo`0lOol00`00Oomoo`03Ool004eoo`03001oogoo03aoo`0300moogoo
02Eoo`03001oogoo00]oo`0300moogoo03Aoo`03001oogoo03Aoo`0300moogoo00aoo`03001oogoo
02Aoo`0300moogoo03aoo`03001oogoo00=oo`00CGoo0P00?Goo00<03gooOol09Goo00<007ooOol0
2goo00<03gooOol0=7oo00<007ooOol0=7oo00<03gooOol02goo00<007ooOol09Goo00<03gooOol0
>goo0P001Goo001=Ool00`00Oomoo`0lOol00`0?Oomoo`0VOol00`00Oomoo`0:Ool00`0?Oomoo`0d
Ool00`00Oomoo`0dOol00`0?Oomoo`0;Ool00`00Oomoo`0UOol00`0?Oomoo`0lOol00`00Oomoo`03
Ool004eoo`03001oogoo03aoo`0300moogoo02Ioo`03001oogoo00Yoo`0300moogoo03Aoo`03001o
ogoo03Aoo`0300moogoo00]oo`03001oogoo02Eoo`0300moogoo03aoo`03001oogoo00=oo`00CGoo
00<007ooOol0?7oo00<03gooOol09Woo00<007ooOol02Woo00<03gooOol0=7oo00<007ooOol0=7oo
00<03gooOol02Woo00<007ooOol09Woo00<03gooOol0?7oo00<007ooOol00goo001=Ool00`00Oomo
o`0lOol00`0?Oomoo`0WOol00`00Oomoo`09Ool00`0?Oomoo`0dOol00`00Oomoo`0dOol00`0?Oomo
o`0:Ool00`00Oomoo`0VOol00`0?Oomoo`0lOol00`00Oomoo`03Ool004eoo`03001oogoo03aoo`03
00moogoo02Moo`03001oogoo00Uoo`0300moogoo03Aoo`03001oogoo03Aoo`0300moogoo00Yoo`03
001oogoo02Ioo`0300moogoo03aoo`03001oogoo00=oo`00CGoo00<007ooOol0?7oo00<03gooOol0
9goo00<007ooOol02Goo00<03gooOol0=7oo00<007ooOol0=7oo00<03gooOol02Goo00<007ooOol0
9goo00<03gooOol0?7oo00<007ooOol00goo000]Ool30003Ool00`00Oomoo`030003Ool30002Ool4
0008Ool00`00Oomoo`0lOol00`0?Oomoo`0XOol00`00Oomoo`08Ool00`0?Oomoo`0dOol00`00Oomo
o`0dOol00`0?Oomoo`09Ool00`00Oomoo`0WOol00`0?Oomoo`0lOol00`00Oomoo`03Ool002aoo`05
001oogooOol00004Ool01`00Oomoogoo001oo`0000=oo`03001oogoo00=oo`03001oogoo00Eoo`03
001oogoo03aoo`0300moogoo02Qoo`03001oogoo00Qoo`0300moogoo03Aoo`03001oogoo03Aoo`03
00moogoo00Uoo`03001oogoo02Moo`0300moogoo03aoo`03001oogoo00=oo`00;7oo00D007ooOomo
o`0000Aoo`07001oogooOol007oo00000goo00<007ooOol00goo00<007ooOol01Goo0`00I`0?00<0
000?00l0?`0?00<0000?00l0@00?00<0000?00l0I00?0`001Goo000/Ool01@00Oomoogoo000017oo
00L007ooOomoo`00Ool00003Ool00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`0lOol00`0?
Oomoo`0XOol00`00Oomoo`08Ool00`0?Oomoo`0dOol00`00Oomoo`0dOol00`0?Oomoo`08Ool00`00
Oomoo`0XOol00`0?Oomoo`0lOol00`00Oomoo`03Ool002aoo`05001oogooOol00004Ool01`00Oomo
ogoo001oo`0000=oo`03001oogoo00<000Qoo`03001oogoo03aoo`0300moogoo02Uoo`03001oogoo
00Moo`0300moogoo03Aoo`03001oogoo03Aoo`0300moogoo00Qoo`03001oogoo02Qoo`0300moogoo
03aoo`03001oogoo00=oo`00;7oo00D007ooOomoo`0000Aoo`07001oogooOol007oo00000goo00<0
07ooOol00Woo00<007ooOol01Woo00<007ooOol0?7oo00<03gooOol0:Goo00<007ooOol01goo00<0
3gooOol0=7oo00<007ooOol0=7oo00<03gooOol027oo00<007ooOol0:7oo00<03gooOol0?7oo00<0
07ooOol00goo000/Ool01@00Oomoogoo000017oo00L007ooOomoo`00Ool00003Ool00`00Ool00003
Ool00`00Oomoo`05Ool00`00Oomoo`0lOol00`0?Oomoo`0YOol00`00Oomoo`07Ool00`0?Oomoo`0d
Ool00`00Oomoo`0dOol00`0?Oomoo`07Ool00`00Oomoo`0YOol00`0?Oomoo`0lOol00`00Oomoo`03
Ool002eoo`<000Ioo`<000=oo`<000=oo`<000Qoo`03001oogoo03aoo`0300moogoo02Uoo`03001o
ogoo00Moo`0300moogoo03Aoo`03001oogoo03Aoo`0300moogoo00Moo`03001oogoo02Uoo`0300mo
ogoo03aoo`03001oogoo00=oo`00CGoo00<007ooOol0?7oo00<03gooOol0:Woo00<007ooOol01Woo
00<03gooOol0=7oo00<007ooOol0=7oo00<03gooOol01goo00<007ooOol0:Goo00<03gooOol0?7oo
00<007ooOol00goo001=Ool00`00Oomoo`0lOol00`0?Oomoo`0ZOol00`00Oomoo`06Ool00`0?Oomo
o`0dOol00`00Oomoo`0dOol00`0?Oomoo`06Ool00`00Oomoo`0ZOol00`0?Oomoo`0lOol00`00Oomo
o`03Ool004eoo`03001oogoo03aoo`0300moogoo02Yoo`03001oogoo00Ioo`0300moogoo03Aoo`03
001oogoo03Aoo`0300moogoo00Ioo`03001oogoo02Yoo`0300moogoo03aoo`03001oogoo00=oo`00
CGoo00<007ooOol0?7oo00<03gooOol0:Woo00<007ooOol01Woo00<03gooOol0=7oo00<007ooOol0
=7oo00<03gooOol01Woo00<007ooOol0:Woo00<03gooOol0?7oo00<007ooOol00goo001=Ool2000m
Ool00`0?Oomoo`0[Ool00`00Oomoo`05Ool00`0?Oomoo`0dOol00`00Oomoo`0dOol00`0?Oomoo`06
Ool00`00Oomoo`0ZOol00`0?Oomoo`0kOol20005Ool004eoo`03001oogoo03aoo`0300moogoo02]o
o`03001oogoo00Eoo`0300moogoo03Aoo`03001oogoo03Aoo`0300moogoo00Eoo`03001oogoo02]o
o`0300moogoo03aoo`03001oogoo00=oo`00CGoo00<007ooOol0?7oo00<03gooOol0:goo00<007oo
Ool01Goo00<03gooOol0=7oo00<007ooOol0=7oo00<03gooOol01Goo00<007ooOol0:goo00<03goo
Ool0?7oo00<007ooOol00goo001=Ool00`00Oomoo`0lOol00`0?Oomoo`0[Ool00`00Oomoo`05Ool0
0`0?Oomoo`0dOol00`00Oomoo`0dOol00`0?Oomoo`05Ool00`00Oomoo`0[Ool00`0?Oomoo`0lOol0
0`00Oomoo`03Ool004eoo`03001oogoo03aoo`0300moogoo02aoo`03001oogoo00Aoo`0300moogoo
03Aoo`03001oogoo03Aoo`0300moogoo00Aoo`03001oogoo02aoo`0300moogoo03aoo`03001oogoo
00=oo`00CGoo00<007ooOol0?7oo00<03gooOol0;7oo00<007ooOol017oo00<03gooOol0=7oo00<0
07ooOol0=7oo00<03gooOol017oo00<007ooOol0;7oo00<03gooOol0?7oo00<007ooOol00goo001=
Ool00`00Oomoo`0lOol00`0?Oomoo`0/Ool00`00Oomoo`04Ool00`0?Oomoo`0dOol00`00Oomoo`0d
Ool00`0?Oomoo`04Ool00`00Oomoo`0/Ool00`0?Oomoo`0lOol00`00Oomoo`03Ool004eoo`03001o
ogoo03aoo`0300moogoo02aoo`03001oogoo00Aoo`0300moogoo03Aoo`03001oogoo03Aoo`0300mo
ogoo00Aoo`03001oogoo02aoo`0300moogoo03aoo`03001oogoo00=oo`00CGoo00<007ooOol0?7oo
00<03gooOol0;Goo00<007ooOol00goo00<03gooOol0=7oo00<007ooOol0=7oo00<03gooOol00goo
00<007ooOol0;Goo00<03gooOol0?7oo00<007ooOol00goo001=Ool00`00Oomoo`0lOol00`0?Oomo
o`0]Ool00`00Oomoo`03Ool00`0?Oomoo`0dOol00`00Oomoo`0dOol00`0?Oomoo`03Ool00`00Oomo
o`0]Ool00`0?Oomoo`0lOol00`00Oomoo`03Ool004eoo`8003eoo`0300moogoo02eoo`03001oogoo
00=oo`0300moogoo03Aoo`03001oogoo03Aoo`0300moogoo00=oo`03001oogoo02eoo`0300moogoo
03]oo`8000Eoo`00CGoo00<007ooOol0?7oo00<03gooOol0;Woo00<007ooOol00Woo00<03gooOol0
=7oo00<007ooOol0=7oo00<03gooOol00Woo00<007ooOol0;Woo00<03gooOol0?7oo00<007ooOol0
0goo001=Ool00`00Oomoo`0lOol00`0?Oomoo`0^Ool00`00Oomoo`02Ool00`0?Oomoo`0dOol00`00
Oomoo`0dOol00`0?Oomoo`02Ool00`00Oomoo`0^Ool00`0?Oomoo`0lOol00`00Oomoo`03Ool004eo
o`03001oogoo03aoo`0300moogoo02ioo`03001oogoo009oo`0300moogoo03Aoo`03001oogoo03Ao
o`0300moogoo009oo`03001oogoo02ioo`0300moogoo03aoo`03001oogoo00=oo`00CGoo00<007oo
Ool0?7oo00<03gooOol0;goo00D007ooOomoo`0?03Ioo`03001oogoo03Aoo`0500moogooOol0000a
Ool00`0?Oomoo`0lOol00`00Oomoo`03Ool004eoo`03001oogoo03aoo`0300moogoo02moo`05001o
ogooOol03`0fOol00`00Oomoo`0dOol01@0?Oomoogoo0000<Goo00<03gooOol0?7oo00<007ooOol0
0goo001=Ool00`00Oomoo`0lOol00`0?Oomoo`0_Ool01@00Oomoogoo00l0=Woo00<007ooOol0=7oo
00D03gooOomoo`00035oo`0300moogoo03aoo`03001oogoo00=oo`00CGoo00<007ooOol0?7oo00<0
3gooOol0<7oo00@007ooOol03cIoo`03001oogoo03Aoo`0500moogooOol0000aOol00`0?Oomoo`0l
Ool00`00Oomoo`03Ool004eoo`03001oogoo03aoo`0300moogoo031oo`04001oogoo00lfOol00`00
Oomoo`0dOol0100?Oomoo`00<Woo00<03gooOol0?7oo00<007ooOol00goo001=Ool2000mOol00`0?
Oomoo`0`Ool01000Oomoo`0?=Woo00<007ooOol0=7oo00@03gooOol0039oo`0300moogoo03]oo`80
00Eoo`00CGoo00<007ooOol0?7oo00<03gooOol0<Goo00<007oo00l0=Woo00<007ooOol0=7oo00@0
3gooOol0039oo`0300moogoo03aoo`03001oogoo00=oo`00CGoo00<007ooOol0?7oo00<03gooOol0
<Goo00<007oo00l0=Woo00<007ooOol0=7oo00<03goo0000<goo00<03gooOol0?7oo00<007ooOol0
0goo001=Ool00`00Oomoo`0lOol00`0?Oomoo`0bOol00`0000moo`0eOol00`00Oomoo`0dOol00`0?
Ool0000cOol00`0?Oomoo`0lOol00`00Oomoo`03Ool004eoo`03001oogoo03aoo`0300moogoo039o
o`0300003goo03Eoo`03001oogoo03Aoo`0300moo`0003=oo`0300moogoo03aoo`03001oogoo00=o
o`00CGoo00<007ooOol0?7oo00<03gooOol0<Woo00<0000?Ool0=Goo00<007ooOol0=7oo00<03`00
Ool0<goo00<03gooOol0?7oo00<007ooOol00goo001=Ool00`00Oomoo`0lOol00`0?Oomoo`0cOol0
0`00Oomoo`0dOol00`00Oomoo`0dOol00`0?001oo`0cOol00`0?Oomoo`0lOol00`00Oomoo`03Ool0
04eoo`03001oogoo03aoo`0300moogoo03=oo`03001oogoo02eoo`l002moo`0300l007oo03=oo`03
00moogoo03aoo`03001oogoo00=oo`00CGoo00<007ooOol0?7oo00<03gooOol0<goo00<007ooOol0
:Goo10001goo00<007ooOol01Goo1`00:7oo00<007ooOol0<goo00<03gooOol0?7oo00<007ooOol0
0goo001=Ool00`00Oomoo`0lOol00`0?Oomoo`0cOol00`0?001oo`0VOol3000;Ool00`00Oomoo`0<
Ool2000VOol00`00Oomoo`0cOol00`0?Oomoo`0lOol00`00Oomoo`03Ool004eoo`8003eoo`0300mo
ogoo03=oo`0300l007oo02=oo`<000ioo`03001oogoo00ioo`<0029oo`0300003goo03Aoo`0300mo
ogoo03]oo`8000Eoo`00CGoo00<007ooOol0?7oo00<03gooOol0<goo00<03`00Ool087oo0`004Goo
00<007ooOol04Goo0P0087oo00<0000?Ool0=7oo00<03gooOol0?7oo00<007ooOol00goo001=Ool0
0`00Oomoo`0lOol00`0?Oomoo`0cOol00`0?Ool0000MOol3000DOol00`00Oomoo`0COol2000NOol0
0`0000moo`0dOol00`0?Oomoo`0lOol00`00Oomoo`03Ool004eoo`03001oogoo03aoo`0300moogoo
03=oo`0300moo`0001]oo`8001Moo`03001oogoo01Eoo`8001]oo`03001oo`0?03Eoo`0300moogoo
03aoo`03001oogoo00=oo`00CGoo00<007ooOol0?7oo00<03gooOol0<goo00<03goo00006Goo0P00
6Goo00<007ooOol05goo0P006Goo00<007oo00l0=Goo00<03gooOol0?7oo00<007ooOol00goo001=
Ool00`00Oomoo`0lOol00`0?Oomoo`0cOol0100?Oomoo`005Woo0P006goo00<007ooOol06Goo0P00
5Woo00@007ooOol03cEoo`0300moogoo03aoo`03001oogoo00=oo`00CGoo00<007ooOol0?7oo00<0
3gooOol0<goo00@03gooOol001Eoo`03001oogoo01]oo`03001oogoo01]oo`03001oogoo01=oo`04
001oogoo00leOol00`0?Oomoo`0lOol00`00Oomoo`03Ool002eoo`<000=oo`03001oogoo00<000=o
o`<000Eoo`03001oogoo00Ioo`03001oogoo03aoo`0300moogoo03=oo`0400moogoo000COol2000N
Ool00`00Oomoo`0LOol2000BOol01@00Oomoogoo00l0=Goo00<03gooOol0?7oo00<007ooOol00goo
000/Ool01@00Oomoogoo000017oo00L007ooOomoo`00Ool00003Ool00`00Oomoo`02Ool00`00Oomo
o`06Ool00`00Oomoo`0lOol00`0?Oomoo`0cOol01@0?Oomoogoo000047oo0P0087oo00<007ooOol0
7Woo00<007ooOol03goo00D007ooOomoo`0?03Eoo`0300moogoo03aoo`03001oogoo00=oo`00;7oo
00D007ooOomoo`0000Aoo`07001oogooOol007oo00000goo00<007oo00001@001Woo0`00?7oo00<0
3gooOol0<goo00<03gooOol00Woo00<007ooOol02goo0P008Woo00<007ooOol07goo0P003Woo00<0
07ooOol00Woo00<03gooOol0<goo00<03gooOol0>Woo0`001Goo000/Ool01@00Oomoogoo000017oo
00L007ooOomoo`00Ool00003Ool00`00Ool00002Ool00`00Oomoo`06Ool00`00Oomoo`0lOol00`0?
Oomoo`0cOol00`0?Oomoo`03Ool00`00Oomoo`09Ool00`00Oomoo`0ROol00`00Oomoo`0QOol2000;
Ool00`00Oomoo`03Ool00`0?Oomoo`0cOol00`0?Oomoo`0lOol00`00Oomoo`03Ool002aoo`05001o
ogooOol00004Ool01`00Oomoogoo001oo`0000=oo`06001oogoo001oo`0027oo00<007ooOol0?7oo
00<03gooOol0<goo00<03gooOol017oo00<007ooOol01Woo0P009Goo00<007ooOol08goo0P0027oo
00<007ooOol017oo00<03gooOol0<goo00<03gooOol0?7oo00<007ooOol00goo000/Ool01@00Oomo
ogoo000017oo00L007ooOomoo`00Ool00003Ool01000Oomoogoo0P0027oo00<007ooOol0?7oo00<0
3gooOol0<goo00<03gooOol01Goo0P001Goo00<007ooOol09Goo00<007ooOol09Goo0P0017oo0P00
1goo00<03gooOol0<goo00<03gooOol0?7oo00<007ooOol00goo000/Ool01@00Oomoogoo000017oo
00L007ooOomoo`00Ool00003Ool01000Oomoogoo0P0027oo00<007ooOol0?7oo00<03gooOol0<goo
00<03gooOol01goo1@00:7oo00<007ooOol09Woo1P0027oo00<03gooOol0<goo00<03gooOol0?7oo
00<007ooOol00goo000]Ool30006Ool30003Ool30005Ool00`00Oomoo`06Ool00`00Oomoo`0lOol0
0`0?Oomoo`0cOol00`0?Oomoo`0dOol00`00Oomoo`0dOol00`0?Oomoo`0cOol00`0?Oomoo`0lOol0
0`00Oomoo`03Ool004eoo`03001oogoo03aoo`0300moogoo03=oo`0300moogoo03Aoo`03001oogoo
03Aoo`0300moogoo03=oo`0300moogoo03aoo`03001oogoo00=oo`00CGoo00<007ooOol01Goo00<0
07ooOol0=7oo00<007ooOol0<goo00<007ooOol0=7oo00<007ooOol0=7oo00<007ooOol0<goo00<0
07ooOol0=7oo00<007ooOol01Goo00<007ooOol00goo001=Ool00`00Oomoo`05Ool00`00Oomoo`08
Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08
Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08
Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08
Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08
Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08
Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`05
Ool00`00Oomoo`03Ool004eoool005X000Eoo`00ogoo[7oo003oOon/Ool00?moojaoo`00ogoo[7oo
003oOon/Ool00?moojaoo`00ogoo[7oo003oOon/Ool00=Qoo`<0019oo`<000Qoo`H0011oo`<000=o
o`05001oogooOol0002BOol00=Uoo`03001oogoo00Moo`L0009oo`05001oogooOol00008Ool01@00
Oomoogoo00001Woo1`000Woo00D007ooOomoo`0000Ioo`03001oogoo091oo`00fGoo00<007ooOol0
47oo00D007ooOomoo`0000Qoo`03001oogoo015oo`05001oogooOol00006Ool00`00Oomoo`2@Ool0
0=Uoo`03001oogoo011oo`05001oogooOol00009Ool00`00Oomoo`0@Ool01@00Oomoogoo00001goo
00<007ooOol0Sgoo003HOol00`00Ool00008Ool70002Ool01@00Oomoogoo00002Woo00<007ooOol0
1Woo1`000Woo00D007ooOomoo`0000Moo`03001oogoo08moo`00f7oo00<007oo00004Goo00D007oo
Oomoo`0000]oo`03001oogoo00ioo`05001oogooOol00007Ool00`00Oomoo`2?Ool00=Moo`05001o
ogooOol0000@Ool01@00Oomoogoo00001goo00D007ooOomoo`00011oo`05001oogooOol00004Ool0
1@00Oomoogoo0000T7oo003FOol3000017oo0000000047oo0`0027oo1P0047oo0`001Woo1000T7oo
003oOon/Ool00?moojaoo`00\
\>"],
  ImageRangeCache->{{{0, 426.375}, {263.125, 0}} -> {-4.57236, -0.000915872, 
  0.0183206, 2.08356*^-5}}]
}, Open  ]],

Cell[TextData[StyleBox[
"The same structure is now created and solved but without the use of \
symmetries. The field profile is identical to that of the previous one but it \
needs more cpu time and memory. It should be noted  that in the previous \
computation  the symmetry is also applied to the racetrak coil. As a result \
four identical coils were  in fact created and used  in the computation. To \
make the following computation (without symmetries) identical to the previous \
one,  one must increase the current density in the coil by a factor 4. One \
could  have placed the symmetries only on the iron cube and not on the coil, \
then only one coil would have been generated in both computation cases  and \
the same current density could have been used. The risk in such practice is \
to end up with inconsitent symmetries giving a wrong field in a manner which \
is difficult to debug. It is therefore recommended (at least for a beginner) \
to apply all symmetries to a container holding all sources of magnetic field \
rather than  slectively to certain  objects. ",
  Evaluatable->False,
  AspectRatioFixed->True]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
  \(radUtiDelAll[]; \ \  (*\ to\ recover\ all\ memory\ *) \n\n
    n = {np[\([1]\)]*2, np[\([2]\)]*2, np[\([3]\)]}; j = jp*4; \n
    \n (*\ create\ the\ coil\ \ *) \n
    coil = radObjRaceTrk[{0, 0, 2}, {1, 2}, {1, 1}, 1, 12, j]; \n
    radObjDrwAtr[coil, {1, 0, 0}]; \n\n (*\ create\ the\ iron\ yoke\ *) \n\n
    m1 = radObjRecMag[{0, 0, p[\([3]\)]}, {w[\([1]\)]*2, w[\([2]\)]*2, 
          w[\([3]\)]}]; \niron = RadMatSteel37[]; radMatApl[m1, iron]; \n
    radObjDrwAtr[m1, {0, 0.5, 1}]; \nradObjDivMag[m1, n]; \n
    g = radObjCnt[{m1, coil}]; \n\n (*\ solve\ *) \nt0 = AbsoluteTime[]; \n
    s = RadSolve[g, 0.00001, 100]; \nt1 = AbsoluteTime[]; \n\n
    Print["\<Solved  in : \>", Round[t1 - t0], "\<  seconds\>"]; \n
    Print[\ "\<Number of elements : \>", radObjDegFre[g]/3]\), 
    RowBox[{\(Print[\ "\<Solved in \>", s[\([4]\)], "\< iterations\>"]\), 
      "\n", "\n", 
      \( (*\ display\ the\ greometry\ in\ Mathematica\ Graphics\ *) \)}], 
    RowBox[{
    \(RadPlot3DOptions[]\), ";", "\n", \(Show[Graphics3D[radObjDrw[g]]]\), 
      ";", "\n", "\n", \( (*\ Field\ Plot\ *) \), "\n", "\t\t", 
      RowBox[{
        StyleBox["RadPlotOptions",
          FontColor->RGBColor[1, 0, 0]], "[", "]"}], ";", "\n", 
      \(Plot[radFld[g, "\<Bz\>", {x, 0, 0.6}], {x, \(-3\), 3}\n\t\t\t, \ 
        PlotRange -> All\n\ , AxesOrigin -> {0, 0}\n, 
        FrameLabel -> {"\<X [mm]\>", "\<Bz [T]\>", "\<Y = 0  Z = 0.7\>", 
            "\<\>"}]\), ";"}]}], "Input"],

Cell[BoxData[
    InterpretationBox[
      \("Solved  in : "\[InvisibleSpace]9\[InvisibleSpace]"  seconds"\),
      SequenceForm[ "Solved  in : ", 9, "  seconds"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Number of elements : "\[InvisibleSpace]400\),
      SequenceForm[ "Number of elements : ", 400],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[
      \("Solved in "\[InvisibleSpace]48\[InvisibleSpace]" iterations"\),
      SequenceForm[ "Solved in ", 48, " iterations"],
      Editable->False]], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.64829 .74765 -8.95579 0 ]
[.64829 .74765 9.29421 14 ]
[.78087 .68946 -4.8231 0 ]
[.78087 .68946 5.1769 14 ]
[.93325 .62258 -4.72481 0 ]
[.93325 .62258 5.27519 14 ]
[.78308 .75192 -7.5361 0 ]
[.78308 .75192 8.0889 14 ]
[.43714 .1793 -9.04779 -14 ]
[.43714 .1793 9.20221 0 ]
[.68015 .24102 -5.12026 -14 ]
[.68015 .24102 4.87974 0 ]
[.90238 .29748 -5.26659 -14 ]
[.90238 .29748 4.73341 0 ]
[.67865 .17854 -8.0004 -14 ]
[.67865 .17854 7.6246 0 ]
[.98124 .33568 0 -5.23351 ]
[.98124 .33568 10 8.76649 ]
[.98502 .39607 0 -5.31844 ]
[.98502 .39607 19 8.68156 ]
[.98886 .45744 0 -5.40487 ]
[.98886 .45744 10 8.59513 ]
[.99276 .5198 0 -5.49284 ]
[.99276 .5198 19 8.50716 ]
[.99672 .58318 0 -5.58239 ]
[.99672 .58318 10 8.41761 ]
[1.0498 .47133 0 -5.40487 ]
[1.0498 .47133 14.3125 8.59513 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.003 w
[ ] 0 setdash
.61014 .75181 m
.98487 .58711 L
s
.25 Mabswid
.64806 .73515 m
.64794 .7289 L
s
gsave
.64829 .74765 -69.9558 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.78043 .67697 m
.78021 .67072 L
s
gsave
.78087 .68946 -65.8231 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.93256 .6101 m
.93222 .60386 L
s
gsave
.93325 .62258 -65.7248 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.67951 .72132 m
.67943 .71758 L
s
.71202 .70704 m
.71192 .70329 L
s
.74564 .69226 m
.74553 .68851 L
s
.81645 .66114 m
.8163 .65739 L
s
.85376 .64474 m
.85359 .64099 L
s
.89244 .62774 m
.89225 .62399 L
s
.61761 .74853 m
.61755 .74478 L
s
.97421 .5918 m
.97398 .58805 L
s
gsave
.78308 .75192 -68.5361 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(X) show
74.625000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.003 w
.35623 .17131 m
.96875 .32662 L
s
.25 Mabswid
.43704 .1918 m
.43698 .19805 L
s
gsave
.43714 .1793 -70.0478 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.68045 .25352 m
.6806 .25977 L
s
gsave
.68015 .24102 -66.1203 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.90304 .30996 m
.90338 .3162 L
s
gsave
.90238 .29748 -66.2666 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.5 .20776 m
.5 .21151 L
s
.56153 .22336 m
.56156 .22711 L
s
.62166 .23861 m
.62172 .24236 L
s
.73794 .2681 m
.73806 .27184 L
s
.79418 .28235 m
.79433 .2861 L
s
.8492 .29631 m
.84937 .30005 L
s
.37258 .17546 m
.37252 .1792 L
s
.95575 .32332 m
.95597 .32706 L
s
gsave
.67865 .17854 -69.0004 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Y) show
74.625000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.003 w
.96875 .32662 m
.98487 .58711 L
s
.25 Mabswid
.96912 .33262 m
.96306 .33109 L
s
gsave
.98124 .33568 -61 -9.23351 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.97287 .39315 m
.96679 .39169 L
s
gsave
.98502 .39607 -61 -9.31844 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.97667 .45466 m
.97058 .45327 L
s
gsave
.98886 .45744 -61 -9.40487 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.98054 .51717 m
.97443 .51585 L
s
gsave
.99276 .5198 -61 -9.49284 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2.5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.98447 .5807 m
.97834 .57946 L
s
gsave
.99672 .58318 -61 -9.58239 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.96986 .34465 m
.96623 .34374 L
s
.97061 .35672 m
.96697 .35582 L
s
.97136 .36882 m
.96772 .36793 L
s
.97211 .38097 m
.96847 .38009 L
s
.97362 .40538 m
.96997 .40451 L
s
.97438 .41764 m
.97073 .41678 L
s
.97514 .42994 m
.97149 .42909 L
s
.97591 .44228 m
.97225 .44144 L
s
.97744 .46708 m
.97378 .46626 L
s
.97821 .47954 m
.97455 .47873 L
s
.97898 .49205 m
.97532 .49124 L
s
.97976 .50459 m
.9761 .50379 L
s
.98132 .52979 m
.97765 .52901 L
s
.9821 .54246 m
.97843 .54169 L
s
.98289 .55516 m
.97922 .5544 L
s
.98368 .56791 m
.98001 .56716 L
s
gsave
1.0498 .47133 -61 -9.40487 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Z) show
73.312500 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.001 w
[ .01 .01 ] 0 setdash
.06722 .42225 m
.05351 .66515 L
s
.05351 .66515 m
.61014 .75181 L
s
.61014 .75181 m
.60708 .52904 L
s
.60708 .52904 m
.06722 .42225 L
s
.35623 .17131 m
.96875 .32662 L
s
.96875 .32662 m
.98487 .58711 L
s
.98487 .58711 m
.35065 .45949 L
s
.35065 .45949 m
.35623 .17131 L
s
.06722 .42225 m
.05351 .66515 L
s
.05351 .66515 m
.35065 .45949 L
s
.35065 .45949 m
.35623 .17131 L
s
.35623 .17131 m
.06722 .42225 L
s
.60708 .52904 m
.96875 .32662 L
s
.96875 .32662 m
.98487 .58711 L
s
.98487 .58711 m
.61014 .75181 L
s
.61014 .75181 m
.60708 .52904 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.52225 .55326 m .49234 .66191 L .52256 .66246 L .814 0 0 r
F
.52225 .55326 m .49244 .55266 L .49234 .66191 L F
.52258 .51399 m .49244 .55266 L .52225 .55326 L .71 0 0 r
F
.55206 .55257 m .52225 .55326 L .52256 .66246 L .794 0 0 r
F
.53805 .51362 m .52225 .55326 L .55206 .55257 L .71 0 0 r
F
.53805 .51362 m .52258 .51399 L .52225 .55326 L F
.49244 .55266 m .46254 .6602 L .49234 .66191 L .835 0 0 r
F
.49244 .55266 m .46305 .55077 L .46254 .6602 L F
.50711 .51366 m .46305 .55077 L .49244 .55266 L .71 0 0 r
F
.52258 .51399 m .50711 .51366 L .49244 .55266 L F
0 g
[ ] 0 setdash
.49244 .55266 m
.52225 .55326 L
s
.55206 .55257 m .52256 .66246 L .55279 .66183 L .794 0 0 r
F
.58149 .55059 m .55206 .55257 L .55279 .66183 L .773 0 0 r
F
.5533 .51255 m .55206 .55257 L .58149 .55059 L .71 0 0 r
F
.5533 .51255 m .53805 .51362 L .55206 .55257 L F
0 g
.52225 .55326 m
.55206 .55257 L
s
.46305 .55077 m .43355 .65733 L .46254 .6602 L .855 0 0 r
F
.46305 .55077 m .43447 .5476 L .43355 .65733 L F
.49188 .51264 m .43447 .5476 L .46305 .55077 L .71 0 0 r
F
.50711 .51366 m .49188 .51264 L .46305 .55077 L F
0 g
.46305 .55077 m
.49244 .55266 L
s
.58149 .55059 m .55279 .66183 L .58264 .66004 L .773 0 0 r
F
.61014 .54734 m .58149 .55059 L .58264 .66004 L .75 0 0 r
F
.56809 .5108 m .58149 .55059 L .61014 .54734 L .71 0 0 r
F
.56809 .5108 m .5533 .51255 L .58149 .55059 L F
0 g
.55206 .55257 m
.58149 .55059 L
s
.43447 .5476 m .40578 .65334 L .43355 .65733 L .876 0 0 r
F
.43447 .5476 m .40709 .5432 L .40578 .65334 L F
.47712 .51094 m .40709 .5432 L .43447 .5476 L .71 0 0 r
F
.49188 .51264 m .47712 .51094 L .43447 .5476 L F
0 g
.43447 .5476 m
.46305 .55077 L
s
.61014 .54734 m .58264 .66004 L .61169 .65709 L .75 0 0 r
F
.63761 .54286 m .61014 .54734 L .61169 .65709 L .725 0 0 r
F
.58219 .5084 m .61014 .54734 L .63761 .54286 L .71 0 0 r
F
.58219 .5084 m .56809 .5108 L .61014 .54734 L F
0 g
.58149 .55059 m
.61014 .54734 L
s
.47712 .51094 m .46306 .50859 L .40709 .5432 L .71 0 0 r
F
.46252 .62198 m .46306 .50859 L .40709 .5432 L p .481 0 0 r
F P
0 g
s
.40709 .5432 m .40578 .65334 L .46252 .62198 L p .481 0 0 r
F P
0 g
s
.40578 .65334 m .40709 .5432 L .30338 .5237 L p .887 0 0 r
F P
0 g
s
.30338 .5237 m .40709 .5432 L .46306 .50859 L p .71 0 0 r
F P
0 g
s
.46306 .50859 m .40578 .65334 L .40709 .5432 L .481 0 0 r
F
.63761 .54286 m .61169 .65709 L .63956 .65303 L .725 0 0 r
F
.66351 .53718 m .63761 .54286 L .63956 .65303 L .696 0 0 r
F
.59538 .50538 m .63761 .54286 L .66351 .53718 L .71 0 0 r
F
.59538 .50538 m .58219 .5084 L .63761 .54286 L F
0 g
.61014 .54734 m
.63761 .54286 L
s
.5229 .62687 m .52256 .66246 L .49234 .66191 L .688 0 0 r
F
.53861 .62654 m .52256 .66246 L .5229 .62687 L F
.53861 .62654 m .55279 .66183 L .52256 .66246 L F
.50721 .62658 m .49234 .66191 L .46254 .6602 L F
.5229 .62687 m .49234 .66191 L .50721 .62658 L F
0 g
.49234 .66191 m
.52256 .66246 L
s
.55408 .62557 m .55279 .66183 L .53861 .62654 L .688 0 0 r
F
.55408 .62557 m .58264 .66004 L .55279 .66183 L F
0 g
.52256 .66246 m
.55279 .66183 L
s
.66351 .53718 m .63956 .65303 L .66583 .64789 L .696 0 0 r
F
.68744 .53037 m .66351 .53718 L .66583 .64789 L .663 0 0 r
F
.60744 .50177 m .66351 .53718 L .68744 .53037 L .71 0 0 r
F
.60744 .50177 m .59538 .50538 L .66351 .53718 L F
0 g
.63761 .54286 m
.66351 .53718 L
s
.49176 .62566 m .46254 .6602 L .43355 .65733 L .688 0 0 r
F
.50721 .62658 m .46254 .6602 L .49176 .62566 L F
0 g
.46254 .6602 m
.49234 .66191 L
s
.56908 .62399 m .58264 .66004 L .55408 .62557 L .688 0 0 r
F
.56908 .62399 m .61169 .65709 L .58264 .66004 L F
0 g
.55279 .66183 m
.58264 .66004 L
s
.47679 .62412 m .43355 .65733 L .40578 .65334 L .688 0 0 r
F
.49176 .62566 m .43355 .65733 L .47679 .62412 L F
0 g
.43355 .65733 m
.46254 .6602 L
s
.58339 .62181 m .61169 .65709 L .56908 .62399 L .688 0 0 r
F
.58339 .62181 m .63956 .65303 L .61169 .65709 L F
0 g
.58264 .66004 m
.61169 .65709 L
s
.68744 .53037 m .66583 .64789 L .69013 .64172 L .663 0 0 r
F
.70903 .5225 m .68744 .53037 L .69013 .64172 L .621 0 0 r
F
.61818 .49764 m .68744 .53037 L .70903 .5225 L .71 0 0 r
F
.61818 .49764 m .60744 .50177 L .68744 .53037 L F
0 g
.66351 .53718 m
.68744 .53037 L
s
.30338 .5237 m .30055 .63568 L .40578 .65334 L p .887 0 0 r
F P
0 g
s
.46306 .50859 m .46252 .62198 L .40578 .65334 L .481 0 0 r
F
.46252 .62198 m .40578 .65334 L .30055 .63568 L p .688 0 0 r
F P
0 g
s
.4061 .62675 m
.40709 .5432 L
s
.47679 .62412 m .40578 .65334 L .46252 .62198 L .688 0 0 r
F
0 g
.40578 .65334 m
.43355 .65733 L
s
.59678 .61907 m .63956 .65303 L .58339 .62181 L .688 0 0 r
F
.59678 .61907 m .66583 .64789 L .63956 .65303 L F
0 g
.61169 .65709 m
.63956 .65303 L
s
.35476 .60308 m .30055 .63568 L .30338 .5237 L p .449 0 0 r
F P
0 g
s
.46306 .50859 m .3569 .48774 L .30338 .5237 L p .71 0 0 r
F P
0 g
s
.30338 .5237 m .3569 .48774 L .35476 .60308 L p .449 0 0 r
F P
0 g
s
.30338 .5237 m .2733 .63041 L .30055 .63568 L .898 0 0 r
F
.30338 .5237 m .27653 .51789 L .2733 .63041 L F
.3569 .48774 m .27653 .51789 L .30338 .5237 L .71 0 0 r
F
.3569 .48774 m .30338 .5237 L .30055 .63568 L .449 0 0 r
F
.70903 .5225 m .69013 .64172 L .71205 .63459 L .621 0 0 r
F
.7279 .51367 m .70903 .5225 L .71205 .63459 L .566 0 0 r
F
.62742 .49303 m .70903 .5225 L .7279 .51367 L .71 0 0 r
F
.62742 .49303 m .61818 .49764 L .70903 .5225 L F
0 g
.68744 .53037 m
.70903 .5225 L
s
.60902 .6158 m .66583 .64789 L .59678 .61907 L .688 0 0 r
F
.60902 .6158 m .69013 .64172 L .66583 .64789 L F
0 g
.63956 .65303 m
.66583 .64789 L
s
.27653 .51789 m .24796 .62407 L .2733 .63041 L .922 0 0 r
F
.27653 .51789 m .25158 .51089 L .24796 .62407 L F
.3432 .48464 m .25158 .51089 L .27653 .51789 L .71 0 0 r
F
.3569 .48774 m .3432 .48464 L .27653 .51789 L F
0 g
.27653 .51789 m
.30338 .5237 L
s
.61993 .61205 m .69013 .64172 L .60902 .6158 L .688 0 0 r
F
.61993 .61205 m .71205 .63459 L .69013 .64172 L F
0 g
.66583 .64789 m
.69013 .64172 L
s
.52258 .51399 m .50721 .62658 L .50711 .51366 L .815 0 0 r
F
.52258 .51399 m .5229 .62687 L .50721 .62658 L F
.53805 .51362 m .5229 .62687 L .52258 .51399 L .793 0 0 r
F
.80111 .59334 m .79664 .47701 L .7279 .51367 L p .532 0 0 r
F P
0 g
s
.7279 .51367 m .73122 .62659 L .80111 .59334 L p .532 0 0 r
F P
0 g
s
.7279 .51367 m .71205 .63459 L .73122 .62659 L .566 0 0 r
F
.73122 .62659 m .7279 .51367 L .62742 .49303 L p .894 0 0 r
F P
0 g
s
.62742 .49303 m .7279 .51367 L .79664 .47701 L p .71 0 0 r
F P
0 g
s
.62742 .49303 m .7279 .51367 L .73122 .62659 L .894 0 0 r
F
.50711 .51366 m .49176 .62566 L .49188 .51264 L .836 0 0 r
F
.50711 .51366 m .50721 .62658 L .49176 .62566 L F
0 g
.50711 .51366 m
.52258 .51399 L
s
.53805 .51362 m .53861 .62654 L .5229 .62687 L .793 0 0 r
F
.5533 .51255 m .53861 .62654 L .53805 .51362 L .771 0 0 r
F
0 g
.52258 .51399 m
.53805 .51362 L
s
.49188 .51264 m .47679 .62412 L .47712 .51094 L .857 0 0 r
F
.49188 .51264 m .49176 .62566 L .47679 .62412 L F
0 g
.49188 .51264 m
.50711 .51366 L
s
.5533 .51255 m .55408 .62557 L .53861 .62654 L .771 0 0 r
F
.56809 .5108 m .55408 .62557 L .5533 .51255 L .747 0 0 r
F
0 g
.53805 .51362 m
.5533 .51255 L
s
.47712 .51094 m .46252 .62198 L .46306 .50859 L .879 0 0 r
F
.47712 .51094 m .47679 .62412 L .46252 .62198 L F
0 g
.47712 .51094 m
.49188 .51264 L
s
.25158 .51089 m .22494 .61673 L .24796 .62407 L .949 0 0 r
F
.25158 .51089 m .22893 .50279 L .22494 .61673 L F
.3306 .48093 m .22893 .50279 L .25158 .51089 L .71 0 0 r
F
.3432 .48464 m .3306 .48093 L .25158 .51089 L F
0 g
.25158 .51089 m
.27653 .51789 L
s
.56809 .5108 m .56908 .62399 L .55408 .62557 L .747 0 0 r
F
.58219 .5084 m .56908 .62399 L .56809 .5108 L .721 0 0 r
F
0 g
.5533 .51255 m
.56809 .5108 L
s
.3569 .48774 m .46306 .50859 L .46252 .62198 L p .891 0 0 r
F P
0 g
s
.46306 .50859 m
.47712 .51094 L
s
.30055 .63568 m .35476 .60308 L .46252 .62198 L p .688 0 0 r
F P
0 g
s
.3569 .48774 m .30055 .63568 L .35476 .60308 L .449 0 0 r
F
.35476 .60308 m .30055 .63568 L .2733 .63041 L .688 0 0 r
F
0 g
.30092 .62114 m
.30338 .5237 L
s
.59538 .50538 m .58339 .62181 L .58219 .5084 L .69 0 0 r
F
.59538 .50538 m .59678 .61907 L .58339 .62181 L F
.60744 .50177 m .59678 .61907 L .59538 .50538 L .654 0 0 r
F
.60744 .50177 m .60902 .6158 L .59678 .61907 L F
.61818 .49764 m .60902 .6158 L .60744 .50177 L .608 0 0 r
F
.62742 .49303 m .62931 .60787 L .73122 .62659 L p .894 0 0 r
F P
0 g
s
.62742 .49303 m .73122 .62659 L .62931 .60787 L .894 0 0 r
F
.80111 .59334 m .73122 .62659 L .62931 .60787 L p .688 0 0 r
F P
0 g
s
.61818 .49764 m .61993 .61205 L .60902 .6158 L .608 0 0 r
F
.62742 .49303 m .61993 .61205 L .61818 .49764 L .548 0 0 r
F
.69697 .57327 m .62931 .60787 L .62742 .49303 L p .509 0 0 r
F P
0 g
s
.79664 .47701 m .69399 .4549 L .62742 .49303 L p .71 0 0 r
F P
0 g
s
.62742 .49303 m .69399 .4549 L .69697 .57327 L p .509 0 0 r
F P
0 g
s
.62742 .49303 m .62931 .60787 L .61993 .61205 L .548 0 0 r
F
.62931 .60787 m .69697 .57327 L .80111 .59334 L p .688 0 0 r
F P
0 g
s
.67558 .42299 m .67423 .36375 L p .57569 .4824 L 0 .19 .704 r
F P
0 g
s
.67423 .36375 m .54432 .44504 L p .57569 .4824 L 0 .19 .704 r
F P
0 g
s
.67978 .60639 m .67558 .42299 L p .57569 .4824 L 0 .19 .704 r
F P
0 g
s
.33099 .39998 m .54432 .44504 L .67423 .36375 L p 0 .442 1 r
F P
0 g
s
.67423 .36375 m .45044 .31181 L .33099 .39998 L p 0 .442 1 r
F P
0 g
s
.45044 .31181 m .67423 .36375 L .67978 .60639 L p 0 .351 .733 r
F P
0 g
s
.67002 .39288 m .68238 .39721 L .77652 .36297 L .71 0 0 r
F
.77831 .3619 m .77652 .36297 L .78362 .36038 L F
.67002 .39288 m .77652 .36297 L .77831 .3619 L F
0 g
.6953 .50698 m
.7279 .51367 L
s
.58219 .5084 m .58339 .62181 L .56908 .62399 L .721 0 0 r
F
.62931 .60787 m .71205 .63459 L .61993 .61205 L .688 0 0 r
F
.62931 .60787 m .73122 .62659 L .71205 .63459 L F
.54432 .44504 m .54564 .6733 L .67978 .60639 L p 0 .19 .704 r
F P
0 g
s
.54564 .6733 m .54432 .44504 L .33099 .39998 L p 0 .35 .741 r
F P
0 g
s
.71205 .63459 m
.73122 .62659 L
s
.69013 .64172 m
.71205 .63459 L
s
.7279 .51367 m
.72984 .57961 L
s
0 0 0 r
.65268 .35875 m
.65268 .35875 L
s
.65268 .35875 m
.65268 .35875 L
s
.22893 .50279 m .20463 .60847 L .22494 .61673 L .979 0 0 r
F
.22893 .50279 m .20895 .49368 L .20463 .60847 L F
.31931 .47667 m .20895 .49368 L .22893 .50279 L .71 0 0 r
F
.3306 .48093 m .31931 .47667 L .22893 .50279 L F
0 g
.22893 .50279 m
.25158 .51089 L
s
.34086 .60026 m .2733 .63041 L .24796 .62407 L .688 0 0 r
F
.35476 .60308 m .2733 .63041 L .34086 .60026 L F
0 g
.2733 .63041 m
.30055 .63568 L
s
0 0 0 r
.67558 .42299 m
.67559 .42299 L
s
.67558 .42299 m
.67558 .42299 L
s
.63096 .35371 m
.63096 .3537 L
s
.63096 .35371 m
.63096 .35371 L
s
0 g
.50721 .62658 m
.50897 .62661 L
s
.66403 .61425 m
.73122 .62659 L
s
.49176 .62566 m
.50721 .62658 L
s
.47679 .62412 m
.49176 .62566 L
s
0 0 0 r
.60905 .34862 m
.60905 .34862 L
s
.60905 .34862 m
.60905 .34862 L
s
.32806 .5969 m .25328 .62227 L .27844 .60644 L .688 0 0 r
F
.34086 .60026 m .24796 .62407 L .32806 .5969 L F
.46252 .62198 m .35476 .60308 L .3569 .48774 L p .891 0 0 r
F P
0 g
s
.3569 .48774 m .34086 .60026 L .3432 .48464 L .902 0 0 r
F
.3569 .48774 m .35476 .60308 L .34086 .60026 L F
.32806 .5969 m .22494 .61673 L .31659 .59303 L .688 0 0 r
F
.3432 .48464 m .32806 .5969 L .3306 .48093 L .928 0 0 r
F
.3432 .48464 m .34086 .60026 L .32806 .5969 L F
.3306 .48093 m .32806 .5969 L .31659 .59303 L .956 0 0 r
F
.3306 .48093 m .31659 .59303 L .31931 .47667 L F
.33099 .39998 m .32577 .63625 L .54564 .6733 L p 0 .35 .741 r
F P
0 g
s
.44879 .5635 m .32577 .63625 L .32711 .57583 L p 0 .16 .674 r
F P
0 g
s
.32711 .57583 m .33099 .39998 L p .41696 .51931 L 0 .16 .674 r
F P
0 g
s
.41696 .51931 m .44879 .5635 L .32711 .57583 L 0 .16 .674 r
F
.27844 .60644 m .24796 .62407 L .22494 .61673 L .688 0 0 r
F
.25328 .62227 m .24796 .62407 L .27844 .60644 L F
0 g
.24796 .62407 m
.2733 .63041 L
s
.30055 .63568 m
.32612 .6203 L
s
.20895 .49368 m .18741 .59938 L .20463 .60847 L 1 0 0 r
F
.20895 .49368 m .19202 .48367 L .18741 .59938 L F
.30951 .4719 m .19202 .48367 L .20895 .49368 L .71 0 0 r
F
0 g
.30338 .5237 m
.31844 .51358 L
s
.31931 .47667 m .30951 .4719 L .20895 .49368 L .71 0 0 r
F
0 g
.20895 .49368 m
.22893 .50279 L
s
0 0 0 r
.32842 .51632 m
.32842 .51632 L
s
.32842 .51632 m
.32842 .51632 L
s
.67696 .48317 m
.67696 .48317 L
s
.67696 .48317 m
.67696 .48317 L
s
0 g
.40578 .65334 m
.41078 .65058 L
s
0 0 0 r
.58696 .34349 m
.58696 .34349 L
s
.58696 .34349 m
.58696 .34349 L
s
.56469 .33832 m
.56469 .33832 L
s
.56469 .33832 m
.56469 .33832 L
s
.31659 .59303 m .22494 .61673 L .20463 .60847 L .688 0 0 r
F
0 g
.22494 .61673 m
.24796 .62407 L
s
0 0 0 r
.32711 .57583 m
.32711 .57583 L
s
.32711 .57583 m
.32711 .57583 L
s
.67836 .5443 m
.67836 .5443 L
s
.67836 .5443 m
.67836 .5443 L
s
.19202 .48367 m .17362 .5896 L .18741 .59938 L 1 0 0 r
F
.19202 .48367 m .17848 .47289 L .17362 .5896 L F
.30138 .46672 m .17848 .47289 L .19202 .48367 L .71 0 0 r
F
.30951 .4719 m .30138 .46672 L .19202 .48367 L F
0 g
.19202 .48367 m
.20895 .49368 L
s
0 0 0 r
.54222 .33311 m
.54223 .33311 L
s
.54222 .33311 m
.54222 .33311 L
s
.51957 .32785 m
.51957 .32785 L
s
.51957 .32785 m
.51957 .32785 L
s
.30663 .58871 m .20463 .60847 L .18741 .59938 L .688 0 0 r
F
.31659 .59303 m .20463 .60847 L .30663 .58871 L F
0 g
.20463 .60847 m
.22494 .61673 L
s
.67978 .60639 m .54564 .6733 L .32577 .63625 L p 0 .453 1 r
F P
0 g
s
0 0 0 r
.39361 .64768 m
.39361 .64768 L
s
.39361 .64768 m
.39361 .64768 L
s
.597 .64768 m
.597 .64768 L
s
.597 .64768 m
.597 .64768 L
s
.41586 .65143 m
.41586 .65143 L
s
.41586 .65143 m
.41586 .65143 L
s
.58389 .65422 m
.58389 .65423 L
s
.58389 .65422 m
.58389 .65422 L
s
.43792 .65515 m
.43792 .65515 L
s
.43792 .65515 m
.43792 .65515 L
s
.45981 .65884 m
.45981 .65884 L
s
.45981 .65884 m
.45981 .65884 L
s
.57096 .66067 m
.57096 .66067 L
s
.57096 .66067 m
.57096 .66067 L
s
.48153 .6625 m
.48153 .6625 L
s
.48153 .6625 m
.48153 .6625 L
s
.50307 .66613 m
.50307 .66613 L
s
.50307 .66613 m
.50307 .66613 L
s
.55821 .66703 m
.55821 .66703 L
s
.55821 .66703 m
.55821 .66703 L
s
.52444 .66973 m
.52444 .66973 L
s
.52444 .66973 m
.52444 .66973 L
s
.32972 .45771 m
.32972 .45771 L
s
.32972 .45771 m
.32972 .45771 L
s
.69399 .4549 m .80111 .59334 L .79664 .47701 L .899 0 0 r
F
.81364 .46664 m .79664 .47701 L .80111 .59334 L .493 0 0 r
F
.70213 .44953 m .79664 .47701 L .81364 .46664 L .71 0 0 r
F
.70213 .44953 m .69399 .4549 L .79664 .47701 L F
.69399 .4549 m .79664 .47701 L .80111 .59334 L p .899 0 0 r
F P
0 g
s
.31931 .47667 m .30663 .58871 L .30951 .4719 L .988 0 0 r
F
.31931 .47667 m .31659 .59303 L .30663 .58871 L F
0 g
.31931 .47667 m
.32922 .48041 L
s
0 0 0 r
.37118 .64391 m
.37118 .6439 L
s
.37118 .6439 m
.37118 .6439 L
s
.17848 .47289 m .1636 .57926 L .17362 .5896 L 1 0 0 r
F
.17848 .47289 m .16866 .46149 L .1636 .57926 L F
.29509 .46119 m .16866 .46149 L .17848 .47289 L .71 0 0 r
F
.30138 .46672 m .29509 .46119 L .17848 .47289 L F
0 g
.17848 .47289 m
.19202 .48367 L
s
0 0 0 r
.52444 .66973 m
.52444 .66973 L
s
.30951 .4719 m .29837 .584 L .30138 .46672 L 1 0 0 r
F
.30951 .4719 m .30663 .58871 L .29837 .584 L F
0 g
.30951 .4719 m
.31931 .47667 L
s
0 0 0 r
.61031 .64105 m
.61031 .64105 L
s
.61031 .64105 m
.61031 .64105 L
s
.34857 .64009 m
.34857 .64009 L
s
.34857 .64009 m
.34857 .64009 L
s
.55821 .66703 m
.55821 .66703 L
s
.50307 .66613 m
.50307 .66613 L
s
.29837 .584 m .18741 .59938 L .17362 .5896 L .688 0 0 r
F
.30663 .58871 m .18741 .59938 L .29837 .584 L F
0 g
.18741 .59938 m
.20463 .60847 L
s
.30138 .46672 m .29196 .57898 L .29509 .46119 L 1 0 0 r
F
.30138 .46672 m .29837 .584 L .29196 .57898 L F
0 g
.30138 .46672 m
.30951 .4719 L
s
.81364 .46664 m .80111 .59334 L .81841 .58393 L .493 0 0 r
F
.82718 .45548 m .81364 .46664 L .81841 .58393 L .389 0 0 r
F
.7084 .4438 m .81364 .46664 L .82718 .45548 L .71 0 0 r
F
.7084 .4438 m .70213 .44953 L .81364 .46664 L F
0 g
.79664 .47701 m
.81364 .46664 L
s
.33099 .39998 m .45044 .31181 L .44879 .5635 L p 0 .16 .674 r
F P
0 g
s
0 0 0 r
.38855 .35749 m
.38855 .35749 L
s
.38855 .35749 m
.38856 .35749 L
s
.37671 .36623 m
.37671 .36623 L
s
.37671 .36623 m
.37671 .36623 L
s
.36504 .37485 m
.36504 .37485 L
s
.36504 .37485 m
.36504 .37485 L
s
.35353 .38335 m
.35353 .38335 L
s
.35353 .38335 m
.35353 .38335 L
s
.34218 .39172 m
.34218 .39172 L
s
.34218 .39172 m
.34218 .39172 L
s
0 g
.31659 .59303 m
.32665 .59642 L
s
0 0 0 r
.40057 .34862 m
.40057 .34862 L
s
.40057 .34862 m
.40057 .34862 L
s
.48153 .6625 m
.48153 .6625 L
s
.57096 .66067 m
.57096 .66067 L
s
.16866 .46149 m .15762 .5685 L .1636 .57926 L 1 0 0 r
F
.16866 .46149 m .16283 .44964 L .15762 .5685 L F
.29076 .45539 m .16283 .44964 L .16866 .46149 L .71 0 0 r
F
.29509 .46119 m .29076 .45539 L .16866 .46149 L F
0 g
.16866 .46149 m
.17848 .47289 L
s
.29509 .46119 m .28755 .57372 L .29076 .45539 L 1 0 0 r
F
.29509 .46119 m .29196 .57898 L .28755 .57372 L F
0 g
.29509 .46119 m
.30138 .46672 L
s
.69399 .4549 m .69697 .57327 L .80111 .59334 L .899 0 0 r
F
.80111 .59334 m .69697 .57327 L .69399 .4549 L p F P
0 g
s
.70525 .56839 m .80111 .59334 L .69697 .57327 L .688 0 0 r
F
.70525 .56839 m .81841 .58393 L .80111 .59334 L F
0 g
.79664 .47701 m
.80065 .58149 L
s
.30663 .58871 m
.31659 .59303 L
s
0 0 0 r
.45981 .65884 m
.45981 .65884 L
s
.34218 .39172 m
.34218 .39172 L
s
.32972 .45771 m
.32972 .45771 L
s
.29196 .57898 m .17362 .5896 L .1636 .57926 L .688 0 0 r
F
.29837 .584 m .17362 .5896 L .29196 .57898 L F
0 g
.17362 .5896 m
.18741 .59938 L
s
0 0 0 r
.41276 .33962 m
.41276 .33962 L
s
.41276 .33962 m
.41276 .33962 L
s
.82718 .45548 m .81841 .58393 L .83221 .5738 L .389 0 0 r
F
.83694 .4437 m .82718 .45548 L .83221 .5738 L .227 0 0 r
F
.71268 .43782 m .82718 .45548 L .83694 .4437 L .71 0 0 r
F
.71268 .43782 m .7084 .4438 L .82718 .45548 L F
0 g
.81364 .46664 m
.82718 .45548 L
s
.29076 .45539 m .2885 .44943 L .16283 .44964 L .71 0 0 r
F
.29076 .45539 m .28523 .56831 L .2885 .44943 L 1 0 0 r
F
.29076 .45539 m .28755 .57372 L .28523 .56831 L F
0 g
.29076 .45539 m
.29509 .46119 L
s
.29837 .584 m
.30663 .58871 L
s
0 0 0 r
.43792 .65515 m
.43792 .65515 L
s
.70213 .44953 m .69697 .57327 L .69399 .4549 L .464 0 0 r
F
0 g
.70184 .45659 m
.79664 .47701 L
s
0 0 0 r
.58389 .65423 m
.58389 .65423 L
s
.41586 .65143 m
.41586 .65143 L
s
.35353 .38335 m
.35353 .38335 L
s
.71164 .5632 m .81841 .58393 L .70525 .56839 L .688 0 0 r
F
.71164 .5632 m .83221 .5738 L .81841 .58393 L F
0 g
.80111 .59334 m
.81841 .58393 L
s
.16283 .44964 m .15593 .55749 L .15762 .5685 L .963 0 0 r
F
.16283 .44964 m .16122 .43752 L .15593 .55749 L F
.2885 .44943 m .16122 .43752 L .16283 .44964 L .71 0 0 r
F
0 g
.16283 .44964 m
.16866 .46149 L
s
.70213 .44953 m .70525 .56839 L .69697 .57327 L .464 0 0 r
F
0 g
.69399 .4549 m
.69697 .57327 L
s
.7084 .4438 m .70525 .56839 L .70213 .44953 L .342 0 0 r
F
0 g
.69399 .4549 m
.70213 .44953 L
s
.2885 .44943 m .28837 .44341 L .16122 .43752 L .71 0 0 r
F
.2885 .44943 m .28508 .56284 L .28837 .44341 L .856 0 0 r
F
.2885 .44943 m .28523 .56831 L .28508 .56284 L F
0 g
.2885 .44943 m
.29076 .45539 L
s
0 0 0 r
.32842 .51632 m
.32842 .51632 L
s
.42514 .33049 m
.42514 .33049 L
s
.42514 .33049 m
.42514 .33049 L
s
.597 .64768 m
.597 .64768 L
s
.39361 .64768 m
.39361 .64768 L
s
.28755 .57372 m .1636 .57926 L .15762 .5685 L .688 0 0 r
F
.29196 .57898 m .1636 .57926 L .28755 .57372 L F
0 g
.1636 .57926 m
.17362 .5896 L
s
.29196 .57898 m
.29837 .584 L
s
.7084 .4438 m .71164 .5632 L .70525 .56839 L .342 0 0 r
F
.71268 .43782 m .71164 .5632 L .7084 .4438 L .147 0 0 r
F
0 g
.70213 .44953 m
.7084 .4438 L
s
.83694 .4437 m .83221 .5738 L .84217 .5631 L .227 0 0 r
F
.84263 .43145 m .83694 .4437 L .84217 .5631 L .1 0 0 r
F
.71485 .43166 m .83694 .4437 L .84263 .43145 L .71 0 0 r
F
.71485 .43166 m .71268 .43782 L .83694 .4437 L F
0 g
.82718 .45548 m
.83694 .4437 L
s
.28837 .44341 m .28715 .5574 L .29042 .43742 L .1 0 0 r
F
.28837 .44341 m .28508 .56284 L .28715 .5574 L F
.28837 .44341 m .16399 .42535 L .16122 .43752 L .71 0 0 r
F
.28837 .44341 m .29042 .43742 L .16399 .42535 L F
0 0 0 r
.36504 .37485 m
.36504 .37485 L
s
.37118 .64391 m
.37118 .6439 L
s
.32711 .57583 m
.32711 .57583 L
s
.4377 .32122 m
.4377 .32122 L
s
.4377 .32122 m
.4377 .32122 L
s
.716 .55776 m .83221 .5738 L .71164 .5632 L .688 0 0 r
F
.716 .55776 m .84217 .5631 L .83221 .5738 L F
0 g
.69697 .57327 m
.80111 .59334 L
s
.81841 .58393 m
.83221 .5738 L
s
.28755 .57372 m .15762 .5685 L .28523 .56831 L .688 0 0 r
F
0 g
.28755 .57372 m
.29196 .57898 L
s
.71268 .43782 m .716 .55776 L .71164 .5632 L .147 0 0 r
F
.71485 .43166 m .716 .55776 L .71268 .43782 L .1 0 0 r
F
0 g
.7084 .4438 m
.71268 .43782 L
s
.69697 .57327 m
.70525 .56839 L
s
0 0 0 r
.6103 .64105 m
.61031 .64105 L
s
.16122 .43752 m .15869 .54644 L .15593 .55749 L .1 0 0 r
F
.16122 .43752 m .16399 .42535 L .15869 .54644 L F
.29042 .43742 m .29142 .55208 L .29464 .43157 L .115 0 0 r
F
.29042 .43742 m .28715 .5574 L .29142 .55208 L F
.29042 .43742 m .17125 .41334 L .16399 .42535 L .71 0 0 r
F
.29042 .43742 m .29464 .43157 L .17125 .41334 L F
0 g
.28837 .44341 m
.29042 .43742 L
s
0 0 0 r
.34857 .64009 m
.34857 .64009 L
s
.37671 .36623 m
.37671 .36623 L
s
.28523 .56831 m .15762 .5685 L .15593 .55749 L .688 0 0 r
F
0 g
.15762 .5685 m
.1636 .57926 L
s
.70525 .56839 m
.71164 .5632 L
s
.28523 .56831 m .15593 .55749 L .28508 .56284 L .688 0 0 r
F
0 g
.28523 .56831 m
.28755 .57372 L
s
.32577 .63625 m .44879 .5635 L .67978 .60639 L p 0 .453 1 r
F P
0 g
s
0 0 0 r
.37279 .60844 m
.37671 .36623 L
s
.37279 .60845 m
.37279 .60844 L
s
.38498 .60123 m
.38498 .60123 L
s
.66548 .61353 m
.66548 .61353 L
s
.66548 .61353 m
.66548 .61353 L
s
.36077 .61555 m
.36504 .37485 L
s
.36077 .61555 m
.36077 .61555 L
s
.37279 .60845 m
.597 .64768 L
s
.37279 .60845 m
.37279 .60845 L
s
.65138 .62056 m
.65138 .62056 L
s
.65138 .62056 m
.65138 .62056 L
s
.34894 .62255 m
.34894 .62255 L
s
.36078 .61555 m
.58389 .65423 L
s
.36077 .61555 m
.36078 .61555 L
s
.63749 .62749 m
.63749 .62749 L
s
.63749 .62749 m
.63749 .62749 L
s
.33727 .62945 m
.33727 .62945 L
s
.34894 .62255 m
.57096 .66067 L
s
.34894 .62255 m
.34894 .62255 L
s
.6238 .63432 m
.6238 .63432 L
s
.6238 .63432 m
.6238 .63432 L
s
.33727 .62945 m
.55821 .66703 L
s
.33727 .62945 m
.33727 .62945 L
s
.71485 .43166 m .71822 .55217 L .716 .55776 L .1 0 0 r
F
.71485 .42545 m .71485 .43166 L .84263 .43145 L .71 0 0 r
F
.71485 .42545 m .71822 .55217 L .71485 .43166 L .1 0 0 r
F
0 g
.71268 .43782 m
.71485 .43166 L
s
.29464 .43157 m .29785 .547 L .30099 .42597 L .335 0 0 r
F
.29464 .43157 m .29142 .55208 L .29785 .547 L F
.29464 .43157 m .18298 .40173 L .17125 .41334 L .71 0 0 r
F
.29464 .43157 m .30099 .42597 L .18298 .40173 L F
0 g
.29042 .43742 m
.29464 .43157 L
s
.84263 .43145 m .84217 .5631 L .84801 .55198 L .1 0 0 r
F
.84403 .41895 m .84263 .43145 L .84801 .55198 L F
.71485 .42545 m .84263 .43145 L .84403 .41895 L .71 0 0 r
F
0 g
.83694 .4437 m
.84263 .43145 L
s
0 0 0 r
.39736 .59391 m
.39736 .59391 L
s
.6238 .63432 m
.6238 .63432 L
s
.65268 .35875 m
.65268 .35875 L
s
.71822 .55217 m .84217 .5631 L .716 .55776 L .688 0 0 r
F
0 g
.71164 .5632 m
.716 .55776 L
s
.71822 .55217 m .84801 .55198 L .84217 .5631 L .688 0 0 r
F
0 g
.83221 .5738 m
.84217 .5631 L
s
.30099 .42597 m .17788 .52496 L .18298 .40173 L .894 0 0 r
F
.30099 .42597 m .29785 .547 L .17788 .52496 L F
.35729 .50781 m .35959 .38286 L .30099 .42597 L p .41 0 0 r
F P
0 g
s
0 0 0 r
.3421 .39573 m
.34218 .39172 L
s
.35345 .38738 m
.35353 .38335 L
s
.32842 .51632 m
.35223 .50046 L
s
.30099 .42597 m .29785 .547 L .35729 .50781 L p .41 0 0 r
F P
0 g
s
0 0 0 r
.34894 .62255 m
.35106 .51191 L
s
.33727 .62945 m
.33954 .51951 L
s
.29785 .547 m .30099 .42597 L .18298 .40173 L p .894 0 0 r
F P
0 g
s
.18298 .40173 m .30099 .42597 L .35959 .38286 L p .71 0 0 r
F P
0 g
s
0 0 0 r
.38498 .60123 m
.38498 .60123 L
s
.38498 .60123 m
.38855 .35749 L
s
.38855 .35749 m
.38855 .35749 L
s
.28508 .56284 m .15869 .54644 L .28715 .5574 L .688 0 0 r
F
.28508 .56284 m .15593 .55749 L .15869 .54644 L F
0 g
.28508 .56284 m
.28523 .56831 L
s
.15593 .55749 m
.15762 .5685 L
s
.71485 .42545 m .71824 .54652 L .71822 .55217 L .1 0 0 r
F
.71263 .41927 m .71824 .54652 L .71485 .42545 L 1 0 0 r
F
.71263 .41927 m .71485 .42545 L .84403 .41895 L .71 0 0 r
F
.16399 .42535 m .166 .53552 L .15869 .54644 L .1 0 0 r
F
.16399 .42535 m .17125 .41334 L .166 .53552 L F
0 g
.16122 .43752 m
.16399 .42535 L
s
0 0 0 r
.67558 .42299 m
.67559 .42299 L
s
.63096 .3537 m
.63096 .35371 L
s
.40993 .58648 m
.40993 .58648 L
s
.63749 .62749 m
.63749 .62749 L
s
.28715 .5574 m .166 .53552 L .29142 .55208 L .688 0 0 r
F
.28715 .5574 m .15869 .54644 L .166 .53552 L F
0 g
.28508 .56284 m
.28715 .5574 L
s
.15593 .55749 m
.15869 .54644 L
s
.71263 .41927 m .71601 .54092 L .71824 .54652 L 1 0 0 r
F
.71263 .41927 m .84403 .41895 L .84096 .40639 L .71 0 0 r
F
.70821 .41326 m .71601 .54092 L .71263 .41927 L 1 0 0 r
F
.70821 .41326 m .71263 .41927 L .84096 .40639 L .71 0 0 r
F
0 g
.71263 .41927 m
.71485 .42545 L
s
.84403 .41895 m .84801 .55198 L .84948 .54062 L .1 0 0 r
F
.84096 .40639 m .84403 .41895 L .84948 .54062 L .976 0 0 r
F
0 0 0 r
.60905 .34862 m
.60905 .34862 L
s
.39736 .59391 m
.39736 .59391 L
s
.39736 .59391 m
.40057 .34862 L
s
.40057 .34862 m
.40057 .34862 L
s
.67696 .48317 m
.67696 .48317 L
s
.71824 .54652 m .84801 .55198 L .71822 .55217 L .688 0 0 r
F
0 g
.716 .55776 m
.71822 .55217 L
s
.29142 .55208 m .17788 .52496 L .29785 .547 L .688 0 0 r
F
.29142 .55208 m .166 .53552 L .17788 .52496 L F
0 g
.28715 .5574 m
.29142 .55208 L
s
.71824 .54652 m .84948 .54062 L .84801 .55198 L .688 0 0 r
F
0 g
.84217 .5631 m
.84801 .55198 L
s
.17125 .41334 m .17788 .52496 L .166 .53552 L .273 0 0 r
F
.17125 .41334 m .18298 .40173 L .17788 .52496 L F
0 g
.16399 .42535 m
.17125 .41334 L
s
.70821 .41326 m .71153 .53545 L .71601 .54092 L 1 0 0 r
F
.70821 .41326 m .84096 .40639 L .83333 .39402 L .71 0 0 r
F
.70163 .4075 m .71153 .53545 L .70821 .41326 L 1 0 0 r
F
.70163 .4075 m .70821 .41326 L .83333 .39402 L .71 0 0 r
F
0 g
.70821 .41326 m
.71263 .41927 L
s
0 0 0 r
.42268 .57894 m
.42268 .57894 L
s
.65138 .62056 m
.65138 .62056 L
s
.58696 .34349 m
.58696 .34349 L
s
.40993 .58648 m
.40993 .58648 L
s
.40993 .58648 m
.41276 .33962 L
s
.41276 .33962 m
.41276 .33962 L
s
.18298 .40173 m .17788 .52496 L .29785 .547 L p .894 0 0 r
F P
0 g
s
.35729 .50781 m .29785 .547 L .17788 .52496 L p .688 0 0 r
F P
0 g
s
.29142 .55208 m
.29785 .547 L
s
.29872 .51341 m
.30099 .42597 L
s
0 0 0 r
.56469 .33832 m
.56469 .33832 L
s
.70163 .4075 m .70487 .53021 L .71153 .53545 L 1 0 0 r
F
.70163 .4075 m .83333 .39402 L .82115 .38206 L .71 0 0 r
F
.69298 .40212 m .70487 .53021 L .70163 .4075 L 1 0 0 r
F
.69298 .40212 m .70163 .4075 L .82115 .38206 L .71 0 0 r
F
0 g
.70163 .4075 m
.70821 .41326 L
s
.71601 .54092 m .84948 .54062 L .71824 .54652 L .688 0 0 r
F
0 g
.71822 .55217 m
.71824 .54652 L
s
.15869 .54644 m
.166 .53552 L
s
.84096 .40639 m .84948 .54062 L .84643 .52921 L .976 0 0 r
F
.83333 .39402 m .84096 .40639 L .84643 .52921 L 1 0 0 r
F
0 g
.84096 .40639 m
.84403 .41895 L
s
0 0 0 r
.67836 .5443 m
.67836 .5443 L
s
.43564 .57128 m
.43564 .57128 L
s
.66548 .61353 m
.66548 .61353 L
s
.54223 .33311 m
.54223 .33311 L
s
.69298 .40212 m .69609 .52532 L .70487 .53021 L 1 0 0 r
F
.69298 .40212 m .82115 .38206 L .80451 .37077 L .71 0 0 r
F
.68238 .39721 m .69609 .52532 L .69298 .40212 L .984 0 0 r
F
.68238 .39721 m .69298 .40212 L .80451 .37077 L .71 0 0 r
F
0 g
.69298 .40212 m
.70163 .4075 L
s
.23395 .48404 m .17788 .52496 L .18298 .40173 L p .363 0 0 r
F P
0 g
s
.35959 .38286 m .23833 .35674 L .18298 .40173 L p .71 0 0 r
F P
0 g
s
.18298 .40173 m .23833 .35674 L .23395 .48404 L p .363 0 0 r
F P
0 g
s
.23641 .4127 m
.30099 .42597 L
s
.17125 .41334 m
.18298 .40173 L
s
.71601 .54092 m .84643 .52921 L .84948 .54062 L .688 0 0 r
F
0 g
.84801 .55198 m
.84948 .54062 L
s
.71153 .53545 m .84643 .52921 L .71601 .54092 L .688 0 0 r
F
0 g
.71601 .54092 m
.71824 .54652 L
s
0 0 0 r
.42268 .57894 m
.42268 .57894 L
s
.42268 .57894 m
.42514 .33049 L
s
.42514 .33049 m
.42514 .33049 L
s
.51957 .32785 m
.51957 .32785 L
s
.68238 .39721 m .68533 .52086 L .69609 .52532 L .984 0 0 r
F
.68238 .39721 m .80451 .37077 L .78362 .36038 L .71 0 0 r
F
.67002 .39288 m .68533 .52086 L .68238 .39721 L .949 0 0 r
F
0 g
.68238 .39721 m
.69298 .40212 L
s
.67978 .60639 m .44879 .5635 L .45044 .31181 L p 0 .351 .733 r
F P
0 g
s
0 0 0 r
.52021 .57676 m
.52021 .57676 L
s
.45004 .3732 m
.45004 .3732 L
s
.54361 .5811 m
.54361 .58111 L
s
.43564 .57128 m
.66548 .61353 L
s
.44922 .49902 m
.44922 .49902 L
s
.5668 .58541 m
.5668 .58541 L
s
.44921 .49902 m
.44922 .49902 L
s
.58978 .58968 m
.58978 .58968 L
s
.42268 .57894 m
.65138 .62056 L
s
.44963 .43559 m
.44963 .43559 L
s
.61257 .59391 m
.61257 .59391 L
s
.40993 .58648 m
.63749 .62749 L
s
.63517 .59811 m
.63517 .59811 L
s
.45004 .3732 m
.45004 .3732 L
s
.44963 .43559 m
.44963 .43559 L
s
.65757 .60227 m
.65757 .60227 L
s
.39736 .59391 m
.6238 .63432 L
s
.65757 .60227 m
.65757 .60227 L
s
.52444 .66973 m
.65757 .60227 L
s
.63517 .59811 m
.63517 .59811 L
s
.50307 .66613 m
.63517 .59811 L
s
.61257 .59391 m
.61257 .59391 L
s
.48153 .6625 m
.61257 .59391 L
s
.58978 .58968 m
.58978 .58968 L
s
.45981 .65884 m
.58978 .58968 L
s
.56679 .58541 m
.5668 .58541 L
s
.43792 .65515 m
.56679 .58541 L
s
.54361 .58111 m
.54361 .58111 L
s
.41586 .65143 m
.54361 .58111 L
s
.52021 .57676 m
.52021 .57676 L
s
.39361 .64768 m
.52021 .57676 L
s
.49662 .57238 m
.49662 .57238 L
s
.37118 .6439 m
.49662 .57238 L
s
.38498 .60123 m
.6103 .64105 L
s
.47281 .56796 m
.47281 .56796 L
s
.34857 .64009 m
.47281 .56796 L
s
.47368 .3172 m
.47368 .3172 L
s
.47368 .3172 m
.47368 .3172 L
s
.49672 .32255 m
.49672 .32255 L
s
.49672 .32255 m
.49673 .32255 L
s
.71153 .53545 m .83874 .51796 L .84643 .52921 L .688 0 0 r
F
.70487 .53021 m .83874 .51796 L .71153 .53545 L F
0 g
.71153 .53545 m
.71601 .54092 L
s
.83333 .39402 m .84643 .52921 L .83874 .51796 L 1 0 0 r
F
0 g
.84643 .52921 m
.84948 .54062 L
s
.82115 .38206 m .83333 .39402 L .83874 .51796 L 1 0 0 r
F
0 g
.83333 .39402 m
.84096 .40639 L
s
0 0 0 r
.49662 .57238 m
.49662 .57238 L
s
.49673 .32255 m
.49673 .32255 L
s
.67002 .39288 m .67278 .51692 L .68533 .52086 L .949 0 0 r
F
.67002 .39288 m .78362 .36038 L .75878 .35113 L .71 0 0 r
F
.65609 .38922 m .67278 .51692 L .67002 .39288 L .917 0 0 r
F
.65609 .38922 m .67002 .39288 L .75878 .35113 L .71 0 0 r
F
0 0 0 r
.65388 .4182 m
.65757 .60227 L
s
.65268 .35875 m
.65388 .4182 L
s
0 g
.67002 .39288 m
.68238 .39721 L
s
0 0 0 r
.43564 .57128 m
.43564 .57127 L
s
.4377 .32122 m
.4377 .32122 L
s
.65609 .38922 m .75878 .35113 L .73043 .34324 L .71 0 0 r
F
.73433 .47175 m .73043 .34324 L .65609 .38922 L p .481 0 0 r
F P
0 g
s
0 0 0 r
.62097 .41094 m
.66006 .41957 L
s
.62193 .47165 m
.66813 .48132 L
s
.65609 .38922 m .65864 .51359 L .67278 .51692 L .917 0 0 r
F
.65609 .38922 m .65864 .51359 L .73433 .47175 L p .481 0 0 r
F P
0 g
s
0 0 0 r
.62291 .53334 m
.67836 .5443 L
s
.65864 .51359 m .65609 .38922 L .54197 .36338 L p .903 0 0 r
F P
0 g
s
0 0 0 r
.63096 .35371 m
.63148 .38364 L
s
.63315 .48077 m
.63517 .59811 L
s
.60905 .34862 m
.60948 .37866 L
s
.61053 .45165 m
.61257 .59391 L
s
.58696 .34349 m
.58731 .37364 L
s
.58787 .42247 m
.58978 .58968 L
s
.56469 .33832 m
.56495 .36858 L
s
.54223 .33311 m
.54239 .36347 L
s
.54197 .36338 m .65609 .38922 L .73043 .34324 L p .71 0 0 r
F P
0 g
s
0 0 0 r
.5424 .36392 m
.54256 .39362 L
s
.45004 .3732 m
.57021 .39973 L
s
.65609 .38922 m .73433 .47175 L .65864 .51359 L .481 0 0 r
F
.65609 .38922 m .73043 .34324 L .73433 .47175 L F
.70487 .53021 m .82641 .50708 L .83874 .51796 L .688 0 0 r
F
.69609 .52532 m .82641 .50708 L .70487 .53021 L F
0 g
.70487 .53021 m
.71153 .53545 L
s
0 0 0 r
.47281 .56796 m
.47281 .56796 L
s
.47368 .3172 m
.47368 .3172 L
s
.69609 .52532 m .80955 .49681 L .82641 .50708 L .688 0 0 r
F
.68533 .52086 m .80955 .49681 L .69609 .52532 L F
0 g
.69609 .52532 m
.70487 .53021 L
s
.17788 .52496 m .23395 .48404 L .35729 .50781 L p .688 0 0 r
F P
0 g
s
.166 .53552 m
.17788 .52496 L
s
.17788 .52496 m
.18298 .40173 L
s
.17788 .52496 m
.29785 .547 L
s
.23833 .35674 m .35959 .38286 L .35729 .50781 L p .899 0 0 r
F P
0 g
s
0 0 0 r
.41696 .51931 m
.44921 .49902 L
s
.32711 .57583 m
.41696 .51931 L
s
.35749 .49696 m
.41762 .45691 L
s
.41828 .3955 m
.45004 .3732 L
s
.35858 .43743 m
.41828 .3955 L
s
.35959 .38286 m .36642 .50267 L .36858 .37721 L .468 0 0 r
F
.35959 .38286 m .35729 .50781 L .36642 .50267 L F
.35959 .38286 m .25562 .34489 L .23833 .35674 L .71 0 0 r
F
.35959 .38286 m .36858 .37721 L .25562 .34489 L F
.35959 .38286 m .23395 .48404 L .35729 .50781 L .899 0 0 r
F
.35959 .38286 m .23833 .35674 L .23395 .48404 L F
.82115 .38206 m .83874 .51796 L .82641 .50708 L 1 0 0 r
F
0 g
.83874 .51796 m
.84643 .52921 L
s
.80451 .37077 m .82115 .38206 L .82641 .50708 L 1 0 0 r
F
0 g
.82115 .38206 m
.83333 .39402 L
s
.68533 .52086 m .78835 .48735 L .80955 .49681 L .688 0 0 r
F
.67278 .51692 m .78835 .48735 L .68533 .52086 L F
0 g
.68533 .52086 m
.69609 .52532 L
s
.36858 .37721 m .37756 .49798 L .37955 .37206 L .554 0 0 r
F
.36858 .37721 m .36642 .50267 L .37756 .49798 L F
.36858 .37721 m .27725 .33396 L .25562 .34489 L .71 0 0 r
F
.36858 .37721 m .37955 .37206 L .27725 .33396 L F
0 g
.35959 .38286 m
.36858 .37721 L
s
.67278 .51692 m .76314 .47893 L .78835 .48735 L .688 0 0 r
F
.65864 .51359 m .76314 .47893 L .67278 .51692 L F
0 g
.67278 .51692 m
.68533 .52086 L
s
.37955 .37206 m .39052 .49382 L .3923 .36749 L .617 0 0 r
F
.37955 .37206 m .37756 .49798 L .39052 .49382 L F
.37955 .37206 m .30287 .3242 L .27725 .33396 L .71 0 0 r
F
.37955 .37206 m .3923 .36749 L .30287 .3242 L F
0 g
.36858 .37721 m
.37955 .37206 L
s
.80451 .37077 m .82641 .50708 L .80955 .49681 L 1 0 0 r
F
0 g
.82641 .50708 m
.83874 .51796 L
s
.78362 .36038 m .80451 .37077 L .80955 .49681 L .995 0 0 r
F
0 g
.80451 .37077 m
.82115 .38206 L
s
.54197 .36338 m .54267 .49008 L .65864 .51359 L p .903 0 0 r
F P
0 g
s
.73433 .47175 m .65864 .51359 L .54267 .49008 L p .688 0 0 r
F P
0 g
s
.65609 .38922 m
.65793 .47906 L
s
0 0 0 r
.54325 .5176 m
.54361 .5811 L
s
.5431 .49016 m
.54325 .5176 L
s
.56626 .52214 m
.5668 .58541 L
s
.56602 .49481 m
.56626 .52214 L
s
.44922 .49902 m
.62291 .53334 L
s
.65864 .51359 m .73433 .47175 L .76314 .47893 L .688 0 0 r
F
0 g
.65864 .51359 m
.67278 .51692 L
s
.3923 .36749 m .40508 .49029 L .40663 .36361 L .664 0 0 r
F
.3923 .36749 m .39052 .49382 L .40508 .49029 L F
.3923 .36749 m .33206 .31585 L .30287 .3242 L .71 0 0 r
F
.3923 .36749 m .40663 .36361 L .33206 .31585 L F
0 g
.37955 .37206 m
.3923 .36749 L
s
.40663 .36361 m .42098 .48746 L .42227 .3605 L .703 0 0 r
F
0 0 0 r
.42131 .45445 m
.44963 .43559 L
s
.40663 .36361 m .40508 .49029 L .42098 .48746 L .703 0 0 r
F
.40663 .36361 m .36427 .3091 L .33206 .31585 L .71 0 0 r
F
.40663 .36361 m .42227 .3605 L .36427 .3091 L F
0 g
.3923 .36749 m
.40663 .36361 L
s
.35729 .50781 m .23395 .48404 L .23833 .35674 L p .899 0 0 r
F P
0 g
s
.35729 .50781 m .25149 .47325 L .36642 .50267 L .688 0 0 r
F
0 g
.35743 .50037 m
.35959 .38286 L
s
.35729 .50781 m .23395 .48404 L .25149 .47325 L .688 0 0 r
F
.61543 .44632 m .54267 .49008 L .54197 .36338 L p .449 0 0 r
F P
0 g
s
0 0 0 r
.44963 .43559 m
.50831 .44787 L
s
.50831 .44787 m
.54248 .45502 L
s
.73043 .34324 m .61347 .31534 L .54197 .36338 L p .71 0 0 r
F P
0 g
s
.54197 .36338 m .61347 .31534 L .61543 .44632 L p .449 0 0 r
F P
0 g
s
.54197 .36338 m .61543 .44632 L .61347 .31534 L .449 0 0 r
F
.54197 .36338 m .54267 .49008 L .61543 .44632 L F
.52613 .36032 m .54267 .49008 L .54197 .36338 L .89 0 0 r
F
.52613 .36032 m .54197 .36338 L .61347 .31534 L .71 0 0 r
F
.42227 .3605 m .43792 .48538 L .43894 .35822 L .735 0 0 r
F
0 0 0 r
.43739 .35843 m
.4377 .32122 L
s
.42227 .3605 m .42098 .48746 L .43792 .48538 L .735 0 0 r
F
0 0 0 r
.43564 .57127 m
.43634 .48558 L
s
.42227 .3605 m .39886 .30413 L .36427 .3091 L .71 0 0 r
F
.42227 .3605 m .43894 .35822 L .39886 .30413 L F
0 g
.40663 .36361 m
.42227 .3605 L
s
.78362 .36038 m .80955 .49681 L .78835 .48735 L .995 0 0 r
F
0 g
.80955 .49681 m
.82641 .50708 L
s
.75878 .35113 m .78362 .36038 L .78835 .48735 L .957 0 0 r
F
0 g
.78362 .36038 m
.80451 .37077 L
s
.52613 .36032 m .52656 .48729 L .54267 .49008 L .89 0 0 r
F
.52613 .36032 m .61347 .31534 L .5808 .3087 L .71 0 0 r
F
.50931 .35809 m .52656 .48729 L .52613 .36032 L .864 0 0 r
F
0 0 0 r
.51957 .32785 m
.51965 .35946 L
s
.51985 .43707 m
.52021 .57676 L
s
.50931 .35809 m .52613 .36032 L .5808 .3087 L .71 0 0 r
F
0 g
.52613 .36032 m
.54197 .36338 L
s
.43894 .35822 m .45558 .48411 L .45631 .35682 L .764 0 0 r
F
.43894 .35822 m .43792 .48538 L .45558 .48411 L F
.43894 .35822 m .43511 .30107 L .39886 .30413 L .71 0 0 r
F
.43894 .35822 m .45631 .35682 L .43511 .30107 L F
0 g
.42227 .3605 m
.43894 .35822 L
s
.50931 .35809 m .50946 .48527 L .52656 .48729 L .864 0 0 r
F
.50931 .35809 m .5808 .3087 L .54587 .30386 L .71 0 0 r
F
.49184 .35675 m .50946 .48527 L .50931 .35809 L .84 0 0 r
F
0 0 0 r
.49671 .35713 m
.49673 .32255 L
s
.49184 .35675 m .50931 .35809 L .54587 .30386 L .71 0 0 r
F
0 g
.50931 .35809 m
.52613 .36032 L
s
.36642 .50267 m .27345 .46329 L .37756 .49798 L .688 0 0 r
F
.36642 .50267 m .25149 .47325 L .27345 .46329 L F
0 g
.35729 .50781 m
.36642 .50267 L
s
.45631 .35682 m .47363 .48366 L .47406 .35632 L .791 0 0 r
F
0 0 0 r
.47355 .35634 m
.47368 .3172 L
s
.45631 .35682 m .45558 .48411 L .47363 .48366 L .791 0 0 r
F
0 0 0 r
.47281 .56796 m
.4731 .48367 L
s
.45631 .35682 m .47223 .29999 L .43511 .30107 L .71 0 0 r
F
.45631 .35682 m .47406 .35632 L .47223 .29999 L F
0 g
.43894 .35822 m
.45631 .35682 L
s
.49184 .35675 m .49171 .48405 L .50946 .48527 L .84 0 0 r
F
0 0 0 r
.49662 .57238 m
.49666 .48439 L
s
.49184 .35675 m .54587 .30386 L .50942 .30093 L .71 0 0 r
F
.47406 .35632 m .49171 .48405 L .49184 .35675 L .815 0 0 r
F
.47406 .35632 m .49184 .35675 L .50942 .30093 L .71 0 0 r
F
0 g
.49184 .35675 m
.50931 .35809 L
s
.23833 .35674 m .25149 .47325 L .23395 .48404 L .431 0 0 r
F
.23833 .35674 m .25562 .34489 L .25149 .47325 L F
0 g
.25513 .36036 m
.35959 .38286 L
s
.23395 .48404 m
.23833 .35674 L
s
.47406 .35632 m .47363 .48366 L .49171 .48405 L .815 0 0 r
F
.47406 .35632 m .50942 .30093 L .47223 .29999 L .71 0 0 r
F
0 g
.45631 .35682 m
.47406 .35632 L
s
.47406 .35632 m
.49184 .35675 L
s
.37756 .49798 m .29948 .4544 L .39052 .49382 L .688 0 0 r
F
.37756 .49798 m .27345 .46329 L .29948 .4544 L F
0 g
.36642 .50267 m
.37756 .49798 L
s
.75878 .35113 m .78835 .48735 L .76314 .47893 L .957 0 0 r
F
.73043 .34324 m .75878 .35113 L .76314 .47893 L .923 0 0 r
F
0 g
.75878 .35113 m
.78362 .36038 L
s
.78835 .48735 m
.80955 .49681 L
s
.39052 .49382 m .32915 .44679 L .40508 .49029 L .688 0 0 r
F
.39052 .49382 m .29948 .4544 L .32915 .44679 L F
0 g
.37756 .49798 m
.39052 .49382 L
s
.25562 .34489 m .27345 .46329 L .25149 .47325 L .531 0 0 r
F
.25562 .34489 m .27725 .33396 L .27345 .46329 L F
0 g
.23833 .35674 m
.25562 .34489 L
s
.40508 .49029 m .36191 .44064 L .42098 .48746 L .688 0 0 r
F
.40508 .49029 m .32915 .44679 L .36191 .44064 L F
0 g
.39052 .49382 m
.40508 .49029 L
s
.23395 .48404 m
.35729 .50781 L
s
.61347 .31534 m .73043 .34324 L .73433 .47175 L p .908 0 0 r
F P
0 g
s
.65609 .38922 m
.66588 .38316 L
s
.73043 .34324 m .76314 .47893 L .73433 .47175 L .923 0 0 r
F
0 g
.73043 .34324 m
.75878 .35113 L
s
.54267 .49008 m .61543 .44632 L .73433 .47175 L p .688 0 0 r
F P
0 g
s
.52656 .48729 m .61543 .44632 L .54267 .49008 L .688 0 0 r
F
0 g
.54197 .36338 m
.54262 .47989 L
s
.42098 .48746 m .39709 .43611 L .43792 .48538 L .688 0 0 r
F
.42098 .48746 m .36191 .44064 L .39709 .43611 L F
0 g
.40508 .49029 m
.42098 .48746 L
s
.76314 .47893 m
.78835 .48735 L
s
.52656 .48729 m .5822 .44028 L .61543 .44632 L .688 0 0 r
F
.50946 .48527 m .5822 .44028 L .52656 .48729 L F
0 g
.52656 .48729 m
.54267 .49008 L
s
.43792 .48538 m .43397 .43332 L .45558 .48411 L .688 0 0 r
F
.43792 .48538 m .39709 .43611 L .43397 .43332 L F
0 g
.42098 .48746 m
.43792 .48538 L
s
.50946 .48527 m .54667 .43587 L .5822 .44028 L .688 0 0 r
F
.49171 .48405 m .54667 .43587 L .50946 .48527 L F
0 g
.50946 .48527 m
.52656 .48729 L
s
.45558 .48411 m .47174 .43234 L .47363 .48366 L .688 0 0 r
F
.45558 .48411 m .43397 .43332 L .47174 .43234 L F
0 g
.43792 .48538 m
.45558 .48411 L
s
.49171 .48405 m .50958 .43319 L .54667 .43587 L .688 0 0 r
F
.47363 .48366 m .50958 .43319 L .49171 .48405 L F
0 g
.49171 .48405 m
.50946 .48527 L
s
.23395 .48404 m
.25149 .47325 L
s
.47363 .48366 m .47174 .43234 L .50958 .43319 L .688 0 0 r
F
0 g
.45558 .48411 m
.47363 .48366 L
s
.47363 .48366 m
.49171 .48405 L
s
.27725 .33396 m .29948 .4544 L .27345 .46329 L .601 0 0 r
F
.27725 .33396 m .30287 .3242 L .29948 .4544 L F
0 g
.25562 .34489 m
.27725 .33396 L
s
.30287 .3242 m .32915 .44679 L .29948 .4544 L .654 0 0 r
F
.30287 .3242 m .33206 .31585 L .32915 .44679 L F
0 g
.27725 .33396 m
.30287 .3242 L
s
.25149 .47325 m
.27345 .46329 L
s
.73433 .47175 m .61543 .44632 L .61347 .31534 L p .908 0 0 r
F P
0 g
s
.73433 .47175 m
.76314 .47893 L
s
.73043 .34324 m
.73433 .47175 L
s
.65864 .51359 m
.73433 .47175 L
s
.33206 .31585 m .36191 .44064 L .32915 .44679 L .696 0 0 r
F
.33206 .31585 m .36427 .3091 L .36191 .44064 L F
0 g
.30287 .3242 m
.33206 .31585 L
s
.5808 .3087 m .61347 .31534 L .61543 .44632 L .894 0 0 r
F
0 g
.54197 .36338 m
.58695 .33315 L
s
.27345 .46329 m
.29948 .4544 L
s
.36427 .3091 m .39709 .43611 L .36191 .44064 L .731 0 0 r
F
.36427 .3091 m .39886 .30413 L .39709 .43611 L F
0 g
.33206 .31585 m
.36427 .3091 L
s
.5808 .3087 m .61543 .44632 L .5822 .44028 L .894 0 0 r
F
0 g
.54267 .49008 m
.61543 .44632 L
s
.61347 .31534 m
.61543 .44632 L
s
.54587 .30386 m .5808 .3087 L .5822 .44028 L .867 0 0 r
F
0 g
.5808 .3087 m
.61347 .31534 L
s
.39886 .30413 m .43397 .43332 L .39709 .43611 L .762 0 0 r
F
.39886 .30413 m .43511 .30107 L .43397 .43332 L F
0 g
.36427 .3091 m
.39886 .30413 L
s
.54587 .30386 m .5822 .44028 L .54667 .43587 L .867 0 0 r
F
.50942 .30093 m .54587 .30386 L .54667 .43587 L .841 0 0 r
F
0 g
.54587 .30386 m
.5808 .3087 L
s
.29948 .4544 m
.32915 .44679 L
s
.43511 .30107 m .47174 .43234 L .43397 .43332 L .79 0 0 r
F
.43511 .30107 m .47223 .29999 L .47174 .43234 L F
0 g
.39886 .30413 m
.43511 .30107 L
s
.50942 .30093 m .54667 .43587 L .50958 .43319 L .841 0 0 r
F
.47223 .29999 m .50942 .30093 L .50958 .43319 L .816 0 0 r
F
0 g
.50942 .30093 m
.54587 .30386 L
s
.47223 .29999 m .50958 .43319 L .47174 .43234 L .816 0 0 r
F
0 g
.43511 .30107 m
.47223 .29999 L
s
.47223 .29999 m
.50942 .30093 L
s
.32915 .44679 m
.36191 .44064 L
s
.5822 .44028 m
.61543 .44632 L
s
.36191 .44064 m
.39709 .43611 L
s
.54667 .43587 m
.5822 .44028 L
s
.39709 .43611 m
.43397 .43332 L
s
.50958 .43319 m
.54667 .43587 L
s
.43397 .43332 m
.47174 .43234 L
s
.47174 .43234 m
.50958 .43319 L
s
[ .01 .01 ] 0 setdash
.35623 .17131 m
.96875 .32662 L
s
.96875 .32662 m
.98487 .58711 L
s
.98487 .58711 m
.35065 .45949 L
s
.35065 .45949 m
.35623 .17131 L
s
.06722 .42225 m
.05351 .66515 L
s
.05351 .66515 m
.35065 .45949 L
s
.35065 .45949 m
.35623 .17131 L
s
.35623 .17131 m
.06722 .42225 L
s
.003 w
[ ] 0 setdash
.96875 .32662 m
.98487 .58711 L
s
.25 Mabswid
.96912 .33262 m
.96306 .33109 L
s
gsave
.98124 .33568 -61 -9.23351 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.97287 .39315 m
.96679 .39169 L
s
gsave
.98502 .39607 -61 -9.31844 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.97667 .45466 m
.97058 .45327 L
s
gsave
.98886 .45744 -61 -9.40487 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.98054 .51717 m
.97443 .51585 L
s
gsave
.99276 .5198 -61 -9.49284 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2.5) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.98447 .5807 m
.97834 .57946 L
s
gsave
.99672 .58318 -61 -9.58239 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.96986 .34465 m
.96623 .34374 L
s
.97061 .35672 m
.96697 .35582 L
s
.97136 .36882 m
.96772 .36793 L
s
.97211 .38097 m
.96847 .38009 L
s
.97362 .40538 m
.96997 .40451 L
s
.97438 .41764 m
.97073 .41678 L
s
.97514 .42994 m
.97149 .42909 L
s
.97591 .44228 m
.97225 .44144 L
s
.97744 .46708 m
.97378 .46626 L
s
.97821 .47954 m
.97455 .47873 L
s
.97898 .49205 m
.97532 .49124 L
s
.97976 .50459 m
.9761 .50379 L
s
.98132 .52979 m
.97765 .52901 L
s
.9821 .54246 m
.97843 .54169 L
s
.98289 .55516 m
.97922 .5544 L
s
.98368 .56791 m
.98001 .56716 L
s
gsave
1.0498 .47133 -61 -9.40487 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Z) show
73.312500 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{356, 356},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005T0001I1000`40O003h00OogooIGoo003oOomU
Ool00?moofEoo`00ogooIGoo003oOomUOol00?moofEoo`00ogooIGoo003oOomUOol00?moofEoo`00
ogooIGoo003oOomUOol00?moofEoo`00ogooIGoo003oOomUOol00?moofEoo`00ogooIGoo003oOomU
Ool00?moofEoo`00ogooIGoo003oOomUOol00?moofEoo`00ogooIGoo003oOomUOol00?moofEoo`00
ogooIGoo003oOomUOol00?moofEoo`00ogooIGoo003oOomUOol00?moofEoo`00ogooIGoo003oOomU
Ool00?moofEoo`00ogooIGoo003oOomUOol00?moofEoo`00ogooIGoo003oOomUOol00?moofEoo`00
ogooIGoo003oOomUOol00?moofEoo`00ogooIGoo003oOomUOol00?moofEoo`00ogooIGoo003oOomU
Ool00?moofEoo`00ogooIGoo003oOomUOol00?moofEoo`00ogooIGoo003oOomUOol00?moofEoo`00
ogooIGoo003oOomUOol00?moofEoo`00ogooIGoo003oOomUOol00?moofEoo`00ogooIGoo003oOomU
Ool00?moofEoo`00ogooIGoo003oOomUOol008moo`@004Eoo`<008Uoo`00Sgoo00D007ooOomoo`00
04Eoo`03001oogoo08Qoo`00T7oo00<007ooOol0AWoo00<007ooOol0R7oo0027Ool70003Ool00`00
Oomoo`15Ool00`00Oomoo`28Ool0099oo`03001oogoo04=oo`03001oo`0008Uoo`00TWoo00<007oo
Ool0@goo00<007oo0000RGoo001cOol3000IOol01000Oomoo`00A7oo00D007ooOomoo`0008Qoo`00
Lgoo00<007ooOol010005Woo0P00A7oo0`0000Aoo`00000008Moo`00LWoo0P0017oo1P00iWoo001a
Ool00`00Ool00004Ool01000Oomoogoo1P00hWoo0020Ool6003NOol006ioo`03001oogoo01Eoo`<0
0=]oo`00KGoo00<007ooOol00goo00<007ooOol04goo1000egoo001/Ool00`00Oomoo`04Ool00`00
Oomoo`0FOol5003COol007=oo`03001oogoo01Moo`04001oo`00Ool5003>Ool006Uoo`03001oogoo
00Moo`03001oogoo01Moo`03001oogoo00Eoo`@00<]oo`00J7oo00<007ooOol027oo00<007ooOol0
8goo1000agoo001WOol00`00Oomoo`0bOol50033Ool009moo`H00;moo`00I7oo00<007ooOol037oo
00<007ooOol0;7oo00<007ooOol01000^goo001SOol00`00Oomoo`0=Ool00`00Oomoo`0bOol5000]
Ool30027Ool0069oo`03001oogoo00ioo`03001oogoo03Ioo`@002Uoo`05001oogooOol00026Ool0
07=oo`03001oogoo03Uoo`H002Aoo`05001oogooOol00026Ool005moo`03001oogoo059oo`@0025o
o`05001oogooOol00026Ool005moo`03001oogoo05Aoo`03001oo`0000<001eoo`05001oogooOol0
0026Ool005ioo`03001oogoo019oo`03001oogoo04Eoo`D001Uoo`05001oogooOol00026Ool005eo
o`03001oogoo01=oo`03001oogoo04Uoo`D001Eoo`05001oogooOol00026Ool007=oo`03001oogoo
04ioo`@0019oo`<008Moo`00FWoo0P005goo00<007ooOol0DWoo1000V7oo001IOol00`00Oomoo`1]
Ool00`00Ool00004002DOol005Qoo`03001oogoo07Eoo`@0091oo`00e7oo1000S7oo001EOol2000L
Ool00`00Oomoo`1ROol30029Ool005Aoo`03001oogoo01aoo`03001oogoo06Eoo`H008=oo`00Dgoo
00<007ooOol07Goo00<007ooOol0IWoo00<007ooOol01000PGoo001cOol00`00Oomoo`1VOol00`00
Oomoo`04Ool4001mOol0051oo`8009Eoo`@007Uoo`00Cgoo00<007ooOol0VGoo1000MGoo001>Ool0
0`00Oomoo`0QOol00`00Oomoo`1jOol5000]Ool4000oOol0079oo`03001oogoo07Yoo`04001oogoo
Ool4000ZOol01@00Oomoogoo0000?Woo001<Ool00`00Oomoo`0SOol00`00Oomoo`22Ool4000WOol0
0`00Oomoo`0oOol004]oo`03001oogoo02Aoo`03001oogoo08Eoo`H002=oo`03001oogoo03ioo`00
BWoo00<007ooOol0/Woo0`008Woo00<007ooOol0?Goo0019Ool00`00Oomoo`2eOol6000MOol00`00
Oomoo`0mOol00?moo`9oo`03001oogoo009oo`@001Moo`04001oogoo000oOol004Moo`03001oogoo
02Qoo`03001oogoo09Eoo`@001Aoo`80041oo`00AWoo00<007ooOol0:Goo00<007ooOol0VGoo1@00
DGoo0015Ool00`00Oomoo`0ZOol00`00Oomoo`2MOol4001>Ool0079oo`03001oogoo019oobD006Mo
o`03001oogoo00@004Yoo`00@Woo00<007ooOol0>Goo2@001V0036@04fP02@00IGoo1P00A7oo0011
Ool00`00Oomoo`0eOol50003G00<H00<I00HJ004K005001TOol40012Ool0041oo`03001oogoo02mo
o`L000QL00aP00aT01QX00U/00H0069oo`@003ioo`00KWoo1@000eP02e`0360036@066P02f`01700
1@00H7oo1000>goo000mOol00`00Oomoo`0ZOol40004F0001000F01H05P02e`0360036@066P02f`0
2G001@00Fgoo00@007ooOomoo`D003Ioo`00?7oo00<007ooOol0:7oo0`0000=@05P0F0001EP000@0
05P0F01H00]L00aP00aT01QX00]/00]`0003001d07@000@005moo`H0035oo`00>goo00<007ooOol0
9Woo0`0015002eP02e`0360036@066P02f`02g0000<007@0M00017@01@00GWoo1000;goo001QOol3
0007D00;F00;G00<H00<I00HJ00;K00;L0000`00M01d0009M004001NOol4000[Ool003Qoo`03001o
ogoo02=oo`<00003C01@050000M@00]H00]L00aP00aT01QX00]/00]`0003001d07@000ed00@005]o
o`03001oo`00008002Uoo`00>7oo00<007ooOol087oo0`0014`02E001eP000@005P0F01H00]L00aP
00aT01QX00]/00]`0003001d07@0015d00@005Qoo`@002Uoo`00=goo00<007ooOol07Woo0`001d`0
2E001eP000@005P0F01H00]L00aP00aT01QX00]/009`0003001`070000I`0003001d07@001Ed00@0
05=oo`05001oogooOol00007Ool3000OOol003Ioo`03001oogoo01eoo`800003@01<04`000M<00U@
00MH0004001H05P0F00;G00<H00<I00HJ00;K00;L0000`00M01d000IM005001BOol00`00Oomoo`06
Ool00`00Oomoo`0NOol005Eoo`0400100400@009C009D007F0001000F01H05P02e`0360036@066P0
2f`02g0000<007@0M0007W@01000AWoo0P001Woo00<007ooOol01Woo00<007ooOol07Woo000cOol0
0`00Oomoo`0MOol20004@009C009D00;F00;G00<H00<I00HJ00;K00;L0000`00M01d000RM0040010
Ool20007Ool20008Ool00`00Oomoo`0NOol0039oo`03001oogoo01aoo`8000I000U<00U@00]H00]L
00aP00aT01QX00]/00]`0003001d07@002=d0003001d07@000<004Moo`03001oogoo00Ioo`03001o
ogoo01ioo`00<Goo00<007ooOol077oo00<003@0@0001T002D`02E001eP000@005P0F01H00]L00aP
00aT01QX00]/00]`0003001d07@002=d0003001d07@000=d00<003Ioo`8000aoo`03001oogoo00Io
o`03001oogoo01ioo`00Cgoo00<003@0=0001d002D`02E001eP000@005P0F01H00]L00aP00aT01QX
00]/00]`0003001d07@002=d0003001d07@000Id0080039oo`8000ioo`03001oogoo00Ioo`03001o
ogoo01ioo`00;Woo00<007ooOol07Goo00@003@0=00d00M000U<00U@00MH0004001H05P0F00;G00<
H00<I00HJ00;K00;L0000`00M01d000SM0000`00M01d0006M002N003000nOol30006Ool2000POol0
02eoo`03001oogoo01aoo`8000@d00M000U<00U@00MH0004001H05P0F00;G00<H00<I00HJ00;K00;
L0000`00M01d000SM0000`00M01d0006M005N003000YOol2000AOol2000XOol002aoo`03001oogoo
01aoo`03000/000000@d00M000U<00U@00]H00]L00aP00aT01QX00]/00]`0003001d07@002=d0003
001d07@000Id00Qh008002Ioo`03001oogoo019oo`03001oogoo02Ioo`00BWoo00@002`0;00000@d
00M000U<00U@00]H00]L00aP00aT01QX00]/00]`0003001d07@002=d0003001d07@000Id00Qh009l
00<0029oo`03001oogoo01=oo`03001oogoo02Ioo`00:Goo0P007Goo0P000b`000<003@0=0000S@0
1d002D`02E002eP02e`0360036@066P02f`02g0000<007@0M0008g@000<007@0M0001W@027P01G`0
0P0077oo0P005goo0P00:7oo000XOol00`00Oomoo`0LOol00`00;00/0003;0000`00=00d0002=007
@009C009D007F0001000F01H05P02e`02f003F@066P02f`02g0000<007@0M0008g@000<007@0M000
1W@027P01g`00P006Goo00<007ooOol067oo00<007ooOol09Woo000WOol00`00Oomoo`0LOol00`00
;00/0004;0000`00=00d0002=007@009C009D007F0001000F01H05P02U`036003F@066P02f`02g00
00<007@0M0008g@000<007@0M0001W@027P02G`000<007ooOol05Goo00<007ooOol06Goo00<007oo
Ool09Woo0015Ool00`00;00/0005;0000`00=00d0002=007@009C009D007F0001000F01H05P02U`0
36003F@066P02f`02g0000<007@0M0008g@000<007@0M0001W@027P02W`000<007ooOol047oo0P00
7Woo00<007ooOol09Woo000UOol00`00Oomoo`0KOol20008;0000`00=00d0002=007@009C009D007
F0000`00F01H000;G00<H00=I00HJ00;K00;L0000`00M01d000SM0000`00M01d0006M008N00;O000
0`00Oomoo`0>Ool00`00Oomoo`0MOol2000XOol002Aoo`03001oogoo01]oo`03000/02`000P/0003
000d03@0008d00M000U<00U@00YH00]L00aP00eT01QX00]/00]`0003001d07@000ed008001Ad0003
001d07@000Id00Qh00al0003001oogoo00aoo`03001oogoo01moo`03001oogoo02Ioo`008goo00<0
07ooOol06goo00<002`0;0002B`000<003@0=0000S@01d002D`025002eP02e`036003F@066P02f`0
2g0000<007@0M0008g@000<007@0M0001W@027P03G`000<007ooOol027oo0P008goo00<007ooOol0
9Woo000ROol00`00Oomoo`0JOol2000<;0000`00=00d0002=007@009C008D008F0000`00F01H000;
G00<H00=I00HJ00;K00;L0000`00M01d000SM0000`00M01d0006M008N00>O0000`00Oomoo`06Ool0
0`00Oomoo`0SOol00`00Oomoo`0VOol003ioo`03000/02`000//0003000d03@000<d00M000U<00Q@
00QH0003001H05P000]L00aP00eT01QX00]/00]`0003001d07@002=d0003001d07@000Id00Qh00ml
0003001oogoo00Aoo`03001oogoo029oo`<002Qoo`007goo0P0077oo00<002`0;00032`000<003@0
=0000c@01d0024`02E0025P000<005P0F0002e`036003F@066P02f`02g0000<007@0M0008g@000<0
07@0M0001W@027P047`000<007ooOol0:Woo00<007ooOol01Goo0`000Woo00<007oo00000`005Woo
000NOol00`00Oomoo`0KOol00`00;00/000=;0000`00=00d0003=007@008C009D008F0000`00F01H
000;G00<H00=I00HJ00;K00;L0000`00M01d000SM0000`00M01d0006M008N00@O0001000Ool00000
:Goo00<007ooOol01Woo00<007ooOol01goo00<007ooOol04goo000MOol00`00Oomoo`0KOol00`00
;00/000>;0000`00=00d0003=007@008C009D00;F00;G00<H00=I00HJ00;K00;L0000`00M01d000S
M0000`00M01d0006M008N00AO0000`00Oomoo`0YOol00`00Oomoo`06Ool00`00Oomoo`07Ool00`00
Oomoo`0COol003Yoo`80010/0003000d03@000<d00I000U<00U@00]H00]L00aP00eT01QX00]/00]`
0003001d07@002=d0003001d07@000Id00Qh015l0003001oogoo02Qoo`8000Qoo`03001oogoo00Mo
o`03001oogoo01=oo`006Woo0P007Goo00<00200000042`000<003@0=0000c@01T002D`02E002eP0
2e`036003F@066P02f`02g0000<007@0M0008g@000<007@0M0001W@027P04W`000<007ooOol0:7oo
0P001goo00<007ooOol01goo00<007ooOol04goo000IOol00`00Oomoo`0LOol01000800P000042`0
00<003@0=0000c@01T002D`02E0025P000<005P0F0002e`036003F@066P02f`02g0000<007@0M000
97@000<007@0M0001G@027P04W`000<007ooOol0:7oo0P001goo00<007ooOol00goo10005Woo000H
Ool00`00Oomoo`0LOol01@00800P0200000042`000<003@0=0000S@01d002D`02E0025P000<005P0
F0002e`036003F@066P02f`02g0000<007@0M00097@000<007@0M0001G@027P04W`000<007ooOol0
:Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol05Woo000gOol01@00800P0200000042`0
00<003@0=0000S@01d002D`02E0025P000<005P0F0002e`036003F@066P02f`02g0000<007@0M000
97@000<007@0M0001W@01gP04g`000<007ooOol09goo0P001Woo0P001Woo10005Goo000FOol00`00
Oomoo`0MOol00`00800P000280000`00;00/000>;0000`00=00d0002=007@009C009D008F0000`00
F01H000;G00<H00=I00HJ00;K00;L0000`00M01d000TM0000`00M01d0006M007N00CO0000`00Oomo
o`0XOol00`00Oomoo`0UOol001Eoo`D001aoo`03000P0200008P0003000/02`000h/0003000d03@0
008d00M000U<00U@00]H00]L00aP00eT01QX00]/00]`0003001d07@002Ad0003001d07@000Id00Mh
01=l02]oo`03001oogoo02Eoo`005Goo00<007ooOol017oo0`005Woo00<000`080000b0000<002`0
;0003R`000<003@0=0000S@01d002D`02E002eP02e`036003F@066P02f`02g0000<007@0M00097@0
00<007@0M0001W@027P04W`0:goo00<007ooOol09Goo000EOol00`00Oomoo`07Ool00`00Oomoo`03
000@Ool00`00300P000380000`00;00/000>;0000`00=00d0002=007@009C009D007F0001000F01H
05P02e`036003F@066P02f`02g0000<007@0M00097@000<007@0M0001W@027P04W`0:Woo0P009goo
000EOol00`00Oomoo`0=Ool00`00Oomoo`0=Ool00`00300P000380000`00;00/000>;0000`00=00d
0002=007@009C009D007F0001000F01H05P02e`01V009P001FP02f`02g0000<007@0M00097@000<0
07@0M0001W@027P04W`000<007ooOol0:7oo00<007ooOol09Goo000YOol40007Ool00`00300<0003
80000`00;00/000?;0000`00=00d0002=007@009C009D007F0001000F01H05P025`02@009UP02@00
1f`02g0000<007@0M00097@000<007@0M0001W@027P04W`000<007ooOol0:7oo00<007ooOol09Goo
000_Ool4000017oo000<00`00b0000<002`0;0003b`000<003@0=0000S@01d002D`02E001eP000@0
05P0F01H00=L00D003QH00D0009/00]`0003001d07@002Ad0003001d07@000Id00Qh019l02]oo`03
001oogoo02Eoo`005Goo00<007ooOol077oo0``00b0000<002`0;0003b`000<003@0=0000S@01d00
2D`02E0025P01P00@UP01P001g0000<007@0M00097@000<007@0M0001W@027P04W`0:Woo0P009goo
000EOol00`00Oomoo`0LOol3300380000`00;00/000?;0000`00=00d0002=007@009C009D003F005
001>F0050002L0000`00M01d000TM0000`00M01d0006M008N00BO00[Ool00`00Oomoo`0UOol001Eo
o`03001oogoo01aoo`<<00<P0003000/02`000l/0003000d03@0008d00M000U<00M@00D005QH00D0
02Ad0003001d07@000Id00Qh019l02]oo`03001oogoo02Eoo`005Goo00<007ooOol077oo0P`01200
00<002`0;0003b`000<003@0=0000S@01d002D`00U001@002EP000<005P0F000DEP000<005P0F000
0UP01@007g@000<007@0M0001W@027P04W`0:goo00<007ooOol09Goo000EOol00`00Oomoo`0LOol2
300480000`00;00/000?;0000`00=00d0002=007@008C003000>F0000`00F01H001?F002000:F005
000JM0000`00M01d0006M008N00CO00XOol3000WOol003Aoo`8<00@P0003000/02`000h/0003000d
03@000<d00M000E<00<0015H0003001H05P004eH0080015H00D001Ed0003001d07@000Id00Qh01=l
02Yoo`03001oogoo00=oo`@001ioo`00=7oo0P`0120000<002`0;0003R`000<003@0=0000c@01d00
0T`00`0055P00`00C5P000<005P0F0005UP01@0047@000<007@0M0001W@027P04g`0:goo00<007oo
Ool00Woo00D007ooOomoo`0001eoo`005Goo00<007ooOol077oo0P`0120000<002`0;0003R`000<0
03@0=0000c@01T000`007EP00`00A5P00P007UP01@002g@000<007@0M0001W@027P04g`0:goo00<0
07ooOol00goo00<007ooOol07Woo000EOol00`00Oomoo`0LOol2300480000`00;00/000>;0000`00
=00d0003=003@003000GF0000`00F01H0009F0000`00F01H0003000lF002000UF0050006M0000`00
M01d0006M008N00CO00ZOol20006Ool00`00Oomoo`0MOol001Aoo`03001oogoo01eoo`8<00@P0003
000/02`000h/0003000d03@000<d0003@000000001UH0003001H05P0011H0003001H05P003QH0003
001H05P002YH00D00003M00007@000Md00Qh01=l02]oo`03001oogoo00Eoo`03001oogoo00ioo`H0
00Qoo`0057oo00<007ooOol07Goo0P`0120000<002`0;0003R`000<003@0=0000S@00P006UP000<0
05P0F00055P01@00<EP00P00<UP010001W@027P04g`0:goo00<007ooOol01Goo00<007ooOol03goo
00D007ooOomoo`0000Qoo`00<goo0``0120000<002`0;0003R`000D003@0=00d000003YH00@002UH
0080039H008000AH00D00003M01h07P000Ih01=l02]oo`03001oogoo009oo`04001oogoo000AOol0
0`00Oomoo`0:Ool003=oo`<<00@P0003000/02`000h/0004000d0000000IF002000VF003000SF000
0`00F01H000`F002000;F0030006N00CO00ZOol20005Ool2000COol00`00Oomoo`09Ool001Aoo`03
001oogoo01aoo`<<00@P0003000/02`000h/008001YH0003001H05P002UH0003001H05P000<001]H
0080035H0080011H00<000=h01=l02]oo`03001oogoo01Uoo`03001oogoo00Qoo`0057oo00<007oo
Ool077oo0``0120000<002`0;0003B`01@005eP000<005P0F0008UP07P002EP00P00<EP00P005EP0
0`004g`0:goo00<007ooOol06Woo00<007ooOol01goo000DOol00`00Oomoo`0LOol3300480000`00
;00/000<;0000`00F01H0003F005000?F002000QF00500020;D01@000;D0]@2e00001`5g00@0005g
0GL1M`D000H1M`H000=H0003001H05P002mH008001YH0080015l02]oo`03001oogoo01Ioo`05001o
ogooOol00009Ool001Aoo`03001oogoo01aoo`<<00@P0003000/02`000//0003001H05P000UH00D0
00UH0003001H05P001aH00D000<0]@050000]@2e0;D000030;D00`000GL1M`050GL00`000GL1M`05
0GL00`000GL0000200020GL00`000GL1M`030GL3000`F002000NF003000>O00ZOol2000HOol60008
Ool003=oo`<<00@P0003000/02`000T/0080015H00D000=H0003001H05P001QH00D000@0]@050000
]@2e0;D000030;D01@000;D0]@2e00001`5g00<0005g0GL01@5g00<0005g0GL00P5g00@0005g0001
M`<000<1M`040001M`5g0GL5000WF0000`00F01H000QF002000<O00[Ool00`00Oomoo`0TOol003=o
o`<<00<P0003000/02`000T/0003001H05P001IH00D001IH00<000050;D0002e0;D000040;D01@00
0;D0]@2e00000`2e00@0002e0;D0]@8000H1M`030001M`5g00D1M`030001M`5g00@1M`030001M`5g
0081M`030001M`5g00<000@1M`030001M`0000@0021H008002IH008000Yl02]oo`03001oogoo02Ao
o`00<goo0``00b0000<002`0;0001b`00P006EP000<005P0F0000UP01@003eP00`000`2e00@0002e
0;D000@0]@050000]@2e0;D000030;D00`000;D0]@0500040GL00`000GL1M`050GL00`000GL1M`04
0GL00`000GL1M`050GL010000GL1M`000`5g00<0005g0GL0105g1P0065P00P00:UP00P0027`0:goo
00<007ooOol097oo000DOol00`00Oomoo`0LOol3300380000`00;00/0006;0000`00F01H000HF000
0`00F01H0008F0050008F00200020;D01@000;D0]@2e00000P2e00<0002e0;D00P2e00D0002e0;D0
]@0000<0]@<000030;D0005g0081M`D000L1M`030001M`5g00@1M`030001M`5g00D1M`030001M`5g
00<1M`@000@1M`030001M`5g00<1M`D0015H008002iH008000Il02Yoo`8002Ioo`0057oo00<007oo
Ool077oo0``00b0000<002`0;0001B`000<005P0F00065P000<005P0F0003UP01@000UP00P000`2e
00D0002e0;D0]@000080]@030000]@2e0080]@050000]@2e0;D000030;D01@000;D0]@2e00001`5g
1P000P5g00<0005g0GL0105g00<0005g0GL01@5g00<0005g0GL0105g00<0005g0GL00`5g0`001P5g
00<0005g0GL01@002UP00P00<UP000<007`0O0000g`0:goo00<007ooOol097oo000DOol00`00Oomo
o`0LOol3300380000`00;00/0003;002000aF00200000`2e0000]@020;D01@000;D0]@2e00000P2e
00<0002e0;D00P2e00H0002e0;D0]@000;D300030;D00`000GL1M`050GL00`000GL1M`030GL50004
0GL00`000GL1M`050GL00`000GL1M`040GL00`000GL1M`050GL200020GL400060GL60003F002000e
F0000`00O01l0002O00[Ool00`00Oomoo`0TOol001Aoo`03001oogoo01aoo`8<00@P0003000/02`0
008/0003001H05P001MH008001MH00050000]@2e0;D000030;D01@000;D0]@2e00000P2e00<0002e
0;D00P2e00@0002e0;D0]@800080]@050000]@2e0;D000070GL00`000GL1M`050GL00`000GL1M`05
00070GL00`000GL1M`040GL00`000GL1M`050GL00`000GL1M`040GL00`000GL1M`040GL00`000GL1
M`030GL6000eF0000`00O01l0002O00[Ool00`00Oomoo`0SOol003=oo`8<00@P0003000/02`00080
01UH0003001H05P001EH00<000<0]@050000]@2e0;D000030;D010000;D0]@00102e00<0002e0;D0
0P000`2e00D0002e0;D0]@0000L1M`030001M`5g00D1M`030001M`5g00@1M`L000030GL0005g00D1
M`030001M`5g00D1M`030001M`5g00@1M`030001M`5g00D000L1M`040001M`5g0GL3000cF0001000
O01l07`0:Goo0`009Goo000cOol2300480000`00;000000JF0000`00F01H000DF00200020;D01@00
0;D0]@2e00000`2e00D0002e0;D0]@000080]@030000]@2e0080]@<000030;D0002e0080]@050000
]@2e0;D000070GL00`000GL1M`050GL00`000GL1M`040GL00`000GL1M`040GL500030GL00`000GL1
M`050GL00`000GL1M`040GL00`000GL1M`040GL00`000GL1M`0300020GL00`000GL1M`030GL3000b
F0000`00O01l000[Ool00`00Oomoo`03Ool40003Ool00`00Ool00003000COol001=oo`03001oogoo
01eoo`8<00@P008001QH008001MH00030000]@000080]@050000]@2e0;D000030;D01@000;D0]@2e
00000P2e00<0002e0;D00P2e00D0002e0;D0]@0000<0]@050000]@2e0;D000070GL00`000GL1M`05
0GL00`000GL1M`040GL00`000GL1M`050GL010000GL1M`5g1@001P5g00<0005g0GL0105g00<0005g
0GL0105g00<0005g0GL00`5g00<0005g00000`000P5g0P0000A00000000002mH0003001l07`002]o
o`03001oogoo00=oo`05001oogooOol00008Ool00`00Oomoo`0@Ool001=oo`03001oogoo01eoo`8<
00@P00@001EH0003001H05P001EH00800080]@040000]@2e00030;D01@000;D0]@2e00000`2e00@0
002e0;D00080]@<000<0]@050000]@2e0;D000030;D00`000GL1M`050GL00`000GL1M`050GL00`00
0GL1M`040GL00`000GL1M`050GL00`000GL1M`040GL00`000GL0000400000`5g0001M`050GL00`00
0GL1M`040GL00`000GL1M`050GL01P000GL1M`5g0001M`@00090008002iH0003001l07oo02Yoo`03
001oogoo00Aoo`03001oogoo00Uoo`03001oogoo011oo`004goo00<007ooOol07Goo0P`00b0000<0
05P0F0000UP01@003eP000<005P0F0005EP00P000`2e00@0002e0;D000<0]@050000]@2e0;D00003
0;D01P000;D0]@000;D00080]@050000]@2e0;D000030;D01@000;D0]@2e00001`5g00<0005g0GL0
1@5g00<0005g0GL0105g00<0005g0GL01@5g00<0005g0GL0105g00<0005g0GL0105g1@000`5g00<0
005g0GL0105g00<0005g0GL01@5g00<0005g0GL00`5g0P000T000P0000=000000000;UP000<007oo
Ool0:7oo0P001goo00<007ooOol027oo00<007ooOol047oo000COol00`00Oomoo`0MOol230028000
0`00F01H0008F006000OF00200000gP00000]@020;D010000;D0]@000`2e00D0002e0;D0]@0000<0
]@030000]@2e008000<0]@050000]@2e0;D000030;D01@000;D0]@2e00001`5g00<0005g0GL01@5g
00<0005g0GL0105g00<0005g0GL01@5g00<0005g0GL0105g00<0005g0GL01@5g00@0005g0GL1M`D0
00D1M`030001M`5g00D1M`030001M`5g00<1M`8000E000D002]H0003001oogoo02Uoo`03001oogoo
00Ioo`03001oogoo00Moo`03001oogoo011oo`00<Woo0``000<P0000F00045P01`005eP000D007P0
N01h000000<0]@040000]@2e00030;D01@000;D0]@2e00000`2e00@0002e000000@0]@050000]@2e
0;D000030;D01@000;D0]@2e00001`5g00<0005g0GL01@5g00<0005g0GL0105g00<0005g0GL01@5g
00<0005g0GL0105g00<0005g0GL01@5g00<0005g0GL0105g00<0005g00001@001`5g00<0005g0GL0
0`5g0P001D0000@003P0:00000=H00<002IH0003001oogoo02Uoo`03001oogoo00Ioo`03001oogoo
00=oo`@001=oo`00<Woo0``000<005P0F0005EP01P004EP00P0000El07P0N01h000000<0]@040000
]@2e00030;D01@000;D0]@2e00000`2e0P0000<0]@000;D00`2e00D0002e0;D0]@0000<0]@050000
]@2e0;D000070GL00`000GL1M`050GL00`000GL1M`040GL00`000GL1M`050GL00`000GL1M`040GL0
0`000GL1M`050GL00`000GL1M`040GL00`000GL1M`040GL700000`5g0001M`040GL20005@0001000
>00X02P00P0015P000@005P0F01H00<0021H0003001oogoo02Qoo`03001oogoo00=oo`04001oogoo
0006Ool00`00Oomoo`0COol0039oo`<<0003001H05P001AH0003001H05P000AH00H000UH0080009l
00Ah00050000]@2e0;D000020;D01@000;D0]@2e00000`2e00<0002e0;D00P000P2e00<0002e0;D0
0P2e00D0002e0;D0]@0000<0]@050000]@2e0;D000070GL00`000GL1M`050GL00`000GL1M`040GL0
0`000GL1M`050GL00`000GL1M`040GL00`000GL1M`050GL00`000GL1M`040GL00`000GL1M`040GL0
0`000GL1M`040GL600000`5g00000005@0001000>00X02P00Q0000<005P0F00025P000<005P0F000
7EP000<007ooOol0:7oo00<007ooOol017oo0P001goo10004Woo000COol00`00Oomoo`0LOol23000
0`00F01H000RF0050003F0000`00O01l0002O004N0001@000;D0]@2e00000P2e00D0002e0;D0]@00
00<0]@@000<0]@030000]@2e0080]@050000]@2e0;D000030;D01@000;D0]@2e00001`5g00<0005g
0GL01@5g00<0005g0GL0105g00<0005g0GL01@5g00<0005g0GL0105g00<0005g0GL01@5g00<0005g
0GL0105g00<0005g0GL01@5g00<0005g0GL0105g00<0005g0GL00P5g0`001D0000@003P0:00X008@
0003001H05P000]H00@001UH0003001oogoo02Moo`8002Eoo`004goo00<007ooOol077oo00<<0000
F0004eP00P0055P00`001G`017P000D0002e0;D0]@000080]@050000]@2e0;D000020;D200020;D0
1@000;D0]@2e0000102e00D0002e0;D0]@0000<0]@050000]@2e0;D000070GL00`000GL1M`050GL0
0`000GL1M`040GL00`000GL1M`050GL00`000GL1M`040GL00`000GL1M`050GL00`000GL1M`040GL0
0`000GL1M`050GL00`000GL1M`040GL00`000GL1M`030GL20005@0001000>00X02P00Q0000<<0000
F0004EP010004eP000<007ooOol0:7oo00<007ooOol08goo000COol00`00Oomoo`0LOol00``0001H
000BF0000`00F01H000EF0000`00O01l0004O004N0001@000;D0]@2e00000P2e00H0002e0;D0]@00
0;D200030;D01@000;D0]@2e0000102e00D0002e0;D0]@0000<0]@050000]@2e0;D000070GL00`00
0GL1M`050GL00`000GL1M`040GL00`000GL1M`050GL00`000GL1M`040GL00`000GL1M`050GL00`00
0GL1M`040GL00`000GL1M`050GL00`000GL1M`040GL00`000GL1M`040GL00`00@0100003@0001000
>00X02P00Q0000<<0000F00065P00`003EP000<007ooOol0:7oo00<007ooOol08goo000COol00`00
Oomoo`0LOol00``0001H000AF0000`00F01H000EF0000`00O01l0005O004N0001@000;D0]@2e0000
0P2e00@0002e0;D0]@8000030;D0002e0080]@050000]@2e0;D000040;D01@000;D0]@2e00000`2e
00D0002e0;D0]@0000L1M`030001M`5g00D1M`030001M`5g00@1M`030001M`5g00D1M`030001M`5g
00@1M`030001M`5g00D1M`030001M`5g00@1M`030001M`5g00D1M`030001M`5g00@1M`030001M`5g
00@1M`030010040000=00004000h02P0:00240000``0001H000KF0000`00F01H00030007F0000`00
Oomoo`0XOol00`00Oomoo`0SOol0039oo`03001H05P002UH0003001l07`000El00Ah00050000]@2e
0;D000020;D00`000;D0]@0200020;D01@000;D0]@2e00000`2e00<0002e0;D00P2e00D0002e0;D0
]@0000<0]@050000]@2e0;D000070GL00`000GL1M`050GL00`000GL1M`040GL00`000GL1M`050GL0
0`000GL1M`040GL00`000GL1M`050GL00`000GL1M`040GL00`000GL1M`050GL00`000GL1M`040GL0
0`000GL1M`040GL00`00@0100003@0001000>00X02P00Q0000<<0000F0008EP000<005P0F00015P0
00<007ooOol09goo0P009Goo000bOol00`00F01H000>F002000HF0000`00O01l0006O004N0001@00
0;D0]@2e00000P2e0`0000D0]@000;D0]@0000<0]@050000]@2e0;D000040;D01@000;D0]@2e0000
0`2e00D0002e0;D0]@0000L1M`030001M`5g00D1M`030001M`5g00@1M`030001M`5g00D1M`030001
M`5g00@1M`030001M`5g00D1M`030001M`5g00@1M`030001M`5g00D1M`030001M`5g00@1M`030001
M`5g00@1M`030010040000=00004000h02P0:00240000`00F01H000TF005000ZOol00`00Oomoo`0S
Ool001=oo`03001oogoo01aoo`03001H05P000aH008001UH0003001l07`000Ml00Ah00050000]@2e
0;D000020;D01@000;D0]@2e00000P2e00D0002e0;D0]@0000<0]@030000]@2e0080]@050000]@2e
0;D000030;D01@000;D0]@2e00001`5g00<0005g0GL01@5g00<0005g0GL0105g00<0005g0GL01@5g
00<0005g0GL0105g00<0005g0GL01@5g00<0005g0GL0105g00<0005g0GL01@5g00<0005g0GL0105g
00<0005g0GL0105g00<00400@0000d0000H003P0:00X0100000YF0000`00Oomoo`02Ool3000UOol0
0`00Oomoo`0SOol001=oo`03001oogoo01eoo`03001H05P002IH0003001l07`000Ml00Ah00040000
]@2e0;D400030;D010000;D0]@000`2e00D0002e0;D0]@0000@0]@050000]@2e0;D000030;D00`00
0;D0]@0500040GL00`000GL1M`050GL00`000GL1M`040GL00`000GL1M`050GL00`000GL1M`040GL0
0`000GL1M`050GL00`000GL1M`040GL00`000GL1M`050GL00`000GL1M`040GL00`000GL1M`040GL0
0`00@0100003@0000`00>00X0002000ZF0000`00Oomoo`05Ool00`00Oomoo`03000POol00`00Oomo
o`0ROol001=oo`03001oogoo01eoo`03001H05P000QH0003001H05P001]H0003001l07`000Ml00Ah
00050000]@2e0;D000020;D01@000;D0]@2e00000P2e00D0002e0;D0]@0000<0]@030000]@2e0080
]@050000]@2e0;D000030;D300050Ml500070GL00`000GL1M`040GL00`000GL1M`050GL00`000GL1
M`040GL00`000GL1M`050GL00`000GL1M`040GL00`000GL1M`050GL00`000GL1M`040GL00`000GL1
M`040GL00`00@0100003@0000`00>000000[F0000`00Oomoo`0<Ool00`00Oomoo`0LOol2000TOol0
01=oo`03001oogoo01eoo`03001H05P000MH0003001H05P001aH0003001l07`000Ml00Ah00030000
]@0000800080]@050000]@2e0;D000020;D01@000;D0]@2e00000`2e00<0002e0;D00P2e00D0002e
0;D0]@0000<0]@@000D1g`800081g`D000030GL0000000H1M`030001M`5g00D1M`030001M`5g00@1
M`030001M`5g00D1M`030001M`5g00@1M`030001M`5g00D1M`030001M`5g00@1M`030001M`5g00@1
M`030010040000=0008002]H0003001oogoo011oo`D001Qoo`03001oogoo029oo`00=7oo00<005P0
F0001EP000<005P0F0007UP000<007`0O0001W`017P00P000P2e00@0002e0;D000<0]@040000]@2e
00030;D01@000;D0]@2e0000102e00H0002e0;D0]@000;D200040Ml500080Ml700030GL00`000GL1
M`050GL00`000GL1M`040GL00`000GL1M`050GL00`000GL1M`040GL00`000GL1M`050GL00`000GL1
M`040GL00`000GL1M`040GL00`00@0100002@005000WF002000JOol4000BOol00`00Oomoo`0ROol0
03Aoo`03001H05P002IH0003001l07`000Il00Ah00040000]@2e00030;D01@000;D0]@2e00000P2e
00D0002e0;D0]@0000<0]@030000]@2e0080]@040000]@2e0;D200080Ml200000`7O000000030002
0Ml00`000Ml1g`050Ml500060GL00`000GL1M`040GL00`000GL1M`050GL00`000GL1M`040GL00`00
0GL1M`050GL00`000GL1M`040GL00`000GL1M`040GL00`00@01000020005F005000PF002000ROol3
000=Ool00`00Oomoo`0ROol003Eoo`03001H05P0008002AH008000Il00=h00800080]@050000]@2e
0;D000030;D010000;D0]@000`2e00D0002e0;D0]@0000@0]@030000]@0000D000@1g`8000P1g`H0
00@1g`8000<1g`L000H1M`030001M`5g00D1M`030001M`5g00@1M`030001M`5g00D1M`030001M`5g
00@1M`030001M`5g00@1M`<000aH00H001UH0003001oogoo02Eoo`04001oogooOol30004Ool30005
Ool4000KOol0019oo`03001oogoo025oo`8002QH008000Al00=h00800080]@050000]@2e0;D00003
0;D010000;D0]@000`2e00D0002e0;D0]@0000@0]@8000H1g`H000H1g`8000H1g`D000L1g`P00081
M`8000H1M`030001M`5g00@1M`030001M`5g00D1M`030001M`5g00@1M`030001M`5g00@1M`03001H
05P0019H00D0019H008002moo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo01Qoo`004Woo
00<007ooOol08Goo0P00:UP000@007`0O01l00=h00800080]@050000]@2e0;D000030;D010000;D0
]@000`2e00D0002e0;D0]@0000<0]@D000D1g`030001g`7O0081g`H000T1g`800081g`L000P1g`D0
00D1M`030001M`5g00@1M`030001M`5g00D1M`030001M`5g00@1M`030001M`5g00@1M`03001H05P0
01MH00H000YH008003Aoo`@000Uoo`03001oogoo01Qoo`004Woo00<007ooOol08goo0P00:EP00`00
0gP00P000P2e00D0002e0;D0]@0000<0]@040000]@2e00030;D01P000;D0]@2e0000]@8000D1g`D0
00P1g`P00081g`8000P1g`H000@1g`8000@1g`H000H1M`030001M`5g00D1M`030001M`5g00@1M`03
0001M`5g00@1M`03001H05P001eH00D000=H008003Ioo`8000]oo`03001oogoo01Qoo`004Woo00<0
07ooOol07Woo0P001Goo00<005P0F000:EP01@000P2e00D0002e0;D0]@0000<0]@040000]@2e0003
0;D010000;D0]@2e10001P7O0P000P7O2000207O1P00107O0P001P7O1P001P7O0P000P7O20001P5g
00<0005g0GL0105g00<0005g0GL0105g00<005P0F0008UP00`00=Goo10002Goo0`006goo000aOol2
0008Ool00`00F01H000[F00200020;D01@000;D0]@2e00000`2e00@0002e0;D000<0]@040000]@2e
00040Ml600080Ml800020Ml200060Ml500070Ml200040Ml600070Ml700040GL00`000GL1M`040GL0
0`000GL1M`040GL00`00F01H000QF002000eOol3000>Ool00`00Oomoo`0IOol003aoo`8002]H0080
0080]@050000]@2e0;D000030;D010000;D0]@000`2e0`00207O00<0007O000010000`7O00<0007O
0Ml01P7O1@001@7O0P000`7O1`002@7O00<0007O0000100000<1g`0000001`7O1P001@5g00<0005g
0GL0105g00<005P0F0007eP00P00=Goo0`003Goo00D007ooOomoo`0001Yoo`004Woo00<007ooOol0
67oo0P003goo0P008eP000<h05P0F0000eP00P000P2e00D0002e0;D0]@0000<0]@040000]@2e0002
0;D500050Ml200070Ml600050Ml200040Ml600080Ml800020Ml200070Ml600050Ml200030Ml60006
0GL00`00F01H000MF002000eOol2000AOol3000KOol0019oo`03001oogoo01Moo`03001oogoo015o
o`8001aH009`00UH00800080]@050000]@2e0;D000030;D01P000;D0]@000;D000D1g`H000L1g`80
00D1g`D000L1g`8000<1g`P000P1g`D000@1g`8000H1g`D000L1g`8000030Ml0000000<00081M`03
001H05P001]H0080039oo`03001oo`0000<0031oo`004Woo00<007ooOol05Woo00<007ooOol057oo
0P005EP00g003EP000D0002e0;D0]@0000<0]@050000]@2e0;D000020;D400060Ml010000Ml1g`7O
1@0000<1g`000Ml01`7O0P000P7O1@0000<1g`000Ml0207O1`000`7O0P001@7O1P001`7O0P000P7O
1`00207O0`006eP00P00=7oo1000<Woo000BOol00`00Oomoo`0_Ool3000>F002M00BF0001@000;D0
]@2e00000`2e00@0002e0;D0]@<000@1g`H000P1g`L00081g`8000P1g`H000@1g`8000L1g`H000@1
g`8000@1g`L000L1g`L000<1g`<001]H008003Aoo`<003Eoo`00:7oo0P007Goo0P001eP000=d05P0
F0005UP000D0002e0;D0]@0000<0]@030000]@2e00D000D1g`8000030Ml0000000@000030Ml00000
00L1g`H000@1g`8000H1g`H000H1g`8000D1g`D000P1g`8000030Ml0000000<000030Ml0000000L1
g`H001UH008003Aoo`8003Qoo`009goo00<007ooOol07goo0`007EP000D0002e0;D0]@0000<0]@03
0000]@0000D1g`D000T1g`H000<1g`8000D1g`D000L1g`8000@1g`H000L1g`8000<1g`P000L1g`L0
00@1g`8000AH00D0019H008003=oo`<003Yoo`009Woo00<007ooOol08goo0`006EP00P000`2e00@0
002e0;D0]@8000P1g`030001g`7O00H000030Ml0000000H1g`D000D1g`8000<1g`L000T1g`L00081
g`030001g`7O00L1g`P000030Ml0000000L1g`@000]H00H000YH008003=oo`<003aoo`004Woo00<0
07ooOol0>Woo100055P000<005P000000`2e00<0002e00001@00107O0P00207O1P000`7O0P00107O
1P00207O20000P7O0P001`7O1P00107O0P001`7O1P001@7O0P004eP01@000eP00P00<Goo00<007oo
00000P00?Woo000BOol00`00Oomoo`0>Ool00`00Oomoo`0]Ool4000>F0020002F00010000;D0]@2e
0P001P7O1P001P7O0P001P7O1P001@7O0P000P7O2000207O1@00107O0P001P7O1@001P7O0P001P7O
1@006UP00`00<Woo0`00@Goo000AOol00`00Oomoo`0>Ool00`00Oomoo`0bOol40008F0020004F000
0`000;D0]@0500040Ml200040Ml600080Ml200040Ml500080Ml700030Ml200050Ml600060Ml20003
0Ml600090Ml2000KF002000cOol20013Ool0015oo`03001oogoo00eoo`03001oogoo03Moo`D0009H
0003001H05P000AH00<000D1g`H000L1g`8000030Ml0000000H000L1g`800081g`P000L1g`H000@1
g`8000@1g`H000L1g`8000030Ml0000000<00081g`<001]H0080039oo`<004Eoo`007Goo0P00@Goo
0P001eP000<0007O0Ml01P7O0P000`7O1`001`7O200000<1g`000000207O20000`7O0P00107O1@00
207O0P0000<1g`0000000`0000<1g`000Ml01`7O0`006UP00`00<Woo0P00B7oo000LOol00`00Oomo
o`16Ool60002F00600080Ml00`000Ml0000700070Ml700030Ml200080Ml500050Ml200020Ml80007
0Ml700020Ml3000HF004000cOol2000BOol4000dOol0015oo`03001oogoo00Moo`03001oogoo04eo
o`D000=H00P000L1g`L00081g`030001g`7O00D1g`H000H1g`8000@1g`H000L1g`P000030Ml00000
00L1g`<001IH00@003Aoo`<001Aoo`05001oogooOol0000cOol0015oo`03001oogoo05aoo`H0009H
00L000030Ml0000000L1g`H000@1g`8000@1g`H000L1g`8000<1g`L000L1g`H000<1g`8001IH00<0
03Ioo`<001Moo`03001oogoo03Aoo`004Goo00<007ooOol017oo0P00G7oo1P000eP01P000P7O0P00
1P7O1P001P7O0P000P7O1`00207O200000<1g`0000001P7O10004eP01000=goo0`006Woo00<007oo
Ool0<goo000AOol00`00Oomoo`03Ool00`00Oomoo`1ROol50003F00700040Ml200040Ml600070Ml2
00000`7O0000000400000`7O000000070Ml600030Ml2000AF005000iOol2000NOol00`00Oomoo`0b
Ool001Ioo`03001oogoo06Qoo`P0009H00H000L1g`8000030Ml0000000D000P1g`L00081g`8000H1
g`<000eH00H003aoo`80021oo`03001oogoo039oo`00RGoo3`001`7O200000<1g`0000001`7O1P00
0`7O0P001UP02@00?Goo00<007oo00000`007Woo00@007ooOol003Aoo`004goo00<007ooOol0O7oo
3@001`7O1`000P7O0P001P7O2`00AWoo0`008Woo0P00=Goo000AOol20029Ool700000`7O00000007
0Ml600030Ml2000=Ool00`00Oomoo`0nOol3001KOol0015oo`@008ioo`H00081g`8000H1g`<000mo
o`03001oogoo03]oo`<005ioo`005goo1000SWoo1P000`7O0P004Goo00<007ooOol0=Goo00@007oo
Oomoo`<0061oo`007Woo1000SGoo0`004goo00<007ooOol0=Goo00<007oo00000P00HWoo000TOol4
003EOol2001UOol002Yoo`D00<aoo`8006Moo`00<Goo1000T7oo00<007ooOol0<7oo0`00JGoo000g
Ool50029Ool00`00Oomoo`0^Ool3001[Ool003ioo`@008=oo`03001oogoo02Uoo`03001oogoo00<0
06eoo`00A7oo1000OGoo00<007ooOol0:Goo0`00L7oo001;Ool4002POol3001bOol0055oo`@009Qo
o`<007Aoo`00Egoo1@00Sgoo0P00Mgoo001NOol4001SOol00`00Oomoo`0OOol01000Ool0000047oo
0`00IWoo001TOol4001MOol00`00Oomoo`0MOol4000AOol01@00Oomoogoo0000IGoo001[Ool4001F
Ool00`00Oomoo`0LOol2000DOol01@00Oomoogoo0000IGoo001aOol4001@Ool00`00Oomoo`0JOol2
000FOol01@00Oomoogoo0000IGoo001gOol5001SOol3000HOol01@00Oomoogoo0000IGoo001nOol4
001JOol4000JOol01@00Oomoogoo0000IGoo0024Ool4000mOol00`00Oomoo`0COol3000LOol01@00
Oomoogoo0000IGoo002;Ool4000fOol00`00Oomoo`0AOol2000POol3001VOol0095oo`@0031oo`03
001oogoo00Yoo`03001oogoo009oo`8008]oo`00Ugoo1@00:Goo00<007ooOol02Woo1@00SGoo002N
Ool4000`Ool3002?Ool00:Aoo`D002Moo`80099oo`00Zgoo10007Woo0`00U7oo002aOol4000@Ool0
1000Oomoo`000Woo0`00UWoo002hOol40009Ool00`00Oomoo`04002HOol00;ioo`@000Aoo`<009]o
o`00a7oo0`00WGoo003oOomUOol00?moofEoo`00dgoo1000SGoo003COol01@00Oomoogoo0000S7oo
003DOol00`00Oomoo`0QOol30002Ool3001TOol00<aoo`L0009oo`03001oogoo029oo`04001oogoo
001VOol00=Ioo`03001oogoo025oo`04001oogoo001VOol00=Ioo`03001oogoo029oo`8006Moo`00
dgoo00@007ooOol002Aoo`8006Moo`00e7oo0P0097oo00@007ooOol006Ioo`00nWoo00@007ooOol0
06Ioo`00n7oo0`000Woo0`00I7oo003oOomUOol00?moofEoo`00ogooIGoo003oOomUOol00?moofEo
o`00ogooIGoo003oOomUOol00?moofEoo`00ogooIGoo003oOomUOol00?moofEoo`00ogooIGoo003o
OomUOol00?moofEoo`00ogooIGoo003oOomUOol00?moofEoo`00ogooIGoo003oOomUOol00?moofEo
o`00ogooIGoo003oOomUOol00?moofEoo`00ogooIGoo003oOomUOol00?moofEoo`00ogooIGoo003o
OomUOol00?moofEoo`00ogooIGoo003oOomUOol00?moofEoo`00ogooIGoo003oOomUOol00?moofEo
o`00ogooIGoo003oOomUOol00?moofEoo`00ogooIGoo003oOomUOol00?moofEoo`00ogooIGoo003o
OomUOol00?moofEoo`00ogooIGoo003oOomUOol00?moofEoo`00ogooIGoo003oOomUOol00?moofEo
o`00ogooIGoo003oOomUOol00?moofEoo`00ogooIGoo003oOomUOol00?moofEoo`00ogooIGoo003o
OomUOol00?moofEoo`00ogooIGoo003oOomUOol00?moofEoo`00ogooIGoo003oOomUOol00?moofEo
o`00ogooIGoo003oOomUOol00?moofEoo`00ogooIGoo003oOomUOol00?moofEoo`00ogooIGoo003o
OomUOol00?moofEoo`00ogooIGoo003oOomUOol00?moofEoo`00ogooIGoo003oOomUOol00?moofEo
o`00ogooIGoo003oOomUOol00?moofEoo`00\
\>"],
  ImageRangeCache->{{{0, 355}, {355, 0}} -> {-5.24905*^-6, -0.0469569, 
  0.00308145, 0.00308145}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0339007 139.569 [
[.02381 -0.0125 -9.125 -14 ]
[.02381 -0.0125 9.125 0 ]
[.18254 -0.0125 -9.125 -14 ]
[.18254 -0.0125 9.125 0 ]
[.34127 -0.0125 -9.125 -14 ]
[.34127 -0.0125 9.125 0 ]
[.5 -0.0125 -5 -14 ]
[.5 -0.0125 5 0 ]
[.65873 -0.0125 -5 -14 ]
[.65873 -0.0125 5 0 ]
[.81746 -0.0125 -5 -14 ]
[.81746 -0.0125 5 0 ]
[.97619 -0.0125 -5 -14 ]
[.97619 -0.0125 5 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -21.0625 -28 ]
[.5 -0.0125 21.0625 -14 ]
[-0.0125 .0339 -10 -7 ]
[-0.0125 .0339 0 7 ]
[-0.0125 .17347 -31 -7 ]
[-0.0125 .17347 0 7 ]
[-0.0125 .31304 -31 -7 ]
[-0.0125 .31304 0 7 ]
[-0.0125 .45261 -31 -7 ]
[-0.0125 .45261 0 7 ]
[-0.0125 .59218 -31 -7 ]
[-0.0125 .59218 0 7 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -66.5 -7 ]
[-0.01875 .30902 -31 7 ]
[ 0 .61803 .125 0 ]
[.5 .63053 -37.1562 0 ]
[.5 .63053 37.1562 14 ]
[ 1 0 .125 0 ]
[ -0.0005 -0.0005 0 0 ]
[ 1.0005 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.18254 0 m
.18254 .61803 L
s
.34127 0 m
.34127 .61803 L
s
.5 0 m
.5 .61803 L
s
.65873 0 m
.65873 .61803 L
s
.81746 0 m
.81746 .61803 L
s
0 .17347 m
1 .17347 L
s
0 .31304 m
1 .31304 L
s
0 .45261 m
1 .45261 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -70.125 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.18254 0 m
.18254 .00625 L
s
gsave
.18254 -0.0125 -70.125 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.34127 0 m
.34127 .00625 L
s
gsave
.34127 -0.0125 -70.125 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(-) show
71.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.65873 0 m
.65873 .00625 L
s
gsave
.65873 -0.0125 -66 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.81746 0 m
.81746 .00625 L
s
gsave
.81746 -0.0125 -66 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(2) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -66 -18 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -82.0625 -32 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(X) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
74.625000 14.000000 moveto
(@) show
78.562500 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(mm) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
97.187500 14.000000 moveto
(D) show
101.125000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2
%%+ font Times-Roman
grestore
0 .0339 m
.00625 .0339 L
s
gsave
-0.0125 .0339 -71 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .17347 m
.00625 .17347 L
s
gsave
-0.0125 .17347 -92 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.001) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .31304 m
.00625 .31304 L
s
gsave
-0.0125 .31304 -92 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.002) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .45261 m
.00625 .45261 L
s
gsave
-0.0125 .45261 -92 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.003) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
0 .59218 m
.00625 .59218 L
s
gsave
-0.0125 .59218 -92 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.004) show
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Times-Roman
grestore
.125 Mabswid
0 .06181 m
.00375 .06181 L
s
0 .08973 m
.00375 .08973 L
s
0 .11764 m
.00375 .11764 L
s
0 .14556 m
.00375 .14556 L
s
0 .20138 m
.00375 .20138 L
s
0 .2293 m
.00375 .2293 L
s
0 .25721 m
.00375 .25721 L
s
0 .28513 m
.00375 .28513 L
s
0 .34095 m
.00375 .34095 L
s
0 .36887 m
.00375 .36887 L
s
0 .39678 m
.00375 .39678 L
s
0 .42469 m
.00375 .42469 L
s
0 .48052 m
.00375 .48052 L
s
0 .50844 m
.00375 .50844 L
s
0 .53635 m
.00375 .53635 L
s
0 .56426 m
.00375 .56426 L
s
0 .00599 m
.00375 .00599 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -127.5 -11 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Bz) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
79.312500 14.000000 moveto
(@) show
83.250000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(T) show
%%IncludeResource: font Math2
%%IncludeFont: Math2
/Math2 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
90.562500 14.000000 moveto
(D) show
94.500000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2
%%+ font Times-Roman
grestore
.02381 .61178 m
.02381 .61803 L
s
.18254 .61178 m
.18254 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05556 .61428 m
.05556 .61803 L
s
.0873 .61428 m
.0873 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.15079 .61428 m
.15079 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.24603 .61428 m
.24603 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.37302 .61428 m
.37302 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.43651 .61428 m
.43651 .61803 L
s
.46825 .61428 m
.46825 .61803 L
s
.53175 .61428 m
.53175 .61803 L
s
.56349 .61428 m
.56349 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.62698 .61428 m
.62698 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.75397 .61428 m
.75397 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.84921 .61428 m
.84921 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.9127 .61428 m
.9127 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
gsave
.5 .63053 -98.1562 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 18.000000 moveto
 541.000000 18.000000 lineto
 541.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 18.000000 lineto
closepath
clip newpath
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Y) show
74.625000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(=) show
85.312500 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0) show
97.312500 14.000000 moveto
(Z) show
107.625000 14.000000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(=) show
118.312500 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.7) show
133.312500 14.000000 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math1
%%+ font Times-Roman
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1
%%+ Times-Roman
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1
%%+ font Times-Roman
grestore
.99375 .0339 m
1 .0339 L
s
.99375 .17347 m
1 .17347 L
s
.99375 .31304 m
1 .31304 L
s
.99375 .45261 m
1 .45261 L
s
.99375 .59218 m
1 .59218 L
s
.125 Mabswid
.99625 .06181 m
1 .06181 L
s
.99625 .08973 m
1 .08973 L
s
.99625 .11764 m
1 .11764 L
s
.99625 .14556 m
1 .14556 L
s
.99625 .20138 m
1 .20138 L
s
.99625 .2293 m
1 .2293 L
s
.99625 .25721 m
1 .25721 L
s
.99625 .28513 m
1 .28513 L
s
.99625 .34095 m
1 .34095 L
s
.99625 .36887 m
1 .36887 L
s
.99625 .39678 m
1 .39678 L
s
.99625 .42469 m
1 .42469 L
s
.99625 .48052 m
1 .48052 L
s
.99625 .50844 m
1 .50844 L
s
.99625 .53635 m
1 .53635 L
s
.99625 .56426 m
1 .56426 L
s
.99625 .00599 m
1 .00599 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.001 w
0 .0339 m
1 .0339 L
s
.5 0 m
.5 .61803 L
s
.002 w
.02381 .01472 m
.04262 .02187 L
.06244 .03195 L
.08255 .04524 L
.10458 .06369 L
.14509 .10861 L
.18408 .16452 L
.22553 .23695 L
.26546 .32437 L
.30387 .43777 L
.32332 .50559 L
.33364 .53985 L
.33933 .5567 L
.34474 .57074 L
.34981 .58177 L
.35535 .59121 L
.35778 .59447 L
.36038 .59734 L
.36282 .59949 L
.36505 .60102 L
.36752 .60223 L
.36882 .60268 L
.36949 .60286 L
.37019 .60302 L
.37139 .60321 L
.3725 .6033 L
.37318 .60332 L
.37383 .60331 L
.37504 .60323 L
.37613 .60309 L
.37729 .60287 L
.37937 .60232 L
.38161 .60153 L
.38409 .60046 L
.40506 .58789 L
.42429 .57721 L
.44433 .56807 L
.4541 .56438 L
.46298 .56161 L
.47213 .55941 L
.47716 .55848 L
.4819 .55779 L
.48441 .55749 L
.48707 .55723 L
.48937 .55704 L
.49184 .55688 L
.49322 .55681 L
.49448 .55675 L
.49576 .55671 L
.49696 .55668 L
Mistroke
.49764 .55667 L
.49836 .55666 L
.49966 .55665 L
.50046 .55665 L
.50121 .55665 L
.50188 .55666 L
.5026 .55667 L
.50385 .5567 L
.50498 .55673 L
.5063 .55678 L
.50753 .55684 L
.50974 .55697 L
.51213 .55715 L
.51756 .55771 L
.52258 .55843 L
.53281 .5605 L
.54366 .56362 L
.56317 .57127 L
.58146 .58017 L
.59998 .59102 L
.61046 .59753 L
.61557 .60027 L
.61798 .60135 L
.6202 .60217 L
.62135 .60252 L
.6226 .60283 L
.62387 .60307 L
.62456 .60317 L
.6252 .60324 L
.62639 .6033 L
.62748 .60329 L
.62873 .60318 L
.62992 .60298 L
.63116 .60267 L
.63249 .60221 L
.63488 .60105 L
.63744 .59927 L
.64028 .59666 L
.64552 .58991 L
.65117 .57981 L
.66139 .55467 L
.7025 .41653 L
.74209 .30593 L
.78017 .22611 L
.8207 .15704 L
.85971 .10256 L
.8796 .07955 L
.90118 .05846 L
.92057 .04296 L
.94113 .02992 L
Mistroke
.95782 .02168 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{366.312, 226.375},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005^0000hQ000`40O003h00OogooKgoo003oOom_
Ool00?moofmoo`00dgoo0`0057oo0`00PGoo003COol00`00Oomoo`0FOol00`00Oomoo`1oOol00<Mo
o`<0009oo`<000Aoo`04001oogooOol3000017oo000007oo1@0000Aoo`00001oo`8000=oo`03001o
ogoo07moo`00bGoo00@007ooOol000Ioo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`00
0Woo00@007ooOol000Aoo`03001oogoo07moo`00bGoo00@007ooOol000Ioo`03001oogoo009oo`04
001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000Aoo`03001oogoo07moo`00bWoo0P001goo
00<007ooOol00Woo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`0017oo00<007ooOol0
Ogoo003:Ool20007Ool00`00Oomoo`02Ool200001Goo000007oo00000Woo0P0000Eoo`00001oo`00
00Aoo`03001oogoo07moo`00bGoo00@007ooOol000Ioo`04001oogooOol200001Goo001oogoo0000
0Woo0P0000Eoo`00Oomoo`0000Eoo`03001oogoo07moo`00bGoo00@007ooOol000Ioo`03001oogoo
01Ioo`03001oogoo07moo`00agoo0`000Woo0`0017oo0`0057oo0`00PGoo003oOom_Ool00?moofmo
o`00ogooKgoo003oOom_Ool00?moofmoo`00ogooKgoo001COol4000ZOol4000[Ool3000UOol3000[
Ool3000YOol4000YOol4000;Ool005Moo`03001oogoo02Moo`05001oogooOol0000[Ool00`00Oomo
o`0SOol01@00Oomoogoo0000:goo00<007ooOol0:7oo00D007ooOomoo`0002aoo`03001oogoo00Qo
o`00Egoo00<007ooOol0:7oo00<007ooOol0;7oo00<007ooOol08goo00D007ooOomoo`0002]oo`03
001oogoo02Uoo`03001oogoo02eoo`03001oogoo00Qoo`00C7oo1`0017oo00<007ooOol07goo1`00
0goo00<007ooOol08Goo1`000goo00<007ooOol08goo00D007ooOomoo`0002]oo`03001oogoo02Yo
o`03001oogoo02aoo`03001oogoo00Qoo`00E7oo0`00;Goo00<007ooOol0:Woo00<007ooOol08goo
00D007ooOomoo`0002]oo`03001oogoo02]oo`03001oogoo02Qoo`<000]oo`00EWoo00<007ooOol0
:goo00<007ooOol0:Woo00<007ooOol08goo00D007ooOomoo`0002]oo`03001oogoo02]oo`03001o
ogoo02Yoo`03001oogoo00Uoo`00Dgoo00D007ooOomoo`0002Uoo`04001oogoo000/Ool00`00Oomo
o`0SOol01@00Oomoogoo0000:goo00<007ooOol0:7oo00@007ooOol002Uoo`05001oogooOol0000:
Ool005Aoo`<002]oo`8002aoo`8002Ioo`<002]oo`8002]oo`8002]oo`<000]oo`00ogooKgoo003o
Oom_Ool00?moofmoo`00ogooKgoo003oOom_Ool004]oool0020000Aoo`00Bgoo0P001Goo00<007oo
Ool01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007oo
Ool01goo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007oo
Ool01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007oo
Ool01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007oo
Ool01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01goo00<007oo
Ool01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007oo
Ool00goo0P0017oo001;Ool00`00Oomoo`0aOol00`0?Oomoo`0[Ool00`0?Oomoo`0ZOol00`00Oomo
o`0ZOol00`0?Oomoo`0[Ool00`0?Oomoo`0aOol00`00Oomoo`02Ool004]oo`03001oogoo035oo`03
00moogoo02]oo`0300moogoo02Yoo`03001oogoo02Yoo`0300moogoo02]oo`0300moogoo035oo`03
001oogoo009oo`00Bgoo00<007ooOol017oo0`00:Woo00<03gooOol0:goo00<03gooOol0:Woo00<0
07ooOol0:Woo00<03gooOol0:goo00<03gooOol0:Goo0P001Woo00<007ooOol00Woo001;Ool00`00
Oomoo`07Ool3000WOol00`0?Oomoo`0[Ool00`0?Oomoo`0ZOol00`00Oomoo`0ZOol00`0?Oomoo`0[
Ool00`0?Oomoo`0VOol30008Ool00`00Oomoo`02Ool004]oo`03001oogoo00Yoo`8002Eoo`0300mo
ogoo02]oo`0300moogoo02Yoo`03001oogoo02Yoo`0300moogoo02]oo`0300moogoo02Aoo`8000]o
o`03001oogoo009oo`00@Goo0`001goo00<007ooOol037oo0P008goo00<03gooOol0:goo00<03goo
Ool0:Woo00<007ooOol0:Woo00<03gooOol0:goo00<03gooOol08Goo0`003Goo00<007ooOol00Woo
0010Ool01@00Oomoogoo00001Woo00<007ooOol03Woo00<007ooOol087oo00<03gooOol0:goo00<0
3gooOol0:Woo00<007ooOol0:Woo00<03gooOol0:goo00<03gooOol07goo0P0047oo00<007ooOol0
0Woo0010Ool01@00Oomoogoo00001Wooo`00800017oo0010Ool01@00Oomoogoo00001Woo00<007oo
Ool04Goo00<007ooOol07Goo00<03gooOol0:goo00<03gooOol0:Woo00<007ooOol0:Woo00<03goo
Ool0:goo00<03gooOol077oo0P004goo00<007ooOol00Woo0010Ool01@00Oomoogoo00001Woo00<0
07ooOol04Woo0P007Goo00<03gooOol0:goo00<03gooOol0:Woo00<007ooOol0:Woo00<03gooOol0
:goo00<03gooOol06goo00<007ooOol04goo00<007ooOol00Woo0010Ool01@00Oomoogoo00001Woo
00<007ooOol057oo00<007ooOol06Woo00<03gooOol0:goo00<03gooOol0:Woo00<007ooOol0:Woo
00<03gooOol0:goo00<03gooOol06Goo0P005Woo00<007ooOol00Woo0010Ool01@00Oomoogoo0000
1Woo00<007ooOol05Goo0P006Woo00<03gooOol0:goo00<03gooOol0:Woo00<007ooOol0:Woo00<0
3gooOol0:goo00<03gooOol067oo00<007ooOol05Woo00<007ooOol00Woo0011Ool30007Ool00`00
Oomoo`0GOol00`00Oomoo`0GOol00`0?Oomoo`0[Ool00`0?Oomoo`0ZOol00`00Oomoo`0ZOol00`0?
Oomoo`0[Ool00`0?Oomoo`0FOol2000IOol00`00Oomoo`02Ool004]oo`03001oogoo01Qoo`03001o
ogoo01Ioo`0300moogoo02]oo`0300moogoo02Yoo`03001oogoo02Yoo`0300moogoo02]oo`0300mo
ogoo01Eoo`03001oogoo01Uoo`03001oogoo009oo`00Bgoo00<007ooOol06Goo00<007ooOol05Goo
00<03gooOol0:goo00<03gooOol0:Woo00<007ooOol0:Woo00<03gooOol0:goo00<03gooOol057oo
00<007ooOol06Woo00<007ooOol00Woo001;Ool2000KOol00`00Oomoo`0DOol00`0?Oomoo`0[Ool0
0`0?Oomoo`0ZOol00`00Oomoo`0ZOol00`0?Oomoo`0[Ool00`0?Oomoo`0COol00`00Oomoo`0JOol2
0004Ool004]oo`03001oogoo01]oo`03001oogoo01=oo`0300moogoo02]oo`0300moogoo02Yoo`03
001oogoo02Yoo`0300moogoo02]oo`0300moogoo019oo`03001oogoo01aoo`03001oogoo009oo`00
Bgoo00<007ooOol06goo00<007ooOol04goo00<03gooOol0:goo00<03gooOol0:Woo00<007ooOol0
:Woo00<03gooOol0:goo00<03gooOol04Goo00<007ooOol07Goo00<007ooOol00Woo001;Ool00`00
Oomoo`0LOol00`00Oomoo`0BOol00`0?Oomoo`0[Ool00`0?Oomoo`0ZOol00`00Oomoo`0ZOol00`0?
Oomoo`0[Ool00`0?Oomoo`0@Ool00`00Oomoo`0NOol00`00Oomoo`02Ool004]oo`03001oogoo01eo
o`03001oogoo015oo`0300moogoo02]oo`0300moogoo02Yoo`03001oogoo02Yoo`0300moogoo02]o
o`0300moogoo00moo`03001oogoo01moo`03001oogoo009oo`00Bgoo00<007ooOol07Woo00<007oo
Ool047oo00<03gooOol0:goo00<03gooOol0:Woo00<007ooOol0:Woo00<03gooOol0:goo00<03goo
Ool03Woo00<007ooOol087oo00<007ooOol00Woo001;Ool00`00Oomoo`0OOol00`00Oomoo`0?Ool0
0`0?Oomoo`0[Ool00`0?Oomoo`0ZOol00`00Oomoo`0ZOol00`0?Oomoo`0[Ool00`0?Oomoo`0>Ool0
0`00Oomoo`0POol00`00Oomoo`02Ool004]oo`03001oogoo021oo`03001oogoo00ioo`0300moogoo
02]oo`0300moogoo02Yoo`03001oogoo02Yoo`0300moogoo02]oo`0300moogoo00eoo`03001oogoo
025oo`03001oogoo009oo`00Bgoo0P008Woo00<007ooOol03Goo00<03gooOol0:goo00<03gooOol0
:Woo00<007ooOol0:Woo00<03gooOol0:goo00<03gooOol037oo00<007ooOol08Goo0P0017oo001;
Ool00`00Oomoo`0ROol00`00Oomoo`0<Ool00`0?Oomoo`0[Ool00`0?Oomoo`0ZOol00`00Oomoo`0Z
Ool00`0?Oomoo`0[Ool00`0?Oomoo`0;Ool00`00Oomoo`0SOol00`00Oomoo`02Ool004]oo`03001o
ogoo02=oo`03001oogoo00]oo`0300moogoo02]oo`0300moogoo02Yoo`03001oogoo02Yoo`0300mo
ogoo02]oo`0300moogoo00]oo`03001oogoo02=oo`03001oogoo009oo`00Bgoo00<007ooOol097oo
00<007ooOol02Woo00<03gooOol0:goo00<03gooOol0:Woo00<007ooOol0:Woo00<03gooOol0:goo
00<03gooOol02Woo00<007ooOol097oo00<007ooOol00Woo001;Ool00`00Oomoo`0UOol00`00Oomo
o`09Ool00`0?Oomoo`0[Ool00`0?Oomoo`0ZOol00`00Oomoo`0ZOol00`0?Oomoo`0[Ool00`0?Oomo
o`09Ool00`00Oomoo`0UOol00`00Oomoo`02Ool004]oo`03001oogoo02Ioo`03001oogoo00Qoo`03
00moogoo02]oo`0300moogoo02Yoo`03001oogoo02Yoo`0300moogoo02]oo`0300moogoo00Uoo`03
001oogoo02Eoo`03001oogoo009oo`00Bgoo00<007ooOol09goo00<007ooOol01goo00<03gooOol0
:goo00<03gooOol0:Woo00<007ooOol0:Woo00<03gooOol0:goo00<03gooOol027oo00<007ooOol0
9Woo00<007ooOol00Woo001;Ool00`00Oomoo`0WOol00`00Oomoo`07Ool00`0?Oomoo`0[Ool00`0?
Oomoo`0ZOol00`00Oomoo`0ZOol00`0?Oomoo`0[Ool00`0?Oomoo`07Ool00`00Oomoo`0WOol00`00
Oomoo`02Ool004]oo`8002Uoo`03001oogoo00Ioo`0300moogoo02]oo`0300moogoo02Yoo`03001o
ogoo02Yoo`0300moogoo02]oo`0300moogoo00Ioo`03001oogoo02Moo`8000Aoo`00Bgoo00<007oo
Ool0:Goo00<007ooOol01Goo00<03gooOol0:goo00<03gooOol0:Woo00<007ooOol0:Woo00<03goo
Ool0:goo00<03gooOol01Goo00<007ooOol0:Goo00<007ooOol00Woo001;Ool00`00Oomoo`0YOol0
0`00Oomoo`05Ool00`0?Oomoo`0[Ool00`0?Oomoo`0ZOol00`00Oomoo`0ZOol00`0?Oomoo`0[Ool0
0`0?Oomoo`05Ool00`00Oomoo`0YOol00`00Oomoo`02Ool004]oo`03001oogoo02Yoo`03001oogoo
00Aoo`0300moogoo02]oo`0300moogoo02Yoo`03001oogoo02Yoo`0300moogoo02]oo`0300moogoo
00Aoo`03001oogoo02Yoo`03001oogoo009oo`00Bgoo00<007ooOol0:goo00<007ooOol00goo00<0
3gooOol0:goo00<03gooOol0:Woo00<007ooOol0:Woo00<03gooOol0:goo00<03gooOol00goo00<0
07ooOol0:goo00<007ooOol00Woo001;Ool00`00Oomoo`0[Ool00`00Oomoo`03Ool00`0?Oomoo`0[
Ool00`0?Oomoo`0ZOol00`00Oomoo`0ZOol00`0?Oomoo`0[Ool00`0?Oomoo`02Ool00`00Oomoo`0/
Ool00`00Oomoo`02Ool004]oo`03001oogoo02aoo`03001oogoo009oo`0300moogoo02]oo`0300mo
ogoo02Yoo`03001oogoo02Yoo`0300moogoo02]oo`0500moogooOol0000_Ool00`00Oomoo`02Ool0
04]oo`03001oogoo02eoo`05001oogooOol03`0]Ool00`0?Oomoo`0ZOol00`00Oomoo`0ZOol00`0?
Oomoo`0[Ool01@0?Oomoogoo0000;goo00<007ooOol00Woo001;Ool2000_Ool01000Oomoo`0?;Goo
00<03gooOol0:Woo00<007ooOol0:Woo00<03gooOol0:goo00@03gooOol002moo`8000Aoo`00Bgoo
00<007ooOol0;Woo00@007ooOol03beoo`0300moogoo02Yoo`03001oogoo02Yoo`0300moogoo02]o
o`0300moo`00035oo`03001oogoo009oo`00Bgoo00<007ooOol0;goo00<007oo00l0;Goo00<03goo
Ool0:Woo00<007ooOol0:Woo00<03gooOol0:goo00<03`00Ool0<Goo00<007ooOol00Woo001;Ool0
0`00Oomoo`0`Ool00`0000moo`0/Ool00`0?Oomoo`0ZOol00`00Oomoo`0ZOol00`0?Oomoo`0[Ool0
0`00Oomoo`0aOol00`00Oomoo`02Ool004]oo`03001oogoo031oo`0300003goo02aoo`0300moogoo
02Yoo`03001oogoo02Yoo`0300moogoo02]oo`03001oogoo035oo`03001oogoo009oo`00Bgoo00<0
07ooOol0<Goo00<007ooOol0:goo00<03gooOol0:Woo00<007ooOol0:Woo00<03gooOol0:Woo00<0
000?Ool0<Woo00<007ooOol00Woo000/Ool30003Ool00`00Oomoo`030003Ool30004Ool30006Ool0
0`00Oomoo`0aOol00`0?001oo`0[Ool00`0?Oomoo`0ZOol00`00Oomoo`0ZOol00`0?Oomoo`0ZOol0
0`0000moo`0bOol00`00Oomoo`02Ool002]oo`05001oogooOol00004Ool01`00Oomoogoo001oo`00
00=oo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo035oo`0300l007oo02]oo`0300moogoo
02Yoo`03001oogoo02Yoo`0300moogoo02Uoo`03001oo`0?03=oo`03001oogoo009oo`00:goo00D0
07ooOomoo`0000Aoo`07001oogooOol007oo00000goo00<007ooOol00Woo00<007ooOol01Goo0`00
<`0?00<0000?00l0EP0?00<0000?00l0EP0?00<0000?00l0<@0?0`0017oo000[Ool01@00Oomoogoo
000017oo00L007ooOomoo`00Ool00003Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`0a
Ool0100?Oomoo`00:Woo00<03gooOol0:Woo00<007ooOol0:Woo00<03gooOol0:7oo00@007ooOol0
3c=oo`03001oogoo009oo`00:goo00D007ooOomoo`0000Aoo`07001oogooOol007oo00000goo00<0
07ooOol00Woo00<007ooOol01Goo00<007ooOol0<Goo00@03gooOol002Yoo`0300moogoo02Yoo`03
001oogoo02Yoo`0300moogoo02Moo`05001oogooOol03`0cOol00`00Oomoo`02Ool002]oo`05001o
ogooOol00004Ool01`00Oomoogoo001oo`0000=oo`03001oogoo009oo`03001oogoo00Eoo`03001o
ogoo035oo`0500moogooOol0000YOol00`0?Oomoo`0ZOol00`00Oomoo`0ZOol00`0?Oomoo`0WOol0
1@00Oomoogoo00l0<goo00<007ooOol00Woo000[Ool01@00Oomoogoo000017oo00L007ooOomoo`00
Ool00003Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`0aOol01@0?Oomoogoo0000:Goo
00<03gooOol0:Woo00<007ooOol0:Woo00<03gooOol09Woo00<007ooOol00Woo00<03gooOol0<Goo
00<007ooOol00Woo000/Ool30006Ool30003Ool30004Ool20007Ool00`00Oomoo`0aOol00`0?Oomo
o`02Ool00`00Oomoo`0VOol00`0?Oomoo`0ZOol00`00Oomoo`0ZOol00`0?Oomoo`0VOol00`00Oomo
o`02Ool00`0?Oomoo`0aOol00`00Oomoo`02Ool004]oo`03001oogoo035oo`0300moogoo00=oo`03
001oogoo02Eoo`0300moogoo02Yoo`03001oogoo02Yoo`0300moogoo02Eoo`03001oogoo00=oo`03
00moogoo035oo`03001oogoo009oo`00Bgoo00<007ooOol0<Goo00<03gooOol00goo00<007ooOol0
9Goo00<03gooOol0:Woo00<007ooOol0:Woo00<03gooOol09Goo00<007ooOol00goo00<03gooOol0
<Goo00<007ooOol00Woo001;Ool2000bOol00`0?Oomoo`04Ool00`00Oomoo`0TOol00`0?Oomoo`0Z
Ool00`00Oomoo`0ZOol00`0?Oomoo`0TOol00`00Oomoo`04Ool00`0?Oomoo`0`Ool20004Ool004]o
o`03001oogoo035oo`0300moogoo00Aoo`03001oogoo02Aoo`0300moogoo02Yoo`03001oogoo02Yo
o`0300moogoo02Aoo`03001oogoo00Aoo`0300moogoo035oo`03001oogoo009oo`00Bgoo00<007oo
Ool0<Goo00<03gooOol01Goo00<007ooOol08goo00<03gooOol0:Woo00<007ooOol0:Woo00<03goo
Ool08goo00<007ooOol01Goo00<03gooOol0<Goo00<007ooOol00Woo001;Ool00`00Oomoo`0aOol0
0`0?Oomoo`06Ool00`00Oomoo`0ROol00`0?Oomoo`0ZOol00`00Oomoo`0ZOol00`0?Oomoo`0ROol0
0`00Oomoo`06Ool00`0?Oomoo`0aOol00`00Oomoo`02Ool004]oo`03001oogoo035oo`0300moogoo
00Ioo`03001oogoo029oo`0300moogoo02Yoo`03001oogoo02Yoo`0300moogoo029oo`03001oogoo
00Ioo`0300moogoo035oo`03001oogoo009oo`00Bgoo00<007ooOol0<Goo00<03gooOol01goo00<0
07ooOol08Goo00<03gooOol0:Woo00<007ooOol0:Woo00<03gooOol08Goo00<007ooOol01goo00<0
3gooOol0<Goo00<007ooOol00Woo001;Ool00`00Oomoo`0aOol00`0?Oomoo`07Ool00`00Oomoo`0Q
Ool00`0?Oomoo`0ZOol00`00Oomoo`0ZOol00`0?Oomoo`0QOol00`00Oomoo`07Ool00`0?Oomoo`0a
Ool00`00Oomoo`02Ool004]oo`03001oogoo035oo`0300moogoo00Qoo`03001oogoo021oo`0300mo
ogoo02Yoo`03001oogoo02Yoo`0300moogoo021oo`03001oogoo00Qoo`0300moogoo035oo`03001o
ogoo009oo`00Bgoo0P00<Woo00<03gooOol02Goo00<007ooOol07goo00<03gooOol0:Woo00<007oo
Ool0:Woo00<03gooOol087oo00<007ooOol027oo00<03gooOol0<7oo0P0017oo001;Ool00`00Oomo
o`0aOol00`0?Oomoo`09Ool00`00Oomoo`0OOol00`0?Oomoo`0ZOol00`00Oomoo`0ZOol00`0?Oomo
o`0OOol00`00Oomoo`09Ool00`0?Oomoo`0aOol00`00Oomoo`02Ool004]oo`03001oogoo035oo`03
00moogoo00Yoo`03001oogoo01ioo`0300moogoo02Yoo`03001oogoo02Yoo`0300moogoo01moo`03
001oogoo00Uoo`0300moogoo035oo`03001oogoo009oo`00Bgoo00<007ooOol0<Goo00<03gooOol0
2Woo00<007ooOol07Woo00<03gooOol0:Woo00<007ooOol0:Woo00<03gooOol07Woo00<007ooOol0
2Woo00<03gooOol0<Goo00<007ooOol00Woo001;Ool00`00Oomoo`0aOol00`0?Oomoo`0;Ool00`00
Oomoo`0MOol00`0?Oomoo`0ZOol00`00Oomoo`0ZOol00`0?Oomoo`0NOol00`00Oomoo`0:Ool00`0?
Oomoo`0aOol00`00Oomoo`02Ool004]oo`03001oogoo035oo`0300moogoo00]oo`03001oogoo01eo
o`0300moogoo02Yoo`03001oogoo02Yoo`0300moogoo01eoo`03001oogoo00]oo`0300moogoo035o
o`03001oogoo009oo`00Bgoo00<007ooOol0<Goo00<03gooOol037oo00<007ooOol077oo00<03goo
Ool0:Woo00<007ooOol0:Woo00<03gooOol07Goo00<007ooOol02goo00<03gooOol0<Goo00<007oo
Ool00Woo001;Ool00`00Oomoo`0aOol00`0?Oomoo`0<Ool00`00Oomoo`0LOol00`0?Oomoo`0ZOol0
0`00Oomoo`0ZOol00`0?Oomoo`0LOol00`00Oomoo`0<Ool00`0?Oomoo`0aOol00`00Oomoo`02Ool0
04]oo`80039oo`0300moogoo00aoo`03001oogoo01aoo`0300moogoo02Yoo`03001oogoo02Yoo`03
00moogoo01aoo`03001oogoo00aoo`0300moogoo031oo`8000Aoo`00Bgoo00<007ooOol0<Goo00<0
3gooOol03Goo00<007ooOol06goo00<03gooOol0:Woo00<007ooOol0:Woo00<03gooOol06goo00<0
07ooOol03Goo00<03gooOol0<Goo00<007ooOol00Woo001;Ool00`00Oomoo`0aOol00`0?Oomoo`0=
Ool00`00Oomoo`0KOol00`0?Oomoo`0ZOol00`00Oomoo`0ZOol00`0?Oomoo`0KOol00`00Oomoo`0=
Ool00`0?Oomoo`0aOol00`00Oomoo`02Ool004]oo`03001oogoo035oo`0300moogoo00ioo`03001o
ogoo01Yoo`0300moogoo02Yoo`03001oogoo02Yoo`0300moogoo01Yoo`03001oogoo00ioo`0300mo
ogoo035oo`03001oogoo009oo`00Bgoo00<007ooOol0<Goo00<03gooOol03Woo00<007ooOol06Woo
00<03gooOol0:Woo00<007ooOol0:Woo00<03gooOol06Woo00<007ooOol03Woo00<03gooOol0<Goo
00<007ooOol00Woo001;Ool00`00Oomoo`0aOol00`0?Oomoo`0?Ool00`00Oomoo`0IOol00`0?Oomo
o`0ZOol00`00Oomoo`0ZOol00`0?Oomoo`0JOol00`00Oomoo`0>Ool00`0?Oomoo`0aOol00`00Oomo
o`02Ool004]oo`03001oogoo035oo`0300moogoo00moo`03001oogoo01Uoo`0300moogoo02Yoo`03
001oogoo02Yoo`0300moogoo01Uoo`03001oogoo00moo`0300moogoo035oo`03001oogoo009oo`00
Bgoo00<007ooOol0<Goo00<03gooOol047oo00<007ooOol067oo00<03gooOol0:Woo00<007ooOol0
:Woo00<03gooOol06Goo00<007ooOol03goo00<03gooOol0<Goo00<007ooOol00Woo001;Ool2000b
Ool00`0?Oomoo`0@Ool00`00Oomoo`0HOol00`0?Oomoo`0ZOol00`00Oomoo`0ZOol00`0?Oomoo`0H
Ool00`00Oomoo`0@Ool00`0?Oomoo`0`Ool20004Ool004]oo`03001oogoo035oo`0300moogoo011o
o`03001oogoo01Qoo`0300moogoo02Yoo`03001oogoo02Yoo`0300moogoo01Qoo`03001oogoo011o
o`0300moogoo035oo`03001oogoo009oo`00Bgoo00<007ooOol0<Goo00<03gooOol04Goo00<007oo
Ool05goo00<03gooOol0:Woo00<007ooOol0:Woo00<03gooOol05goo00<007ooOol04Goo00<03goo
Ool0<Goo00<007ooOol00Woo000FOol30009Ool3000VOol00`00Oomoo`0aOol00`0?Oomoo`0AOol0
0`00Oomoo`0GOol00`0?Oomoo`0ZOol00`00Oomoo`0ZOol00`0?Oomoo`0GOol00`00Oomoo`0AOol0
0`0?Oomoo`0aOol00`00Oomoo`02Ool001Ioo`03001oogoo00]oo`03001oogoo02Aoo`03001oogoo
035oo`0300moogoo019oo`03001oogoo01Ioo`0300moogoo02Yoo`03001oogoo02Yoo`0300moogoo
01Ioo`03001oogoo019oo`0300moogoo035oo`03001oogoo009oo`001Woo1P000Woo1@000goo00<0
07ooOol00goo0`001Goo00<007ooOol097oo00<007ooOol0<Goo00<03gooOol04Woo00<007ooOol0
5Woo00<03gooOol0:Woo00<007ooOol0:Woo00<03gooOol05Woo00<007ooOol04Woo00<03gooOol0
<Goo00<007ooOol00Woo0007Ool00`00Oomoo`02Ool01000Oomoo`000Woo00D007ooOomoo`0000Io
o`03001oogoo00Aoo`03001oogoo00Eoo`<000=oo`03001oogoo00<000=oo`<0009oo`@000Moo`03
001oogoo035oo`0300moogoo01=oo`03001oogoo01Eoo`0300moogoo02Yoo`03001oogoo02Yoo`03
00moogoo01Eoo`03001oogoo01=oo`0300moogoo035oo`03001oogoo009oo`001goo00<007ooOol0
0Woo00D007ooOomoo`0000Eoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`05001o
ogooOol00004Ool01`00Oomoogoo001oo`0000=oo`03001oo`0000=oo`03001oogoo00Aoo`03001o
ogoo035oo`0300moogoo01=oo`03001oogoo01Eoo`0300moogoo02Yoo`03001oogoo02Yoo`0300mo
ogoo01Eoo`03001oogoo01=oo`0300moogoo035oo`03001oogoo009oo`001goo00<007ooOol00Woo
00D007ooOomoo`0000Eoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`05001oogoo
Ool00004Ool01`00Oomoogoo001oo`0000=oo`04001oogoo0009Ool3001700l00`0000l03`1200l0
0`0000l03`1100l00`0000l03`1600l30004Ool000Moo`D0009oo`04001oogoo0004Ool00`00Oomo
o`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool01@00Oomoogoo000017oo00L007ooOomoo`00Ool0
0003Ool01@00Oomoogoo000027oo00<007ooOol0<Goo00<03gooOol057oo00<007ooOol057oo00<0
3gooOol0:Woo00<007ooOol0:Woo00<03gooOol057oo00<007ooOol057oo00<03gooOol0<Goo00<0
07ooOol00Woo0007Ool00`00Oomoo`02Ool00`00Ool000040003Ool01@00Oomoogoo00000Woo00@0
07ooOol000=oo`03001oogoo00Aoo`05001oogooOol00004Ool01`00Oomoogoo001oo`0000=oo`03
001oogoo009oo`03001oogoo00Eoo`03001oogoo035oo`0300moogoo01Aoo`03001oogoo01Aoo`03
00moogoo02Yoo`03001oogoo02Yoo`0300moogoo01Aoo`03001oogoo01Aoo`0300moogoo035oo`03
001oogoo009oo`001goo00<007ooOol00Woo00<007ooOol01goo00D007ooOomoo`00009oo`04001o
ogoo0003Ool00`00Oomoo`04Ool01@00Oomoogoo000017oo00L007ooOomoo`00Ool00003Ool00`00
Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`0aOol00`0?Oomoo`0EOol00`00Oomoo`0COol00`0?
Oomoo`0ZOol00`00Oomoo`0ZOol00`0?Oomoo`0COol00`00Oomoo`0EOol00`0?Oomoo`0aOol00`00
Oomoo`02Ool000Ioo`H000Yoo`<00003Ool0000000D00004Ool000000006Ool01@00Oomoogoo0000
17oo00L007ooOomoo`00Ool00003Ool00`00Ool00002Ool00`00Oomoo`05Ool00`00Oomoo`0aOol0
0`0?Oomoo`0EOol00`00Oomoo`0COol00`0?Oomoo`0ZOol00`00Oomoo`0ZOol00`0?Oomoo`0COol0
0`00Oomoo`0EOol00`0?Oomoo`0aOol00`00Oomoo`02Ool002aoo`<000Ioo`<000=oo`<000=oo`80
00Qoo`03001oogoo035oo`0300moogoo01Ioo`03001oogoo019oo`0300moogoo02Yoo`03001oogoo
02Yoo`0300moogoo01=oo`03001oogoo01Eoo`0300moogoo035oo`03001oogoo009oo`00Bgoo00<0
07ooOol0<Goo00<03gooOol05Woo00<007ooOol04Woo00<03gooOol0:Woo00<007ooOol0:Woo00<0
3gooOol04Woo00<007ooOol05Woo00<03gooOol0<Goo00<007ooOol00Woo001;Ool00`00Oomoo`0a
Ool00`0?Oomoo`0FOol00`00Oomoo`0BOol00`0?Oomoo`0ZOol00`00Oomoo`0ZOol00`0?Oomoo`0B
Ool00`00Oomoo`0FOol00`0?Oomoo`0aOol00`00Oomoo`02Ool004]oo`80039oo`0300moogoo01Mo
o`03001oogoo015oo`0300moogoo02Yoo`03001oogoo02Yoo`0300moogoo019oo`03001oogoo01Io
o`0300moogoo031oo`8000Aoo`00Bgoo00<007ooOol0<Goo00<03gooOol05goo00<007ooOol04Goo
00<03gooOol0:Woo00<007ooOol0:Woo00<03gooOol04Goo00<007ooOol05goo00<03gooOol0<Goo
00<007ooOol00Woo001;Ool00`00Oomoo`0aOol00`0?Oomoo`0GOol00`00Oomoo`0AOol00`0?Oomo
o`0ZOol00`00Oomoo`0ZOol00`0?Oomoo`0AOol00`00Oomoo`0GOol00`0?Oomoo`0aOol00`00Oomo
o`02Ool004]oo`03001oogoo035oo`0300moogoo01Qoo`03001oogoo011oo`0300moogoo02Yoo`03
001oogoo02Yoo`0300moogoo015oo`03001oogoo01Moo`0300moogoo035oo`03001oogoo009oo`00
Bgoo00<007ooOol0<Goo00<03gooOol067oo00<007ooOol047oo00<03gooOol0:Woo00<007ooOol0
:Woo00<03gooOol047oo00<007ooOol067oo00<03gooOol0<Goo00<007ooOol00Woo001;Ool00`00
Oomoo`0aOol00`0?Oomoo`0HOol00`00Oomoo`0@Ool00`0?Oomoo`0ZOol00`00Oomoo`0ZOol00`0?
Oomoo`0@Ool00`00Oomoo`0HOol00`0?Oomoo`0aOol00`00Oomoo`02Ool004]oo`03001oogoo035o
o`0300moogoo01Uoo`03001oogoo00moo`0300moogoo02Yoo`03001oogoo02Yoo`0300moogoo00mo
o`03001oogoo01Uoo`0300moogoo035oo`03001oogoo009oo`00Bgoo00<007ooOol0<Goo00<03goo
Ool06Goo00<007ooOol03goo00<03gooOol0:Woo00<007ooOol0:Woo00<03gooOol03goo00<007oo
Ool06Goo00<03gooOol0<Goo00<007ooOol00Woo001;Ool2000bOol00`0?Oomoo`0IOol00`00Oomo
o`0?Ool00`0?Oomoo`0ZOol00`00Oomoo`0ZOol00`0?Oomoo`0?Ool00`00Oomoo`0IOol00`0?Oomo
o`0`Ool20004Ool004]oo`03001oogoo035oo`0300moogoo01Yoo`03001oogoo00ioo`0300moogoo
02Yoo`03001oogoo02Yoo`0300moogoo00ioo`03001oogoo01Yoo`0300moogoo035oo`03001oogoo
009oo`00Bgoo00<007ooOol0<Goo00<03gooOol06Woo00<007ooOol03Woo00<03gooOol0:Woo00<0
07ooOol0:Woo00<03gooOol03Woo00<007ooOol06Woo00<03gooOol0<Goo00<007ooOol00Woo001;
Ool00`00Oomoo`0aOol00`0?Oomoo`0JOol00`00Oomoo`0>Ool00`0?Oomoo`0ZOol00`00Oomoo`0Z
Ool00`0?Oomoo`0>Ool00`00Oomoo`0JOol00`0?Oomoo`0aOol00`00Oomoo`02Ool004]oo`03001o
ogoo035oo`0300moogoo01]oo`03001oogoo00eoo`0300moogoo02Yoo`03001oogoo02Yoo`0300mo
ogoo00eoo`03001oogoo01]oo`0300moogoo035oo`03001oogoo009oo`00Bgoo00<007ooOol0<Goo
00<03gooOol06goo00<007ooOol03Goo00<03gooOol0:Woo00<007ooOol0:Woo00<03gooOol03Goo
00<007ooOol06goo00<03gooOol0<Goo00<007ooOol00Woo001;Ool00`00Oomoo`0aOol00`0?Oomo
o`0KOol00`00Oomoo`0=Ool00`0?Oomoo`0ZOol00`00Oomoo`0ZOol00`0?Oomoo`0=Ool00`00Oomo
o`0KOol00`0?Oomoo`0aOol00`00Oomoo`02Ool004]oo`03001oogoo035oo`0300moogoo01aoo`03
001oogoo00aoo`0300moogoo02Yoo`03001oogoo02Yoo`0300moogoo00aoo`03001oogoo01aoo`03
00moogoo035oo`03001oogoo009oo`00Bgoo0P00<Woo00<03gooOol077oo00<007ooOol037oo00<0
3gooOol0:Woo00<007ooOol0:Woo00<03gooOol037oo00<007ooOol077oo00<03gooOol0<7oo0P00
17oo001;Ool00`00Oomoo`0aOol00`0?Oomoo`0LOol00`00Oomoo`0<Ool00`0?Oomoo`0ZOol00`00
Oomoo`0ZOol00`0?Oomoo`0<Ool00`00Oomoo`0LOol00`0?Oomoo`0aOol00`00Oomoo`02Ool004]o
o`03001oogoo035oo`0300moogoo01eoo`03001oogoo00]oo`0300moogoo02Yoo`03001oogoo02Yo
o`0300moogoo00]oo`03001oogoo01eoo`0300moogoo035oo`03001oogoo009oo`00Bgoo00<007oo
Ool0<Goo00<03gooOol07Goo00<007ooOol02goo00<03gooOol0:Woo00<007ooOol0:Woo00<03goo
Ool02goo00<007ooOol07Goo00<03gooOol0<Goo00<007ooOol00Woo001;Ool00`00Oomoo`0aOol0
0`0?Oomoo`0MOol00`00Oomoo`0;Ool00`0?Oomoo`0ZOol00`00Oomoo`0ZOol00`0?Oomoo`0;Ool0
0`00Oomoo`0MOol00`0?Oomoo`0aOol00`00Oomoo`02Ool004]oo`03001oogoo035oo`0300moogoo
01ioo`03001oogoo00Yoo`0300moogoo02Yoo`03001oogoo02Yoo`0300moogoo00Yoo`03001oogoo
01ioo`0300moogoo035oo`03001oogoo009oo`00Bgoo00<007ooOol0<Goo00<03gooOol07Woo00<0
07ooOol02Woo00<03gooOol0:Woo00<007ooOol0:Woo00<03gooOol02Woo00<007ooOol07Woo00<0
3gooOol0<Goo00<007ooOol00Woo001;Ool00`00Oomoo`0aOol00`0?Oomoo`0NOol00`00Oomoo`0:
Ool00`0?Oomoo`0ZOol00`00Oomoo`0ZOol00`0?Oomoo`0:Ool00`00Oomoo`0NOol00`0?Oomoo`0a
Ool00`00Oomoo`02Ool004]oo`80039oo`0300moogoo01moo`03001oogoo00Uoo`0300moogoo02Yo
o`03001oogoo02Yoo`0300moogoo00Uoo`03001oogoo01moo`0300moogoo031oo`8000Aoo`00Bgoo
00<007ooOol0<Goo00<03gooOol07goo00<007ooOol02Goo00<03gooOol0:Woo00<007ooOol0:Woo
00<03gooOol02Goo00<007ooOol07goo00<03gooOol0<Goo00<007ooOol00Woo001;Ool00`00Oomo
o`0aOol00`0?Oomoo`0OOol00`00Oomoo`09Ool00`0?Oomoo`0ZOol00`00Oomoo`0ZOol00`0?Oomo
o`09Ool00`00Oomoo`0OOol00`0?Oomoo`0aOol00`00Oomoo`02Ool004]oo`03001oogoo035oo`03
00moogoo021oo`03001oogoo00Qoo`0300moogoo02Yoo`03001oogoo02Yoo`0300moogoo00Qoo`03
001oogoo021oo`0300moogoo035oo`03001oogoo009oo`00Bgoo00<007ooOol0<Goo00<03gooOol0
87oo00<007ooOol027oo00<03gooOol0:Woo00<007ooOol0:Woo00<03gooOol027oo00<007ooOol0
87oo00<03gooOol0<Goo00<007ooOol00Woo001;Ool00`00Oomoo`0aOol00`0?Oomoo`0POol00`00
Oomoo`08Ool00`0?Oomoo`0ZOol00`00Oomoo`0ZOol00`0?Oomoo`08Ool00`00Oomoo`0POol00`0?
Oomoo`0aOol00`00Oomoo`02Ool002aoo`<000=oo`03001oogoo00<000=oo`<0009oo`@000Moo`03
001oogoo035oo`0300moogoo021oo`03001oogoo00Qoo`0300moogoo02Yoo`03001oogoo02Yoo`03
00moogoo00Moo`03001oogoo025oo`0300moogoo035oo`03001oogoo009oo`00:goo00D007ooOomo
o`0000Aoo`07001oogooOol007oo00000goo00<007ooOol00goo00<007ooOol017oo00<007ooOol0
<Goo00<03gooOol08Goo00<007ooOol01goo00<03gooOol0:Woo00<007ooOol0:Woo00<03gooOol0
1goo00<007ooOol08Goo00<03gooOol0<Goo00<007ooOol00Woo000[Ool01@00Oomoogoo000017oo
00L007ooOomoo`00Ool00003Ool00`00Oomoo`03Ool00`00Oomoo`04Ool3001E00l00`0000l03`0d
00l00`0000l03`0d00l00`0000l03`1C00l30004Ool002]oo`05001oogooOol00004Ool01`00Oomo
ogoo001oo`0000=oo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo035oo`0300moogoo025o
o`03001oogoo00Moo`0300moogoo02Yoo`03001oogoo02Yoo`0300moogoo00Moo`03001oogoo025o
o`0300moogoo035oo`03001oogoo009oo`00:goo00D007ooOomoo`0000Aoo`07001oogooOol007oo
00000goo00<007ooOol00`001goo00<007ooOol0<Goo00<03gooOol08Woo00<007ooOol01Woo00<0
3gooOol0:Woo00<007ooOol0:Woo00<03gooOol01Woo00<007ooOol08Woo00<03gooOol0<Goo00<0
07ooOol00Woo000[Ool01@00Oomoogoo000017oo00L007ooOomoo`00Ool00003Ool00`00Oomoo`02
Ool00`00Oomoo`05Ool00`00Oomoo`0aOol00`0?Oomoo`0ROol00`00Oomoo`06Ool00`0?Oomoo`0Z
Ool00`00Oomoo`0ZOol00`0?Oomoo`06Ool00`00Oomoo`0ROol00`0?Oomoo`0aOol00`00Oomoo`02
Ool002]oo`05001oogooOol00004Ool01`00Oomoogoo001oo`0000=oo`03001oo`0000=oo`03001o
ogoo00Aoo`03001oogoo035oo`0300moogoo029oo`03001oogoo00Ioo`0300moogoo02Yoo`03001o
ogoo02Yoo`0300moogoo00Ioo`03001oogoo029oo`0300moogoo035oo`03001oogoo009oo`00;7oo
0`001Woo0`000goo0`000goo0`001goo00<007ooOol0<Goo00<03gooOol08goo00<007ooOol01Goo
00<03gooOol0:Woo00<007ooOol0:Woo00<03gooOol01Goo00<007ooOol08goo00<03gooOol0<Goo
00<007ooOol00Woo001;Ool00`00Oomoo`0aOol00`0?Oomoo`0SOol00`00Oomoo`05Ool00`0?Oomo
o`0ZOol00`00Oomoo`0ZOol00`0?Oomoo`05Ool00`00Oomoo`0SOol00`0?Oomoo`0aOol00`00Oomo
o`02Ool004]oo`03001oogoo035oo`0300moogoo02=oo`03001oogoo00Eoo`0300moogoo02Yoo`03
001oogoo02Yoo`0300moogoo00Eoo`03001oogoo02=oo`0300moogoo035oo`03001oogoo009oo`00
Bgoo0P00<Woo00<03gooOol097oo00<007ooOol017oo00<03gooOol0:Woo00<007ooOol0:Woo00<0
3gooOol017oo00<007ooOol097oo00<03gooOol0<7oo0P0017oo001;Ool00`00Oomoo`0aOol00`0?
Oomoo`0TOol00`00Oomoo`04Ool00`0?Oomoo`0ZOol00`00Oomoo`0ZOol00`0?Oomoo`04Ool00`00
Oomoo`0TOol00`0?Oomoo`0aOol00`00Oomoo`02Ool004]oo`03001oogoo035oo`0300moogoo02Ao
o`03001oogoo00Aoo`0300moogoo02Yoo`03001oogoo02Yoo`0300moogoo00Aoo`03001oogoo02Ao
o`0300moogoo035oo`03001oogoo009oo`00Bgoo00<007ooOol0<Goo00<03gooOol09Goo00<007oo
Ool00goo00<03gooOol0:Woo00<007ooOol0:Woo00<03gooOol017oo00<007ooOol097oo00<03goo
Ool0<Goo00<007ooOol00Woo001;Ool00`00Oomoo`0aOol00`0?Oomoo`0UOol00`00Oomoo`03Ool0
0`0?Oomoo`0ZOol00`00Oomoo`0ZOol00`0?Oomoo`03Ool00`00Oomoo`0UOol00`0?Oomoo`0aOol0
0`00Oomoo`02Ool004]oo`03001oogoo035oo`0300moogoo02Eoo`03001oogoo00=oo`0300moogoo
02Yoo`03001oogoo02Yoo`0300moogoo00=oo`03001oogoo02Eoo`0300moogoo035oo`03001oogoo
009oo`00Bgoo00<007ooOol0<Goo00<03gooOol09Woo00<007ooOol00Woo00<03gooOol0:Woo00<0
07ooOol0:Woo00<03gooOol00goo00<007ooOol09Goo00<03gooOol0<Goo00<007ooOol00Woo001;
Ool00`00Oomoo`0aOol00`0?Oomoo`0VOol00`00Oomoo`02Ool00`0?Oomoo`0ZOol00`00Oomoo`0Z
Ool00`0?Oomoo`02Ool00`00Oomoo`0VOol00`0?Oomoo`0aOol00`00Oomoo`02Ool004]oo`80039o
o`0300moogoo02Ioo`03001oogoo009oo`0300moogoo02Yoo`03001oogoo02Yoo`0300moogoo009o
o`03001oogoo02Ioo`0300moogoo031oo`8000Aoo`00Bgoo00<007ooOol0<Goo00<03gooOol09Woo
00<007ooOol00Woo00<03gooOol0:Woo00<007ooOol0:Woo00<03gooOol00Woo00<007ooOol09Woo
00<03gooOol0<Goo00<007ooOol00Woo001;Ool00`00Oomoo`0aOol00`0?Oomoo`0WOol01@00Oomo
ogoo00l0;7oo00<007ooOol0:Woo00D03gooOomoo`0002Uoo`0300moogoo035oo`03001oogoo009o
o`00Bgoo00<007ooOol0<Goo00<03gooOol09goo00D007ooOomoo`0?02aoo`03001oogoo02Yoo`05
00moogooOol0000YOol00`0?Oomoo`0aOol00`00Oomoo`02Ool004]oo`03001oogoo035oo`0300mo
ogoo02Moo`05001oogooOol03`0/Ool00`00Oomoo`0ZOol01@0?Oomoogoo0000:Goo00<03gooOol0
<Goo00<007ooOol00Woo001;Ool00`00Oomoo`0aOol00`0?Oomoo`0XOol01000Oomoo`0?;7oo00<0
07ooOol0:Woo00D03gooOomoo`0002Uoo`0300moogoo035oo`03001oogoo009oo`00Bgoo00<007oo
Ool0<Goo00<03gooOol0:7oo00@007ooOol03baoo`03001oogoo02Yoo`0400moogoo000ZOol00`0?
Oomoo`0aOol00`00Oomoo`02Ool004]oo`03001oogoo035oo`0300moogoo02Qoo`04001oogoo00l/
Ool00`00Oomoo`0ZOol0100?Oomoo`00:Woo00<03gooOol0<Goo00<007ooOol00Woo001;Ool2000b
Ool00`0?Oomoo`0YOol00`00Ool03`0/Ool00`00Oomoo`0ZOol0100?Oomoo`00:Woo00<03gooOol0
<7oo0P0017oo001;Ool00`00Oomoo`0aOol00`0?Oomoo`0YOol00`00Ool03`0/Ool00`00Oomoo`0Z
Ool00`0?Ool0000[Ool00`0?Oomoo`0aOol00`00Oomoo`02Ool004]oo`03001oogoo035oo`0300mo
ogoo02Uoo`03001oo`0?02aoo`03001oogoo02Yoo`0300moo`0002]oo`0300moogoo035oo`03001o
ogoo009oo`00Bgoo00<007ooOol0<Goo00<03gooOol0:Goo00<007oo00l0;7oo00<007ooOol0:Woo
00<03goo0000:goo00<03gooOol0<Goo00<007ooOol00Woo001;Ool00`00Oomoo`0aOol00`0?Oomo
o`0ZOol00`0000moo`0[Ool00`00Oomoo`0ZOol00`0?001oo`0[Ool00`0?Oomoo`0aOol00`00Oomo
o`02Ool004]oo`03001oogoo035oo`0300moogoo02Yoo`0300003goo02Uoo`D002Yoo`0300l007oo
02]oo`0300moogoo035oo`03001oogoo009oo`00Bgoo00<007ooOol0<Goo00<03gooOol0:Woo00<0
000?Ool08Woo1`000Woo00<007ooOol01P0097oo00<03`00Ool0:goo00<03gooOol0<Goo00<007oo
Ool00Woo001;Ool00`00Oomoo`0aOol00`0?Oomoo`0[Ool00`00Oomoo`0NOol30009Ool00`00Oomo
o`06Ool5000OOol00`00Oomoo`0[Ool00`0?Oomoo`0aOol00`00Oomoo`02Ool004]oo`80039oo`03
00moogoo02]oo`03001oogoo01aoo`8000aoo`03001oogoo00]oo`8001eoo`03001oogoo02]oo`03
00moogoo031oo`8000Aoo`00Bgoo00<007ooOol0<Goo00<03gooOol0:goo00<03`00Ool06Goo0`00
3Woo00<007ooOol03Goo0P006Woo00<0000?Ool0;7oo00<03gooOol0<Goo00<007ooOol00Woo001;
Ool00`00Oomoo`0aOol00`0?Oomoo`0[Ool00`0?001oo`0FOol3000AOol00`00Oomoo`0?Ool2000H
Ool00`0000moo`0/Ool00`0?Oomoo`0aOol00`00Oomoo`02Ool004]oo`03001oogoo035oo`0300mo
ogoo02]oo`0300l007oo01=oo`<001Aoo`03001oogoo015oo`<001Eoo`0300003goo02aoo`0300mo
ogoo035oo`03001oogoo009oo`00Bgoo00<007ooOol0<Goo00<03gooOol0:goo00<03goo00004Goo
0P005goo00<007ooOol057oo0P004Woo00<007oo00l0;Goo00<03gooOol0<Goo00<007ooOol00Woo
001;Ool00`00Oomoo`0aOol00`0?Oomoo`0[Ool00`0?Ool0000@Ool00`00Oomoo`0GOol00`00Oomo
o`0FOol2000@Ool00`00Ool03`0]Ool00`0?Oomoo`0aOol00`00Oomoo`02Ool002aoo`<000=oo`03
001oogoo00<000=oo`<000Eoo`03001oogoo00Eoo`03001oogoo035oo`0300moogoo02]oo`0400mo
ogoo000=Ool2000JOol00`00Oomoo`0HOol2000=Ool01000Oomoo`0?;Goo00<03gooOol0<Goo00<0
07ooOol00Woo000[Ool01@00Oomoogoo000017oo00L007ooOomoo`00Ool00003Ool00`00Oomoo`02
Ool00`00Oomoo`05Ool00`00Oomoo`0aOol00`0?Oomoo`0[Ool01@0?Oomoogoo00002goo00<007oo
Ool06Woo00<007ooOol06Woo0P002goo00@007ooOol03beoo`0300moogoo035oo`03001oogoo009o
o`00:goo00D007ooOomoo`0000Aoo`07001oogooOol007oo00000goo00<007oo00001@001Goo0`00
<Goo00<03gooOol0:goo00D03gooOomoo`0000Uoo`8001eoo`03001oogoo01aoo`03001oogoo00Mo
o`05001oogooOol03`0]Ool00`0?Oomoo`0_Ool30004Ool002]oo`05001oogooOol00004Ool01`00
Oomoogoo001oo`0000=oo`03001oo`00009oo`03001oogoo00Eoo`03001oogoo035oo`0300moogoo
02]oo`0300moogoo009oo`03001oogoo00Eoo`03001oogoo01eoo`03001oogoo01eoo`03001oogoo
00Eoo`03001oogoo009oo`0300moogoo02]oo`0300moogoo035oo`03001oogoo009oo`00:goo00D0
07ooOomoo`0000Aoo`07001oogooOol007oo00000goo00H007ooOol007oo0007Ool00`00Oomoo`0a
Ool00`0?Oomoo`0[Ool00`0?Oomoo`03Ool20003Ool2000POol00`00Oomoo`0NOol20003Ool20005
Ool00`0?Oomoo`0[Ool00`0?Oomoo`0aOol00`00Oomoo`02Ool002]oo`05001oogooOol00004Ool0
1`00Oomoogoo001oo`0000=oo`04001oogooOol20007Ool00`00Oomoo`0aOol00`0?Oomoo`0[Ool0
0`0?Oomoo`05Ool3000ROol00`00Oomoo`0POol30007Ool00`0?Oomoo`0[Ool00`0?Oomoo`0aOol0
0`00Oomoo`02Ool002]oo`05001oogooOol00004Ool01`00Oomoogoo001oo`0000=oo`04001oogoo
Ool20007Ool00`00Oomoo`0aOol00`0?Oomoo`0[Ool00`0?Oomoo`0ZOol00`00Oomoo`0ZOol00`0?
Oomoo`0[Ool00`0?Oomoo`0aOol00`00Oomoo`02Ool002aoo`<000Ioo`<000=oo`<000Eoo`03001o
ogoo00Eoo`03001oogoo00Aoo`03001oogoo02Yoo`03001oogoo02]oo`03001oogoo02Yoo`03001o
ogoo02Yoo`03001oogoo02]oo`03001oogoo02Yoo`03001oogoo00Aoo`03001oogoo009oo`00Bgoo
00<007ooOol017oo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo
00<007ooOol01Woo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo
00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo
00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo
00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo
00<007ooOol01goo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo
00<007ooOol01Woo00<007ooOol017oo00<007ooOol00Woo001;Oooo000P0004Ool00?moofmoo`00
ogooKgoo003oOom_Ool00?moofmoo`00ogooKgoo003oOom_Ool00?moofmoo`00^Goo0`004Woo0`00
27oo1P0047oo0`000goo00D007ooOomoo`0007Aoo`00^Woo00<007ooOol01Woo1`000goo00D007oo
Oomoo`0000Qoo`05001oogooOol00005Ool70003Ool01@00Oomoogoo00001Woo00<007ooOol0LWoo
002jOol00`00Oomoo`0@Ool01@00Oomoogoo000027oo00<007ooOol04Goo00D007ooOomoo`0000Io
o`03001oogoo079oo`00^Woo00<007ooOol047oo00D007ooOomoo`0000Uoo`03001oogoo011oo`05
001oogooOol00007Ool00`00Oomoo`1aOol00;Uoo`03001oo`0000Moo`L000=oo`05001oogooOol0
000:Ool00`00Oomoo`05Ool70003Ool01@00Oomoogoo00001goo00<007ooOol0LGoo002iOol00`00
Ool0000AOol01@00Oomoogoo00002goo00<007ooOol03Woo00D007ooOomoo`0000Moo`03001oogoo
075oo`00^7oo00D007ooOomoo`00011oo`05001oogooOol00007Ool01@00Oomoogoo000047oo00D0
07ooOomoo`0000Aoo`05001oogooOol0001bOol00;Moo`<00004Ool00000000@Ool30008Ool6000@
Ool30006Ool4001bOol00?moofmoo`00ogooKgoo0000\
\>"],
  ImageRangeCache->{{{0, 365.312}, {225.375, 0}} -> {-4.8273, -0.00103598, 
  0.0220921, 2.5125*^-5}}]
}, Open  ]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 1152}, {0, 850}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{1026, 722},
WindowMargins->{{Automatic, 27}, {Automatic, 23}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->False,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding",
Magnification->1.5,
StyleDefinitions -> "Classroom.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oQon@3:`8g0dL5N`?P0080001804P000000]P2:001
0000I00000400`<30?l00BL?00400@0000000000000006P801T1T00000000000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1709, 49, 123, 3, 60, "Title",
  Evaluatable->False],
Cell[1835, 54, 59, 5, 147, "Text"],
Cell[1897, 61, 79, 2, 83, "Section",
  Evaluatable->False],
Cell[1979, 65, 906, 15, 159, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[2910, 84, 98, 2, 83, "Section",
  Evaluatable->False],
Cell[3011, 88, 5922, 88, 1143, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[8970, 181, 107, 2, 83, "Section",
  Evaluatable->False],
Cell[9080, 185, 2580, 58, 447, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[11685, 247, 77, 4, 88, "Input"],
Cell[11765, 253, 358, 7, 32, "Print"],
Cell[12126, 262, 126, 2, 53, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[12301, 270, 1550, 26, 943, "Input"],
Cell[13854, 298, 197, 4, 32, "Print"],
Cell[14054, 304, 169, 3, 32, "Print"],
Cell[14226, 309, 197, 4, 32, "Print"],
Cell[14426, 315, 197533, 8470, 516, 168273, 8104, "GraphicsData", 
"PostScript", "Graphics"],
Cell[211962, 8787, 59945, 1662, 409, 22648, 1197, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[271922, 10452, 1140, 16, 207, "Text"],

Cell[CellGroupData[{
Cell[273087, 10472, 1485, 25, 851, "Input"],
Cell[274575, 10499, 197, 4, 33, "Print"],
Cell[274775, 10505, 169, 3, 33, "Print"],
Cell[274947, 10510, 197, 4, 33, "Print"],
Cell[275147, 10516, 96294, 3894, 546, 65236, 3506, "GraphicsData", 
"PostScript", "Graphics"],
Cell[371444, 14412, 54467, 1594, 352, 22661, 1197, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

